(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    714798,      36971]
NotebookOptionsPosition[    712755,      36900]
NotebookOutlinePosition[    713202,      36918]
CellTagsIndexPosition[    713159,      36915]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Reinforcement Learning Dynamics in Social Dilemmas- Figure 11\
\>", "Title"],

Cell[TextData[StyleBox["Luis R. Izquierdo and Segismundo S. Izquierdo", \
"Subtitle"]], "Subtitle"],

Cell[TextData[{
 "This program was used to generate figure 11 in the paper:\n",
 "Izquierdo, S. S., Izquierdo, L. R. and Gotts, N. M. (2008). Reinforcement \
Learning Dynamics in Social Dilemmas. Journal of Artificial Societies and \
Social Simulation 11(2)1. <",
 ButtonBox["http://jasss.soc.surrey.ac.uk/11/2/1.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://jasss.soc.surrey.ac.uk/11/2/1.html"], None}],
 ">",
 ".  \nThe output of this program is a phase plane with several trajectories \
and with a sample simulation run, and also a time series showing the \
propensity to cooperate of one of the players over time. "
}], "Subsubtitle",
 CellChangeTimes->{3.4140423147476254`*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting the Environment", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`Arrow`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Payoffs", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Aspiration", " ", "Threshold"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Learning", " ", "rate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"noise", "=", 
     RowBox[{"0", "/", "1000"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Distance", " ", "between", " ", "consecutive", " ", "trajectories", " ", 
     "in", " ", "the", " ", "perimeter", " ", "of", " ", "the", " ", "state", 
     " ", "space"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"step", "=", 
     RowBox[{"5", "/", "100"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Simulation", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SeedRandom", "[", "2", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfIterations", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb1", "=", 
     RowBox[{"5", "/", "10"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb2", "=", 
     RowBox[{"5", "/", "10"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
     "be", " ", "saved"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"File", " ", "extensions", " ", "required"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"extensions", "=", 
     RowBox[{"{", "\"\<.gif\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figureResolution", " ", "=", " ", "600"}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Expected", " ", "change", " ", "in", " ", "the", " ", 
     RowBox[{"probability", " ", "/", " ", "propensity"}], " ", "to", " ", 
     "cooperate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CD", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DD", ",", "x"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeY", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"y", ",", "x"}], "]"}]}], ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trajectories - Initialisation", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"listOfTrajectories", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"listOfArrows", "=", 
   RowBox[{"{", "}"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trajectories - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"initX", "=", "0"}], ",", 
     RowBox[{"initX", "\[LessEqual]", 
      RowBox[{"1", "+", 
       RowBox[{"step", "/", "2"}]}]}], ",", 
     RowBox[{"initX", "=", 
      RowBox[{"initX", "+", "step"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"initY", "=", "0"}], ",", 
        RowBox[{"initY", "\[LessEqual]", 
         RowBox[{"1", "+", 
          RowBox[{"step", "/", "2"}]}]}], ",", 
        RowBox[{"initY", "=", 
         RowBox[{"initY", "+", "step"}]}], ",", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"initX", "\[Equal]", "0"}], "||", 
              RowBox[{"initX", "\[Equal]", "1"}]}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"initY", "\[Equal]", "0"}], "||", 
              RowBox[{"initY", "\[Equal]", "1"}]}], ")"}]}], ",", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"phaseSolutions", "=", 
             RowBox[{"NDSolve", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
                  RowBox[{
                   RowBox[{"ReplaceAll", "[", 
                    RowBox[{
                    RowBox[{"expectedChangeX", "[", 
                    RowBox[{"x", ",", "y"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x", "\[Rule]", 
                    RowBox[{"x", "[", "t", "]"}]}], ",", 
                    RowBox[{"y", "\[Rule]", 
                    RowBox[{"y", "[", "t", "]"}]}]}], "}"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"16", "*", "l"}], ")"}]}]}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"y", "'"}], "[", "t", "]"}], "\[Equal]", 
                  RowBox[{
                   RowBox[{"ReplaceAll", "[", 
                    RowBox[{
                    RowBox[{"expectedChangeY", "[", 
                    RowBox[{"x", ",", "y"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x", "\[Rule]", 
                    RowBox[{"x", "[", "t", "]"}]}], ",", 
                    RowBox[{"y", "\[Rule]", 
                    RowBox[{"y", "[", "t", "]"}]}]}], "}"}]}], "]"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"16", "*", "l"}], ")"}]}]}], ",", 
                 RowBox[{
                  RowBox[{"x", "[", "0", "]"}], "\[Equal]", "initX"}], ",", 
                 RowBox[{
                  RowBox[{"y", "[", "0", "]"}], "\[Equal]", "initY"}]}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"t", ",", "0", ",", "75"}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"listOfTrajectories", ",", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "/.", "phaseSolutions"}], ",", 
                
                RowBox[{
                 RowBox[{"y", "[", "t", "]"}], "/.", "phaseSolutions"}]}], 
               "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"listOfArrows", ",", "\[IndentingNewLine]", 
              RowBox[{"Arrow", "[", 
               RowBox[{
                RowBox[{"Join", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"x", "[", "5", "]"}], "/.", "phaseSolutions"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"y", "[", "5", "]"}], "/.", "phaseSolutions"}]}], 
                 "]"}], ",", 
                RowBox[{"Join", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"x", "[", "6", "]"}], "/.", "phaseSolutions"}], 
                  ",", 
                  RowBox[{
                   RowBox[{"y", "[", "6", "]"}], "/.", "phaseSolutions"}]}], 
                 "]"}], ",", 
                RowBox[{"HeadScaling", "\[Rule]", "Absolute"}], ",", 
                RowBox[{"HeadShape", "\[Rule]", "Automatic"}], ",", 
                RowBox[{"HeadWidth", "\[Rule]", "0.4"}], ",", 
                RowBox[{"HeadCenter", "\[Rule]", "0.6"}]}], "]"}]}], "]"}], 
            ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
         ";"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphWithTrajectories", " ", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", "listOfTrajectories", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "75"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"graphWithArrows", "=", " ", 
   RowBox[{"Graphics", "[", "listOfArrows", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"graphWithTrajectories", ",", "graphWithArrows"}], "}"}], ",", 
    RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], "]"}], 
  ";"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3. moveto 0 0 lineto
-15. -3. lineto
-9. 0 lineto fill
-15. 3. moveto 0 0 lineto
-15. -3. lineto
-9. 0 lineto
-15. 3. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
.02381 .01472 m
.04502 .02782 L
.06654 .04112 L
.08533 .05274 L
.1022 .06316 L
.11896 .07352 L
.134 .08281 L
.1489 .09203 L
.16229 .1003 L
.17433 .10774 L
.1863 .11514 L
.19708 .1218 L
.20679 .1278 L
.21648 .13379 L
.22523 .1392 L
.23394 .14458 L
.2418 .14944 L
.2489 .15383 L
.256 .15821 L
.26241 .16218 L
.26881 .16614 L
.2746 .16971 L
.27985 .17295 L
.28509 .1762 L
.28985 .17914 L
.29416 .1818 L
.29848 .18447 L
.30241 .1869 L
.30634 .18933 L
.30991 .19153 L
.31315 .19354 L
.3164 .19555 L
.31936 .19738 L
.32205 .19904 L
.32476 .20071 L
.32722 .20223 L
.32969 .20376 L
.33194 .20515 L
.33399 .20642 L
.33605 .20769 L
.33793 .20885 L
.33981 .21001 L
.34153 .21107 L
.34309 .21204 L
.34466 .21301 L
.3461 .2139 L
.3474 .21471 L
.34872 .21552 L
.34992 .21626 L
.35113 .21701 L
Mistroke
.35223 .21769 L
.35324 .21831 L
.35425 .21894 L
.35518 .21951 L
.35611 .22009 L
.35696 .22061 L
.35773 .22109 L
.35851 .22157 L
.35922 .22201 L
.35987 .22241 L
.36052 .22282 L
.36112 .22319 L
.36173 .22356 L
.36228 .2239 L
.36278 .22421 L
.36328 .22452 L
.36375 .22481 L
.36417 .22507 L
.36459 .22533 L
.36498 .22557 L
.36538 .22582 L
.36574 .22604 L
.36606 .22624 L
.36639 .22644 L
.3667 .22663 L
.367 .22682 L
.36728 .22699 L
.36753 .22715 L
.36779 .2273 L
.36802 .22745 L
.36823 .22758 L
.36845 .22771 L
.36865 .22784 L
.36885 .22796 L
.36903 .22807 L
.36919 .22817 L
.36936 .22828 L
.36951 .22837 L
.36965 .22846 L
.3698 .22855 L
.36992 .22863 L
.37005 .22871 L
.37017 .22878 L
.37028 .22885 L
.37039 .22892 L
.37049 .22898 L
.37059 .22904 L
.37069 .2291 L
.37077 .22915 L
.37086 .2292 L
Mistroke
Mfstroke
.02381 .04415 m
.04398 .0559 L
.06451 .06779 L
.08248 .07816 L
.09866 .08745 L
.11477 .09665 L
.12928 .1049 L
.1437 .11306 L
.15669 .12037 L
.16841 .12693 L
.18011 .13345 L
.19066 .1393 L
.2002 .14457 L
.20975 .14982 L
.21839 .15454 L
.22702 .15924 L
.23484 .16347 L
.24192 .16728 L
.24901 .17109 L
.25545 .17452 L
.26189 .17794 L
.26773 .18102 L
.27303 .18381 L
.27836 .18659 L
.28319 .1891 L
.28759 .19138 L
.29202 .19366 L
.29605 .19572 L
.30009 .19778 L
.30377 .19965 L
.30713 .20134 L
.31051 .20304 L
.31358 .20457 L
.31639 .20596 L
.31922 .20736 L
.3218 .20863 L
.32441 .2099 L
.32678 .21105 L
.32894 .2121 L
.33113 .21315 L
.33313 .2141 L
.33514 .21506 L
.33698 .21592 L
.33865 .21671 L
.34035 .2175 L
.3419 .21822 L
.34331 .21887 L
.34474 .21952 L
.34605 .22012 L
.34737 .22071 L
Mistroke
.34858 .22126 L
.34968 .22175 L
.3508 .22224 L
.35182 .22269 L
.35285 .22314 L
.35379 .22355 L
.35465 .22392 L
.35553 .2243 L
.35633 .22464 L
.35706 .22494 L
.3578 .22525 L
.35847 .22553 L
.35916 .22582 L
.35979 .22607 L
.36036 .22631 L
.36094 .22654 L
.36147 .22675 L
.36196 .22695 L
.36246 .22714 L
.36291 .22732 L
.36337 .22749 L
.36379 .22765 L
.36417 .2278 L
.36456 .22795 L
.36492 .22808 L
.36528 .22821 L
.36562 .22833 L
.36592 .22844 L
.36623 .22855 L
.36651 .22865 L
.36677 .22874 L
.36703 .22883 L
.36727 .22892 L
.36752 .229 L
.36774 .22907 L
.36795 .22914 L
.36815 .22921 L
.36835 .22927 L
.36852 .22933 L
.3687 .22938 L
.36886 .22943 L
.36903 .22948 L
.36918 .22953 L
.36932 .22957 L
.36946 .22961 L
.36959 .22965 L
.36972 .22969 L
.36984 .22972 L
.36995 .22975 L
.37006 .22978 L
Mistroke
Mfstroke
.02381 .07358 m
.04295 .08391 L
.06248 .09434 L
.07963 .10341 L
.09511 .11152 L
.11059 .11955 L
.12456 .12672 L
.13849 .1338 L
.15108 .14013 L
.16248 .14581 L
.17388 .15143 L
.18421 .15647 L
.19358 .16099 L
.20298 .16549 L
.21151 .16953 L
.22006 .17353 L
.22782 .17713 L
.23488 .18037 L
.24197 .1836 L
.24842 .1865 L
.25489 .18938 L
.26078 .19197 L
.26615 .19431 L
.27155 .19664 L
.27647 .19874 L
.28095 .20063 L
.28548 .20252 L
.28961 .20423 L
.29377 .20593 L
.29756 .20746 L
.30103 .20885 L
.30453 .21023 L
.30773 .21148 L
.31065 .21261 L
.31361 .21374 L
.31632 .21477 L
.31905 .21579 L
.32155 .21671 L
.32384 .21754 L
.32615 .21838 L
.32827 .21913 L
.33041 .21988 L
.33237 .22056 L
.33416 .22117 L
.33598 .22179 L
.33764 .22234 L
.33916 .22284 L
.34071 .22334 L
.34213 .2238 L
.34356 .22425 L
Mistroke
.34487 .22466 L
.34608 .22503 L
.3473 .22539 L
.34842 .22573 L
.34955 .22606 L
.35059 .22636 L
.35155 .22663 L
.35251 .2269 L
.3534 .22714 L
.35421 .22736 L
.35504 .22758 L
.3558 .22778 L
.35657 .22797 L
.35727 .22815 L
.35792 .22831 L
.35858 .22847 L
.35918 .22861 L
.35974 .22874 L
.3603 .22886 L
.36082 .22898 L
.36135 .22909 L
.36183 .2292 L
.36227 .22929 L
.36272 .22938 L
.36314 .22946 L
.36356 .22954 L
.36395 .22962 L
.3643 .22968 L
.36466 .22974 L
.36499 .2298 L
.3653 .22985 L
.36561 .2299 L
.36589 .22995 L
.36618 .22999 L
.36645 .23003 L
.3667 .23007 L
.36695 .2301 L
.36717 .23013 L
.36739 .23016 L
.3676 .23018 L
.3678 .23021 L
.368 .23023 L
.36818 .23025 L
.36836 .23026 L
.36853 .23028 L
.36869 .2303 L
.36885 .23031 L
.369 .23032 L
.36914 .23033 L
.36928 .23034 L
Mistroke
Mfstroke
.02381 .10301 m
.04191 .11186 L
.06044 .12077 L
.07677 .1285 L
.09157 .1354 L
.10639 .14221 L
.11983 .14828 L
.13327 .15426 L
.14546 .15959 L
.15653 .16436 L
.16764 .16907 L
.17773 .17328 L
.18692 .17706 L
.19617 .1808 L
.20459 .18415 L
.21305 .18747 L
.22076 .19044 L
.22779 .1931 L
.23487 .19575 L
.24134 .19812 L
.24784 .20047 L
.25378 .20258 L
.2592 .20447 L
.26467 .20635 L
.26967 .20804 L
.27424 .20956 L
.27887 .21107 L
.2831 .21242 L
.28738 .21377 L
.29129 .21498 L
.29487 .21607 L
.29849 .21715 L
.30181 .21812 L
.30485 .21899 L
.30794 .21986 L
.31077 .22065 L
.31363 .22142 L
.31626 .22212 L
.31867 .22275 L
.32111 .22337 L
.32336 .22393 L
.32563 .22449 L
.32771 .22499 L
.32962 .22544 L
.33156 .22588 L
.33334 .22628 L
.33497 .22663 L
.33664 .22699 L
.33816 .2273 L
.33971 .22762 L
Mistroke
.34114 .2279 L
.34244 .22815 L
.34377 .2284 L
.34499 .22862 L
.34623 .22884 L
.34737 .22903 L
.34841 .2292 L
.34947 .22937 L
.35045 .22953 L
.35135 .22966 L
.35226 .22979 L
.35311 .22991 L
.35396 .23002 L
.35474 .23012 L
.35547 .23021 L
.3562 .2303 L
.35688 .23038 L
.3575 .23044 L
.35814 .23051 L
.35872 .23057 L
.35931 .23062 L
.35986 .23067 L
.36036 .23071 L
.36088 .23075 L
.36135 .23078 L
.36183 .23081 L
.36227 .23084 L
.36268 .23086 L
.36309 .23088 L
.36347 .2309 L
.36382 .23091 L
.36418 .23092 L
.36451 .23093 L
.36485 .23094 L
.36501 .23094 L
.36516 .23095 L
.36531 .23095 L
.36544 .23095 L
.36558 .23095 L
.36565 .23095 L
.36573 .23095 L
.36579 .23095 L
.36583 .23095 L
.36586 .23095 L
.36588 .23095 L
.36589 .23095 L
.3659 .23095 L
.36591 .23095 L
.36592 .23095 L
.36592 .23095 L
Mistroke
.36593 .23095 L
.36594 .23095 L
.36594 .23095 L
.36595 .23095 L
.36596 .23095 L
.36596 .23095 L
.36597 .23095 L
.36598 .23095 L
.36599 .23095 L
.36601 .23095 L
.36602 .23095 L
.36604 .23095 L
.36607 .23095 L
.36613 .23095 L
.3662 .23095 L
.36627 .23095 L
.3664 .23095 L
.36651 .23095 L
.36675 .23094 L
.36697 .23094 L
.3672 .23093 L
.36741 .23093 L
.3676 .23092 L
.36779 .23091 L
.36797 .2309 L
.36816 .2309 L
.36833 .23089 L
.36848 .23088 L
.36849 .23088 L
Mfstroke
.02381 .13244 m
.04088 .13974 L
.05841 .14708 L
.07392 .15343 L
.08801 .15907 L
.10219 .16463 L
.11509 .16957 L
.12804 .17442 L
.13982 .17874 L
.15056 .18259 L
.16137 .18638 L
.17123 .18976 L
.18023 .19278 L
.18932 .19576 L
.19763 .19842 L
.206 .20104 L
.21365 .20339 L
.22065 .20548 L
.22772 .20755 L
.2342 .20939 L
.24073 .21121 L
.24671 .21284 L
.25219 .21429 L
.25774 .21573 L
.26282 .21701 L
.26748 .21816 L
.2722 .21929 L
.27654 .2203 L
.28092 .2213 L
.28495 .2222 L
.28864 .22299 L
.29239 .22378 L
.29584 .22448 L
.299 .22511 L
.30221 .22572 L
.30517 .22627 L
.30817 .22682 L
.31092 .2273 L
.31345 .22773 L
.31603 .22815 L
.31839 .22852 L
.3208 .22889 L
.323 .22921 L
.32504 .2295 L
.3271 .22978 L
.329 .23003 L
.33075 .23025 L
.33253 .23046 L
.33417 .23065 L
.33583 .23083 L
Mistroke
.33736 .23099 L
.33878 .23112 L
.34021 .23126 L
.34153 .23137 L
.34288 .23148 L
.34412 .23157 L
.34526 .23166 L
.34641 .23173 L
.34748 .2318 L
.34847 .23185 L
.34947 .2319 L
.35039 .23194 L
.35134 .23198 L
.3522 .232 L
.353 .23203 L
.35381 .23205 L
.35456 .23206 L
.35493 .23206 L
.35526 .23207 L
.3556 .23207 L
.35578 .23207 L
.35596 .23207 L
.35612 .23207 L
.35622 .23207 L
.3563 .23207 L
.35637 .23207 L
.35642 .23207 L
.35644 .23207 L
.35646 .23207 L
.35647 .23207 L
.35649 .23207 L
.35651 .23207 L
.35653 .23207 L
.35655 .23207 L
.35657 .23207 L
.35659 .23207 L
.3566 .23207 L
.35662 .23207 L
.35664 .23207 L
.35668 .23207 L
.35672 .23207 L
.35676 .23207 L
.35684 .23207 L
.35691 .23207 L
.35707 .23207 L
.35724 .23207 L
.3574 .23207 L
.35757 .23207 L
.35787 .23207 L
.35848 .23206 L
Mistroke
.35903 .23205 L
.35955 .23204 L
.36007 .23202 L
.36056 .232 L
.36105 .23198 L
.3615 .23196 L
.36192 .23194 L
.36235 .23192 L
.36274 .2319 L
.36315 .23187 L
.36352 .23184 L
.36386 .23182 L
.36421 .23179 L
.36453 .23176 L
.36483 .23173 L
.36513 .23171 L
.36541 .23168 L
.3657 .23165 L
.36596 .23162 L
.36621 .23159 L
.36646 .23156 L
.36669 .23153 L
.3669 .2315 L
.36712 .23147 L
.36732 .23144 L
.36752 .23141 L
.36771 .23139 L
Mfstroke
.02381 .16187 m
.03984 .16756 L
.05637 .17327 L
.07106 .17818 L
.08446 .18254 L
.09799 .18682 L
.11034 .1906 L
.12279 .19431 L
.13417 .19759 L
.14457 .2005 L
.15508 .20336 L
.16471 .2059 L
.17352 .20815 L
.18245 .21037 L
.19063 .21233 L
.19892 .21426 L
.20651 .21597 L
.21347 .21749 L
.22053 .21899 L
.22702 .22031 L
.23358 .22161 L
.23961 .22276 L
.24514 .22378 L
.25076 .22477 L
.25592 .22566 L
.26066 .22644 L
.26548 .2272 L
.26992 .22788 L
.27442 .22854 L
.27856 .22912 L
.28237 .22963 L
.28625 .23013 L
.28981 .23057 L
.29309 .23095 L
.29644 .23133 L
.29952 .23165 L
.30265 .23197 L
.30554 .23224 L
.30819 .23248 L
.3109 .2327 L
.31339 .2329 L
.31593 .23308 L
.31826 .23324 L
.32042 .23337 L
.32261 .2335 L
.32463 .2336 L
.32649 .23369 L
.32839 .23376 L
.33014 .23383 L
.33193 .23388 L
Mistroke
.33357 .23392 L
.33509 .23395 L
.33591 .23396 L
.33663 .23397 L
.33738 .23398 L
.33806 .23399 L
.33839 .23399 L
.33874 .23399 L
.33908 .23399 L
.33928 .23399 L
.33937 .23399 L
.33946 .23399 L
.33954 .23399 L
.33963 .23399 L
.33972 .23399 L
.33977 .23399 L
.33979 .23399 L
.33981 .23399 L
.33985 .23399 L
.3399 .23399 L
.33994 .23399 L
.33997 .23399 L
.34002 .23399 L
.34006 .23399 L
.3401 .23399 L
.34015 .23399 L
.34022 .23399 L
.3403 .23399 L
.34044 .23399 L
.34059 .23399 L
.34076 .23399 L
.34109 .23399 L
.34139 .23399 L
.34205 .23398 L
.34264 .23398 L
.34328 .23397 L
.34447 .23395 L
.34558 .23393 L
.3466 .2339 L
.34764 .23387 L
.3486 .23383 L
.34958 .23379 L
.35049 .23375 L
.35132 .23371 L
.35218 .23366 L
.35297 .23361 L
.35377 .23356 L
.35451 .23351 L
.35519 .23346 L
.35589 .2334 L
Mistroke
.35653 .23334 L
.35713 .23329 L
.35774 .23323 L
.3583 .23318 L
.35887 .23312 L
.3594 .23306 L
.35989 .233 L
.36039 .23294 L
.36085 .23288 L
.36132 .23282 L
.36176 .23276 L
.36216 .23271 L
.36257 .23265 L
.36295 .23259 L
.3633 .23254 L
.36366 .23248 L
.36399 .23243 L
.36432 .23237 L
.36464 .23232 L
.36492 .23227 L
.36522 .23221 L
.36549 .23216 L
.36574 .23212 L
.366 .23207 L
.36624 .23202 L
.36648 .23197 L
.36671 .23192 L
.36692 .23188 L
.36693 .23188 L
Mfstroke
.02381 .1913 m
.0388 .19532 L
.05434 .19934 L
.0682 .20278 L
.0809 .20581 L
.09378 .20877 L
.10559 .21137 L
.11754 .2139 L
.1285 .21613 L
.13857 .2181 L
.14878 .22001 L
.15816 .22169 L
.16678 .22318 L
.17555 .22462 L
.18362 .22589 L
.1918 .22713 L
.19933 .22821 L
.20626 .22916 L
.21331 .23008 L
.2198 .23089 L
.22639 .23166 L
.23246 .23234 L
.23804 .23293 L
.24373 .23349 L
.24897 .23398 L
.2538 .2344 L
.25872 .23481 L
.26326 .23516 L
.26788 .23548 L
.27213 .23576 L
.27606 .236 L
.28006 .23621 L
.28375 .2364 L
.28715 .23655 L
.29063 .23668 L
.29384 .23679 L
.2971 .23688 L
.30012 .23695 L
.3029 .23701 L
.3044 .23703 L
.30574 .23704 L
.3071 .23706 L
.30836 .23707 L
.309 .23707 L
.30966 .23707 L
.31023 .23707 L
.31054 .23708 L
.31084 .23708 L
.311 .23708 L
.31115 .23708 L
Mistroke
.31124 .23708 L
.31132 .23708 L
.31136 .23708 L
.31141 .23708 L
.31145 .23708 L
.31149 .23708 L
.31157 .23708 L
.31164 .23708 L
.31171 .23708 L
.31179 .23708 L
.31188 .23708 L
.31196 .23708 L
.31211 .23708 L
.31239 .23708 L
.31265 .23708 L
.31324 .23707 L
.31382 .23707 L
.31436 .23707 L
.31558 .23706 L
.31674 .23705 L
.31778 .23704 L
.31995 .237 L
.32195 .23696 L
.324 .23691 L
.32589 .23685 L
.32781 .23679 L
.32959 .23672 L
.33123 .23664 L
.3329 .23656 L
.33445 .23648 L
.33588 .23639 L
.33734 .2363 L
.33868 .23621 L
.34006 .23611 L
.34133 .23601 L
.3425 .23592 L
.3437 .23581 L
.34481 .23571 L
.34583 .23561 L
.34688 .23551 L
.34785 .23541 L
.34884 .2353 L
.34975 .2352 L
.35059 .2351 L
.35146 .23499 L
.35225 .23489 L
.35307 .23478 L
.35382 .23468 L
.35451 .23458 L
.35522 .23448 L
Mistroke
.35588 .23438 L
.35649 .23428 L
.35711 .23419 L
.35768 .23409 L
.35827 .23399 L
.35881 .2339 L
.35931 .23381 L
.35982 .23372 L
.3603 .23363 L
.36078 .23354 L
.36123 .23345 L
.36164 .23337 L
.36206 .23328 L
.36245 .2332 L
.36281 .23313 L
.36318 .23305 L
.36353 .23297 L
.36388 .23289 L
.3642 .23282 L
.3645 .23275 L
.36481 .23268 L
.36509 .23261 L
.36535 .23255 L
.36562 .23248 L
.36587 .23242 L
.36612 .23235 L
.36615 .23234 L
Mfstroke
.02381 .22073 m
.03777 .22302 L
.05231 .22528 L
.06534 .2272 L
.07734 .22887 L
.08957 .23048 L
.10083 .23188 L
.11228 .23322 L
.12283 .23437 L
.13256 .23537 L
.14247 .23633 L
.1516 .23715 L
.16003 .23786 L
.16864 .23853 L
.17658 .2391 L
.18467 .23964 L
.19213 .24009 L
.19902 .24047 L
.20606 .24083 L
.21255 .24112 L
.21917 .24138 L
.22528 .24158 L
.23092 .24175 L
.23667 .24189 L
.24199 .24199 L
.2469 .24206 L
.24935 .24209 L
.25193 .24211 L
.25316 .24212 L
.25448 .24213 L
.25572 .24213 L
.25627 .24214 L
.25685 .24214 L
.25744 .24214 L
.25769 .24214 L
.25797 .24214 L
.25821 .24214 L
.25848 .24214 L
.25862 .24214 L
.25875 .24214 L
.25887 .24214 L
.25901 .24214 L
.25915 .24214 L
.25923 .24214 L
.25931 .24214 L
.25944 .24214 L
.25959 .24214 L
.25967 .24214 L
.25976 .24214 L
.25984 .24214 L
Mistroke
.25991 .24214 L
.26006 .24214 L
.26021 .24214 L
.26052 .24214 L
.26081 .24214 L
.26134 .24214 L
.26186 .24214 L
.26243 .24214 L
.26357 .24213 L
.26461 .24213 L
.26558 .24212 L
.26775 .2421 L
.26969 .24209 L
.27373 .24203 L
.27746 .24197 L
.28128 .24188 L
.2848 .24179 L
.28806 .24169 L
.2914 .24157 L
.29448 .24145 L
.29763 .24132 L
.30054 .24118 L
.30323 .24104 L
.30598 .24088 L
.30852 .24073 L
.31111 .24056 L
.31351 .24039 L
.31573 .24023 L
.31799 .24005 L
.32008 .23988 L
.32202 .23971 L
.324 .23954 L
.32583 .23936 L
.3277 .23918 L
.32943 .239 L
.33103 .23883 L
.33267 .23865 L
.33418 .23847 L
.33558 .23831 L
.33701 .23813 L
.33834 .23796 L
.33969 .23778 L
.34094 .23761 L
.3421 .23745 L
.34328 .23728 L
.34438 .23712 L
.3455 .23695 L
.34653 .23679 L
.34749 .23663 L
.34847 .23647 L
Mistroke
.34937 .23632 L
.35021 .23617 L
.35106 .23602 L
.35186 .23588 L
.35267 .23573 L
.35342 .23559 L
.35411 .23545 L
.35482 .23531 L
.35548 .23518 L
.35615 .23504 L
.35677 .23492 L
.35734 .23479 L
.35793 .23467 L
.35847 .23455 L
.35898 .23443 L
.35949 .23431 L
.35997 .2342 L
.36045 .23409 L
.3609 .23398 L
.36132 .23388 L
.36175 .23377 L
.36214 .23367 L
.36251 .23358 L
.36288 .23348 L
.36323 .23339 L
.36358 .23329 L
.36391 .2332 L
.36422 .23312 L
.36453 .23303 L
.36481 .23295 L
.36511 .23287 L
.36538 .23279 L
.36539 .23279 L
Mfstroke
.02381 .25016 m
.03673 .25066 L
.05027 .25111 L
.06248 .25146 L
.07378 .25173 L
.08536 .25196 L
.09607 .25212 L
.10138 .25219 L
.10702 .25224 L
.11234 .25228 L
.11484 .2523 L
.11715 .25231 L
.11958 .25232 L
.12177 .25233 L
.12301 .25233 L
.12419 .25233 L
.12542 .25233 L
.12612 .25233 L
.12643 .25234 L
.12676 .25234 L
.12706 .25234 L
.12722 .25234 L
.12739 .25234 L
.12769 .25234 L
.12797 .25234 L
.12814 .25234 L
.12833 .25234 L
.1285 .25234 L
.12866 .25234 L
.12896 .25234 L
.12911 .25234 L
.12928 .25234 L
.12986 .25234 L
.13019 .25233 L
.13049 .25233 L
.13163 .25233 L
.13264 .25233 L
.13375 .25233 L
.13596 .25232 L
.13831 .25231 L
.14043 .2523 L
.14512 .25227 L
.14933 .25224 L
.15381 .2522 L
.16236 .25208 L
.17027 .25195 L
.1776 .2518 L
.18511 .25163 L
.19207 .25144 L
.19918 .25122 L
Mistroke
.20577 .25099 L
.21187 .25076 L
.21812 .2505 L
.2239 .25024 L
.22981 .24996 L
.23528 .24967 L
.24035 .24939 L
.24553 .24909 L
.25034 .24879 L
.25478 .2485 L
.25934 .24819 L
.26356 .24789 L
.26787 .24757 L
.27186 .24725 L
.27555 .24695 L
.27934 .24663 L
.28284 .24631 L
.28608 .24602 L
.28941 .2457 L
.29249 .24539 L
.29564 .24507 L
.29855 .24476 L
.30125 .24447 L
.30401 .24416 L
.30657 .24386 L
.30918 .24355 L
.3116 .24325 L
.31384 .24297 L
.31613 .24267 L
.31825 .24239 L
.32022 .24212 L
.32223 .24184 L
.32409 .24157 L
.326 .24129 L
.32776 .24103 L
.32939 .24077 L
.33106 .24051 L
.33261 .24026 L
.33404 .24002 L
.3355 .23978 L
.33686 .23954 L
.33825 .2393 L
.33954 .23907 L
.34073 .23885 L
.34195 .23862 L
.34308 .23841 L
.34423 .23818 L
.3453 .23797 L
.34628 .23778 L
.34729 .23757 L
Mistroke
.34823 .23737 L
.3491 .23719 L
.34999 .237 L
.35081 .23682 L
.35165 .23663 L
.35243 .23645 L
.35315 .23629 L
.35389 .23612 L
.35457 .23595 L
.35527 .23579 L
.35591 .23563 L
.35651 .23548 L
.35712 .23533 L
.35769 .23518 L
.35821 .23505 L
.35875 .2349 L
.35925 .23477 L
.35976 .23463 L
.36023 .23451 L
.36067 .23438 L
.36112 .23426 L
.36153 .23414 L
.36191 .23403 L
.36231 .23392 L
.36267 .23381 L
.36304 .2337 L
.36339 .2336 L
.36371 .2335 L
.36404 .2334 L
.36434 .2333 L
.36463 .23321 L
Mfstroke
.02381 .27959 m
.03569 .27823 L
.04823 .27682 L
.05962 .27556 L
.07022 .27439 L
.08114 .27321 L
.09131 .27211 L
.10175 .27099 L
.11147 .26995 L
.12051 .26898 L
.12981 .26799 L
.13845 .26707 L
.14649 .26621 L
.15476 .26532 L
.16245 .26449 L
.17034 .26363 L
.17767 .26283 L
.18449 .26207 L
.19149 .2613 L
.19799 .26056 L
.20466 .25981 L
.21085 .2591 L
.21659 .25843 L
.22249 .25774 L
.22797 .25708 L
.23305 .25647 L
.23827 .25583 L
.24311 .25523 L
.24808 .25461 L
.25268 .25402 L
.25696 .25346 L
.26134 .25289 L
.2654 .25234 L
.26918 .25183 L
.27305 .2513 L
.27664 .2508 L
.28032 .25027 L
.28374 .24978 L
.2869 .24932 L
.29015 .24883 L
.29316 .24837 L
.29624 .2479 L
.29909 .24745 L
.30174 .24703 L
.30445 .24659 L
.30696 .24618 L
.30929 .24579 L
.31168 .24538 L
.3139 .245 L
.31616 .2446 L
Mistroke
.31826 .24423 L
.32021 .24388 L
.32221 .24351 L
.32405 .24317 L
.32594 .24281 L
.3277 .24247 L
.32932 .24215 L
.33098 .24182 L
.33252 .24151 L
.33394 .24122 L
.3354 .24092 L
.33676 .24063 L
.33814 .24034 L
.33942 .24006 L
.34061 .2398 L
.34183 .23952 L
.34296 .23927 L
.344 .23903 L
.34507 .23878 L
.34607 .23855 L
.34708 .2383 L
.34802 .23808 L
.34889 .23786 L
.34979 .23764 L
.35061 .23743 L
.35146 .23722 L
.35224 .23701 L
.35297 .23682 L
.35371 .23663 L
.3544 .23644 L
.35503 .23627 L
.35569 .23609 L
.35629 .23592 L
.35691 .23575 L
.35749 .23558 L
.35802 .23543 L
.35856 .23527 L
.35907 .23512 L
.35953 .23499 L
.36001 .23484 L
.36046 .23471 L
.36091 .23457 L
.36133 .23444 L
.36172 .23431 L
.36212 .23419 L
.36249 .23407 L
.36287 .23395 L
.36323 .23383 L
.36355 .23373 L
.36388 .23362 L
Mistroke
Mfstroke
.02381 .30902 m
.03466 .30574 L
.0462 .30241 L
.05676 .29949 L
.06666 .29685 L
.07693 .29422 L
.08654 .29183 L
.09648 .28945 L
.10578 .28729 L
.11448 .28532 L
.12347 .28334 L
.13186 .28153 L
.1397 .27988 L
.14781 .2782 L
.15537 .27667 L
.16316 .27511 L
.17043 .27368 L
.1772 .27237 L
.18419 .27103 L
.19069 .26979 L
.19738 .26854 L
.20361 .26738 L
.20941 .2663 L
.21538 .2652 L
.22094 .26418 L
.2261 .26323 L
.23142 .26226 L
.23637 .26136 L
.24145 .26043 L
.24617 .25957 L
.25056 .25877 L
.25507 .25794 L
.25927 .25717 L
.26316 .25645 L
.26717 .25571 L
.27089 .25502 L
.27471 .2543 L
.27826 .25364 L
.28155 .25301 L
.28494 .25237 L
.28808 .25176 L
.2913 .25114 L
.29428 .25056 L
.29705 .25001 L
.2999 .24945 L
.30254 .24892 L
.30499 .24843 L
.3075 .24791 L
.30983 .24743 L
.31222 .24694 L
Mistroke
.31444 .24647 L
.31649 .24604 L
.3186 .24558 L
.32056 .24516 L
.32256 .24472 L
.32441 .24431 L
.32613 .24393 L
.3279 .24353 L
.32953 .24315 L
.33105 .2428 L
.3326 .24244 L
.33404 .2421 L
.33552 .24175 L
.33688 .24142 L
.33815 .24111 L
.33945 .24079 L
.34065 .24049 L
.34177 .24021 L
.34292 .23992 L
.34398 .23964 L
.34506 .23936 L
.34607 .23909 L
.347 .23885 L
.34796 .23859 L
.34885 .23835 L
.34975 .2381 L
.35059 .23787 L
.35137 .23765 L
.35217 .23742 L
.35291 .23721 L
.3536 .23701 L
.3543 .23681 L
.35495 .23661 L
.35562 .23641 L
.35624 .23623 L
.35681 .23605 L
.35739 .23587 L
.35794 .23571 L
.35844 .23555 L
.35896 .23538 L
.35944 .23523 L
.35993 .23507 L
.36038 .23493 L
.36081 .23479 L
.36124 .23465 L
.36164 .23451 L
.36205 .23437 L
.36243 .23424 L
.36278 .23412 L
.36313 .234 L
Mistroke
Mfstroke
.02381 .33845 m
.03362 .33319 L
.04416 .32787 L
.0539 .32325 L
.0631 .31911 L
.07271 .31499 L
.08178 .3113 L
.09121 .30763 L
.10009 .30433 L
.10845 .30134 L
.11713 .29836 L
.12527 .29566 L
.13292 .29321 L
.14085 .29075 L
.14829 .28851 L
.15598 .28626 L
.16318 .28421 L
.16991 .28233 L
.17688 .28044 L
.18339 .2787 L
.19011 .27695 L
.19638 .27534 L
.20223 .27387 L
.20827 .27237 L
.2139 .27099 L
.21916 .26971 L
.22457 .26842 L
.22963 .26722 L
.23482 .266 L
.23966 .26487 L
.24417 .26383 L
.24881 .26276 L
.25313 .26177 L
.25715 .26085 L
.26129 .2599 L
.26515 .25903 L
.26911 .25813 L
.27279 .2573 L
.27621 .25652 L
.27973 .25572 L
.283 .25498 L
.28636 .25421 L
.28948 .2535 L
.29238 .25284 L
.29536 .25215 L
.29812 .25151 L
.30069 .25092 L
.30333 .25031 L
.30578 .24973 L
.30829 .24914 L
Mistroke
.31062 .24859 L
.31279 .24807 L
.31501 .24754 L
.31707 .24704 L
.31919 .24653 L
.32115 .24605 L
.32296 .2456 L
.32483 .24514 L
.32656 .2447 L
.32816 .2443 L
.32981 .24388 L
.33134 .24349 L
.33291 .24308 L
.33436 .2427 L
.3357 .24235 L
.33708 .24198 L
.33836 .24164 L
.33955 .24132 L
.34077 .24099 L
.3419 .24068 L
.34306 .24036 L
.34413 .24006 L
.34513 .23978 L
.34615 .23949 L
.3471 .23922 L
.34806 .23893 L
.34896 .23867 L
.34979 .23843 L
.35065 .23817 L
.35144 .23794 L
.35217 .23771 L
.35292 .23748 L
.35362 .23727 L
.35433 .23705 L
.355 .23684 L
.35561 .23665 L
.35624 .23644 L
.35682 .23626 L
.35736 .23608 L
.35792 .2359 L
.35843 .23573 L
.35896 .23556 L
.35945 .23539 L
.3599 .23524 L
.36036 .23508 L
.36079 .23493 L
.36123 .23478 L
.36164 .23464 L
.36202 .2345 L
.3624 .23437 L
Mistroke
Mfstroke
.02381 .36788 m
.03259 .36057 L
.04213 .35322 L
.05104 .34685 L
.05954 .34116 L
.06849 .33554 L
.07701 .33051 L
.08594 .32553 L
.09441 .32107 L
.10242 .31706 L
.11078 .31307 L
.11869 .30947 L
.12613 .30622 L
.1339 .30297 L
.14121 .30002 L
.1488 .29708 L
.15593 .2944 L
.16263 .29197 L
.16958 .28952 L
.17609 .2873 L
.18283 .28505 L
.18914 .28301 L
.19505 .28113 L
.20116 .27924 L
.20687 .27751 L
.21221 .27592 L
.21773 .2743 L
.22289 .27282 L
.2282 .27131 L
.23316 .26992 L
.23779 .26864 L
.24256 .26734 L
.24701 .26614 L
.25115 .26502 L
.25543 .26389 L
.25941 .26283 L
.26351 .26176 L
.26733 .26076 L
.27088 .25984 L
.27454 .25889 L
.27795 .25802 L
.28144 .25712 L
.28469 .25628 L
.28772 .2555 L
.29083 .25471 L
.29372 .25396 L
.2964 .25327 L
.29917 .25256 L
.30174 .2519 L
.30437 .25122 L
Mistroke
.30682 .25059 L
.3091 .25 L
.31143 .24939 L
.3136 .24882 L
.31583 .24823 L
.31789 .24769 L
.31981 .24718 L
.32178 .24666 L
.3236 .24617 L
.3253 .24571 L
.32704 .24524 L
.32866 .2448 L
.33031 .24434 L
.33185 .24392 L
.33327 .24352 L
.33473 .24311 L
.33609 .24273 L
.33735 .24237 L
.33864 .242 L
.33984 .24166 L
.34107 .2413 L
.34221 .24097 L
.34327 .24066 L
.34435 .24034 L
.34536 .24004 L
.34639 .23972 L
.34734 .23944 L
.34823 .23916 L
.34914 .23888 L
.34998 .23862 L
.35076 .23838 L
.35156 .23813 L
.3523 .23789 L
.35306 .23765 L
.35377 .23742 L
.35442 .23721 L
.3551 .23699 L
.35572 .23678 L
.35629 .23659 L
.35689 .23639 L
.35743 .2362 L
.358 .23601 L
.35852 .23583 L
.359 .23567 L
.3595 .23549 L
.35996 .23533 L
.36043 .23517 L
.36087 .23501 L
.36127 .23487 L
.36168 .23472 L
Mistroke
Mfstroke
.02381 .39731 m
.03155 .38789 L
.04009 .37845 L
.04818 .37028 L
.05598 .36302 L
.06428 .35585 L
.07225 .34946 L
.08067 .34316 L
.08872 .33752 L
.09639 .33247 L
.10444 .32746 L
.1121 .32296 L
.11935 .31891 L
.12695 .31486 L
.13413 .31121 L
.14162 .30757 L
.14869 .30427 L
.15535 .30129 L
.16228 .2983 L
.1688 .29558 L
.17557 .29285 L
.18192 .29037 L
.18788 .28811 L
.19406 .28583 L
.19986 .28375 L
.20528 .28185 L
.2109 .27992 L
.21616 .27816 L
.2216 .27637 L
.22667 .27473 L
.23142 .27323 L
.23632 .27169 L
.2409 .27029 L
.24517 .26899 L
.24958 .26766 L
.2537 .26644 L
.25794 .2652 L
.26189 .26405 L
.26557 .26298 L
.26937 .26189 L
.27291 .26089 L
.27654 .25986 L
.27993 .25891 L
.28308 .25802 L
.28632 .25712 L
.28934 .25627 L
.29214 .25549 L
.29503 .25469 L
.29772 .25395 L
.30048 .25318 L
Mistroke
.30304 .25247 L
.30543 .25181 L
.30788 .25113 L
.31016 .25049 L
.31249 .24984 L
.31466 .24923 L
.31668 .24867 L
.31875 .24809 L
.32067 .24754 L
.32245 .24704 L
.32429 .24652 L
.32599 .24603 L
.32774 .24553 L
.32936 .24506 L
.33086 .24463 L
.3324 .24418 L
.33384 .24376 L
.33517 .24336 L
.33653 .24296 L
.3378 .24258 L
.3391 .24219 L
.34031 .24183 L
.34143 .24149 L
.34257 .24114 L
.34364 .24081 L
.34473 .24047 L
.34574 .24016 L
.34668 .23986 L
.34764 .23956 L
.34854 .23927 L
.34936 .23901 L
.35021 .23873 L
.351 .23848 L
.35181 .23821 L
.35256 .23797 L
.35325 .23774 L
.35397 .2375 L
.35463 .23728 L
.35524 .23707 L
.35587 .23685 L
.35645 .23665 L
.35705 .23645 L
.3576 .23625 L
.35812 .23607 L
.35865 .23589 L
.35914 .23571 L
.35964 .23553 L
.3601 .23537 L
.36053 .23521 L
.36096 .23505 L
Mistroke
Mfstroke
.02381 .42674 m
.03051 .41515 L
.03806 .40355 L
.04532 .39355 L
.05241 .38467 L
.06006 .37593 L
.06748 .36815 L
.0754 .3605 L
.08303 .35368 L
.09036 .34758 L
.09811 .34154 L
.10552 .33613 L
.11258 .33127 L
.12001 .32643 L
.12706 .32208 L
.13446 .31774 L
.14146 .31383 L
.14808 .3103 L
.155 .30676 L
.16153 .30356 L
.16832 .30035 L
.17471 .29745 L
.18073 .29481 L
.18699 .29215 L
.19286 .28973 L
.19837 .28752 L
.2041 .28529 L
.20946 .28325 L
.21501 .28119 L
.22021 .27931 L
.22507 .27758 L
.23011 .27583 L
.23481 .27423 L
.23921 .27275 L
.24376 .27124 L
.248 .26986 L
.25238 .26845 L
.25647 .26715 L
.26029 .26595 L
.26422 .26473 L
.26789 .2636 L
.27167 .26245 L
.27519 .26138 L
.27846 .2604 L
.28184 .25939 L
.28498 .25845 L
.28791 .25759 L
.29092 .2567 L
.29373 .25587 L
.29661 .25503 L
Mistroke
.29929 .25424 L
.30178 .25351 L
.30435 .25276 L
.30674 .25207 L
.30918 .25135 L
.31146 .25069 L
.31357 .25007 L
.31574 .24943 L
.31776 .24884 L
.31963 .24829 L
.32156 .24772 L
.32335 .24719 L
.32518 .24665 L
.32689 .24614 L
.32847 .24567 L
.3301 .24518 L
.33161 .24472 L
.33301 .2443 L
.33445 .24386 L
.33578 .24345 L
.33715 .24303 L
.33842 .24264 L
.3396 .24227 L
.34081 .24189 L
.34194 .24154 L
.34309 .24118 L
.34416 .24084 L
.34515 .24052 L
.34617 .24019 L
.34711 .23989 L
.34798 .2396 L
.34888 .23931 L
.34972 .23903 L
.35057 .23875 L
.35136 .23849 L
.3521 .23824 L
.35285 .23798 L
.35355 .23775 L
.3542 .23752 L
.35486 .23729 L
.35548 .23708 L
.35612 .23686 L
.3567 .23665 L
.35725 .23646 L
.35781 .23626 L
.35832 .23607 L
.35885 .23588 L
.35935 .2357 L
.3598 .23554 L
.36026 .23537 L
Mistroke
Mfstroke
.02381 .45617 m
.02948 .44235 L
.03602 .42854 L
.04245 .41666 L
.04885 .40612 L
.05585 .39578 L
.06272 .38659 L
.07014 .37758 L
.07736 .36955 L
.08434 .36239 L
.09179 .35532 L
.09895 .34899 L
.10581 .34332 L
.11308 .33769 L
.12001 .33262 L
.1273 .3276 L
.13425 .32308 L
.14083 .319 L
.14773 .31492 L
.15427 .31124 L
.16109 .30757 L
.16753 .30424 L
.17361 .30122 L
.17993 .2982 L
.18589 .29544 L
.19149 .29294 L
.19732 .29041 L
.20279 .28811 L
.20846 .28579 L
.21377 .28367 L
.21876 .28173 L
.22392 .27976 L
.22876 .27796 L
.23328 .27631 L
.23796 .27464 L
.24234 .27309 L
.24687 .27153 L
.25109 .27009 L
.25504 .26876 L
.25911 .26741 L
.26291 .26616 L
.26683 .26489 L
.27048 .26372 L
.27388 .26264 L
.27739 .26153 L
.28066 .26051 L
.2837 .25956 L
.28684 .25859 L
.28977 .25769 L
.29277 .25677 L
Mistroke
.29557 .25591 L
.29817 .25512 L
.30085 .25431 L
.30334 .25355 L
.3059 .25278 L
.30828 .25206 L
.31049 .25139 L
.31276 .2507 L
.31488 .25006 L
.31684 .24947 L
.31886 .24886 L
.32073 .24829 L
.32266 .2477 L
.32445 .24715 L
.32611 .24665 L
.32781 .24612 L
.3294 .24564 L
.33087 .24518 L
.33238 .24471 L
.33378 .24427 L
.33522 .24382 L
.33656 .2434 L
.3378 .24301 L
.33908 .24261 L
.34026 .24223 L
.34147 .24184 L
.3426 .24148 L
.34364 .24114 L
.34471 .2408 L
.3457 .24047 L
.34662 .24017 L
.34757 .23985 L
.34845 .23956 L
.34935 .23926 L
.35018 .23898 L
.35096 .23872 L
.35175 .23845 L
.35249 .23819 L
.35317 .23796 L
.35388 .23771 L
.35453 .23748 L
.35519 .23725 L
.35581 .23703 L
.35639 .23683 L
.35698 .23661 L
.35753 .23642 L
.35809 .23621 L
.35861 .23602 L
.35909 .23585 L
.35957 .23567 L
Mistroke
Mfstroke
.02381 .4856 m
.02844 .46948 L
.03399 .45341 L
.0396 .4396 L
.0453 .42738 L
.05164 .4154 L
.05797 .40478 L
.06488 .39438 L
.07168 .38513 L
.07833 .3769 L
.08547 .36878 L
.09239 .36154 L
.09906 .35506 L
.10616 .34863 L
.11297 .34286 L
.12017 .33715 L
.12705 .33202 L
.1336 .3274 L
.1405 .32279 L
.14704 .31864 L
.15389 .3145 L
.16038 .31076 L
.16651 .30737 L
.17291 .30398 L
.17895 .3009 L
.18464 .29811 L
.19057 .29529 L
.19615 .29273 L
.20194 .29016 L
.20738 .28781 L
.21248 .28566 L
.21778 .28349 L
.22274 .28151 L
.22739 .27969 L
.23221 .27784 L
.23672 .27615 L
.24138 .27444 L
.24574 .27286 L
.24982 .27141 L
.25403 .26994 L
.25797 .26858 L
.26202 .2672 L
.26581 .26592 L
.26934 .26475 L
.27298 .26355 L
.27637 .26244 L
.27953 .26141 L
.2828 .26037 L
.28584 .2594 L
.28897 .2584 L
Mistroke
.29188 .25748 L
.29459 .25663 L
.29738 .25576 L
.29998 .25495 L
.30265 .25412 L
.30513 .25334 L
.30744 .25263 L
.30982 .25189 L
.31202 .25121 L
.31408 .25058 L
.31619 .24992 L
.31815 .24932 L
.32016 .24869 L
.32203 .24811 L
.32377 .24757 L
.32556 .24701 L
.32721 .24649 L
.32876 .24601 L
.33034 .24551 L
.33181 .24505 L
.33332 .24457 L
.33472 .24413 L
.33602 .24371 L
.33736 .24328 L
.3386 .24288 L
.33987 .24247 L
.34105 .24209 L
.34215 .24173 L
.34327 .24136 L
.34431 .24102 L
.34528 .2407 L
.34628 .24037 L
.3472 .24006 L
.34814 .23974 L
.34902 .23944 L
.34983 .23917 L
.35067 .23888 L
.35144 .23861 L
.35216 .23837 L
.3529 .23811 L
.35359 .23787 L
.35429 .23762 L
.35494 .23739 L
.35554 .23717 L
.35616 .23695 L
.35674 .23674 L
.35733 .23653 L
.35788 .23633 L
.35838 .23614 L
.35889 .23595 L
Mistroke
Mfstroke
.02381 .51503 m
.0274 .49655 L
.03195 .47816 L
.03674 .46238 L
.04174 .44843 L
.04743 .43479 L
.05321 .42271 L
.05963 .4109 L
.06602 .40043 L
.07233 .39112 L
.07917 .38195 L
.08585 .37378 L
.09233 .36648 L
.09927 .35926 L
.10596 .35279 L
.11307 .3464 L
.11989 .34066 L
.1264 .3355 L
.13328 .33037 L
.13984 .32575 L
.14672 .32116 L
.15325 .31701 L
.15945 .31326 L
.16592 .30952 L
.17205 .30612 L
.17783 .30304 L
.18386 .29995 L
.18955 .29713 L
.19546 .29431 L
.20102 .29174 L
.20624 .28939 L
.21167 .28702 L
.21676 .28486 L
.22154 .28288 L
.2265 .28088 L
.23114 .27904 L
.23594 .27718 L
.24044 .27548 L
.24465 .27391 L
.249 .27232 L
.25306 .27085 L
.25726 .26937 L
.26117 .268 L
.26483 .26673 L
.2686 .26545 L
.27212 .26426 L
.27541 .26316 L
.27879 .26204 L
.28195 .261 L
.2852 .25994 L
Mistroke
.28823 .25896 L
.29105 .25805 L
.29395 .25712 L
.29666 .25626 L
.29944 .25537 L
.30202 .25455 L
.30443 .25379 L
.3069 .25301 L
.3092 .25229 L
.31134 .25162 L
.31355 .25093 L
.31559 .25028 L
.31769 .24962 L
.31965 .24901 L
.32146 .24844 L
.32333 .24785 L
.32506 .2473 L
.32667 .24679 L
.32833 .24627 L
.32987 .24578 L
.33144 .24528 L
.33291 .24481 L
.33427 .24437 L
.33567 .24392 L
.33697 .2435 L
.3383 .24307 L
.33953 .24266 L
.34068 .24229 L
.34186 .2419 L
.34295 .24154 L
.34396 .2412 L
.345 .24086 L
.34597 .24053 L
.34696 .2402 L
.34788 .23989 L
.34873 .23959 L
.3496 .23929 L
.35042 .23901 L
.35117 .23875 L
.35194 .23848 L
.35266 .23823 L
.3534 .23797 L
.35408 .23773 L
.35471 .2375 L
.35536 .23727 L
.35597 .23705 L
.35659 .23683 L
.35716 .23662 L
.35769 .23642 L
.35822 .23623 L
Mistroke
Mfstroke
.02381 .54446 m
.02637 .52356 L
.02992 .50279 L
.03388 .48499 L
.03818 .46929 L
.04323 .45395 L
.04847 .4404 L
.05438 .42716 L
.06036 .41545 L
.06634 .40504 L
.07288 .39482 L
.07932 .38572 L
.08561 .37761 L
.09239 .36959 L
.09897 .36243 L
.10599 .35535 L
.11275 .34901 L
.11924 .34332 L
.12611 .33767 L
.13268 .33259 L
.13959 .32755 L
.14617 .323 L
.15242 .3189 L
.15898 .3148 L
.16519 .3111 L
.17106 .30774 L
.1772 .30438 L
.18299 .30132 L
.18902 .29825 L
.19471 .29547 L
.20005 .29293 L
.20561 .29037 L
.21084 .28804 L
.21574 .2859 L
.22083 .28375 L
.22561 .28177 L
.23055 .27978 L
.23519 .27795 L
.23952 .27627 L
.24401 .27456 L
.24821 .273 L
.25254 .27141 L
.25659 .26995 L
.26037 .2686 L
.26428 .26723 L
.26792 .26597 L
.27132 .2648 L
.27483 .26361 L
.27811 .26251 L
.28148 .26138 L
Mistroke
.28462 .26034 L
.28755 .25938 L
.29056 .2584 L
.29337 .25749 L
.29626 .25655 L
.29895 .25569 L
.30145 .25489 L
.30402 .25407 L
.30642 .25331 L
.30865 .2526 L
.31094 .25187 L
.31307 .25119 L
.31526 .2505 L
.31729 .24985 L
.31919 .24925 L
.32113 .24864 L
.32294 .24806 L
.32461 .24753 L
.32634 .24698 L
.32795 .24647 L
.32959 .24594 L
.33112 .24545 L
.33254 .24499 L
.334 .24452 L
.33536 .24408 L
.33675 .24363 L
.33804 .24321 L
.33923 .24281 L
.34046 .24241 L
.3416 .24203 L
.34266 .24168 L
.34375 .24132 L
.34476 .24098 L
.34579 .24063 L
.34675 .2403 L
.34764 .24 L
.34856 .23969 L
.34941 .23939 L
.35019 .23912 L
.351 .23884 L
.35175 .23858 L
.35252 .23831 L
.35324 .23805 L
.3539 .23782 L
.35458 .23757 L
.35521 .23735 L
.35586 .23711 L
.35646 .23689 L
.35701 .23669 L
.35757 .23648 L
Mistroke
Mfstroke
.02381 .57389 m
.02445 .56224 L
.02533 .55051 L
.02644 .53915 L
.02788 .5273 L
.0311 .50699 L
.03482 .48913 L
.03935 .47176 L
.0442 .45645 L
.04924 .44291 L
.05496 .42967 L
.06075 .41793 L
.06654 .40751 L
.07289 .39725 L
.07915 .38812 L
.08594 .37913 L
.09256 .37112 L
.09898 .36396 L
.10585 .35687 L
.11247 .35053 L
.11949 .34425 L
.12623 .33862 L
.13266 .33355 L
.13945 .32851 L
.14591 .32397 L
.15205 .31987 L
.1585 .31577 L
.16461 .31207 L
.17099 .30836 L
.17702 .305 L
.18272 .30196 L
.18866 .2989 L
.19426 .29611 L
.19952 .29358 L
.205 .29102 L
.21016 .28869 L
.2155 .28633 L
.22052 .28418 L
.22523 .28221 L
.23011 .28022 L
.23468 .2784 L
.2394 .27655 L
.24382 .27485 L
.24796 .2733 L
.25224 .27171 L
.25623 .27026 L
.25996 .26892 L
.26382 .26755 L
.26742 .26629 L
.27114 .26501 L
Mistroke
.2746 .26382 L
.27783 .26273 L
.28116 .26161 L
.28426 .26058 L
.28746 .25952 L
.29043 .25854 L
.2932 .25764 L
.29605 .25671 L
.29871 .25585 L
.30118 .25506 L
.30373 .25424 L
.30609 .25348 L
.30853 .2527 L
.31079 .25198 L
.31289 .25131 L
.31506 .25062 L
.31707 .24998 L
.31894 .24939 L
.32086 .24877 L
.32265 .2482 L
.32449 .24761 L
.32619 .24707 L
.32778 .24656 L
.32941 .24604 L
.33092 .24555 L
.33247 .24505 L
.33391 .24458 L
.33525 .24414 L
.33662 .2437 L
.3379 .24328 L
.33908 .24289 L
.3403 .24249 L
.34143 .24211 L
.34259 .24173 L
.34366 .24137 L
.34466 .24103 L
.34568 .24068 L
.34663 .24036 L
.34751 .24006 L
.34842 .23975 L
.34926 .23946 L
.35012 .23916 L
.35092 .23888 L
.35166 .23862 L
.35243 .23835 L
.35313 .2381 L
.35386 .23784 L
.35453 .2376 L
.35515 .23738 L
.35579 .23715 L
Mistroke
.35638 .23693 L
.35693 .23673 L
Mfstroke
.02381 .60332 m
.02381 .60249 L
.02381 .60175 L
.02381 .60089 L
.02382 .60007 L
.02382 .59864 L
.02384 .59708 L
.02385 .59538 L
.02388 .59359 L
.02393 .5904 L
.024 .58715 L
.02407 .58414 L
.0243 .57739 L
.02459 .57068 L
.02492 .56469 L
.02585 .55169 L
.02686 .5409 L
.02818 .52966 L
.03131 .50909 L
.03497 .491 L
.03944 .47342 L
.04424 .45793 L
.04925 .44424 L
.05494 .43084 L
.06071 .41899 L
.06648 .40845 L
.07283 .39809 L
.07909 .38886 L
.08587 .3798 L
.09249 .37171 L
.09892 .36449 L
.10579 .35734 L
.11242 .35094 L
.11879 .3452 L
.12554 .33949 L
.132 .33435 L
.1388 .32924 L
.14529 .32464 L
.15145 .32049 L
.15792 .31634 L
.16405 .31258 L
.17046 .30884 L
.17652 .30544 L
.18224 .30236 L
.18821 .29926 L
.19383 .29645 L
.19912 .29389 L
.20463 .29131 L
.2098 .28895 L
.21517 .28657 L
Mistroke
.22021 .2844 L
.22494 .28242 L
.22984 .28041 L
.23443 .27857 L
.23918 .27671 L
.24362 .275 L
.24778 .27343 L
.25207 .27183 L
.25608 .27037 L
.25983 .26902 L
.2637 .26764 L
.26732 .26637 L
.27105 .26508 L
.27452 .26389 L
.27777 .26279 L
.28111 .26166 L
.28423 .26062 L
.28713 .25966 L
.29012 .25867 L
.29291 .25776 L
.29578 .25683 L
.29846 .25596 L
.30094 .25516 L
.30351 .25433 L
.30589 .25357 L
.30834 .25279 L
.31061 .25206 L
.31273 .25138 L
.3149 .25069 L
.31693 .25004 L
.31881 .24944 L
.32074 .24882 L
.32254 .24825 L
.32439 .24766 L
.3261 .24711 L
.3277 .2466 L
.32933 .24607 L
.33085 .24558 L
.33227 .24512 L
.33372 .24465 L
.33507 .24421 L
.33645 .24376 L
.33774 .24334 L
.33893 .24295 L
.34016 .24254 L
.3413 .24216 L
.34246 .24177 L
.34354 .24141 L
.34455 .24107 L
.34558 .24073 L
Mistroke
.34654 .2404 L
.34742 .2401 L
.34834 .23978 L
.34918 .23949 L
.35005 .23919 L
.35086 .23891 L
.3516 .23865 L
.35237 .23838 L
.35308 .23812 L
.35381 .23786 L
.35448 .23762 L
.35511 .2374 L
.35575 .23716 L
.3563 .23696 L
Mfstroke
.07143 .01472 m
.09044 .02718 L
.10969 .03987 L
.12647 .05098 L
.14149 .06098 L
.15638 .07093 L
.16973 .0799 L
.18293 .08881 L
.19476 .09684 L
.20538 .10409 L
.21593 .11131 L
.2254 .11783 L
.23392 .12373 L
.24241 .12963 L
.25006 .13497 L
.25765 .14031 L
.2645 .14514 L
.27067 .14951 L
.27682 .1539 L
.28238 .15788 L
.28791 .16186 L
.2929 .16547 L
.2974 .16874 L
.30191 .17203 L
.30598 .17502 L
.30966 .17774 L
.31335 .18048 L
.31669 .18297 L
.32002 .18547 L
.32304 .18774 L
.32578 .18982 L
.32852 .1919 L
.331 .1938 L
.33325 .19554 L
.33552 .19729 L
.33757 .19889 L
.33962 .20049 L
.34149 .20196 L
.34318 .2033 L
.34488 .20465 L
.34642 .20589 L
.34797 .20713 L
.34937 .20826 L
.35064 .2093 L
.35192 .21035 L
.35308 .2113 L
.35413 .21218 L
.35519 .21306 L
.35616 .21387 L
.35712 .21469 L
Mistroke
.358 .21543 L
.3588 .21611 L
.3596 .2168 L
.36032 .21744 L
.36105 .21807 L
.36171 .21866 L
.36232 .21919 L
.36292 .21973 L
.36347 .22022 L
.36397 .22067 L
.36447 .22113 L
.36492 .22155 L
.36538 .22197 L
.36579 .22236 L
.36617 .22271 L
.36655 .22307 L
.36689 .2234 L
.36721 .2237 L
.36752 .22401 L
.36781 .22429 L
.36809 .22457 L
.36835 .22483 L
.36859 .22507 L
.36882 .22531 L
.36904 .22553 L
.36925 .22576 L
.36945 .22596 L
.36963 .22615 L
.36981 .22634 L
.36997 .22652 L
.37011 .22668 L
.37026 .22684 L
.37039 .22699 L
.37053 .22714 L
.37065 .22728 L
.37076 .2274 L
.37087 .22753 L
.37097 .22765 L
.37106 .22776 L
.37115 .22787 L
.37123 .22797 L
.37131 .22807 L
.37139 .22817 L
.37145 .22825 L
.37152 .22834 L
.37158 .22842 L
.37164 .2285 L
.3717 .22858 L
.37175 .22864 L
.3718 .22871 L
Mistroke
Mfstroke
.07143 .60332 m
.07121 .59739 L
.07103 .59103 L
.07096 .58787 L
.0709 .58453 L
.07088 .58292 L
.07086 .58141 L
.07085 .57996 L
.07084 .57861 L
.07083 .57783 L
.07083 .57712 L
.07082 .57634 L
.07082 .57591 L
.07082 .5755 L
.07082 .57511 L
.07082 .57469 L
.07082 .57394 L
.07082 .57348 L
.07082 .57305 L
.07082 .57266 L
.07082 .57224 L
.07083 .57154 L
.07083 .57078 L
.07084 .56923 L
.07085 .56781 L
.07086 .56649 L
.07091 .56327 L
.07097 .56036 L
.07114 .55394 L
.07135 .54845 L
.07158 .54348 L
.07225 .53259 L
.07302 .5232 L
.07403 .51326 L
.07649 .49508 L
.07938 .47896 L
.08296 .46318 L
.08684 .44918 L
.0909 .43673 L
.09555 .42447 L
.10028 .41356 L
.10555 .40282 L
.11081 .39324 L
.11602 .38468 L
.12168 .37621 L
.12723 .36863 L
.13262 .36183 L
.1384 .35506 L
.14399 .34898 L
.14993 .34294 L
Mistroke
.15565 .3375 L
.16112 .3326 L
.16691 .3277 L
.17243 .32327 L
.17823 .31886 L
.18374 .31487 L
.18898 .31125 L
.19446 .30762 L
.19965 .30433 L
.20456 .30133 L
.20968 .29831 L
.21451 .29557 L
.21954 .2928 L
.22428 .29028 L
.22873 .28798 L
.23336 .28565 L
.23771 .28352 L
.24179 .28158 L
.24603 .2796 L
.25 .27779 L
.25412 .27595 L
.25797 .27427 L
.26158 .27272 L
.26531 .27114 L
.2688 .26969 L
.2724 .26822 L
.27577 .26686 L
.27892 .26561 L
.28216 .26434 L
.28519 .26316 L
.28802 .26207 L
.29094 .26096 L
.29366 .25994 L
.29646 .25889 L
.29908 .25792 L
.30151 .25702 L
.30402 .2561 L
.30636 .25525 L
.30853 .25446 L
.31078 .25365 L
.31287 .2529 L
.31501 .25213 L
.31701 .25141 L
.31887 .25075 L
.32079 .25007 L
.32257 .24944 L
.3244 .24879 L
.3261 .24818 L
.32768 .24762 L
.3293 .24705 L
Mistroke
.33081 .24651 L
.33222 .24601 L
.33366 .2455 L
.335 .24502 L
.33638 .24453 L
.33766 .24407 L
.33885 .24365 L
.34007 .24321 L
.34121 .2428 L
.34237 .24238 L
.34345 .24199 L
.34445 .24163 L
.34548 .24125 L
.34644 .2409 L
.34732 .24058 L
.34824 .24024 L
.34908 .23993 L
.34995 .23961 L
.35076 .23931 L
.3515 .23903 L
.35227 .23874 L
.35298 .23847 L
.35364 .23822 L
.35432 .23796 L
.35495 .23772 L
.3556 .23748 L
.3562 .23724 L
.35676 .23703 L
.35731 .23681 L
Mfstroke
.11905 .01472 m
.13577 .02654 L
.15265 .03861 L
.16733 .04921 L
.18045 .05878 L
.19343 .06835 L
.20504 .07698 L
.21649 .08559 L
.22674 .09338 L
.23592 .10042 L
.24501 .10747 L
.25317 .11385 L
.26049 .11964 L
.26776 .12545 L
.2743 .13072 L
.28078 .136 L
.28661 .1408 L
.29185 .14516 L
.29707 .14955 L
.30176 .15353 L
.30642 .15753 L
.31062 .16117 L
.3144 .16449 L
.31817 .16783 L
.32156 .17086 L
.32463 .17364 L
.32769 .17644 L
.33045 .17899 L
.3332 .18156 L
.33568 .18391 L
.33793 .18605 L
.34017 .18821 L
.34219 .19019 L
.34402 .19199 L
.34585 .19382 L
.3475 .1955 L
.34915 .19718 L
.35064 .19873 L
.35199 .20014 L
.35334 .20157 L
.35456 .20288 L
.35577 .2042 L
.35687 .20541 L
.35786 .20652 L
.35886 .20765 L
.35975 .20867 L
.36056 .20962 L
.36138 .21057 L
.36211 .21145 L
.36284 .21233 L
Mistroke
.3635 .21314 L
.3641 .21389 L
.36469 .21464 L
.36523 .21534 L
.36577 .21604 L
.36625 .21668 L
.36669 .21727 L
.36713 .21787 L
.36752 .21841 L
.36787 .21892 L
.36823 .21943 L
.36855 .2199 L
.36887 .22037 L
.36915 .22081 L
.36941 .22121 L
.36967 .22161 L
.3699 .22199 L
.3701 .22233 L
.37031 .22268 L
.3705 .223 L
.37068 .22332 L
.37085 .22362 L
.371 .2239 L
.37114 .22418 L
.37128 .22443 L
.37141 .22469 L
.37153 .22493 L
.37163 .22515 L
.37173 .22537 L
.37183 .22558 L
.37191 .22577 L
.37199 .22596 L
.37206 .22614 L
.37213 .22631 L
.3722 .22648 L
.37225 .22663 L
.37231 .22678 L
.37236 .22693 L
.3724 .22706 L
.37244 .22719 L
.37248 .22731 L
.37252 .22744 L
.37255 .22755 L
.37258 .22766 L
.3726 .22776 L
.37263 .22786 L
.37265 .22796 L
.37267 .22805 L
.37268 .22814 L
.3727 .22822 L
Mistroke
Mfstroke
.11905 .60332 m
.11818 .59165 L
.11748 .57983 L
.11697 .56831 L
.11677 .56198 L
.1167 .5592 L
.11664 .55622 L
.11659 .5533 L
.11658 .55203 L
.11656 .55064 L
.11655 .54942 L
.11654 .54812 L
.11654 .54741 L
.11654 .54675 L
.11654 .5461 L
.11653 .54548 L
.11653 .54487 L
.11653 .54433 L
.11653 .5437 L
.11654 .54311 L
.11654 .54257 L
.11654 .54207 L
.11655 .54094 L
.11655 .5398 L
.11657 .53856 L
.1166 .53608 L
.11664 .53349 L
.11669 .53106 L
.11682 .52657 L
.11699 .52183 L
.11723 .51679 L
.11776 .5079 L
.11849 .49883 L
.12015 .48343 L
.12239 .46823 L
.12496 .45467 L
.12807 .44131 L
.1314 .42937 L
.13487 .41869 L
.13881 .40811 L
.1428 .39864 L
.14723 .38927 L
.15165 .38086 L
.15602 .37331 L
.16076 .36581 L
.16539 .35905 L
.1699 .35296 L
.17473 .34688 L
.1794 .3414 L
.18437 .33592 L
Mistroke
.18915 .33098 L
.19372 .3265 L
.19856 .32201 L
.20317 .31794 L
.20802 .31387 L
.21264 .31018 L
.21702 .30682 L
.22161 .30344 L
.22596 .30037 L
.23007 .29757 L
.23436 .29474 L
.23842 .29216 L
.24263 .28955 L
.24661 .28717 L
.25035 .285 L
.25424 .2828 L
.2579 .28078 L
.26133 .27893 L
.2649 .27705 L
.26824 .27532 L
.2717 .27357 L
.27495 .27196 L
.27799 .27049 L
.28114 .26898 L
.28408 .26759 L
.28712 .26618 L
.28996 .26488 L
.29262 .26369 L
.29536 .26247 L
.29792 .26134 L
.30031 .2603 L
.30278 .25923 L
.30509 .25825 L
.30746 .25724 L
.30967 .25631 L
.31174 .25545 L
.31386 .25457 L
.31585 .25375 L
.31769 .253 L
.3196 .25222 L
.32137 .2515 L
.32319 .25077 L
.32489 .25008 L
.32647 .24945 L
.3281 .2488 L
.32962 .24819 L
.33117 .24757 L
.33262 .247 L
.33396 .24646 L
.33535 .24591 L
Mistroke
.33664 .2454 L
.33783 .24493 L
.33906 .24444 L
.34021 .24399 L
.34138 .24352 L
.34248 .24309 L
.34349 .24268 L
.34453 .24227 L
.3455 .24188 L
.3465 .24149 L
.34742 .24112 L
.34828 .24077 L
.34916 .24042 L
.34998 .24009 L
.35074 .23978 L
.35152 .23947 L
.35225 .23917 L
.35299 .23887 L
.35368 .23859 L
.35432 .23833 L
.35498 .23806 L
.35559 .23781 L
.35616 .23757 L
.35674 .23733 L
.35728 .23711 L
.35784 .23688 L
.35834 .23667 L
Mfstroke
.16667 .01472 m
.18099 .0259 L
.19541 .03736 L
.20792 .04745 L
.21908 .05659 L
.23009 .06575 L
.23992 .07406 L
.24959 .08237 L
.25822 .0899 L
.26594 .09674 L
.27356 .10361 L
.28038 .10985 L
.28649 .11552 L
.29254 .12124 L
.29796 .12644 L
.30333 .13167 L
.30814 .13644 L
.31245 .14078 L
.31673 .14516 L
.32057 .14915 L
.32437 .15317 L
.32778 .15684 L
.33084 .16019 L
.33388 .16358 L
.33661 .16667 L
.33907 .16949 L
.34151 .17235 L
.34371 .17497 L
.34588 .17761 L
.34784 .18003 L
.3496 .18224 L
.35135 .18448 L
.35292 .18653 L
.35434 .18841 L
.35575 .19032 L
.35701 .19207 L
.35827 .19384 L
.3594 .19546 L
.36042 .19695 L
.36143 .19846 L
.36233 .19984 L
.36323 .20125 L
.36404 .20253 L
.36476 .20372 L
.36548 .20491 L
.36612 .20602 L
.3667 .20703 L
.36727 .20805 L
.36779 .209 L
.36829 .20995 L
Mistroke
.36875 .21083 L
.36915 .21164 L
.36955 .21246 L
.36991 .21322 L
.37027 .21398 L
.37058 .21468 L
.37086 .21533 L
.37114 .21599 L
.37138 .21659 L
.3716 .21715 L
.37181 .21771 L
.372 .21823 L
.37219 .21876 L
.37235 .21924 L
.37249 .21969 L
.37263 .22015 L
.37276 .22056 L
.37287 .22095 L
.37297 .22134 L
.37306 .2217 L
.37315 .22207 L
.37323 .22241 L
.37329 .22272 L
.37336 .22303 L
.37341 .22333 L
.37346 .22362 L
.3735 .2239 L
.37354 .22415 L
.37357 .2244 L
.3736 .22464 L
.37362 .22486 L
.37364 .22508 L
.37366 .22528 L
.37367 .22549 L
.37367 .22559 L
.37368 .22568 L
.37368 .22577 L
.37368 .22586 L
.37368 .22594 L
.37368 .22598 L
.37369 .22603 L
.37369 .22607 L
.37369 .22609 L
.37369 .22612 L
.37369 .22613 L
.37369 .22613 L
.37369 .22614 L
.37369 .22614 L
.37369 .22615 L
.37369 .22615 L
Mistroke
.37369 .22616 L
.37369 .22616 L
.37369 .22617 L
.37369 .22617 L
.37369 .22617 L
.37369 .22618 L
.37369 .22618 L
.37369 .22619 L
.37369 .22619 L
.37369 .2262 L
.37369 .22621 L
.37369 .22622 L
.37369 .22625 L
.37369 .22628 L
.37369 .22633 L
.37368 .22637 L
.37368 .22645 L
.37368 .22652 L
.37368 .22667 L
.37367 .2268 L
.37366 .22694 L
.37365 .22707 L
.37364 .22719 L
.37363 .22731 L
.37361 .22742 L
.3736 .22753 L
.37358 .22764 L
.37357 .22773 L
.37356 .22774 L
Mfstroke
.16667 .60332 m
.16423 .58106 L
.16323 .57009 L
.16235 .55853 L
.1617 .54808 L
.16126 .53891 L
.1611 .53446 L
.16095 .52972 L
.16089 .52715 L
.16084 .52481 L
.16081 .5226 L
.16079 .52139 L
.16078 .52025 L
.16077 .51918 L
.16076 .51802 L
.16075 .51751 L
.16075 .51697 L
.16075 .51646 L
.16075 .516 L
.16075 .51549 L
.16075 .51494 L
.16075 .51445 L
.16075 .51394 L
.16075 .51348 L
.16075 .51305 L
.16075 .51258 L
.16075 .51208 L
.16076 .51095 L
.16077 .50972 L
.16078 .50857 L
.16079 .5075 L
.16082 .50552 L
.16086 .5034 L
.16096 .49946 L
.16107 .49583 L
.16143 .48776 L
.1619 .48019 L
.16252 .47251 L
.16391 .45936 L
.16577 .44631 L
.16788 .4346 L
.17043 .42301 L
.17315 .41259 L
.17599 .40323 L
.1792 .39392 L
.18246 .38553 L
.18573 .37797 L
.18933 .37042 L
.19289 .36361 L
.19676 .35681 L
Mistroke
.20055 .35067 L
.20424 .34512 L
.20819 .33956 L
.21202 .33452 L
.2161 .32948 L
.22002 .32491 L
.22378 .32076 L
.22776 .3166 L
.23156 .31281 L
.23518 .30937 L
.23899 .30589 L
.24261 .30272 L
.2464 .29954 L
.25 .29663 L
.25341 .29397 L
.25696 .29129 L
.26033 .28884 L
.2635 .28659 L
.2668 .28431 L
.26992 .28223 L
.27316 .28011 L
.27621 .27818 L
.27907 .2764 L
.28205 .27459 L
.28484 .27293 L
.28773 .27125 L
.29045 .2697 L
.29299 .26827 L
.29562 .26682 L
.29808 .26549 L
.30039 .26426 L
.30278 .263 L
.30501 .26184 L
.30731 .26066 L
.30947 .25957 L
.31148 .25856 L
.31355 .25753 L
.31549 .25658 L
.3173 .2557 L
.31917 .2548 L
.32092 .25397 L
.32271 .25312 L
.32439 .25233 L
.32595 .2516 L
.32756 .25085 L
.32906 .25015 L
.33061 .24944 L
.33204 .24878 L
.33338 .24817 L
.33476 .24755 L
Mistroke
.33605 .24697 L
.33724 .24643 L
.33847 .24587 L
.33962 .24536 L
.34079 .24483 L
.34189 .24434 L
.34291 .24389 L
.34395 .24342 L
.34493 .24299 L
.34593 .24254 L
.34686 .24213 L
.34772 .24174 L
.34861 .24135 L
.34944 .24098 L
.35021 .24064 L
.351 .24029 L
.35173 .23996 L
.35249 .23963 L
.35319 .23931 L
.35384 .23902 L
.3545 .23872 L
.35513 .23845 L
.3557 .23819 L
.3563 .23792 L
.35685 .23767 L
.35741 .23742 L
.35794 .23718 L
.35843 .23696 L
.35893 .23673 L
.35938 .23653 L
Mfstroke
.21429 .01472 m
.22611 .02526 L
.23798 .0361 L
.24825 .04568 L
.25739 .0544 L
.26638 .06316 L
.27437 .07113 L
.28223 .07913 L
.28921 .08641 L
.29544 .09305 L
.30157 .09973 L
.30704 .10583 L
.31192 .11139 L
.31674 .11701 L
.32105 .12214 L
.3253 .12732 L
.32908 .13204 L
.33247 .13637 L
.33582 .14074 L
.33881 .14474 L
.34175 .14878 L
.34438 .15248 L
.34673 .15586 L
.34906 .15929 L
.35113 .16243 L
.35299 .16531 L
.35482 .16823 L
.35646 .17091 L
.35808 .17362 L
.35952 .17611 L
.36081 .17839 L
.36208 .18071 L
.36322 .18284 L
.36423 .18479 L
.36523 .18678 L
.36612 .1886 L
.367 .19046 L
.36778 .19216 L
.36847 .19372 L
.36915 .19532 L
.36976 .19678 L
.37035 .19826 L
.37088 .19963 L
.37134 .20088 L
.37179 .20216 L
.37219 .20333 L
.37255 .20441 L
.37289 .20551 L
.37319 .20653 L
.37349 .20756 L
Mistroke
.37374 .2085 L
.37397 .20937 L
.37418 .21026 L
.37437 .21108 L
.37454 .21191 L
.3747 .21268 L
.37483 .21338 L
.37495 .2141 L
.37505 .21476 L
.37514 .21536 L
.37522 .21598 L
.37529 .21656 L
.37535 .21714 L
.37539 .21767 L
.37543 .21817 L
.37546 .21867 L
.37548 .21913 L
.37549 .21936 L
.37549 .21956 L
.3755 .21977 L
.3755 .21988 L
.3755 .22 L
.3755 .2201 L
.3755 .22015 L
.3755 .2202 L
.3755 .22025 L
.3755 .22028 L
.3755 .22029 L
.3755 .2203 L
.3755 .22031 L
.3755 .22032 L
.3755 .22033 L
.3755 .22035 L
.3755 .22036 L
.3755 .22037 L
.3755 .22038 L
.3755 .22039 L
.3755 .2204 L
.3755 .22042 L
.3755 .22044 L
.3755 .22046 L
.3755 .22049 L
.3755 .22054 L
.3755 .22058 L
.3755 .22068 L
.3755 .22078 L
.3755 .22088 L
.3755 .22099 L
.37549 .22118 L
.37548 .22155 L
Mistroke
.37546 .2219 L
.37544 .22221 L
.37542 .22254 L
.37539 .22284 L
.37536 .22314 L
.37533 .22342 L
.37529 .22368 L
.37525 .22394 L
.37522 .22419 L
.37517 .22444 L
.37513 .22467 L
.37509 .22488 L
.37504 .22509 L
.375 .22529 L
.37495 .22548 L
.37491 .22566 L
.37486 .22584 L
.37481 .22601 L
.37476 .22618 L
.37472 .22633 L
.37467 .22648 L
.37462 .22662 L
.37458 .22676 L
.37453 .22689 L
.37448 .22701 L
.37444 .22714 L
.37439 .22725 L
Mfstroke
.21429 .60332 m
.21108 .5823 L
.20827 .56088 L
.20623 .54209 L
.20478 .52517 L
.20418 .5162 L
.20375 .50831 L
.20358 .50448 L
.20342 .50039 L
.2033 .49662 L
.20322 .49314 L
.20315 .48961 L
.20313 .48776 L
.20312 .48673 L
.20311 .48579 L
.2031 .48481 L
.2031 .48429 L
.2031 .48375 L
.2031 .4835 L
.2031 .48322 L
.2031 .48299 L
.2031 .48273 L
.2031 .48251 L
.2031 .48226 L
.2031 .48182 L
.2031 .48135 L
.2031 .48093 L
.2031 .48069 L
.2031 .48044 L
.2031 .47997 L
.2031 .47908 L
.20311 .47826 L
.20312 .47663 L
.20315 .4749 L
.2032 .47179 L
.20329 .46816 L
.2034 .46489 L
.20367 .45875 L
.20405 .45225 L
.20505 .44015 L
.2063 .42923 L
.20791 .41837 L
.20971 .40857 L
.21164 .39971 L
.21388 .39087 L
.21621 .38288 L
.21857 .37565 L
.22122 .3684 L
.22386 .36184 L
.22677 .35527 L
Mistroke
.22964 .34932 L
.23246 .34392 L
.2355 .3385 L
.23847 .33357 L
.24165 .32863 L
.24472 .32415 L
.24769 .32006 L
.25084 .31595 L
.25386 .31221 L
.25675 .3088 L
.2598 .30535 L
.26272 .3022 L
.26578 .29903 L
.26869 .29614 L
.27146 .29349 L
.27436 .29081 L
.2771 .28835 L
.2797 .28611 L
.28241 .28383 L
.28498 .28174 L
.28765 .27962 L
.29016 .27768 L
.29254 .27589 L
.295 .27408 L
.29732 .27241 L
.29973 .27072 L
.302 .26917 L
.30412 .26774 L
.30632 .26628 L
.30839 .26494 L
.31032 .2637 L
.31233 .26244 L
.31421 .26128 L
.31615 .26009 L
.31797 .259 L
.31967 .25799 L
.32142 .25696 L
.32307 .25601 L
.3246 .25513 L
.32619 .25423 L
.32767 .25339 L
.3292 .25254 L
.33063 .25176 L
.33196 .25103 L
.33334 .25028 L
.33462 .24959 L
.33594 .24888 L
.33717 .24823 L
.33832 .24762 L
.3395 .247 L
Mistroke
.34061 .24642 L
.34163 .24589 L
.34269 .24534 L
.34368 .24483 L
.34469 .24431 L
.34564 .24383 L
.34652 .24338 L
.34742 .24292 L
.34826 .24249 L
.34913 .24206 L
.34994 .24165 L
.35068 .24127 L
.35146 .24089 L
.35217 .24053 L
.35284 .24019 L
.35353 .23985 L
.35416 .23953 L
.35482 .2392 L
.35543 .2389 L
.356 .23861 L
.35658 .23832 L
.35712 .23805 L
.35763 .2378 L
.35814 .23754 L
.35863 .2373 L
.35912 .23706 L
.35958 .23683 L
.36001 .23661 L
.36044 .2364 L
Mfstroke
.2619 .01472 m
.27112 .02462 L
.28036 .03484 L
.28831 .04392 L
.29536 .0522 L
.30227 .06056 L
.3084 .06819 L
.3144 .07589 L
.31971 .08292 L
.32442 .08935 L
.32904 .09585 L
.33315 .10179 L
.33679 .10724 L
.34038 .11276 L
.34356 .11782 L
.34668 .12294 L
.34945 .12763 L
.35191 .13193 L
.35433 .1363 L
.35647 .1403 L
.35857 .14436 L
.36043 .14808 L
.36208 .1515 L
.36369 .15498 L
.36512 .15816 L
.36638 .1611 L
.36762 .16408 L
.36872 .16682 L
.36979 .1696 L
.37073 .17216 L
.37156 .17452 L
.37236 .17691 L
.37307 .17911 L
.37369 .18114 L
.3743 .18321 L
.37482 .18511 L
.37533 .18705 L
.37577 .18883 L
.37616 .19047 L
.37652 .19215 L
.37684 .19369 L
.37714 .19525 L
.37739 .1967 L
.37761 .19803 L
.37781 .19938 L
.37797 .20063 L
.37811 .20178 L
.37824 .20296 L
.37834 .20404 L
.37843 .20514 L
Mistroke
.37849 .20616 L
.37854 .20709 L
.37856 .2076 L
.37858 .20805 L
.37859 .20851 L
.3786 .20893 L
.3786 .20914 L
.37861 .20935 L
.37861 .20956 L
.37861 .20968 L
.37861 .20974 L
.37861 .2098 L
.37861 .20985 L
.37861 .2099 L
.37861 .20996 L
.37861 .20999 L
.37861 .21 L
.37861 .21002 L
.37861 .21004 L
.37861 .21007 L
.37861 .21009 L
.37861 .21011 L
.37861 .21014 L
.37861 .21017 L
.37861 .21019 L
.37861 .21022 L
.37861 .21027 L
.37861 .21032 L
.37861 .2104 L
.37861 .2105 L
.37861 .2106 L
.37861 .21081 L
.3786 .21099 L
.3786 .2114 L
.37859 .21177 L
.37857 .21216 L
.37854 .2129 L
.3785 .21358 L
.37846 .21421 L
.37841 .21485 L
.37835 .21545 L
.37829 .21605 L
.37822 .21661 L
.37815 .21713 L
.37807 .21766 L
.378 .21814 L
.37791 .21864 L
.37782 .2191 L
.37774 .21952 L
.37765 .21995 L
Mistroke
.37756 .22035 L
.37747 .22072 L
.37738 .22109 L
.37729 .22144 L
.37719 .2218 L
.37709 .22212 L
.377 .22243 L
.37691 .22273 L
.37681 .22302 L
.37672 .22331 L
.37662 .22358 L
.37653 .22383 L
.37643 .22408 L
.37634 .22431 L
.37626 .22453 L
.37617 .22475 L
.37608 .22496 L
.37599 .22516 L
.3759 .22536 L
.37582 .22554 L
.37573 .22572 L
.37565 .22589 L
.37557 .22604 L
.37549 .2262 L
.37541 .22635 L
.37533 .2265 L
.37526 .22664 L
.37519 .22677 L
.37518 .22677 L
Mfstroke
.2619 .60332 m
.25805 .58355 L
.25441 .56325 L
.25151 .54534 L
.24917 .5291 L
.24713 .51283 L
.24559 .49809 L
.24436 .48337 L
.2439 .47633 L
.24356 .47004 L
.24331 .46409 L
.24321 .46112 L
.24312 .45797 L
.24305 .45488 L
.24301 .45209 L
.243 .45077 L
.24299 .45007 L
.24298 .44933 L
.24298 .44863 L
.24298 .44799 L
.24298 .44768 L
.24297 .44735 L
.24297 .44704 L
.24297 .44675 L
.24297 .44639 L
.24297 .44604 L
.24297 .44574 L
.24297 .4454 L
.24298 .44504 L
.24298 .44465 L
.24298 .44397 L
.24298 .44334 L
.24299 .44275 L
.243 .44141 L
.24302 .43996 L
.24304 .43864 L
.2431 .43571 L
.24317 .43308 L
.24326 .43066 L
.24349 .42529 L
.24379 .42015 L
.24412 .41561 L
.24498 .40627 L
.24601 .39781 L
.24728 .38932 L
.24867 .38161 L
.25014 .37462 L
.25183 .36758 L
.25358 .36119 L
.25553 .35477 L
Mistroke
.2575 .34894 L
.25947 .34364 L
.26162 .3383 L
.26374 .33343 L
.26604 .32855 L
.26829 .32409 L
.27048 .32003 L
.27282 .31594 L
.27509 .31221 L
.27727 .30879 L
.27959 .30534 L
.28182 .30219 L
.28417 .29901 L
.28643 .2961 L
.28857 .29343 L
.29084 .29074 L
.29299 .28827 L
.29503 .286 L
.29717 .2837 L
.29921 .28159 L
.30133 .27945 L
.30334 .27749 L
.30524 .27568 L
.30722 .27385 L
.30909 .27216 L
.31104 .27045 L
.31287 .26888 L
.31459 .26743 L
.31638 .26596 L
.31807 .26461 L
.31965 .26336 L
.3213 .26208 L
.32284 .26091 L
.32444 .25971 L
.32594 .25861 L
.32734 .25759 L
.3288 .25655 L
.33016 .25559 L
.33143 .2547 L
.33275 .2538 L
.33399 .25296 L
.33527 .2521 L
.33646 .25131 L
.33758 .25058 L
.33873 .24983 L
.33981 .24914 L
.34092 .24843 L
.34195 .24778 L
.34292 .24717 L
.34392 .24655 L
Mistroke
.34485 .24598 L
.34572 .24545 L
.34662 .2449 L
.34746 .2444 L
.34832 .24388 L
.34912 .2434 L
.34987 .24296 L
.35064 .2425 L
.35136 .24208 L
.3521 .24164 L
.35279 .24124 L
.35343 .24087 L
.35409 .24049 L
.35471 .24013 L
.35528 .23981 L
.35587 .23947 L
.35642 .23915 L
.35698 .23883 L
.35751 .23853 L
.358 .23826 L
.3585 .23797 L
.35897 .23771 L
.3594 .23746 L
.35985 .23721 L
.36027 .23698 L
.3607 .23674 L
.3611 .23651 L
.36147 .23631 L
.36151 .23628 L
Mfstroke
.30952 .01472 m
.31604 .02398 L
.32253 .03358 L
.3281 .04215 L
.33301 .05 L
.33779 .05796 L
.34201 .06526 L
.3461 .07264 L
.34971 .07942 L
.35289 .08564 L
.35598 .09195 L
.35871 .09775 L
.36111 .10308 L
.36345 .1085 L
.3655 .11348 L
.3675 .11854 L
.36925 .12319 L
.37079 .12748 L
.37228 .13183 L
.37358 .13584 L
.37484 .13992 L
.37593 .14367 L
.37688 .14712 L
.3778 .15063 L
.37859 .15387 L
.37928 .15686 L
.37993 .1599 L
.38049 .1627 L
.38102 .16556 L
.38147 .16819 L
.38185 .17061 L
.3822 .17309 L
.3825 .17537 L
.38274 .17747 L
.38296 .17962 L
.38313 .1816 L
.38329 .18362 L
.3834 .18548 L
.38348 .1872 L
.38352 .18813 L
.38355 .18896 L
.38357 .1898 L
.38358 .19058 L
.38359 .19097 L
.38359 .19138 L
.3836 .19173 L
.3836 .19193 L
.3836 .19211 L
.3836 .19221 L
.3836 .1923 L
Mistroke
.3836 .19236 L
.3836 .19241 L
.3836 .19243 L
.3836 .19246 L
.3836 .19249 L
.3836 .19251 L
.3836 .19256 L
.3836 .1926 L
.3836 .19265 L
.3836 .1927 L
.3836 .19275 L
.3836 .1928 L
.3836 .19289 L
.3836 .19307 L
.3836 .19323 L
.38359 .19359 L
.38359 .19395 L
.38358 .19429 L
.38357 .19504 L
.38355 .19576 L
.38353 .1964 L
.38348 .19774 L
.38341 .19898 L
.38333 .20024 L
.38324 .20141 L
.38313 .2026 L
.38301 .2037 L
.3829 .20471 L
.38276 .20574 L
.38263 .2067 L
.38249 .20758 L
.38234 .20849 L
.3822 .20932 L
.38203 .21017 L
.38188 .21095 L
.38172 .21168 L
.38155 .21242 L
.38139 .2131 L
.38123 .21374 L
.38106 .21438 L
.3809 .21498 L
.38072 .21559 L
.38055 .21616 L
.38039 .21668 L
.38022 .21721 L
.38006 .2177 L
.37988 .21821 L
.37972 .21867 L
.37956 .2191 L
.37939 .21954 L
Mistroke
.37923 .21995 L
.37908 .22032 L
.37892 .2207 L
.37877 .22106 L
.37861 .22142 L
.37846 .22176 L
.37832 .22207 L
.37817 .22238 L
.37802 .22267 L
.37787 .22297 L
.37773 .22325 L
.3776 .22351 L
.37746 .22377 L
.37733 .22401 L
.37721 .22423 L
.37708 .22446 L
.37696 .22467 L
.37683 .22489 L
.37671 .22509 L
.3766 .22527 L
.37648 .22546 L
.37637 .22564 L
.37627 .2258 L
.37616 .22597 L
.37606 .22612 L
.37595 .22628 L
.37594 .2263 L
Mfstroke
.30952 .60332 m
.30512 .5848 L
.30077 .56566 L
.29712 .54865 L
.29397 .53314 L
.29102 .51749 L
.28854 .50324 L
.28627 .48891 L
.28443 .47587 L
.28296 .464 L
.28171 .45205 L
.28077 .44118 L
.28011 .43128 L
.27986 .42641 L
.27965 .42131 L
.27957 .41889 L
.2795 .4163 L
.27945 .41388 L
.27942 .41167 L
.27941 .41052 L
.2794 .40992 L
.2794 .40928 L
.27939 .40873 L
.27939 .40844 L
.27939 .40813 L
.27939 .40784 L
.27939 .40758 L
.27939 .40732 L
.27939 .40707 L
.27939 .40684 L
.27939 .40658 L
.27939 .40631 L
.27939 .40605 L
.27939 .40582 L
.27939 .4056 L
.27939 .40512 L
.27939 .40463 L
.2794 .40409 L
.2794 .40302 L
.27942 .40189 L
.27943 .40082 L
.27947 .39886 L
.27952 .39677 L
.27958 .39454 L
.27974 .39056 L
.27995 .38646 L
.28044 .37937 L
.2811 .37223 L
.28187 .36572 L
.28281 .35917 L
Mistroke
.28382 .35319 L
.28489 .34775 L
.28611 .34225 L
.28736 .33724 L
.28876 .33219 L
.29016 .32758 L
.29156 .32337 L
.29308 .31911 L
.29459 .31523 L
.29606 .31168 L
.29765 .30808 L
.2992 .30479 L
.30086 .30146 L
.30246 .29842 L
.304 .29563 L
.30565 .2928 L
.30722 .29021 L
.30873 .28784 L
.31033 .28543 L
.31185 .28321 L
.31345 .28097 L
.31498 .27891 L
.31643 .27701 L
.31796 .27509 L
.3194 .27332 L
.32091 .27153 L
.32235 .26988 L
.3237 .26836 L
.32511 .26681 L
.32645 .26539 L
.32771 .26409 L
.32902 .26275 L
.33025 .26152 L
.33154 .26027 L
.33275 .25912 L
.33389 .25806 L
.33507 .25697 L
.33618 .25597 L
.33722 .25505 L
.3383 .2541 L
.33932 .25323 L
.34037 .25234 L
.34136 .25152 L
.34228 .25076 L
.34324 .24999 L
.34413 .24927 L
.34506 .24854 L
.34593 .24786 L
.34674 .24724 L
.34758 .2466 L
Mistroke
.34836 .24601 L
.34909 .24546 L
.34985 .2449 L
.35056 .24438 L
.35129 .24385 L
.35197 .24336 L
.35261 .24291 L
.35327 .24244 L
.35388 .24201 L
.35451 .24157 L
.3551 .24116 L
.35565 .24078 L
.35622 .24039 L
.35675 .24003 L
.35724 .2397 L
.35775 .23936 L
.35823 .23904 L
.35871 .23871 L
.35917 .23841 L
.35959 .23813 L
.36003 .23785 L
.36044 .23758 L
.36082 .23733 L
.36121 .23708 L
.36157 .23685 L
.36195 .23661 L
.3623 .23638 L
.36261 .23618 L
Mfstroke
.35714 .01472 m
.36086 .02334 L
.36452 .03233 L
.36762 .04038 L
.37032 .0478 L
.37293 .05536 L
.37519 .06232 L
.37735 .06939 L
.37922 .07591 L
.38084 .08192 L
.38239 .08805 L
.38372 .0937 L
.38486 .0989 L
.38595 .10422 L
.38688 .10913 L
.38775 .11413 L
.38848 .11874 L
.3891 .123 L
.38966 .12735 L
.39013 .13136 L
.39055 .13545 L
.39089 .13923 L
.39116 .14271 L
.39138 .14627 L
.39155 .14956 L
.39166 .1526 L
.39171 .15411 L
.39175 .1557 L
.39176 .15646 L
.39177 .15728 L
.39178 .15804 L
.39178 .15838 L
.39179 .15874 L
.39179 .1591 L
.39179 .15926 L
.39179 .15943 L
.39179 .15959 L
.39179 .15975 L
.39179 .15984 L
.39179 .15992 L
.39179 .15999 L
.39179 .16008 L
.39179 .16017 L
.39179 .16022 L
.39179 .16026 L
.39179 .16035 L
.39179 .16043 L
.39179 .16048 L
.39179 .16054 L
.39179 .16059 L
Mistroke
.39179 .16064 L
.39179 .16073 L
.39179 .16082 L
.39179 .16101 L
.39179 .16119 L
.39179 .16152 L
.39179 .16184 L
.39178 .16219 L
.39178 .16289 L
.39177 .16354 L
.39176 .16413 L
.39173 .16548 L
.3917 .16667 L
.39162 .16917 L
.39151 .17148 L
.39138 .17384 L
.39123 .17602 L
.39106 .17803 L
.39088 .18009 L
.39068 .182 L
.39046 .18394 L
.39023 .18574 L
.39 .1874 L
.38975 .1891 L
.3895 .19067 L
.38923 .19228 L
.38896 .19376 L
.3887 .19513 L
.38841 .19653 L
.38814 .19782 L
.38787 .19902 L
.38758 .20024 L
.3873 .20138 L
.387 .20253 L
.38671 .2036 L
.38643 .20459 L
.38614 .2056 L
.38586 .20653 L
.38559 .2074 L
.3853 .20828 L
.38503 .2091 L
.38474 .20994 L
.38447 .21071 L
.3842 .21143 L
.38393 .21216 L
.38367 .21284 L
.38339 .21353 L
.38313 .21417 L
.38288 .21476 L
.38262 .21536 L
Mistroke
.38237 .21592 L
.38214 .21644 L
.38189 .21697 L
.38166 .21746 L
.38142 .21796 L
.38119 .21842 L
.38097 .21885 L
.38075 .21929 L
.38053 .2197 L
.38031 .22011 L
.3801 .2205 L
.3799 .22085 L
.3797 .22121 L
.3795 .22155 L
.37932 .22186 L
.37913 .22218 L
.37895 .22247 L
.37876 .22277 L
.37859 .22305 L
.37842 .22331 L
.37825 .22357 L
.37809 .22382 L
.37794 .22404 L
.37778 .22427 L
.37763 .22449 L
.37748 .22471 L
.37733 .22491 L
.3772 .2251 L
.37706 .22529 L
.37693 .22547 L
.37679 .22565 L
.37666 .22582 L
.37666 .22582 L
Mfstroke
.35714 .60332 m
.3523 .58607 L
.34736 .56811 L
.34306 .55203 L
.33921 .53728 L
.33544 .5223 L
.33211 .50858 L
.32888 .4947 L
.32607 .482 L
.32364 .47037 L
.32132 .4586 L
.31935 .44784 L
.31768 .438 L
.31614 .42804 L
.31487 .41892 L
.31373 .40973 L
.31283 .40132 L
.31214 .39364 L
.31159 .38587 L
.3112 .37877 L
.31106 .37503 L
.311 .37335 L
.31096 .3716 L
.31092 .37001 L
.31089 .36828 L
.31088 .36753 L
.31087 .36673 L
.31087 .36598 L
.31086 .3653 L
.31086 .36494 L
.31086 .36454 L
.31086 .36434 L
.31086 .36423 L
.31086 .36412 L
.31086 .36392 L
.31086 .36373 L
.31086 .36356 L
.31086 .36337 L
.31086 .3632 L
.31086 .36304 L
.31086 .36286 L
.31086 .36266 L
.31086 .3623 L
.31086 .36191 L
.31086 .36148 L
.31087 .36063 L
.31088 .35984 L
.31089 .35911 L
.31092 .35754 L
.31095 .35608 L
Mistroke
.31103 .35338 L
.31114 .35055 L
.31127 .348 L
.3116 .34276 L
.31206 .33747 L
.31258 .33264 L
.31315 .32821 L
.31383 .32374 L
.31454 .31964 L
.31528 .31589 L
.31611 .31209 L
.31694 .3086 L
.31787 .30508 L
.3188 .30185 L
.31971 .29889 L
.32071 .29589 L
.32169 .29314 L
.32264 .29061 L
.32367 .28805 L
.32466 .28569 L
.32573 .2833 L
.32676 .28111 L
.32774 .27909 L
.32879 .27704 L
.3298 .27516 L
.33087 .27325 L
.33188 .27149 L
.33285 .26988 L
.33388 .26824 L
.33485 .26673 L
.33578 .26533 L
.33675 .26392 L
.33767 .26261 L
.33863 .26129 L
.33955 .26006 L
.34041 .25894 L
.34131 .25779 L
.34216 .25673 L
.34297 .25575 L
.34381 .25476 L
.3446 .25384 L
.34542 .2529 L
.3462 .25204 L
.34693 .25124 L
.34769 .25042 L
.3484 .24967 L
.34914 .2489 L
.34984 .24819 L
.35049 .24754 L
.35117 .24687 L
Mistroke
.3518 .24625 L
.3524 .24568 L
.35301 .2451 L
.35359 .24455 L
.35419 .244 L
.35475 .24349 L
.35528 .24302 L
.35582 .24254 L
.35633 .24209 L
.35686 .24163 L
.35735 .24121 L
.35781 .24082 L
.35828 .24042 L
.35873 .24005 L
.35914 .23971 L
.35957 .23936 L
.35997 .23903 L
.36038 .2387 L
.36077 .23839 L
.36113 .2381 L
.3615 .23781 L
.36185 .23754 L
.36217 .23729 L
.36251 .23703 L
.36282 .23679 L
.36314 .23655 L
.36344 .23632 L
.36372 .23611 L
.36375 .23609 L
Mfstroke
.40476 .01472 m
.40557 .0227 L
.40631 .03107 L
.40687 .03862 L
.40731 .0456 L
.40768 .05275 L
.40795 .05938 L
.40805 .06265 L
.40814 .06614 L
.4082 .06943 L
.40823 .07097 L
.40825 .07241 L
.40826 .0739 L
.40827 .07526 L
.40828 .07603 L
.40828 .07675 L
.40829 .07752 L
.40829 .07795 L
.40829 .07814 L
.40829 .07834 L
.40829 .07853 L
.40829 .07863 L
.40829 .07873 L
.40829 .07892 L
.40829 .07909 L
.40829 .0792 L
.40829 .07931 L
.40829 .07942 L
.40829 .07952 L
.40829 .0797 L
.40829 .0798 L
.40829 .0799 L
.40829 .08026 L
.40829 .08046 L
.40829 .08065 L
.40828 .08135 L
.40828 .08198 L
.40828 .08266 L
.40827 .08403 L
.40825 .08548 L
.40824 .08679 L
.40819 .08969 L
.40813 .09229 L
.40806 .09506 L
.40788 .10034 L
.40767 .10523 L
.40743 .10976 L
.40714 .11441 L
.40683 .1187 L
.40648 .1231 L
Mistroke
.40611 .12717 L
.40573 .13094 L
.40532 .1348 L
.4049 .13838 L
.40444 .14203 L
.40398 .14541 L
.40353 .14854 L
.40304 .15175 L
.40256 .15472 L
.40209 .15746 L
.40158 .16028 L
.40109 .16289 L
.40057 .16555 L
.40006 .16802 L
.39957 .1703 L
.39905 .17264 L
.39855 .17481 L
.39806 .17681 L
.39755 .17887 L
.39706 .18077 L
.39654 .18271 L
.39604 .18451 L
.39556 .18618 L
.39506 .18789 L
.39458 .18947 L
.39407 .19109 L
.39359 .19258 L
.39314 .19397 L
.39265 .19538 L
.3922 .19669 L
.39176 .19791 L
.3913 .19915 L
.39087 .2003 L
.39042 .20148 L
.38999 .20257 L
.38958 .20357 L
.38915 .20461 L
.38875 .20556 L
.38837 .20645 L
.38797 .20735 L
.38759 .20819 L
.38719 .20905 L
.38682 .20985 L
.38647 .21058 L
.3861 .21133 L
.38575 .21203 L
.38539 .21274 L
.38505 .2134 L
.38473 .21402 L
.38439 .21464 L
Mistroke
.38408 .21522 L
.38378 .21575 L
.38347 .2163 L
.38318 .21681 L
.38288 .21733 L
.38259 .21781 L
.38232 .21826 L
.38205 .21871 L
.38178 .21914 L
.38151 .21957 L
.38126 .21997 L
.38102 .22034 L
.38077 .22071 L
.38053 .22106 L
.38031 .22139 L
.38008 .22172 L
.37987 .22203 L
.37965 .22234 L
.37944 .22264 L
.37924 .22291 L
.37904 .22318 L
.37885 .22344 L
.37867 .22367 L
.37849 .22392 L
.37831 .22414 L
.37813 .22437 L
.37797 .22459 L
.37781 .22478 L
.37765 .22499 L
.37749 .22517 L
.37734 .22535 L
Mfstroke
.40476 .60332 m
.39959 .58734 L
.39419 .57059 L
.38934 .55549 L
.3849 .54153 L
.38041 .52728 L
.37633 .51413 L
.37224 .50076 L
.36854 .48844 L
.36521 .4771 L
.36191 .46556 L
.35896 .45496 L
.35633 .4452 L
.35374 .43528 L
.35145 .42617 L
.34922 .41693 L
.34728 .40845 L
.34558 .40067 L
.34396 .39277 L
.34256 .38552 L
.34124 .37819 L
.34013 .37146 L
.33919 .3653 L
.33834 .35905 L
.33764 .35332 L
.33708 .34806 L
.3366 .34273 L
.33623 .33784 L
.33594 .33289 L
.33583 .3305 L
.33576 .32835 L
.3357 .32631 L
.33567 .32528 L
.33565 .32418 L
.33565 .32366 L
.33564 .32311 L
.33563 .32261 L
.33563 .32214 L
.33563 .32171 L
.33563 .32146 L
.33563 .32124 L
.33563 .321 L
.33563 .32087 L
.33562 .32074 L
.33562 .32063 L
.33562 .32051 L
.33562 .32039 L
.33562 .32027 L
.33562 .32014 L
.33562 .32007 L
Mistroke
.33563 .32001 L
.33563 .31977 L
.33563 .31963 L
.33563 .31948 L
.33563 .31922 L
.33563 .31871 L
.33564 .31824 L
.33565 .31735 L
.33566 .31642 L
.3357 .31454 L
.33576 .31283 L
.33591 .30931 L
.33613 .30575 L
.3364 .30248 L
.3367 .29949 L
.33706 .29644 L
.33744 .29365 L
.33784 .29108 L
.33829 .28847 L
.33875 .28607 L
.33927 .28364 L
.33979 .28141 L
.3403 .27935 L
.34086 .27726 L
.34142 .27534 L
.34202 .2734 L
.3426 .27161 L
.34317 .26996 L
.34378 .26828 L
.34438 .26674 L
.34495 .26533 L
.34556 .26388 L
.34614 .26255 L
.34676 .2612 L
.34736 .25995 L
.34793 .25881 L
.34853 .25764 L
.3491 .25656 L
.34964 .25557 L
.35022 .25456 L
.35076 .25362 L
.35133 .25267 L
.35188 .25179 L
.35239 .25098 L
.35293 .25016 L
.35344 .2494 L
.35397 .24862 L
.35448 .24791 L
.35495 .24724 L
.35545 .24657 L
Mistroke
.35591 .24595 L
.35635 .24537 L
.35681 .24478 L
.35724 .24424 L
.35769 .24369 L
.35811 .24318 L
.35851 .2427 L
.35892 .24222 L
.35931 .24177 L
.35971 .24132 L
.36009 .2409 L
.36045 .24051 L
.36081 .24011 L
.36116 .23974 L
.36148 .2394 L
.36182 .23905 L
.36213 .23873 L
.36245 .2384 L
.36276 .23809 L
.36304 .23781 L
.36334 .23752 L
.36361 .23726 L
.36387 .23701 L
.36414 .23675 L
.36439 .23652 L
.36465 .23628 L
.36489 .23606 L
.36492 .23603 L
Mfstroke
.45238 .01472 m
.45018 .02206 L
.4479 .02981 L
.44586 .03685 L
.44398 .0434 L
.44206 .05015 L
.44028 .05643 L
.43847 .06289 L
.43679 .06889 L
.43522 .07448 L
.43362 .08022 L
.43212 .08557 L
.43073 .09053 L
.42929 .09565 L
.42795 .1004 L
.42656 .10528 L
.42526 .10981 L
.42405 .11402 L
.42278 .11835 L
.4216 .12237 L
.42038 .12648 L
.41923 .13031 L
.41815 .13386 L
.41703 .13751 L
.41597 .14089 L
.41498 .14403 L
.41395 .14726 L
.41297 .15025 L
.41196 .15332 L
.41101 .15617 L
.41011 .15881 L
.40918 .16152 L
.4083 .16403 L
.40747 .16636 L
.40661 .16875 L
.4058 .17097 L
.40495 .17325 L
.40415 .17536 L
.4034 .17731 L
.40262 .17932 L
.40188 .18118 L
.40111 .18308 L
.40039 .18485 L
.3997 .18648 L
.39899 .18816 L
.39832 .18971 L
.39769 .19115 L
.39704 .19263 L
.39642 .194 L
.39578 .1954 L
Mistroke
.39517 .1967 L
.3946 .1979 L
.39401 .19913 L
.39345 .20028 L
.39287 .20144 L
.39232 .20253 L
.39181 .20353 L
.39128 .20456 L
.39078 .20551 L
.3903 .20639 L
.38981 .20729 L
.38935 .20813 L
.38887 .20898 L
.38842 .20978 L
.388 .21051 L
.38756 .21126 L
.38715 .21196 L
.38676 .2126 L
.38635 .21327 L
.38598 .21388 L
.38558 .21451 L
.38521 .21509 L
.38487 .21563 L
.38451 .21618 L
.38417 .21669 L
.38382 .21721 L
.3835 .2177 L
.38319 .21815 L
.38287 .2186 L
.38257 .21903 L
.38229 .21942 L
.382 .21983 L
.38173 .2202 L
.38145 .22058 L
.38118 .22094 L
.38094 .22127 L
.38068 .2216 L
.38044 .22192 L
.38022 .2222 L
.37998 .2225 L
.37976 .22277 L
.37954 .22306 L
.37933 .22332 L
.37913 .22356 L
.37892 .2238 L
.37873 .22403 L
.37853 .22427 L
.37835 .22449 L
.37818 .22469 L
.378 .22489 L
Mistroke
Mfstroke
.45238 .60332 m
.447 .58862 L
.44125 .5731 L
.43599 .55901 L
.43106 .5459 L
.42597 .53243 L
.42124 .51991 L
.41639 .5071 L
.41191 .49522 L
.40777 .48423 L
.40356 .47297 L
.39969 .46257 L
.39615 .45295 L
.39257 .44312 L
.38931 .43404 L
.38604 .42479 L
.38307 .41626 L
.38039 .4084 L
.37771 .40038 L
.3753 .39301 L
.37292 .38551 L
.37078 .37861 L
.36888 .37226 L
.367 .36581 L
.36534 .35988 L
.36387 .35442 L
.36243 .34886 L
.36116 .34376 L
.35994 .33858 L
.35888 .33381 L
.35795 .32944 L
.35707 .32499 L
.35632 .32091 L
.35567 .31715 L
.35507 .31333 L
.35456 .30982 L
.35409 .30625 L
.35372 .30298 L
.35341 .29997 L
.35315 .29691 L
.35295 .2941 L
.35279 .29125 L
.35273 .28987 L
.35269 .28863 L
.35265 .28744 L
.35264 .28685 L
.35263 .28622 L
.35262 .2856 L
.35261 .28503 L
.35261 .28477 L
Mistroke
.35261 .28462 L
.35261 .28447 L
.35261 .28433 L
.35261 .2842 L
.35261 .28414 L
.35261 .28407 L
.35261 .28401 L
.35261 .28395 L
.35261 .28388 L
.35261 .28381 L
.35261 .28374 L
.35261 .2837 L
.35261 .28366 L
.35261 .2836 L
.35261 .28353 L
.35261 .28346 L
.35261 .28339 L
.35261 .28324 L
.35261 .2831 L
.35261 .28279 L
.35261 .28251 L
.35262 .28221 L
.35262 .2816 L
.35263 .28103 L
.35265 .28051 L
.35268 .27938 L
.35271 .27837 L
.35276 .27729 L
.35288 .27526 L
.35301 .27338 L
.35317 .27166 L
.35335 .2699 L
.35355 .26828 L
.35378 .26664 L
.35401 .26513 L
.35425 .26374 L
.35452 .26233 L
.35479 .26103 L
.35505 .25983 L
.35534 .25861 L
.35563 .25748 L
.35594 .25634 L
.35624 .25528 L
.35654 .25431 L
.35686 .25332 L
.35716 .2524 L
.35749 .25148 L
.35781 .25062 L
.35811 .24983 L
.35844 .24903 L
Mistroke
.35875 .24829 L
.35905 .2476 L
.35936 .2469 L
.35966 .24626 L
.35997 .2456 L
.36028 .245 L
.36056 .24444 L
.36086 .24387 L
.36115 .24335 L
.36145 .24281 L
.36173 .24232 L
.362 .24186 L
.36228 .24139 L
.36255 .24096 L
.3628 .24057 L
.36306 .24016 L
.36331 .23978 L
.36357 .2394 L
.36381 .23905 L
.36404 .23872 L
.36428 .23839 L
.3645 .23808 L
.36471 .23779 L
.36493 .2375 L
.36514 .23723 L
.36536 .23696 L
.36556 .2367 L
.36575 .23647 L
.36595 .23623 L
.36613 .236 L
.36614 .23599 L
Mfstroke
.5 .01472 m
.4947 .02142 L
.4893 .02855 L
.48458 .03508 L
.48031 .0412 L
.47605 .04754 L
.4722 .05349 L
.46834 .05963 L
.46484 .06538 L
.46165 .07075 L
.45845 .07631 L
.45552 .0815 L
.45285 .08634 L
.45014 .09135 L
.44766 .09602 L
.44514 .10084 L
.44283 .10533 L
.4407 .10952 L
.43853 .11383 L
.43654 .11785 L
.4345 .12199 L
.43262 .12584 L
.43088 .12943 L
.4291 .13311 L
.42745 .13655 L
.42592 .13974 L
.42435 .14303 L
.42289 .14608 L
.42139 .14922 L
.42 .15214 L
.4187 .15486 L
.41736 .15764 L
.41611 .16024 L
.41495 .16264 L
.41375 .16512 L
.41263 .16742 L
.41147 .16978 L
.41039 .17197 L
.40938 .17401 L
.40834 .1761 L
.40736 .17804 L
.40636 .18003 L
.40541 .18188 L
.40453 .18359 L
.40362 .18535 L
.40276 .18698 L
.40196 .18849 L
.40113 .19005 L
.40036 .19149 L
.39955 .19296 L
Mistroke
.3988 .19433 L
.39809 .1956 L
.39736 .19691 L
.39668 .19812 L
.39597 .19935 L
.3953 .2005 L
.39468 .20156 L
.39404 .20265 L
.39343 .20366 L
.39287 .2046 L
.39228 .20556 L
.39173 .20645 L
.39116 .20736 L
.39062 .20821 L
.39012 .20899 L
.38961 .20979 L
.38912 .21054 L
.38866 .21123 L
.38819 .21193 L
.38775 .21259 L
.38729 .21326 L
.38686 .21388 L
.38646 .21446 L
.38605 .21505 L
.38566 .2156 L
.38525 .21616 L
.38487 .21668 L
.38452 .21716 L
.38416 .21765 L
.38381 .21811 L
.38349 .21853 L
.38316 .21897 L
.38285 .21937 L
.38253 .21978 L
.38223 .22017 L
.38194 .22052 L
.38165 .22088 L
.38138 .22122 L
.38112 .22153 L
.38086 .22185 L
.38061 .22215 L
.38036 .22245 L
.38012 .22273 L
.3799 .22299 L
.37966 .22326 L
.37945 .22351 L
.37922 .22376 L
.37902 .22399 L
.37882 .22421 L
.37862 .22443 L
Mistroke
Mfstroke
.5 .60332 m
.49452 .58991 L
.48856 .57565 L
.483 .56261 L
.47771 .5504 L
.47215 .53775 L
.46689 .52593 L
.4614 .51375 L
.45624 .50238 L
.45139 .49178 L
.44637 .48087 L
.44168 .47073 L
.4373 .4613 L
.4328 .4516 L
.42863 .4426 L
.42436 .43338 L
.42041 .42484 L
.41677 .41693 L
.41307 .40883 L
.40966 .40134 L
.40622 .39369 L
.40307 .38663 L
.40019 .38011 L
.39729 .37345 L
.39464 .36731 L
.39224 .36165 L
.38982 .35587 L
.38764 .35054 L
.38545 .34511 L
.38348 .34012 L
.3817 .33551 L
.37993 .33082 L
.37834 .32651 L
.37692 .32253 L
.3755 .31848 L
.37424 .31475 L
.37299 .31096 L
.37188 .30748 L
.3709 .30427 L
.36993 .301 L
.36908 .298 L
.36825 .29495 L
.36753 .29214 L
.36689 .28956 L
.36628 .28694 L
.36574 .28453 L
.36528 .28231 L
.36484 .28005 L
.36446 .27797 L
.36411 .27586 L
Mistroke
.36381 .27391 L
.36356 .27213 L
.36333 .27031 L
.36314 .26864 L
.36297 .26694 L
.36285 .26538 L
.36275 .26394 L
.36267 .26248 L
.36264 .26178 L
.36262 .26113 L
.3626 .26053 L
.36259 .2599 L
.36258 .25957 L
.36258 .25941 L
.36258 .25923 L
.36258 .25907 L
.36258 .25899 L
.36258 .2589 L
.36258 .25882 L
.36258 .25875 L
.36258 .25868 L
.36258 .25865 L
.36258 .25861 L
.36258 .25859 L
.36258 .25857 L
.36258 .25853 L
.36258 .25849 L
.36258 .25847 L
.36258 .25845 L
.36258 .25841 L
.36258 .25837 L
.36258 .2583 L
.36258 .25823 L
.36258 .25815 L
.36258 .25802 L
.36258 .25786 L
.36258 .2577 L
.36259 .2574 L
.36259 .25713 L
.3626 .25684 L
.36261 .25633 L
.36263 .25578 L
.36265 .25521 L
.3627 .25422 L
.36277 .25321 L
.36284 .25228 L
.36294 .25133 L
.36303 .25046 L
.36314 .24966 L
.36325 .24884 L
Mistroke
.36337 .24809 L
.36349 .2474 L
.36363 .24669 L
.36376 .24604 L
.36391 .24537 L
.36405 .24476 L
.36419 .2442 L
.36434 .24362 L
.36449 .24309 L
.36465 .24255 L
.3648 .24206 L
.36495 .2416 L
.36511 .24113 L
.36526 .2407 L
.36541 .2403 L
.36557 .23989 L
.36572 .23952 L
.36588 .23914 L
.36603 .23878 L
.36617 .23846 L
.36632 .23813 L
.36647 .23782 L
.3666 .23754 L
.36675 .23725 L
.36689 .23698 L
.36703 .23671 L
.36717 .23645 L
.3673 .23622 L
.36742 .23599 L
Mfstroke
.54762 .01472 m
.53911 .02078 L
.53051 .02729 L
.52303 .03331 L
.51633 .039 L
.50967 .04494 L
.50369 .05054 L
.49776 .05637 L
.49241 .06186 L
.48758 .06702 L
.48276 .07239 L
.47839 .07742 L
.47443 .08215 L
.47044 .08705 L
.46682 .09165 L
.46318 .0964 L
.45986 .10085 L
.45682 .10501 L
.45376 .10932 L
.45095 .11334 L
.44811 .11749 L
.44551 .12137 L
.44312 .12499 L
.4407 .12872 L
.43846 .1322 L
.43641 .13545 L
.43431 .13879 L
.43237 .14192 L
.43039 .14513 L
.42857 .14812 L
.42688 .15091 L
.42515 .15377 L
.42355 .15644 L
.42206 .15893 L
.42053 .16149 L
.41912 .16387 L
.41766 .16632 L
.41631 .16859 L
.41506 .17071 L
.41376 .17288 L
.41256 .17491 L
.41132 .17698 L
.41017 .17891 L
.4091 .1807 L
.40799 .18254 L
.40696 .18425 L
.406 .18583 L
.405 .18747 L
.40407 .18898 L
.40312 .19053 L
Mistroke
.40222 .19197 L
.40139 .19331 L
.40053 .19469 L
.39972 .19596 L
.39889 .19727 L
.39812 .19848 L
.39739 .1996 L
.39664 .20076 L
.39594 .20182 L
.39528 .20282 L
.39461 .20384 L
.39397 .20478 L
.39332 .20575 L
.3927 .20664 L
.39213 .20748 L
.39154 .20833 L
.39098 .20912 L
.39047 .20985 L
.38993 .21061 L
.38943 .21131 L
.38891 .21202 L
.38842 .21269 L
.38797 .2133 L
.3875 .21393 L
.38706 .21452 L
.3866 .21512 L
.38618 .21567 L
.38578 .21618 L
.38537 .21671 L
.38499 .2172 L
.38463 .21765 L
.38426 .21812 L
.38391 .21855 L
.38355 .21899 L
.38321 .2194 L
.3829 .21978 L
.38258 .22017 L
.38227 .22053 L
.38199 .22086 L
.38169 .2212 L
.38142 .22152 L
.38114 .22185 L
.38087 .22215 L
.38062 .22243 L
.38037 .22272 L
.38013 .22298 L
.37988 .22325 L
.37965 .22351 L
.37944 .22374 L
.37922 .22398 L
Mistroke
Mfstroke
.54762 .60332 m
.54215 .59121 L
.53611 .57824 L
.53039 .56629 L
.52486 .55502 L
.51897 .54327 L
.51331 .5322 L
.50733 .52072 L
.50161 .50993 L
.49617 .49981 L
.49045 .48932 L
.48504 .4795 L
.47993 .47032 L
.4746 .46082 L
.46959 .45195 L
.46439 .44282 L
.45952 .43431 L
.45498 .42639 L
.45028 .41824 L
.44592 .41066 L
.44144 .4029 L
.43728 .39569 L
.43344 .389 L
.4295 .38216 L
.42587 .37581 L
.42253 .36994 L
.41912 .36393 L
.41598 .35836 L
.41281 .35269 L
.40989 .34744 L
.40723 .34259 L
.40453 .33765 L
.40207 .33308 L
.39982 .32887 L
.39755 .32456 L
.39549 .3206 L
.39341 .31655 L
.39153 .31283 L
.38982 .3094 L
.38811 .3059 L
.38656 .30267 L
.38501 .2994 L
.38361 .29638 L
.38236 .29361 L
.3811 .29078 L
.37997 .28818 L
.37896 .28579 L
.37795 .28335 L
.37705 .2811 L
.37615 .27882 L
Mistroke
.37535 .27672 L
.37464 .27479 L
.37394 .27283 L
.37331 .27102 L
.3727 .26918 L
.37216 .26749 L
.37168 .26594 L
.37121 .26436 L
.3708 .26291 L
.37044 .26157 L
.37009 .26021 L
.36978 .25896 L
.36949 .25769 L
.36923 .25652 L
.36901 .25544 L
.3688 .25434 L
.36862 .25334 L
.36847 .25241 L
.36833 .25146 L
.36821 .25059 L
.3681 .24971 L
.36801 .24889 L
.36794 .24814 L
.36788 .24738 L
.36783 .24667 L
.3678 .24596 L
.36778 .24561 L
.36777 .2453 L
.36776 .245 L
.36776 .24485 L
.36776 .24469 L
.36776 .24454 L
.36776 .2444 L
.36775 .24433 L
.36775 .24429 L
.36775 .24425 L
.36775 .24422 L
.36775 .24419 L
.36775 .24417 L
.36775 .24415 L
.36775 .24414 L
.36775 .24412 L
.36775 .2441 L
.36775 .24409 L
.36775 .24407 L
.36775 .24406 L
.36775 .24405 L
.36775 .24403 L
.36775 .24402 L
.36775 .244 L
Mistroke
.36775 .24398 L
.36775 .24394 L
.36775 .24391 L
.36775 .24383 L
.36776 .24375 L
.36776 .24367 L
.36776 .24353 L
.36776 .24338 L
.36776 .24325 L
.36777 .24297 L
.36778 .24271 L
.36779 .24244 L
.36781 .24192 L
.36785 .24144 L
.36788 .241 L
.36792 .24055 L
.36797 .24014 L
.36802 .23972 L
.36807 .23933 L
.36813 .23897 L
.36819 .23861 L
.36825 .23827 L
.36831 .23796 L
.36838 .23765 L
.36844 .23736 L
.36851 .23706 L
.36858 .23679 L
.36865 .23653 L
.36872 .23627 L
.36879 .23604 L
Mfstroke
.59524 .01472 m
.58342 .02014 L
.57152 .02604 L
.56121 .03154 L
.55201 .0368 L
.54291 .04233 L
.53477 .0476 L
.52672 .05311 L
.51951 .05835 L
.51302 .0633 L
.50656 .06847 L
.50074 .07335 L
.49548 .07795 L
.49021 .08275 L
.48545 .08727 L
.48068 .09196 L
.47635 .09637 L
.47242 .10051 L
.46846 .1048 L
.46485 .10883 L
.46122 .113 L
.45791 .1169 L
.45488 .12055 L
.45182 .12432 L
.44902 .12786 L
.44644 .13115 L
.44383 .13457 L
.44143 .13775 L
.43899 .14104 L
.43674 .1441 L
.43467 .14696 L
.43256 .14991 L
.43062 .15266 L
.42882 .15522 L
.42698 .15786 L
.42528 .16033 L
.42354 .16286 L
.42192 .16522 L
.42043 .16741 L
.4189 .16968 L
.41748 .17178 L
.41602 .17394 L
.41467 .17595 L
.41341 .17782 L
.41212 .17974 L
.41092 .18153 L
.4098 .18319 L
.40865 .1849 L
.40758 .18648 L
.40648 .18811 L
Mistroke
.40546 .18963 L
.4045 .19103 L
.40352 .19248 L
.4026 .19382 L
.40165 .19519 L
.40077 .19647 L
.39995 .19765 L
.3991 .19887 L
.3983 .2 L
.39757 .20105 L
.3968 .20212 L
.39609 .20312 L
.39535 .20414 L
.39467 .20509 L
.39403 .20597 L
.39336 .20688 L
.39274 .20772 L
.39217 .20849 L
.39157 .20929 L
.39101 .21003 L
.39043 .21079 L
.3899 .2115 L
.38939 .21215 L
.38887 .21282 L
.38838 .21344 L
.38788 .21408 L
.38741 .21467 L
.38698 .21522 L
.38652 .21578 L
.3861 .2163 L
.3857 .21678 L
.3853 .21728 L
.38491 .21774 L
.38452 .21821 L
.38415 .21864 L
.38381 .21905 L
.38345 .21946 L
.38312 .21985 L
.38281 .2202 L
.38249 .22057 L
.38219 .22091 L
.38188 .22125 L
.38159 .22158 L
.38132 .22188 L
.38104 .22218 L
.38078 .22247 L
.38051 .22276 L
.38026 .22303 L
.38002 .22328 L
.37978 .22353 L
Mistroke
Mfstroke
.59524 .60332 m
.5899 .59252 L
.58391 .58086 L
.57817 .57004 L
.57255 .55977 L
.56648 .54898 L
.56057 .53874 L
.55424 .52804 L
.54812 .51792 L
.54222 .50835 L
.53596 .49836 L
.52995 .48895 L
.52422 .4801 L
.51817 .47088 L
.51242 .46221 L
.5064 .45324 L
.50069 .44482 L
.4953 .43694 L
.48969 .42879 L
.48441 .42117 L
.47894 .41332 L
.47381 .40599 L
.46901 .39917 L
.46406 .39214 L
.45945 .38561 L
.45516 .37953 L
.45074 .37329 L
.44664 .36749 L
.44245 .36155 L
.43857 .35604 L
.43498 .35094 L
.43131 .34572 L
.42794 .34088 L
.42482 .33641 L
.42165 .33183 L
.41874 .32759 L
.41578 .32327 L
.41307 .31928 L
.41058 .31559 L
.40806 .31183 L
.40576 .30836 L
.40344 .30482 L
.40131 .30156 L
.39938 .29856 L
.39743 .2955 L
.39565 .29268 L
.39403 .29008 L
.3924 .28743 L
.39092 .28499 L
.38944 .28251 L
Mistroke
.38809 .28023 L
.38687 .27812 L
.38565 .27598 L
.38454 .27401 L
.38343 .27201 L
.38243 .27017 L
.38153 .26848 L
.38063 .26676 L
.37982 .26518 L
.37909 .26372 L
.37836 .26224 L
.37771 .26087 L
.37706 .25949 L
.37648 .25821 L
.37596 .25704 L
.37544 .25585 L
.37498 .25475 L
.37456 .25374 L
.37415 .25272 L
.37379 .25177 L
.37343 .25081 L
.37311 .24993 L
.37283 .24912 L
.37255 .24829 L
.3723 .24753 L
.37206 .24675 L
.37185 .24604 L
.37167 .24539 L
.37149 .24473 L
.37133 .24411 L
.37119 .24355 L
.37106 .24298 L
.37095 .24245 L
.37084 .24191 L
.37074 .24142 L
.37066 .24096 L
.37059 .2405 L
.37053 .24007 L
.37047 .23968 L
.37043 .23928 L
.37039 .23891 L
.37035 .23854 L
.37032 .23819 L
.3703 .23787 L
.37029 .23755 L
.37028 .2374 L
.37028 .23725 L
.37027 .23709 L
.37027 .23702 L
.37027 .23695 L
Mistroke
.37027 .23687 L
.37027 .23681 L
.37027 .23677 L
.37027 .23674 L
.37027 .23672 L
.37027 .23671 L
.37027 .2367 L
.37027 .23669 L
.37027 .23669 L
.37027 .23668 L
.37027 .23667 L
.37027 .23667 L
.37027 .23666 L
.37027 .23665 L
.37027 .23664 L
.37027 .23664 L
.37027 .23663 L
.37027 .23661 L
.37027 .23659 L
.37027 .23656 L
.37027 .23653 L
.37027 .2365 L
.37027 .23647 L
.37027 .2364 L
.37027 .23633 L
.37027 .23627 L
.37027 .23615 L
Mfstroke
.64286 .01472 m
.62762 .0195 L
.61234 .02478 L
.59913 .02977 L
.58737 .03459 L
.57578 .03973 L
.56543 .04465 L
.55524 .04986 L
.54612 .05483 L
.53795 .05957 L
.52985 .06455 L
.52256 .06928 L
.516 .07376 L
.50946 .07846 L
.50355 .0829 L
.49766 .08753 L
.49233 .09189 L
.4875 .09601 L
.48265 .10029 L
.47825 .10433 L
.47384 .10851 L
.46983 .11243 L
.46617 .11612 L
.46249 .11994 L
.45912 .12352 L
.45604 .12687 L
.45293 .13035 L
.45007 .1336 L
.44718 .13695 L
.44453 .14009 L
.44209 .14303 L
.43961 .14605 L
.43733 .14888 L
.43523 .15152 L
.43309 .15425 L
.43111 .15679 L
.4291 .15941 L
.42724 .16186 L
.42552 .16413 L
.42375 .16648 L
.42213 .16867 L
.42046 .17091 L
.41892 .173 L
.41749 .17495 L
.41602 .17696 L
.41466 .17882 L
.4134 .18055 L
.4121 .18234 L
.41089 .184 L
.40966 .18571 L
Mistroke
.4085 .18729 L
.40743 .18876 L
.40633 .19028 L
.4053 .19169 L
.40425 .19313 L
.40327 .19447 L
.40235 .19572 L
.40141 .197 L
.40053 .19818 L
.39972 .19929 L
.39887 .20042 L
.39808 .20147 L
.39727 .20255 L
.39652 .20355 L
.39581 .20448 L
.39508 .20544 L
.39441 .20632 L
.39377 .20714 L
.39312 .20799 L
.39251 .20877 L
.39187 .20958 L
.39129 .21032 L
.39074 .21101 L
.39017 .21172 L
.38964 .21238 L
.38909 .21305 L
.38858 .21368 L
.3881 .21426 L
.38761 .21486 L
.38715 .21541 L
.38672 .21592 L
.38628 .21644 L
.38587 .21693 L
.38544 .21743 L
.38504 .21789 L
.38467 .21832 L
.38428 .21876 L
.38392 .21917 L
.38359 .21955 L
.38324 .21994 L
.38291 .2203 L
.38258 .22067 L
.38227 .22101 L
.38197 .22133 L
.38167 .22166 L
.38139 .22196 L
.3811 .22227 L
.38083 .22255 L
.38058 .22282 L
.38032 .22309 L
Mistroke
Mfstroke
.64286 .60332 m
.63776 .59383 L
.63198 .58352 L
.62636 .57388 L
.62079 .56466 L
.6147 .5549 L
.60871 .54557 L
.60222 .53575 L
.59586 .52637 L
.58967 .51745 L
.58303 .50808 L
.57659 .49917 L
.57038 .49073 L
.56377 .48189 L
.55742 .47352 L
.55069 .46478 L
.54426 .45654 L
.53814 .44877 L
.53169 .44069 L
.52558 .43308 L
.51919 .4252 L
.51314 .41781 L
.50744 .41088 L
.5015 .40371 L
.49593 .39701 L
.4907 .39075 L
.48527 .38428 L
.4802 .37825 L
.47498 .37205 L
.4701 .36628 L
.46556 .3609 L
.46089 .35539 L
.45655 .35026 L
.45253 .3455 L
.44841 .34062 L
.44458 .33609 L
.44068 .33145 L
.43708 .32716 L
.43375 .32319 L
.43036 .31912 L
.42724 .31537 L
.42407 .31153 L
.42115 .30799 L
.41847 .30472 L
.41575 .30139 L
.41326 .29831 L
.41097 .29547 L
.40865 .29257 L
.40653 .2899 L
.40439 .28718 L
Mistroke
.40243 .28467 L
.40064 .28236 L
.39883 .28001 L
.39718 .27785 L
.39552 .27565 L
.39401 .27362 L
.39263 .27176 L
.39125 .26986 L
.38999 .26812 L
.38884 .26651 L
.38769 .26488 L
.38664 .26338 L
.38559 .26185 L
.38464 .26045 L
.38378 .25916 L
.38291 .25784 L
.38213 .25664 L
.38142 .25553 L
.38071 .2544 L
.38006 .25336 L
.37942 .2523 L
.37884 .25133 L
.37832 .25044 L
.37779 .24953 L
.37732 .2487 L
.37685 .24785 L
.37643 .24708 L
.37605 .24636 L
.37567 .24563 L
.37533 .24497 L
.37502 .24435 L
.37472 .24373 L
.37445 .24315 L
.37418 .24257 L
.37394 .24203 L
.37372 .24154 L
.37351 .24103 L
.37332 .24057 L
.37315 .24015 L
.37299 .23971 L
.37284 .23932 L
.37269 .23891 L
.37256 .23854 L
.37245 .2382 L
.37234 .23785 L
.37224 .23753 L
.37214 .2372 L
.37206 .2369 L
.37198 .23663 L
.37191 .23635 L
Mistroke
Mfstroke
.69048 .01472 m
.67173 .01886 L
.65296 .02352 L
.63678 .02801 L
.62241 .03239 L
.60827 .03712 L
.59568 .04171 L
.58331 .0466 L
.57227 .05132 L
.5624 .05584 L
.55263 .06064 L
.54387 .06521 L
.53601 .06958 L
.52818 .07417 L
.52113 .07853 L
.51412 .0831 L
.50779 .08743 L
.50207 .09152 L
.49635 .09579 L
.49117 .09983 L
.48598 .10403 L
.48128 .10798 L
.477 .1117 L
.47271 .11556 L
.46879 .11919 L
.46522 .1226 L
.46161 .12614 L
.45831 .12945 L
.45498 .13288 L
.45194 .1361 L
.44914 .1391 L
.44631 .14221 L
.44371 .14512 L
.44132 .14784 L
.43888 .15065 L
.43664 .15328 L
.43436 .15598 L
.43226 .15851 L
.43032 .16087 L
.42834 .1633 L
.42652 .16557 L
.42465 .1679 L
.42293 .17007 L
.42133 .1721 L
.4197 .17419 L
.41819 .17613 L
.41679 .17794 L
.41535 .1798 L
.41401 .18153 L
.41264 .18331 L
Mistroke
.41137 .18497 L
.41019 .18651 L
.40898 .1881 L
.40785 .18957 L
.4067 .19108 L
.40562 .19249 L
.40462 .1938 L
.40359 .19514 L
.40263 .19639 L
.40174 .19754 L
.40082 .19874 L
.39997 .19984 L
.39908 .20098 L
.39826 .20203 L
.3975 .20301 L
.39671 .20401 L
.39597 .20494 L
.39528 .20581 L
.39458 .2067 L
.39392 .20752 L
.39323 .20837 L
.3926 .20916 L
.39201 .20989 L
.39139 .21064 L
.39082 .21133 L
.39023 .21204 L
.38968 .2127 L
.38917 .21331 L
.38864 .21394 L
.38815 .21453 L
.38769 .21507 L
.38721 .21562 L
.38677 .21614 L
.38631 .21666 L
.38588 .21715 L
.38548 .21761 L
.38507 .21807 L
.38468 .21851 L
.38432 .21891 L
.38395 .21932 L
.3836 .2197 L
.38325 .22009 L
.38291 .22045 L
.3826 .22079 L
.38228 .22114 L
.38198 .22146 L
.38167 .22178 L
.38138 .22209 L
.38111 .22237 L
.38083 .22265 L
Mistroke
Mfstroke
.69048 .60332 m
.68574 .59516 L
.68031 .58623 L
.67496 .57781 L
.6696 .56969 L
.66368 .56104 L
.65779 .55271 L
.65134 .54386 L
.64495 .53535 L
.63867 .52718 L
.63185 .51853 L
.62518 .51025 L
.61868 .50235 L
.61169 .49399 L
.60491 .48603 L
.59767 .47766 L
.59068 .4697 L
.58396 .46214 L
.57683 .45422 L
.57 .44672 L
.56279 .43889 L
.55593 .43149 L
.5494 .42452 L
.54255 .41726 L
.53606 .41043 L
.52993 .40402 L
.52353 .39736 L
.51749 .39112 L
.51123 .38466 L
.50535 .37863 L
.49984 .37298 L
.49413 .36716 L
.4888 .36173 L
.48382 .35667 L
.47869 .35145 L
.4739 .3466 L
.46899 .34162 L
.46442 .33699 L
.46018 .33269 L
.45584 .32828 L
.45182 .32419 L
.44771 .32001 L
.44391 .31614 L
.4404 .31256 L
.43683 .3089 L
.43353 .30551 L
.43049 .30238 L
.4274 .29918 L
.42455 .29623 L
.42166 .29322 L
Mistroke
.419 .29044 L
.41656 .28787 L
.41409 .28526 L
.41182 .28285 L
.40952 .2804 L
.40742 .27815 L
.4055 .27607 L
.40355 .27396 L
.40177 .27201 L
.40014 .27022 L
.3985 .2684 L
.397 .26672 L
.39548 .26501 L
.3941 .26344 L
.39284 .262 L
.39157 .26054 L
.39041 .25919 L
.38936 .25795 L
.3883 .25669 L
.38733 .25553 L
.38635 .25435 L
.38547 .25327 L
.38466 .25227 L
.38385 .25126 L
.38312 .25033 L
.38238 .24939 L
.38171 .24852 L
.3811 .24773 L
.38049 .24692 L
.37994 .24618 L
.37944 .24549 L
.37894 .2448 L
.37848 .24416 L
.37802 .24352 L
.37761 .24292 L
.37724 .24238 L
.37687 .24182 L
.37653 .24131 L
.37622 .24084 L
.37592 .24037 L
.37564 .23993 L
.37537 .23948 L
.37512 .23907 L
.3749 .2387 L
.37467 .23832 L
.37447 .23797 L
.37427 .23761 L
.3741 .23728 L
.37393 .23698 L
.37378 .23668 L
Mistroke
Mfstroke
.7381 .01472 m
.71573 .01822 L
.6934 .02226 L
.67417 .02624 L
.65712 .03019 L
.64038 .03452 L
.62552 .03876 L
.61093 .04335 L
.59795 .04781 L
.58636 .05212 L
.57491 .05673 L
.56468 .06115 L
.5555 .0654 L
.54639 .06988 L
.5382 .07417 L
.53007 .07868 L
.52275 .08297 L
.51615 .08704 L
.50956 .0913 L
.5036 .09534 L
.49765 .09956 L
.49227 .10354 L
.48739 .10729 L
.48249 .1112 L
.47804 .11489 L
.47398 .11835 L
.4699 .12195 L
.46617 .12533 L
.46241 .12883 L
.45898 .13212 L
.45584 .1352 L
.45267 .13839 L
.44975 .14138 L
.44708 .14418 L
.44437 .14707 L
.44188 .14978 L
.43934 .15257 L
.43701 .15518 L
.43487 .15762 L
.43268 .16014 L
.43066 .16249 L
.42861 .16491 L
.42671 .16716 L
.42496 .16927 L
.42317 .17144 L
.42151 .17346 L
.41998 .17534 L
.4184 .17728 L
.41695 .17908 L
.41546 .18094 L
Mistroke
.41408 .18267 L
.41279 .18428 L
.41148 .18594 L
.41025 .18748 L
.409 .18906 L
.40784 .19053 L
.40676 .19189 L
.40564 .1933 L
.40461 .1946 L
.40365 .19582 L
.40266 .19707 L
.40174 .19822 L
.40079 .19941 L
.3999 .20052 L
.39908 .20155 L
.39824 .2026 L
.39745 .20358 L
.39671 .20449 L
.39595 .20542 L
.39524 .20629 L
.39452 .20718 L
.39384 .20801 L
.3932 .20877 L
.39255 .20956 L
.39194 .21029 L
.39131 .21104 L
.39073 .21174 L
.39018 .21238 L
.38962 .21304 L
.38909 .21366 L
.3886 .21423 L
.38809 .21481 L
.38762 .21535 L
.38713 .21591 L
.38668 .21643 L
.38625 .2169 L
.38581 .21739 L
.3854 .21785 L
.38502 .21827 L
.38463 .21871 L
.38426 .21911 L
.38388 .21952 L
.38352 .21991 L
.38319 .22026 L
.38285 .22062 L
.38253 .22096 L
.3822 .22131 L
.3819 .22163 L
.38161 .22193 L
.38132 .22223 L
Mistroke
Mfstroke
.7381 .60332 m
.73385 .5965 L
.72891 .58897 L
.724 .58182 L
.71902 .57488 L
.71347 .56741 L
.70788 .56017 L
.7017 .55241 L
.69551 .54488 L
.68936 .5376 L
.68262 .52983 L
.67596 .52231 L
.66941 .51508 L
.6623 .50737 L
.65533 .49997 L
.64781 .49211 L
.64049 .48457 L
.63338 .47736 L
.62577 .46974 L
.61841 .46247 L
.61058 .45482 L
.60305 .44753 L
.59583 .44061 L
.58819 .43335 L
.5809 .42648 L
.57395 .41998 L
.56664 .41318 L
.5597 .40677 L
.55244 .4001 L
.54558 .39382 L
.5391 .38792 L
.53235 .3818 L
.52599 .37606 L
.52003 .37069 L
.51383 .36512 L
.50803 .35992 L
.50203 .35455 L
.49642 .34954 L
.4912 .34488 L
.48581 .34007 L
.48079 .3356 L
.47564 .33102 L
.47085 .32675 L
.46641 .3228 L
.46186 .31874 L
.45765 .31499 L
.45375 .3115 L
.44976 .30793 L
.44607 .30463 L
.44231 .30126 L
Mistroke
.43884 .29814 L
.43564 .29526 L
.43238 .29232 L
.42938 .2896 L
.42634 .28684 L
.42354 .28429 L
.42096 .28194 L
.41835 .27954 L
.41596 .27733 L
.41375 .2753 L
.41152 .27323 L
.40947 .27132 L
.4074 .26938 L
.4055 .2676 L
.40377 .26595 L
.40201 .26429 L
.4004 .26275 L
.39893 .26134 L
.39744 .2599 L
.39608 .25858 L
.3947 .25724 L
.39345 .256 L
.3923 .25487 L
.39115 .25372 L
.39009 .25266 L
.38903 .25159 L
.38806 .2506 L
.38717 .2497 L
.38629 .24878 L
.38547 .24793 L
.38474 .24716 L
.38399 .24637 L
.38331 .24565 L
.38263 .24491 L
.38201 .24424 L
.38145 .24362 L
.38088 .24299 L
.38036 .24242 L
.37989 .24189 L
.37942 .24135 L
.37899 .24086 L
.37856 .24036 L
.37817 .2399 L
.37781 .23947 L
.37746 .23904 L
.37713 .23865 L
.37681 .23825 L
.37651 .23788 L
.37625 .23755 L
.37599 .23721 L
Mistroke
Mfstroke
.78571 .01472 m
.75964 .01758 L
.73363 .02101 L
.71129 .02447 L
.69151 .02799 L
.67213 .03191 L
.65495 .03582 L
.63811 .0401 L
.62316 .0443 L
.60984 .04841 L
.5967 .05282 L
.58498 .0571 L
.57449 .06122 L
.56409 .06561 L
.55476 .06982 L
.54552 .07427 L
.53722 .07852 L
.52974 .08257 L
.52229 .08683 L
.51557 .09088 L
.50887 .09511 L
.50282 .09912 L
.49734 .10291 L
.49185 .10686 L
.48687 .1106 L
.48235 .11411 L
.4778 .11778 L
.47365 .12123 L
.46948 .1248 L
.46568 .12816 L
.46221 .13132 L
.4587 .13459 L
.45549 .13766 L
.45255 .14053 L
.44956 .14351 L
.44682 .1463 L
.44405 .14918 L
.4415 .15188 L
.43915 .1544 L
.43677 .157 L
.43457 .15943 L
.43233 .16194 L
.43027 .16428 L
.42837 .16646 L
.42643 .16871 L
.42464 .17081 L
.42298 .17276 L
.42128 .17478 L
.41971 .17666 L
.4181 .17859 L
Mistroke
.41662 .18039 L
.41524 .18207 L
.41382 .18379 L
.41251 .1854 L
.41117 .18705 L
.40992 .18858 L
.40876 .19001 L
.40757 .19148 L
.40647 .19284 L
.40544 .19411 L
.40438 .19541 L
.4034 .19663 L
.40239 .19787 L
.40145 .19903 L
.40058 .2001 L
.39967 .2012 L
.39884 .20223 L
.39805 .20318 L
.39725 .20416 L
.3965 .20507 L
.39572 .206 L
.395 .20687 L
.39433 .20767 L
.39364 .2085 L
.39299 .20927 L
.39233 .21005 L
.39171 .21078 L
.39113 .21146 L
.39054 .21215 L
.38998 .2128 L
.38946 .2134 L
.38892 .21401 L
.38842 .21458 L
.38791 .21516 L
.38743 .21571 L
.38698 .21621 L
.38652 .21673 L
.38609 .2172 L
.38568 .21765 L
.38527 .21811 L
.38488 .21853 L
.38448 .21896 L
.3841 .21937 L
.38375 .21974 L
.38339 .22012 L
.38306 .22048 L
.38271 .22084 L
.38239 .22118 L
.38209 .22149 L
.38178 .22181 L
Mistroke
Mfstroke
.78571 .60332 m
.78207 .59784 L
.77779 .59175 L
.77348 .58592 L
.76907 .58022 L
.7641 .57404 L
.75905 .56798 L
.7534 .56144 L
.74768 .55504 L
.74195 .5488 L
.7356 .54206 L
.72926 .53549 L
.72295 .52911 L
.71604 .52224 L
.7092 .51558 L
.70175 .50845 L
.6944 .50154 L
.68721 .49487 L
.67943 .48775 L
.67184 .48089 L
.66368 .47361 L
.65574 .4666 L
.64807 .45989 L
.63987 .4528 L
.63197 .44601 L
.62438 .43954 L
.61632 .43272 L
.60861 .42624 L
.60047 .41944 L
.59271 .41299 L
.58532 .40689 L
.57757 .4005 L
.57021 .39448 L
.56326 .3888 L
.55599 .38289 L
.54913 .37732 L
.54199 .37155 L
.53528 .36614 L
.52898 .36106 L
.52245 .35581 L
.51633 .3509 L
.51001 .34584 L
.50411 .34112 L
.49861 .33671 L
.49294 .33218 L
.48766 .32797 L
.48275 .32405 L
.4777 .32002 L
.47302 .31627 L
.46822 .31244 L
Mistroke
.46378 .30889 L
.45966 .3056 L
.45545 .30223 L
.45156 .29911 L
.4476 .29593 L
.44394 .29299 L
.44057 .29027 L
.43713 .2875 L
.43396 .28494 L
.43105 .28258 L
.42808 .28017 L
.42535 .27795 L
.42257 .27569 L
.42003 .27361 L
.41769 .2717 L
.41531 .26975 L
.41313 .26795 L
.41113 .2663 L
.4091 .26462 L
.40724 .26307 L
.40536 .2615 L
.40363 .26005 L
.40205 .25872 L
.40045 .25737 L
.39898 .25613 L
.3975 .25487 L
.39615 .25372 L
.39492 .25266 L
.39367 .25158 L
.39252 .25059 L
.39148 .24968 L
.39042 .24876 L
.38946 .24791 L
.38849 .24705 L
.3876 .24627 L
.38679 .24554 L
.38597 .24481 L
.38523 .24413 L
.38455 .24352 L
.38386 .24289 L
.38323 .24231 L
.3826 .24173 L
.38202 .24119 L
.3815 .2407 L
.38097 .2402 L
.38049 .23974 L
.38 .23928 L
.37956 .23886 L
.37916 .23847 L
.37876 .23808 L
Mistroke
Mfstroke
.83333 .01472 m
.80344 .01694 L
.77368 .01975 L
.74814 .0227 L
.72558 .0258 L
.7035 .02931 L
.68396 .03289 L
.66486 .03685 L
.64791 .0408 L
.63284 .0447 L
.61801 .04893 L
.60479 .05306 L
.59299 .05706 L
.5813 .06135 L
.57083 .06549 L
.56048 .06988 L
.5512 .07409 L
.54286 .07812 L
.53455 .08237 L
.52708 .08643 L
.51964 .09068 L
.51293 .09472 L
.50687 .09854 L
.50081 .10255 L
.49531 .10633 L
.49033 .1099 L
.48532 .11363 L
.48077 .11715 L
.4762 .1208 L
.47204 .12424 L
.46824 .12747 L
.46441 .13082 L
.46091 .13397 L
.45772 .13692 L
.45447 .13998 L
.4515 .14285 L
.44849 .14582 L
.44573 .1486 L
.4432 .1512 L
.44062 .15389 L
.43825 .1564 L
.43584 .15899 L
.43363 .16141 L
.43158 .16367 L
.4295 .16601 L
.42758 .16818 L
.4258 .17021 L
.42399 .1723 L
.42231 .17426 L
.42059 .17626 L
Mistroke
.419 .17814 L
.41753 .17988 L
.41603 .18167 L
.41463 .18335 L
.4132 .18506 L
.41188 .18666 L
.41065 .18815 L
.40939 .18968 L
.40822 .1911 L
.40713 .19242 L
.40601 .19378 L
.40497 .19505 L
.4039 .19635 L
.4029 .19755 L
.40198 .19867 L
.40103 .19983 L
.40014 .2009 L
.39932 .20189 L
.39847 .20292 L
.39768 .20387 L
.39686 .20484 L
.3961 .20575 L
.3954 .20659 L
.39467 .20745 L
.39399 .20826 L
.39329 .20908 L
.39264 .20984 L
.39203 .21055 L
.3914 .21128 L
.39082 .21195 L
.39027 .21258 L
.38971 .21322 L
.38919 .21382 L
.38865 .21443 L
.38814 .215 L
.38767 .21553 L
.38719 .21607 L
.38673 .21657 L
.38631 .21703 L
.38587 .21751 L
.38547 .21796 L
.38505 .21841 L
.38465 .21883 L
.38429 .21923 L
.38391 .21963 L
.38356 .22 L
.3832 .22038 L
.38286 .22074 L
.38254 .22106 L
.38222 .22139 L
Mistroke
Mfstroke
.83333 .60332 m
.83041 .5992 L
.82695 .59458 L
.82342 .59012 L
.81978 .58573 L
.81563 .58092 L
.81137 .57618 L
.80656 .571 L
.80164 .56589 L
.79665 .56085 L
.79106 .55536 L
.78542 .54995 L
.77976 .54464 L
.77348 .53887 L
.7672 .53322 L
.76027 .52709 L
.75338 .52109 L
.74654 .51523 L
.73907 .50891 L
.73169 .50275 L
.72367 .49613 L
.71578 .4897 L
.70806 .48346 L
.69972 .47679 L
.69159 .47035 L
.6837 .46413 L
.67524 .45752 L
.66705 .45116 L
.65832 .44443 L
.6499 .43797 L
.64181 .4318 L
.63323 .42529 L
.62502 .41908 L
.61718 .41318 L
.60891 .40698 L
.60104 .4011 L
.59278 .39494 L
.58495 .38912 L
.57754 .38363 L
.56979 .3779 L
.56247 .3725 L
.55487 .36691 L
.54771 .36164 L
.54099 .35671 L
.53402 .3516 L
.52749 .34682 L
.52138 .34236 L
.51507 .33774 L
.50917 .33343 L
.5031 .329 L
Mistroke
.49744 .32487 L
.49218 .32103 L
.48677 .31709 L
.48175 .31342 L
.4766 .30967 L
.47183 .30619 L
.46742 .30296 L
.4629 .29966 L
.45872 .29661 L
.45486 .29378 L
.45091 .29089 L
.44726 .28822 L
.44355 .2855 L
.44013 .28299 L
.43697 .28067 L
.43376 .27831 L
.4308 .27613 L
.42808 .27412 L
.42531 .27207 L
.42276 .27018 L
.42018 .26827 L
.4178 .2665 L
.41562 .26488 L
.41341 .26322 L
.41137 .26171 L
.40932 .26016 L
.40743 .25875 L
.4057 .25745 L
.40395 .25612 L
.40234 .25491 L
.40087 .2538 L
.39938 .25266 L
.39802 .25162 L
.39664 .25057 L
.39538 .2496 L
.39422 .24871 L
.39305 .24781 L
.39198 .24699 L
.39101 .24623 L
.39002 .24546 L
.38911 .24475 L
.3882 .24403 L
.38736 .24338 L
.3866 .24278 L
.38583 .24216 L
.38513 .2416 L
.38442 .24104 L
.38377 .24052 L
.38318 .24004 L
.38259 .23957 L
Mistroke
Mfstroke
.88095 .01472 m
.84714 .0163 L
.81353 .01849 L
.78473 .02094 L
.75933 .0236 L
.73451 .02672 L
.71258 .02995 L
.69116 .03361 L
.6722 .03731 L
.65537 .041 L
.63883 .04504 L
.62411 .04902 L
.61099 .05291 L
.59801 .0571 L
.58642 .06117 L
.57496 .0655 L
.56471 .06968 L
.55551 .07369 L
.54636 .07794 L
.53814 .082 L
.52998 .08627 L
.52263 .09034 L
.51599 .0942 L
.50936 .09825 L
.50337 .10209 L
.49794 .10572 L
.49249 .10951 L
.48754 .11309 L
.48258 .11682 L
.47807 .12033 L
.47397 .12364 L
.46983 .12708 L
.46605 .1303 L
.4626 .13333 L
.45911 .13648 L
.45592 .13943 L
.45269 .14249 L
.44973 .14535 L
.44701 .14803 L
.44425 .15081 L
.44172 .1534 L
.43915 .15608 L
.43678 .15858 L
.4346 .16092 L
.43239 .16333 L
.43034 .16558 L
.42846 .16769 L
.42653 .16986 L
.42475 .17188 L
.42293 .17396 L
Mistroke
.42125 .1759 L
.41969 .17771 L
.4181 .17958 L
.41662 .18132 L
.41511 .1831 L
.41372 .18476 L
.41242 .18631 L
.41109 .1879 L
.40986 .18938 L
.40871 .19075 L
.40753 .19217 L
.40644 .19349 L
.40532 .19484 L
.40427 .1961 L
.4033 .19727 L
.4023 .19847 L
.40137 .19959 L
.40051 .20062 L
.39962 .20169 L
.39879 .20268 L
.39794 .2037 L
.39714 .20464 L
.3964 .20552 L
.39564 .20642 L
.39493 .20726 L
.3942 .20812 L
.39351 .20892 L
.39288 .20966 L
.39222 .21042 L
.39161 .21112 L
.39104 .21178 L
.39046 .21245 L
.38991 .21307 L
.38934 .21371 L
.38882 .2143 L
.38833 .21486 L
.38782 .21542 L
.38735 .21594 L
.38691 .21643 L
.38645 .21693 L
.38602 .2174 L
.38559 .21787 L
.38518 .21831 L
.3848 .21872 L
.3844 .21914 L
.38403 .21953 L
.38366 .21993 L
.3833 .2203 L
.38297 .22065 L
.38264 .22099 L
Mistroke
Mfstroke
.88095 .60332 m
.87888 .60056 L
.8764 .59745 L
.87384 .59442 L
.87118 .59141 L
.86812 .58809 L
.86494 .58477 L
.86131 .58113 L
.85756 .57749 L
.85371 .57386 L
.84936 .56987 L
.84491 .5659 L
.84039 .56195 L
.83533 .55761 L
.83019 .5533 L
.82446 .54857 L
.81868 .54388 L
.81288 .53924 L
.80644 .53416 L
.80001 .52915 L
.79291 .52368 L
.78583 .51829 L
.77881 .513 L
.77111 .50725 L
.76351 .50161 L
.75602 .49611 L
.74787 .49016 L
.73987 .48435 L
.73122 .47812 L
.72276 .47205 L
.71452 .46618 L
.70566 .45989 L
.69707 .45381 L
.68875 .44796 L
.67987 .44172 L
.6713 .43574 L
.6622 .42939 L
.65345 .42332 L
.64508 .41751 L
.63622 .41139 L
.62777 .40556 L
.61887 .39944 L
.61041 .39363 L
.60238 .38812 L
.59397 .38237 L
.58601 .37692 L
.57849 .37179 L
.57065 .36645 L
.56326 .36142 L
.55559 .3562 L
Mistroke
.54839 .3513 L
.54163 .34671 L
.53463 .34196 L
.52809 .33751 L
.52134 .33293 L
.51503 .32866 L
.50916 .32468 L
.50311 .32058 L
.49749 .31677 L
.49226 .31323 L
.48688 .30958 L
.4819 .30621 L
.47679 .30275 L
.47206 .29954 L
.46768 .29657 L
.46321 .29353 L
.45907 .29072 L
.45524 .28813 L
.45133 .28547 L
.44772 .28302 L
.44404 .28052 L
.44065 .27821 L
.43753 .27608 L
.43434 .27391 L
.43141 .27192 L
.42844 .26989 L
.4257 .26802 L
.42319 .2663 L
.42063 .26455 L
.41828 .26294 L
.41613 .26146 L
.41394 .25995 L
.41192 .25857 L
.40989 .25717 L
.40802 .25588 L
.4063 .2547 L
.40456 .2535 L
.40297 .25239 L
.40151 .25138 L
.40003 .25035 L
.39867 .24941 L
.39729 .24845 L
.39604 .24757 L
.39488 .24677 L
.39372 .24595 L
.39265 .2452 L
.39157 .24445 L
.39058 .24375 L
.38968 .24311 L
.38878 .24248 L
Mistroke
Mfstroke
.92857 .01472 m
.90973 .01511 L
.89074 .01566 L
.87236 .01634 L
.85318 .01723 L
.82033 .01922 L
.79142 .02152 L
.76332 .02432 L
.73855 .02732 L
.71665 .03043 L
.69521 .03397 L
.67623 .03754 L
.65936 .04112 L
.64276 .04505 L
.62798 .04892 L
.61345 .05311 L
.60049 .0572 L
.5889 .06117 L
.57743 .06542 L
.56716 .06951 L
.557 .07385 L
.54789 .07801 L
.5397 .08199 L
.53154 .08618 L
.5242 .09018 L
.51757 .09397 L
.51093 .09796 L
.50493 .10173 L
.49894 .10568 L
.49351 .10941 L
.48858 .11293 L
.48362 .1166 L
.47912 .12006 L
.47502 .12331 L
.47088 .1267 L
.4671 .12988 L
.46329 .13319 L
.45982 .13629 L
.45663 .1392 L
.45341 .14221 L
.45045 .14504 L
.44747 .14796 L
.44472 .15069 L
.4422 .15325 L
.43964 .15589 L
.43729 .15836 L
.43512 .16067 L
.43291 .16305 L
.43087 .16528 L
.42879 .16757 L
Mistroke
.42687 .16971 L
.4251 .17171 L
.42329 .17377 L
.42162 .17569 L
.41991 .17766 L
.41833 .1795 L
.41687 .18121 L
.41537 .18297 L
.41398 .18461 L
.41269 .18614 L
.41137 .18771 L
.41014 .18918 L
.40888 .19068 L
.40772 .19208 L
.40663 .19338 L
.40551 .19472 L
.40448 .19596 L
.40351 .19711 L
.40252 .1983 L
.4016 .19941 L
.40065 .20054 L
.39976 .2016 L
.39894 .20258 L
.39809 .20359 L
.39731 .20452 L
.39649 .20548 L
.39574 .20637 L
.39503 .2072 L
.39431 .20804 L
.39363 .20883 L
.393 .20956 L
.39235 .21032 L
.39175 .21101 L
.39112 .21173 L
.39054 .21239 L
.39 .21301 L
.38944 .21364 L
.38891 .21423 L
.38843 .21477 L
.38792 .21533 L
.38745 .21585 L
.38697 .21639 L
.38652 .21688 L
.3861 .21734 L
.38566 .21781 L
.38526 .21825 L
.38484 .2187 L
.38445 .21911 L
.38409 .2195 L
.38371 .21989 L
Mistroke
.38336 .22026 L
.38304 .22059 L
Mfstroke
.92857 .60332 m
.92747 .60193 L
.92614 .60036 L
.92476 .59882 L
.92331 .59727 L
.92162 .59554 L
.91984 .59381 L
.9178 .59188 L
.91566 .58993 L
.91344 .58797 L
.9109 .58579 L
.90827 .58358 L
.90557 .58136 L
.90249 .57889 L
.89934 .5764 L
.89576 .57363 L
.8921 .57084 L
.88836 .56803 L
.88415 .56491 L
.87987 .56177 L
.87506 .55829 L
.87018 .55479 L
.86525 .55129 L
.85974 .54741 L
.85418 .54353 L
.84861 .53966 L
.84242 .5354 L
.83622 .53115 L
.82937 .52649 L
.82253 .52185 L
.81572 .51726 L
.80824 .51223 L
.80081 .50727 L
.79348 .50239 L
.78548 .49707 L
.77759 .49184 L
.76901 .48619 L
.76059 .48064 L
.75235 .47523 L
.74345 .4694 L
.73477 .46373 L
.72545 .45764 L
.71638 .45174 L
.70761 .44603 L
.69823 .43994 L
.68917 .43407 L
.68047 .42843 L
.67121 .42244 L
.66233 .41671 L
.65295 .41065 L
Mistroke
.64397 .40487 L
.63542 .39936 L
.62642 .39356 L
.61786 .38806 L
.6089 .3823 L
.60042 .37685 L
.59239 .37169 L
.58402 .36632 L
.57613 .36126 L
.5687 .3565 L
.56098 .35155 L
.55373 .3469 L
.54623 .3421 L
.5392 .3376 L
.53263 .33339 L
.52585 .32904 L
.51951 .32499 L
.51361 .32121 L
.50753 .31732 L
.50186 .31369 L
.49605 .30997 L
.49065 .30652 L
.48564 .30331 L
.48051 .30002 L
.47575 .29698 L
.47088 .29386 L
.46638 .29098 L
.46222 .28832 L
.45797 .2856 L
.45405 .28308 L
.45042 .28076 L
.44673 .27839 L
.44331 .27621 L
.43984 .27398 L
.43665 .27193 L
.4337 .27004 L
.43071 .26812 L
.42795 .26635 L
.42542 .26472 L
.42283 .26306 L
.42046 .26154 L
.41805 .25999 L
.41584 .25856 L
.41381 .25726 L
.41174 .25593 L
.40985 .25471 L
.40793 .25347 L
.40617 .25234 L
.40456 .2513 L
.40296 .25026 L
Mistroke
Mfstroke
.97619 .01472 m
.97486 .01472 L
.97365 .01472 L
.97225 .01472 L
.97094 .01472 L
.96861 .01472 L
.9661 .01473 L
.96335 .01474 L
.96045 .01476 L
.95529 .01479 L
.95003 .01483 L
.94515 .01488 L
.93424 .01502 L
.92339 .0152 L
.91369 .0154 L
.89265 .01598 L
.8752 .0166 L
.857 .01741 L
.82373 .01935 L
.79445 .02161 L
.76601 .02437 L
.74095 .02734 L
.71879 .03044 L
.69712 .03395 L
.67793 .03752 L
.66089 .04109 L
.64412 .04501 L
.6292 .04888 L
.61452 .05307 L
.60145 .05716 L
.58976 .06114 L
.57819 .06538 L
.56784 .06948 L
.55855 .07342 L
.5493 .07759 L
.54099 .08158 L
.53272 .08578 L
.52528 .08979 L
.51856 .0936 L
.51185 .0976 L
.50577 .10139 L
.49971 .10535 L
.49421 .1091 L
.48923 .11263 L
.48422 .11632 L
.47967 .11979 L
.47552 .12306 L
.47134 .12647 L
.46753 .12967 L
.46369 .13298 L
Mistroke
.46017 .1361 L
.45696 .13902 L
.45371 .14205 L
.45073 .14489 L
.44772 .14782 L
.44495 .15057 L
.44241 .15313 L
.43984 .15579 L
.43746 .15827 L
.43528 .16058 L
.43305 .16298 L
.431 .16521 L
.42891 .16752 L
.42698 .16966 L
.4252 .17167 L
.42338 .17374 L
.4217 .17566 L
.42014 .17746 L
.41854 .17931 L
.41707 .18103 L
.41556 .1828 L
.41415 .18446 L
.41285 .18599 L
.41152 .18758 L
.41028 .18905 L
.40902 .19056 L
.40784 .19197 L
.40675 .19328 L
.40562 .19462 L
.40458 .19587 L
.40361 .19703 L
.40261 .19823 L
.40168 .19934 L
.40072 .20048 L
.39983 .20154 L
.399 .20253 L
.39815 .20354 L
.39736 .20448 L
.39662 .20535 L
.39586 .20625 L
.39515 .20708 L
.39441 .20794 L
.39373 .20873 L
.3931 .20947 L
.39244 .21023 L
.39183 .21093 L
.3912 .21165 L
.39061 .21232 L
.39007 .21294 L
.3895 .21358 L
Mistroke
.38898 .21417 L
.38848 .21472 L
.38798 .21528 L
.3875 .21581 L
.38702 .21634 L
.38656 .21684 L
.38614 .2173 L
.3857 .21778 L
.38529 .21822 L
.38487 .21867 L
.38448 .21908 L
.38411 .21947 L
.38374 .21987 L
.38342 .2202 L
Mfstroke
.97619 .04415 m
.9666 .04401 L
.9563 .0439 L
.95119 .04386 L
.94579 .04382 L
.94319 .04381 L
.94075 .04379 L
.9384 .04379 L
.93621 .04378 L
.93495 .04378 L
.93381 .04377 L
.93254 .04377 L
.93184 .04377 L
.93118 .04377 L
.93054 .04377 L
.92987 .04377 L
.92865 .04377 L
.92791 .04377 L
.92721 .04377 L
.92658 .04377 L
.92591 .04377 L
.92477 .04377 L
.92353 .04377 L
.92104 .04378 L
.91874 .04379 L
.91661 .0438 L
.91139 .04383 L
.90668 .04386 L
.89629 .04397 L
.88742 .04409 L
.87937 .04424 L
.86175 .04465 L
.84656 .04513 L
.83048 .04576 L
.80105 .04727 L
.77497 .04906 L
.74944 .05127 L
.72679 .05367 L
.70664 .05618 L
.68681 .05905 L
.66915 .06198 L
.65177 .06523 L
.63628 .06849 L
.62243 .0717 L
.60872 .0752 L
.59646 .07863 L
.58545 .08196 L
.5745 .08554 L
.56466 .08899 L
.55489 .09266 L
Mistroke
.54609 .0962 L
.53815 .09958 L
.53023 .10315 L
.52307 .10657 L
.51593 .11015 L
.50947 .11356 L
.50361 .1168 L
.49774 .12018 L
.49241 .12339 L
.48756 .12642 L
.48268 .12959 L
.47823 .13258 L
.47376 .13568 L
.46968 .13861 L
.46596 .14136 L
.46219 .14422 L
.45875 .14691 L
.4556 .14944 L
.4524 .15206 L
.44947 .15451 L
.4465 .15705 L
.44377 .15943 L
.44126 .16166 L
.43871 .16397 L
.43637 .16613 L
.43399 .16835 L
.43179 .17044 L
.42977 .17238 L
.4277 .17438 L
.4258 .17626 L
.42404 .17801 L
.42225 .17981 L
.42059 .18149 L
.41889 .18322 L
.41732 .18484 L
.41587 .18634 L
.41438 .18789 L
.413 .18934 L
.41173 .19068 L
.41041 .19207 L
.4092 .19336 L
.40795 .19469 L
.4068 .19593 L
.40572 .19708 L
.40462 .19826 L
.4036 .19936 L
.40255 .20049 L
.40157 .20154 L
.40066 .20252 L
.39973 .20352 L
Mistroke
.39886 .20445 L
.39806 .20532 L
.39723 .20621 L
.39645 .20704 L
.39566 .2079 L
.39492 .20869 L
.39423 .20942 L
.39352 .21018 L
.39286 .21088 L
.39218 .2116 L
.39155 .21226 L
.39096 .21288 L
.39035 .21352 L
.38979 .21411 L
.38926 .21466 L
.38872 .21522 L
.38821 .21574 L
.38769 .21628 L
.38721 .21678 L
.38676 .21724 L
.38629 .21772 L
.38586 .21816 L
.38545 .21856 L
.38503 .21898 L
.38464 .21937 L
.38424 .21977 L
.38387 .22014 L
.38352 .22049 L
.38317 .22083 L
Mfstroke
.97619 .07358 m
.95732 .07304 L
.93818 .07261 L
.91955 .07229 L
.90931 .07217 L
.90481 .07213 L
.89998 .07209 L
.89526 .07206 L
.89321 .07205 L
.89096 .07204 L
.88899 .07203 L
.88688 .07203 L
.88572 .07203 L
.88466 .07202 L
.8836 .07202 L
.8826 .07202 L
.88163 .07202 L
.88074 .07202 L
.87973 .07202 L
.87878 .07202 L
.87789 .07202 L
.87708 .07203 L
.87526 .07203 L
.87342 .07203 L
.87141 .07204 L
.86739 .07206 L
.8632 .07209 L
.85927 .07212 L
.85201 .0722 L
.84435 .07231 L
.83618 .07245 L
.82179 .07278 L
.80712 .07323 L
.78221 .07426 L
.75762 .07564 L
.73568 .07723 L
.71405 .07915 L
.69474 .08121 L
.67746 .08335 L
.66034 .08579 L
.64501 .08826 L
.62985 .09099 L
.61625 .09373 L
.60403 .09642 L
.59189 .09935 L
.58096 .10222 L
.57111 .105 L
.56127 .10799 L
.55239 .11088 L
.54353 .11395 L
Mistroke
.53553 .1169 L
.52828 .11973 L
.52103 .12271 L
.51444 .12557 L
.50786 .12856 L
.50188 .13142 L
.49644 .13413 L
.49098 .13696 L
.48601 .13965 L
.48147 .14219 L
.47689 .14484 L
.47272 .14735 L
.46851 .14996 L
.46466 .15241 L
.46114 .15473 L
.45757 .15713 L
.45431 .15939 L
.45131 .16151 L
.44827 .16372 L
.44548 .16578 L
.44265 .16792 L
.44005 .16993 L
.43765 .17181 L
.43522 .17375 L
.43297 .17557 L
.43069 .17745 L
.42859 .17921 L
.42665 .18085 L
.42468 .18254 L
.42285 .18413 L
.42117 .1856 L
.41945 .18713 L
.41785 .18855 L
.41623 .19002 L
.41472 .19139 L
.41333 .19266 L
.4119 .19398 L
.41058 .1952 L
.40936 .19634 L
.4081 .19752 L
.40694 .19862 L
.40575 .19974 L
.40464 .20079 L
.40362 .20177 L
.40256 .20278 L
.40158 .20371 L
.40058 .20467 L
.39965 .20557 L
.39879 .2064 L
.3979 .20726 L
Mistroke
.39707 .20805 L
.3963 .20879 L
.39551 .20955 L
.39478 .21026 L
.39403 .21099 L
.39332 .21166 L
.39267 .21229 L
.392 .21293 L
.39137 .21353 L
.39073 .21415 L
.39014 .21472 L
.38958 .21525 L
.38901 .21579 L
.38848 .2163 L
.38798 .21677 L
.38747 .21725 L
.38699 .2177 L
.3865 .21816 L
.38605 .21859 L
.38562 .21898 L
.38519 .21939 L
.38478 .21977 L
.3844 .22012 L
.38401 .22048 L
.38365 .22081 L
.38327 .22116 L
.38293 .22147 L
Mfstroke
.97619 .10301 m
.94017 .1015 L
.92242 .10088 L
.90372 .10034 L
.88681 .09994 L
.87197 .09967 L
.86478 .09956 L
.85711 .09947 L
.85295 .09944 L
.84916 .09941 L
.84559 .09938 L
.84363 .09937 L
.84178 .09937 L
.84006 .09936 L
.83818 .09935 L
.83735 .09935 L
.83648 .09935 L
.83566 .09935 L
.8349 .09935 L
.83408 .09935 L
.83318 .09935 L
.8324 .09935 L
.83157 .09935 L
.83083 .09935 L
.83014 .09935 L
.82938 .09935 L
.82857 .09935 L
.82673 .09935 L
.82474 .09936 L
.82288 .09937 L
.82116 .09937 L
.81795 .09939 L
.81453 .09942 L
.80815 .09948 L
.80227 .09955 L
.78921 .09977 L
.77696 .10006 L
.76454 .10044 L
.74326 .1013 L
.72215 .10245 L
.7032 .10375 L
.68444 .10533 L
.66759 .10701 L
.65244 .10877 L
.63737 .11075 L
.6238 .11277 L
.61157 .11479 L
.59935 .11701 L
.58833 .11921 L
.57733 .1216 L
Mistroke
.5674 .12395 L
.55841 .12623 L
.54941 .12867 L
.54126 .13104 L
.53311 .13356 L
.52572 .13598 L
.51901 .1383 L
.51227 .14076 L
.50614 .14311 L
.50056 .14535 L
.49494 .1477 L
.48982 .14994 L
.48466 .15229 L
.47996 .15451 L
.47566 .15661 L
.47132 .15881 L
.46735 .16089 L
.46371 .16285 L
.46003 .16489 L
.45665 .16682 L
.45323 .16882 L
.4501 .17071 L
.44722 .17248 L
.4443 .17432 L
.44161 .17604 L
.43889 .17783 L
.43638 .17951 L
.43408 .18108 L
.43173 .1827 L
.42957 .18423 L
.42758 .18565 L
.42554 .18713 L
.42367 .18851 L
.42176 .18993 L
.41999 .19126 L
.41836 .1925 L
.4167 .19379 L
.41516 .19499 L
.41373 .1961 L
.41228 .19726 L
.41093 .19834 L
.40955 .19945 L
.40827 .20048 L
.40709 .20145 L
.40588 .20244 L
.40476 .20337 L
.40361 .20433 L
.40254 .20521 L
.40155 .20604 L
.40054 .20689 L
Mistroke
.3996 .20769 L
.39873 .20843 L
.39783 .20919 L
.397 .20989 L
.39615 .21062 L
.39536 .2113 L
.39462 .21193 L
.39386 .21258 L
.39316 .21318 L
.39244 .2138 L
.39177 .21437 L
.39115 .21491 L
.39051 .21545 L
.38992 .21597 L
.38936 .21644 L
.3888 .21693 L
.38827 .21738 L
.38772 .21785 L
.38722 .21828 L
.38675 .21868 L
.38626 .2191 L
.38581 .21948 L
.3854 .21984 L
.38497 .2202 L
.38456 .22054 L
.38415 .22089 L
.38377 .22122 L
.38341 .22152 L
.38304 .22183 L
.38271 .22211 L
Mfstroke
.97619 .13244 m
.94218 .13046 L
.90752 .12872 L
.87712 .12746 L
.84975 .12656 L
.83523 .12619 L
.82247 .12592 L
.81627 .12582 L
.80964 .12572 L
.80354 .12565 L
.79791 .1256 L
.7922 .12556 L
.78921 .12554 L
.78755 .12553 L
.78602 .12553 L
.78444 .12553 L
.7836 .12552 L
.78272 .12552 L
.78231 .12552 L
.78187 .12552 L
.78149 .12552 L
.78108 .12552 L
.78071 .12552 L
.78031 .12552 L
.77961 .12552 L
.77885 .12552 L
.77816 .12552 L
.77778 .12552 L
.77736 .12552 L
.77661 .12552 L
.77517 .12553 L
.77384 .12553 L
.77121 .12554 L
.7684 .12555 L
.76338 .12559 L
.7575 .12564 L
.7522 .12571 L
.74227 .12587 L
.73176 .12611 L
.71217 .12673 L
.69451 .1275 L
.67693 .1285 L
.66107 .12961 L
.64675 .1308 L
.63244 .13219 L
.61952 .13362 L
.60781 .13509 L
.59609 .13672 L
.58547 .13835 L
.57484 .14015 L
Mistroke
.56521 .14193 L
.55647 .14367 L
.5477 .14555 L
.53973 .14738 L
.53174 .14935 L
.52448 .15125 L
.51787 .15308 L
.51122 .15502 L
.50517 .15689 L
.49964 .15868 L
.49407 .16057 L
.48898 .16237 L
.48384 .16426 L
.47916 .16606 L
.47487 .16777 L
.47054 .16956 L
.46657 .17126 L
.46293 .17286 L
.45924 .17454 L
.45586 .17612 L
.45244 .17777 L
.44929 .17933 L
.4464 .1808 L
.44347 .18232 L
.44077 .18376 L
.43804 .18524 L
.43552 .18664 L
.43321 .18796 L
.43085 .18932 L
.42868 .19059 L
.42668 .19179 L
.42464 .19303 L
.42276 .19419 L
.42084 .19539 L
.41907 .19651 L
.41744 .19757 L
.41577 .19865 L
.41423 .19967 L
.41281 .20062 L
.41135 .2016 L
.41 .20251 L
.40862 .20346 L
.40735 .20434 L
.40617 .20516 L
.40496 .20601 L
.40384 .20681 L
.4027 .20762 L
.40164 .20838 L
.40066 .20909 L
.39966 .20982 L
Mistroke
.39872 .21051 L
.39786 .21114 L
.39697 .21179 L
.39615 .2124 L
.39531 .21303 L
.39453 .21362 L
.3938 .21416 L
.39306 .21472 L
.39236 .21524 L
.39166 .21577 L
.391 .21627 L
.39039 .21674 L
.38976 .21721 L
.38918 .21765 L
.38864 .21807 L
.38808 .21849 L
.38757 .21889 L
.38704 .21929 L
.38654 .21967 L
.38609 .22002 L
.38562 .22038 L
.38518 .22071 L
.38477 .22102 L
.38435 .22135 L
.38396 .22164 L
.38356 .22195 L
.38319 .22223 L
.38285 .2225 L
.3825 .22276 L
Mfstroke
.97619 .16187 m
.9442 .15948 L
.91136 .15723 L
.88238 .15544 L
.85611 .15399 L
.82977 .15274 L
.80593 .15178 L
.7821 .15102 L
.77072 .15074 L
.76054 .15053 L
.75091 .15037 L
.7461 .15031 L
.741 .15026 L
.73601 .15022 L
.7315 .15019 L
.72936 .15018 L
.72823 .15018 L
.72704 .15017 L
.7259 .15017 L
.72486 .15017 L
.72436 .15017 L
.72383 .15017 L
.72332 .15017 L
.72286 .15017 L
.72227 .15017 L
.72171 .15017 L
.72121 .15017 L
.72067 .15017 L
.72009 .15017 L
.71947 .15017 L
.71835 .15017 L
.71733 .15017 L
.71638 .15017 L
.71421 .15018 L
.71187 .15019 L
.70974 .15021 L
.705 .15024 L
.70073 .15029 L
.69682 .15034 L
.68813 .15049 L
.67981 .15067 L
.67247 .15087 L
.65737 .15141 L
.64366 .15204 L
.62993 .15283 L
.61746 .15369 L
.60614 .1546 L
.59476 .15564 L
.58442 .15672 L
.57404 .15793 L
Mistroke
.5646 .15914 L
.55602 .16036 L
.54737 .16169 L
.5395 .163 L
.5316 .16442 L
.52439 .16581 L
.51782 .16716 L
.5112 .16861 L
.50516 .17001 L
.49964 .17136 L
.49406 .1728 L
.48896 .17417 L
.48381 .17563 L
.4791 .17702 L
.47479 .17835 L
.47042 .17975 L
.46642 .18108 L
.46276 .18234 L
.45904 .18366 L
.45562 .18492 L
.45216 .18623 L
.44898 .18747 L
.44606 .18865 L
.4431 .18987 L
.44037 .19103 L
.4376 .19223 L
.43506 .19336 L
.43272 .19443 L
.43034 .19554 L
.42814 .19658 L
.42612 .19756 L
.42406 .19857 L
.42216 .19953 L
.42022 .20051 L
.41844 .20144 L
.41679 .20231 L
.41511 .20321 L
.41355 .20405 L
.41212 .20484 L
.41065 .20565 L
.4093 .20642 L
.40791 .20721 L
.40663 .20794 L
.40545 .20863 L
.40424 .20935 L
.40312 .21001 L
.40198 .2107 L
.40092 .21134 L
.39994 .21194 L
.39893 .21255 L
Mistroke
.398 .21313 L
.39714 .21367 L
.39626 .21422 L
.39544 .21474 L
.39461 .21527 L
.39383 .21577 L
.39311 .21623 L
.39237 .21671 L
.39169 .21715 L
.39099 .21761 L
.39034 .21804 L
.38974 .21843 L
.38912 .21884 L
.38855 .21922 L
.38801 .21957 L
.38747 .21994 L
.38696 .22028 L
.38644 .22063 L
.38596 .22095 L
.38551 .22125 L
.38505 .22156 L
.38462 .22185 L
.38422 .22212 L
.38382 .2224 L
.38344 .22266 L
.38305 .22292 L
.38269 .22317 L
.38235 .2234 L
.38231 .22343 L
Mfstroke
.97619 .1913 m
.94623 .18857 L
.91526 .18589 L
.88774 .18363 L
.86263 .18169 L
.83732 .17986 L
.81425 .17833 L
.79107 .17693 L
.76998 .17579 L
.75077 .17488 L
.73144 .1741 L
.71385 .17353 L
.69783 .17312 L
.68994 .17296 L
.68169 .17283 L
.67778 .17279 L
.67358 .17274 L
.66967 .17271 L
.66609 .17269 L
.66423 .17268 L
.66326 .17268 L
.66224 .17268 L
.66134 .17267 L
.66087 .17267 L
.66036 .17267 L
.6599 .17267 L
.65948 .17267 L
.65906 .17267 L
.65866 .17267 L
.65827 .17267 L
.65786 .17267 L
.65742 .17267 L
.65701 .17267 L
.65663 .17267 L
.65628 .17267 L
.65549 .17267 L
.6547 .17267 L
.65383 .17268 L
.6521 .17268 L
.65026 .17269 L
.64855 .1727 L
.64537 .17272 L
.64199 .17275 L
.63838 .17279 L
.63193 .17289 L
.6253 .17302 L
.61384 .17332 L
.60228 .17373 L
.59175 .17421 L
.58114 .17479 L
Mistroke
.57148 .17541 L
.56267 .17607 L
.55377 .17683 L
.54566 .1776 L
.53749 .17846 L
.53003 .17933 L
.52322 .18019 L
.51634 .18114 L
.51005 .18207 L
.5043 .18298 L
.49848 .18396 L
.49316 .18492 L
.48778 .18594 L
.48285 .18693 L
.47834 .18789 L
.47377 .1889 L
.46958 .18987 L
.46573 .19081 L
.46183 .19179 L
.45825 .19273 L
.45461 .19373 L
.45128 .19467 L
.44822 .19557 L
.4451 .19651 L
.44224 .1974 L
.43934 .19834 L
.43667 .19922 L
.43421 .20006 L
.43172 .20093 L
.42942 .20176 L
.4273 .20253 L
.42514 .20334 L
.42315 .20411 L
.42113 .2049 L
.41926 .20565 L
.41754 .20635 L
.41579 .20708 L
.41417 .20777 L
.41268 .20841 L
.41115 .20908 L
.40974 .20971 L
.4083 .21036 L
.40697 .21097 L
.40574 .21154 L
.40449 .21213 L
.40333 .21269 L
.40215 .21326 L
.40105 .21379 L
.40004 .2143 L
.39901 .21481 L
Mistroke
.39805 .2153 L
.39717 .21575 L
.39626 .21622 L
.39542 .21666 L
.39456 .21711 L
.39377 .21753 L
.39303 .21792 L
.39228 .21833 L
.39158 .21871 L
.39086 .2191 L
.3902 .21946 L
.38959 .2198 L
.38896 .22016 L
.38838 .22048 L
.38784 .22079 L
.38729 .2211 L
.38677 .2214 L
.38625 .2217 L
.38576 .22198 L
.38531 .22224 L
.38484 .22251 L
.38441 .22276 L
.38402 .223 L
.38361 .22324 L
.38323 .22346 L
.38284 .2237 L
.38247 .22391 L
.38215 .22411 L
Mfstroke
.97619 .22073 m
.94827 .21773 L
.91922 .21468 L
.89321 .21202 L
.86934 .20965 L
.84511 .20731 L
.8229 .20525 L
.80044 .20326 L
.77989 .20152 L
.76107 .20002 L
.74204 .19859 L
.72463 .19737 L
.7087 .19634 L
.69258 .19538 L
.67783 .1946 L
.66295 .1939 L
.64935 .19334 L
.63692 .19292 L
.62435 .19257 L
.61286 .19234 L
.60681 .19224 L
.6041 .19221 L
.60127 .19218 L
.59869 .19216 L
.59589 .19214 L
.59468 .19214 L
.59338 .19213 L
.59217 .19213 L
.59107 .19212 L
.59048 .19212 L
.58983 .19212 L
.58951 .19212 L
.58934 .19212 L
.58916 .19212 L
.58883 .19212 L
.58853 .19212 L
.58825 .19212 L
.58795 .19212 L
.58767 .19212 L
.58742 .19212 L
.58712 .19212 L
.58679 .19212 L
.58621 .19212 L
.58558 .19212 L
.58489 .19213 L
.58351 .19213 L
.58223 .19213 L
.58105 .19214 L
.57852 .19216 L
.57615 .19218 L
Mistroke
.57177 .19223 L
.56721 .1923 L
.56308 .19237 L
.5546 .19258 L
.54605 .19286 L
.53822 .19319 L
.53106 .19354 L
.52382 .19396 L
.51719 .1944 L
.51112 .19485 L
.50497 .19536 L
.49933 .19588 L
.49363 .19646 L
.48841 .19703 L
.48362 .19759 L
.47876 .19821 L
.47431 .19881 L
.47022 .1994 L
.46607 .20004 L
.46225 .20065 L
.45839 .20131 L
.45484 .20195 L
.45158 .20256 L
.44826 .20321 L
.44522 .20383 L
.44213 .20449 L
.43929 .20512 L
.43667 .20572 L
.43402 .20635 L
.43157 .20695 L
.42932 .20752 L
.42703 .20812 L
.42492 .20869 L
.42277 .20929 L
.42079 .20985 L
.41897 .21038 L
.41711 .21094 L
.4154 .21147 L
.41382 .21197 L
.41221 .21249 L
.41072 .21297 L
.4092 .21348 L
.4078 .21396 L
.40651 .21441 L
.40519 .21488 L
.40397 .21532 L
.40273 .21578 L
.40158 .21621 L
.40052 .21661 L
.39944 .21703 L
Mistroke
.39844 .21742 L
.39752 .21779 L
.39657 .21817 L
.3957 .21853 L
.39481 .2189 L
.39398 .21925 L
.39322 .21957 L
.39243 .21991 L
.39171 .22022 L
.39097 .22055 L
.39029 .22085 L
.38966 .22114 L
.38901 .22143 L
.38841 .22171 L
.38786 .22196 L
.38729 .22223 L
.38676 .22247 L
.38622 .22273 L
.38572 .22297 L
.38526 .22319 L
.38479 .22342 L
.38435 .22364 L
.38394 .22384 L
.38353 .22404 L
.38314 .22424 L
.38274 .22443 L
.38238 .22462 L
.38204 .22479 L
.38201 .22481 L
Mfstroke
.97619 .25016 m
.95033 .24696 L
.92323 .24362 L
.89879 .24063 L
.87622 .23788 L
.85316 .23511 L
.83189 .23258 L
.81025 .23006 L
.79031 .22777 L
.77196 .22571 L
.7533 .22367 L
.73614 .22185 L
.72036 .22022 L
.7043 .21862 L
.68956 .21721 L
.67461 .21583 L
.66089 .21463 L
.64829 .21358 L
.63551 .21258 L
.62379 .21171 L
.61192 .2109 L
.60104 .21021 L
.59106 .20963 L
.58095 .2091 L
.57168 .20867 L
.56318 .20833 L
.55455 .20803 L
.54663 .2078 L
.53862 .20762 L
.53476 .20756 L
.53128 .20751 L
.52797 .20747 L
.52631 .20746 L
.52454 .20745 L
.52369 .20744 L
.52281 .20744 L
.52199 .20743 L
.52124 .20743 L
.52053 .20743 L
.52014 .20743 L
.51978 .20743 L
.51939 .20743 L
.51917 .20743 L
.51897 .20743 L
.51879 .20743 L
.5186 .20743 L
.51839 .20743 L
.51821 .20743 L
.518 .20743 L
.51789 .20743 L
Mistroke
.51778 .20743 L
.51739 .20743 L
.51717 .20743 L
.51694 .20743 L
.51651 .20743 L
.51568 .20743 L
.51492 .20743 L
.51348 .20744 L
.51198 .20745 L
.50894 .20748 L
.50617 .20751 L
.50048 .2076 L
.49472 .20774 L
.48943 .20791 L
.48458 .20809 L
.47965 .20831 L
.47513 .20855 L
.47098 .20879 L
.46676 .20907 L
.46288 .20936 L
.45894 .20968 L
.45533 .21 L
.452 .21032 L
.44862 .21066 L
.44552 .21101 L
.44237 .21138 L
.43947 .21174 L
.4368 .21209 L
.43409 .21247 L
.4316 .21284 L
.42931 .21319 L
.42697 .21357 L
.42482 .21393 L
.42263 .21431 L
.42061 .21468 L
.41876 .21503 L
.41687 .2154 L
.41512 .21575 L
.41352 .21609 L
.41188 .21645 L
.41037 .21678 L
.40883 .21714 L
.40741 .21747 L
.4061 .21779 L
.40477 .21812 L
.40353 .21844 L
.40228 .21877 L
.40112 .21908 L
.40005 .21937 L
.39896 .21968 L
Mistroke
.39795 .21997 L
.39702 .22024 L
.39607 .22052 L
.39519 .22079 L
.3943 .22107 L
.39347 .22133 L
.3927 .22157 L
.39192 .22183 L
.3912 .22207 L
.39046 .22232 L
.38978 .22255 L
.38915 .22277 L
.3885 .22299 L
.38791 .22321 L
.38736 .22341 L
.38679 .22361 L
.38627 .22381 L
.38574 .22401 L
.38524 .2242 L
.38479 .22437 L
.38432 .22455 L
.38389 .22473 L
.38349 .22488 L
.38308 .22505 L
.3827 .2252 L
.38231 .22536 L
.38195 .22551 L
.3819 .22553 L
Mfstroke
.97619 .27959 m
.95241 .27626 L
.92729 .27271 L
.9045 .26945 L
.88329 .26641 L
.86149 .26327 L
.84124 .26034 L
.82051 .25734 L
.80129 .25457 L
.78349 .25201 L
.76529 .24941 L
.74845 .24702 L
.73289 .24484 L
.71698 .24262 L
.70229 .24061 L
.68732 .23859 L
.67352 .23675 L
.6608 .23509 L
.64784 .23344 L
.6359 .23195 L
.62377 .23048 L
.61261 .22916 L
.60233 .22798 L
.59189 .22682 L
.58229 .22579 L
.57346 .22488 L
.56447 .22399 L
.55621 .22321 L
.54783 .22246 L
.54012 .2218 L
.53304 .22123 L
.52585 .22068 L
.51924 .22022 L
.51316 .21982 L
.50698 .21944 L
.5013 .21913 L
.49553 .21884 L
.49023 .21861 L
.48536 .21842 L
.48041 .21826 L
.47586 .21813 L
.47125 .21804 L
.46902 .218 L
.46701 .21797 L
.46509 .21795 L
.46413 .21794 L
.46311 .21794 L
.4621 .21793 L
.46119 .21793 L
.46076 .21793 L
Mistroke
.46053 .21793 L
.46029 .21792 L
.46006 .21792 L
.45985 .21792 L
.45975 .21792 L
.45964 .21792 L
.45954 .21792 L
.45944 .21792 L
.45932 .21792 L
.45921 .21792 L
.4591 .21792 L
.45903 .21792 L
.45897 .21792 L
.45887 .21792 L
.45876 .21792 L
.45865 .21792 L
.45854 .21792 L
.45829 .21792 L
.45807 .21792 L
.45757 .21793 L
.45711 .21793 L
.45662 .21793 L
.45564 .21793 L
.45471 .21794 L
.45388 .21795 L
.45205 .21797 L
.45041 .21799 L
.44867 .21802 L
.44537 .21809 L
.44234 .21817 L
.43955 .21827 L
.43671 .21838 L
.43409 .2185 L
.43144 .21865 L
.429 .21879 L
.42675 .21894 L
.42446 .2191 L
.42235 .21927 L
.42041 .21943 L
.41843 .21961 L
.41661 .21979 L
.41476 .21998 L
.41305 .22017 L
.41148 .22035 L
.40988 .22055 L
.4084 .22074 L
.4069 .22094 L
.40551 .22114 L
.40424 .22133 L
.40293 .22153 L
Mistroke
.40174 .22172 L
.40063 .2219 L
.3995 .2221 L
.39846 .22228 L
.3974 .22248 L
.39642 .22266 L
.39551 .22284 L
.39459 .22303 L
.39374 .2232 L
.39287 .22339 L
.39207 .22356 L
.39134 .22373 L
.39058 .2239 L
.38989 .22407 L
.38924 .22422 L
.38859 .22438 L
.38798 .22454 L
.38736 .2247 L
.38679 .22485 L
.38626 .22499 L
.38572 .22514 L
.38522 .22527 L
.38476 .22541 L
.38429 .22554 L
.38385 .22567 L
.3834 .2258 L
.38299 .22593 L
.38261 .22605 L
.38222 .22617 L
.38186 .22628 L
.38185 .22629 L
Mfstroke
.97619 .30902 m
.95449 .30563 L
.93142 .30194 L
.91032 .29851 L
.89056 .29524 L
.8701 .2918 L
.85098 .28855 L
.83126 .28516 L
.81286 .28197 L
.79572 .27897 L
.77807 .27587 L
.76165 .27297 L
.74639 .27027 L
.7307 .26749 L
.71614 .26491 L
.70123 .26227 L
.68741 .25983 L
.6746 .25758 L
.6615 .25529 L
.64938 .25319 L
.63701 .25106 L
.62558 .24911 L
.61503 .24733 L
.60426 .24554 L
.59433 .2439 L
.58516 .24242 L
.5758 .24092 L
.56718 .23957 L
.5584 .23822 L
.55032 .237 L
.54287 .2359 L
.53528 .23481 L
.5283 .23383 L
.52187 .23295 L
.51532 .23207 L
.50928 .23129 L
.50315 .23052 L
.49751 .22984 L
.49232 .22923 L
.48703 .22863 L
.48217 .2281 L
.47724 .22759 L
.4727 .22714 L
.46852 .22675 L
.46428 .22637 L
.46037 .22604 L
.45678 .22576 L
.45312 .22548 L
.44976 .22525 L
.44634 .22503 L
Mistroke
.4432 .22485 L
.44031 .22469 L
.43737 .22455 L
.43466 .22443 L
.43192 .22433 L
.42939 .22425 L
.42706 .22419 L
.4247 .22414 L
.42356 .22412 L
.42253 .22411 L
.42155 .2241 L
.42052 .22409 L
.42 .22409 L
.41973 .22409 L
.41944 .22409 L
.41919 .22409 L
.41906 .22409 L
.41892 .22409 L
.41879 .22409 L
.41867 .22409 L
.41856 .22409 L
.4185 .22409 L
.41844 .22409 L
.41841 .22409 L
.41837 .22409 L
.41831 .22409 L
.41825 .22409 L
.41821 .22409 L
.41818 .22409 L
.41812 .22409 L
.41806 .22409 L
.41793 .22409 L
.41782 .22409 L
.4177 .22409 L
.41748 .22409 L
.41723 .22409 L
.41696 .22409 L
.41648 .22409 L
.41605 .22409 L
.41558 .2241 L
.41475 .2241 L
.41386 .22412 L
.41294 .22413 L
.41133 .22416 L
.4097 .2242 L
.40819 .22425 L
.40666 .22431 L
.40526 .22437 L
.40396 .22443 L
.40264 .2245 L
Mistroke
.40142 .22458 L
.4003 .22465 L
.39915 .22473 L
.3981 .22482 L
.39702 .22491 L
.39603 .22499 L
.39512 .22508 L
.39419 .22518 L
.39333 .22527 L
.39246 .22537 L
.39165 .22546 L
.39091 .22555 L
.39016 .22565 L
.38946 .22575 L
.38881 .22584 L
.38816 .22593 L
.38755 .22603 L
.38693 .22612 L
.38636 .22622 L
.38583 .22631 L
.3853 .2264 L
.3848 .22649 L
.38434 .22657 L
.38387 .22666 L
.38344 .22675 L
.383 .22684 L
.38259 .22692 L
.38221 .227 L
.38185 .22708 L
Mfstroke
.97619 .33845 m
.9566 .33507 L
.93561 .33133 L
.91627 .3278 L
.89804 .32438 L
.87902 .32074 L
.86112 .31725 L
.84254 .31355 L
.82508 .31001 L
.8087 .30665 L
.79174 .30312 L
.77585 .29977 L
.76099 .29661 L
.74562 .29332 L
.73128 .29022 L
.7165 .28701 L
.70273 .284 L
.68991 .28119 L
.67672 .27829 L
.66447 .27559 L
.6519 .27282 L
.64024 .27026 L
.62942 .26788 L
.61834 .26545 L
.60808 .2632 L
.59858 .26114 L
.58885 .25903 L
.57984 .25709 L
.57066 .25513 L
.56217 .25333 L
.55433 .25168 L
.54633 .25001 L
.53894 .24849 L
.53212 .2471 L
.52516 .2457 L
.51874 .24442 L
.5122 .24314 L
.50617 .24198 L
.50061 .24092 L
.49495 .23986 L
.48974 .23891 L
.48444 .23795 L
.47956 .23709 L
.47506 .23631 L
.47049 .23553 L
.46628 .23484 L
.46241 .23421 L
.45846 .23359 L
.45483 .23303 L
.45114 .23248 L
Mistroke
.44775 .23198 L
.44462 .23154 L
.44144 .23111 L
.43852 .23072 L
.43555 .23034 L
.43281 .23001 L
.4303 .22971 L
.42775 .22942 L
.4254 .22917 L
.42323 .22894 L
.42103 .22873 L
.41901 .22854 L
.41695 .22835 L
.41505 .2282 L
.41331 .22806 L
.41154 .22793 L
.40991 .22782 L
.40841 .22773 L
.40687 .22764 L
.40547 .22756 L
.40403 .2275 L
.40271 .22744 L
.4015 .2274 L
.40026 .22736 L
.39913 .22733 L
.39797 .22731 L
.39741 .2273 L
.3969 .2273 L
.39642 .22729 L
.39618 .22729 L
.39592 .22729 L
.39567 .22729 L
.39544 .22729 L
.39533 .22728 L
.39527 .22728 L
.39521 .22728 L
.39516 .22728 L
.3951 .22728 L
.39507 .22728 L
.39505 .22728 L
.39502 .22728 L
.395 .22728 L
.39497 .22728 L
.39494 .22728 L
.39491 .22728 L
.39489 .22728 L
.39488 .22728 L
.39485 .22728 L
.39483 .22728 L
.3948 .22728 L
Mistroke
.39477 .22728 L
.39471 .22728 L
.39465 .22728 L
.39452 .22728 L
.3944 .22729 L
.39427 .22729 L
.39404 .22729 L
.3938 .22729 L
.39359 .22729 L
.39313 .22729 L
.39271 .2273 L
.39227 .22731 L
.39143 .22732 L
.39066 .22734 L
.38995 .22736 L
.38922 .22739 L
.38856 .22742 L
.38787 .22745 L
.38725 .22748 L
.38667 .22752 L
.38608 .22755 L
.38554 .22759 L
.38503 .22763 L
.38452 .22767 L
.38405 .22771 L
.38357 .22775 L
.38313 .2278 L
.38272 .22784 L
.3823 .22788 L
.38192 .22793 L
Mfstroke
.97619 .36788 m
.95871 .36458 L
.93985 .36088 L
.92235 .35733 L
.90572 .35385 L
.88826 .3501 L
.87171 .34645 L
.85439 .34254 L
.838 .33876 L
.82252 .33511 L
.80637 .33124 L
.79114 .32753 L
.77681 .32399 L
.76189 .32025 L
.74788 .31669 L
.73335 .31297 L
.71973 .30944 L
.70698 .30611 L
.69379 .30264 L
.68146 .29938 L
.66876 .296 L
.65691 .29283 L
.64586 .28987 L
.6345 .28681 L
.62393 .28396 L
.6141 .2813 L
.60399 .27857 L
.59461 .27604 L
.585 .27345 L
.57609 .27105 L
.56784 .26883 L
.55938 .26657 L
.55156 .26448 L
.54432 .26256 L
.53691 .2606 L
.53005 .25879 L
.52306 .25697 L
.5166 .25529 L
.51064 .25375 L
.50455 .2522 L
.49893 .25077 L
.49321 .24934 L
.48794 .24803 L
.48308 .24683 L
.47813 .24562 L
.47356 .24453 L
.46936 .24353 L
.46507 .24252 L
.46113 .2416 L
.45711 .24069 L
Mistroke
.45342 .23985 L
.45001 .2391 L
.44655 .23834 L
.44336 .23766 L
.44013 .23697 L
.43715 .23636 L
.43441 .2358 L
.43163 .23524 L
.42907 .23474 L
.42671 .23429 L
.42431 .23384 L
.4221 .23344 L
.41986 .23304 L
.4178 .23268 L
.4159 .23235 L
.41397 .23203 L
.4122 .23175 L
.41057 .23149 L
.4089 .23124 L
.40738 .23101 L
.40582 .23079 L
.40439 .2306 L
.40308 .23042 L
.40174 .23025 L
.40051 .2301 L
.39926 .22995 L
.39811 .22982 L
.39705 .2297 L
.39597 .22959 L
.39498 .2295 L
.39407 .22941 L
.39314 .22933 L
.39229 .22926 L
.39142 .22919 L
.39062 .22913 L
.38989 .22908 L
.38914 .22904 L
.38845 .229 L
.38781 .22897 L
.38716 .22894 L
.38657 .22891 L
.38596 .22889 L
.3854 .22887 L
.38489 .22886 L
.38436 .22885 L
.38413 .22885 L
.38388 .22884 L
.38362 .22884 L
.38351 .22884 L
.38339 .22884 L
Mistroke
.38327 .22884 L
.38316 .22884 L
.3831 .22884 L
.38305 .22884 L
.38302 .22884 L
.383 .22884 L
.38298 .22884 L
.38298 .22884 L
.38297 .22884 L
.38296 .22884 L
.38294 .22884 L
.38293 .22884 L
.38293 .22884 L
.38291 .22884 L
.3829 .22884 L
.38289 .22884 L
.38287 .22884 L
.38284 .22884 L
.38282 .22884 L
.38277 .22884 L
.38272 .22884 L
.38266 .22884 L
.38261 .22884 L
.3825 .22884 L
.3824 .22884 L
.38229 .22884 L
.3821 .22884 L
Mfstroke
.97619 .39731 m
.96084 .39416 L
.94416 .39058 L
.92856 .38711 L
.91364 .38367 L
.89784 .37991 L
.88276 .3762 L
.86686 .37219 L
.85169 .36826 L
.83726 .36444 L
.82209 .36033 L
.80768 .35635 L
.79402 .35252 L
.77971 .34843 L
.76617 .3445 L
.75204 .34035 L
.7387 .33637 L
.72613 .33259 L
.71304 .32861 L
.70074 .32483 L
.68799 .32087 L
.67602 .31714 L
.66481 .31361 L
.65322 .30995 L
.64237 .3065 L
.63224 .30327 L
.62178 .29992 L
.61202 .29678 L
.60199 .29355 L
.59265 .29054 L
.58396 .28773 L
.57503 .28485 L
.56673 .28217 L
.55904 .27968 L
.55113 .27713 L
.5438 .27477 L
.5363 .27236 L
.52936 .27013 L
.52293 .26807 L
.51635 .26598 L
.51027 .26405 L
.50407 .26209 L
.49834 .26029 L
.49305 .25863 L
.48766 .25695 L
.48268 .25541 L
.47808 .25399 L
.47339 .25256 L
.46907 .25125 L
.46467 .24993 L
Mistroke
.46061 .24871 L
.45687 .24761 L
.45307 .24649 L
.44956 .24547 L
.446 .24445 L
.44273 .24351 L
.43971 .24266 L
.43664 .24181 L
.43382 .24103 L
.43123 .24032 L
.42858 .23961 L
.42615 .23896 L
.42368 .23831 L
.42141 .23772 L
.41932 .23719 L
.4172 .23665 L
.41525 .23617 L
.41345 .23573 L
.41162 .23529 L
.40994 .23489 L
.40823 .23449 L
.40667 .23414 L
.40522 .23381 L
.40375 .23349 L
.4024 .2332 L
.40104 .23291 L
.39978 .23265 L
.39862 .23241 L
.39744 .23218 L
.39636 .23197 L
.39537 .23178 L
.39436 .23159 L
.39343 .23142 L
.39248 .23126 L
.39161 .23111 L
.39081 .23097 L
.39 .23084 L
.38925 .23073 L
.38857 .23062 L
.38787 .23052 L
.38722 .23043 L
.38657 .23034 L
.38597 .23026 L
.38541 .23018 L
.38485 .23012 L
.38433 .23005 L
.3838 .23 L
.38332 .22994 L
.38287 .2299 L
.38243 .22985 L
Mistroke
Mfstroke
.97619 .42674 m
.96299 .42381 L
.94853 .42045 L
.93491 .41715 L
.92178 .41384 L
.90778 .41018 L
.8943 .40654 L
.87998 .40255 L
.86621 .3986 L
.853 .39472 L
.83901 .3905 L
.82561 .38638 L
.81281 .38236 L
.7993 .37804 L
.78642 .37385 L
.77287 .36938 L
.75998 .36506 L
.74776 .36091 L
.73494 .3565 L
.7228 .35228 L
.71013 .34783 L
.69817 .34358 L
.68688 .33955 L
.67514 .33531 L
.66409 .3313 L
.65372 .32751 L
.64294 .32356 L
.63284 .31983 L
.6224 .31596 L
.61263 .31232 L
.6035 .30892 L
.59408 .30539 L
.58529 .3021 L
.5771 .29902 L
.56866 .29584 L
.56081 .29289 L
.55275 .28985 L
.54526 .28703 L
.5383 .28441 L
.53117 .28172 L
.52455 .27924 L
.51779 .2767 L
.51153 .27435 L
.50573 .27218 L
.4998 .26997 L
.49433 .26794 L
.48926 .26606 L
.48409 .26415 L
.47931 .26238 L
.47443 .2606 L
Mistroke
.46994 .25896 L
.46579 .25745 L
.46156 .25592 L
.45767 .25452 L
.4537 .2531 L
.45005 .2518 L
.44669 .25061 L
.44327 .24941 L
.44012 .24831 L
.43723 .2473 L
.43427 .24629 L
.43156 .24536 L
.4288 .24442 L
.42626 .24357 L
.42393 .24279 L
.42156 .242 L
.41938 .24129 L
.41737 .24064 L
.41533 .23998 L
.41345 .23938 L
.41155 .23878 L
.40979 .23823 L
.40818 .23773 L
.40655 .23723 L
.40504 .23678 L
.40352 .23632 L
.40212 .23591 L
.40083 .23553 L
.39952 .23516 L
.39832 .23482 L
.39722 .23451 L
.39609 .23419 L
.39506 .23391 L
.39402 .23363 L
.39306 .23338 L
.39217 .23315 L
.39127 .23292 L
.39045 .23271 L
.38969 .23252 L
.38892 .23233 L
.38821 .23216 L
.38749 .23199 L
.38683 .23184 L
.38622 .2317 L
.38561 .23156 L
.38504 .23144 L
.38446 .23131 L
.38393 .2312 L
.38345 .2311 L
.38296 .23101 L
Mistroke
Mfstroke
.97619 .45617 m
.96515 .45354 L
.95297 .45049 L
.94141 .44745 L
.93017 .44438 L
.9181 .44095 L
.90637 .43749 L
.89382 .43367 L
.88164 .42985 L
.86986 .42605 L
.85728 .42189 L
.84512 .41777 L
.83342 .41372 L
.82095 .40932 L
.80896 .40502 L
.79625 .40037 L
.78406 .39584 L
.77239 .39145 L
.76006 .38674 L
.74829 .3822 L
.73591 .37736 L
.72412 .37271 L
.71292 .36824 L
.70118 .36352 L
.69006 .35901 L
.67954 .35472 L
.66854 .3502 L
.65817 .34591 L
.64738 .34143 L
.63722 .33718 L
.62767 .33318 L
.61777 .32901 L
.60848 .32508 L
.59978 .32139 L
.59078 .31756 L
.58236 .31398 L
.57367 .31027 L
.56557 .30681 L
.55803 .30358 L
.55025 .30024 L
.54302 .29714 L
.5356 .29396 L
.5287 .291 L
.5223 .28826 L
.51574 .28545 L
.50966 .28284 L
.50402 .28043 L
.49825 .27796 L
.49291 .27569 L
.48745 .27336 L
Mistroke
.4824 .27122 L
.47774 .26924 L
.47298 .26723 L
.46859 .26537 L
.46411 .26349 L
.45999 .26176 L
.45618 .26017 L
.45231 .25856 L
.44873 .25707 L
.44544 .25571 L
.44209 .25433 L
.439 .25307 L
.43587 .25179 L
.43298 .25062 L
.43032 .24954 L
.42762 .24846 L
.42514 .24746 L
.42285 .24655 L
.42053 .24563 L
.41839 .24479 L
.41622 .24394 L
.41422 .24316 L
.41239 .24246 L
.41052 .24174 L
.40881 .24109 L
.40707 .24043 L
.40548 .23983 L
.40402 .23929 L
.40253 .23874 L
.40116 .23824 L
.39991 .23778 L
.39864 .23732 L
.39746 .2369 L
.39628 .23648 L
.39519 .2361 L
.39419 .23575 L
.39317 .2354 L
.39224 .23508 L
.39138 .23479 L
.39051 .2345 L
.38971 .23423 L
.3889 .23396 L
.38816 .23372 L
.38748 .2335 L
.38678 .23328 L
.38614 .23308 L
.3855 .23288 L
.38491 .2327 L
.38436 .23253 L
.38382 .23237 L
Mistroke
Mfstroke
.97619 .4856 m
.96733 .48334 L
.95748 .4807 L
.94805 .47804 L
.93881 .47531 L
.92881 .47224 L
.91902 .46912 L
.90844 .46562 L
.89808 .46209 L
.88797 .45855 L
.87707 .45463 L
.86644 .4507 L
.85611 .44681 L
.84501 .44254 L
.83423 .43831 L
.82269 .4337 L
.81151 .42917 L
.80071 .42472 L
.7892 .41991 L
.7781 .41522 L
.76631 .41017 L
.75498 .40527 L
.74412 .40053 L
.73264 .39546 L
.72166 .39058 L
.71119 .38589 L
.70016 .38091 L
.68967 .37614 L
.67867 .37111 L
.66823 .36631 L
.65835 .36175 L
.64803 .35696 L
.63828 .35241 L
.6291 .34811 L
.61952 .34362 L
.61052 .33938 L
.60118 .33497 L
.59242 .33082 L
.58421 .32693 L
.57571 .32289 L
.56777 .31911 L
.55958 .3152 L
.55194 .31156 L
.54481 .30815 L
.53748 .30465 L
.53066 .30139 L
.52432 .29836 L
.5178 .29524 L
.51174 .29234 L
.50554 .28938 L
Mistroke
.49979 .28663 L
.49447 .28409 L
.48901 .28149 L
.48397 .27908 L
.47882 .27663 L
.47406 .27437 L
.46967 .27229 L
.46518 .27016 L
.46105 .2682 L
.45723 .2664 L
.45333 .26457 L
.44974 .26288 L
.44608 .26116 L
.44272 .25959 L
.43962 .25814 L
.43646 .25668 L
.43356 .25533 L
.43088 .25409 L
.42816 .25284 L
.42565 .25169 L
.42311 .25052 L
.42077 .24946 L
.41862 .24848 L
.41644 .24749 L
.41443 .24659 L
.41239 .24567 L
.41052 .24484 L
.40881 .24407 L
.40706 .2433 L
.40546 .24259 L
.40399 .24195 L
.4025 .2413 L
.40113 .2407 L
.39974 .2401 L
.39847 .23955 L
.3973 .23905 L
.39611 .23854 L
.39502 .23808 L
.39402 .23766 L
.393 .23724 L
.39207 .23685 L
.39112 .23646 L
.39026 .2361 L
.38946 .23578 L
.38865 .23545 L
.38791 .23515 L
.38716 .23485 L
.38648 .23458 L
.38585 .23433 L
.38522 .23409 L
Mistroke
Mfstroke
.97619 .51503 m
.96952 .51322 L
.96205 .51108 L
.95484 .5089 L
.94772 .50665 L
.93995 .50409 L
.93227 .50146 L
.9239 .49848 L
.91562 .49544 L
.90747 .49236 L
.89859 .4889 L
.88984 .48542 L
.88125 .48192 L
.87192 .47804 L
.86276 .47415 L
.85285 .46988 L
.84314 .46561 L
.83366 .46139 L
.82343 .45677 L
.81346 .45221 L
.80276 .44725 L
.79234 .44237 L
.78226 .4376 L
.77147 .43245 L
.76104 .42743 L
.75099 .42255 L
.74028 .41732 L
.73 .41226 L
.7191 .40686 L
.70865 .40166 L
.69867 .39666 L
.68813 .39136 L
.67809 .38628 L
.66854 .38144 L
.6585 .37633 L
.64899 .37146 L
.63903 .36636 L
.62961 .36152 L
.62072 .35694 L
.61145 .35215 L
.60272 .34763 L
.59366 .34293 L
.58515 .3385 L
.57717 .33435 L
.56891 .33004 L
.56117 .32601 L
.55394 .32223 L
.54647 .31833 L
.53951 .31469 L
.53233 .31093 L
Mistroke
.52566 .30744 L
.51944 .30418 L
.51306 .30084 L
.50713 .29774 L
.50106 .29456 L
.49543 .29161 L
.49021 .28888 L
.48487 .28609 L
.47992 .2835 L
.47535 .28112 L
.47068 .27868 L
.46636 .27642 L
.46195 .27413 L
.45789 .27201 L
.45413 .27006 L
.45031 .26808 L
.44678 .26625 L
.44353 .26457 L
.44022 .26286 L
.43717 .26128 L
.43406 .25968 L
.43121 .25822 L
.42858 .25687 L
.42591 .2555 L
.42345 .25424 L
.42095 .25297 L
.41866 .25181 L
.41656 .25074 L
.41442 .24965 L
.41245 .24866 L
.41065 .24775 L
.40882 .24683 L
.40713 .24599 L
.40543 .24514 L
.40386 .24436 L
.40243 .24364 L
.40097 .24292 L
.39963 .24226 L
.3984 .24166 L
.39716 .24104 L
.39601 .24048 L
.39486 .23992 L
.39379 .2394 L
.39282 .23893 L
.39183 .23846 L
.39092 .23802 L
.39001 .23758 L
.38917 .23718 L
.38839 .23682 L
.38763 .23645 L
Mistroke
Mfstroke
.97619 .54446 m
.97173 .54318 L
.96669 .54164 L
.96179 .54007 L
.95691 .53842 L
.95154 .53653 L
.94619 .53456 L
.94029 .53232 L
.93439 .53 L
.92853 .52762 L
.92207 .52493 L
.91564 .52218 L
.90925 .51939 L
.90223 .51626 L
.89525 .51309 L
.88761 .50955 L
.88001 .50597 L
.8725 .50239 L
.86429 .49841 L
.85618 .49443 L
.84734 .49004 L
.83862 .48567 L
.83005 .48133 L
.82075 .47657 L
.81163 .47187 L
.80272 .46724 L
.79309 .46221 L
.7837 .45727 L
.77361 .45192 L
.7638 .44669 L
.75429 .4416 L
.74411 .43612 L
.73428 .43081 L
.72481 .42567 L
.71473 .42018 L
.70504 .41489 L
.69477 .40926 L
.68494 .40386 L
.67555 .39868 L
.66565 .39321 L
.65621 .38798 L
.64631 .38248 L
.63691 .37725 L
.628 .37229 L
.61868 .36709 L
.60988 .36217 L
.60158 .35753 L
.59292 .35268 L
.58478 .34812 L
.57634 .34338 L
Mistroke
.56841 .33892 L
.56098 .33475 L
.5533 .33042 L
.54611 .32638 L
.5387 .3222 L
.53179 .31831 L
.52534 .31468 L
.51871 .31094 L
.51254 .30746 L
.50681 .30423 L
.50092 .30091 L
.49545 .29783 L
.48985 .29467 L
.48467 .29175 L
.47986 .28904 L
.47495 .28628 L
.4704 .28372 L
.4662 .28135 L
.4619 .27894 L
.45793 .2767 L
.45388 .27443 L
.45015 .27234 L
.44671 .27041 L
.4432 .26844 L
.43997 .26663 L
.43668 .26479 L
.43366 .2631 L
.43088 .26154 L
.42805 .25996 L
.42544 .25851 L
.42305 .25718 L
.42062 .25583 L
.41838 .25458 L
.41611 .25332 L
.41402 .25217 L
.41211 .25111 L
.41016 .25003 L
.40838 .24905 L
.40674 .24815 L
.40508 .24723 L
.40355 .24639 L
.402 .24554 L
.40058 .24476 L
.39928 .24405 L
.39796 .24333 L
.39675 .24267 L
.39552 .242 L
.3944 .24139 L
.39337 .24083 L
.39235 .24028 L
Mistroke
Mfstroke
.97619 .57389 m
.97395 .57321 L
.9714 .57239 L
.96891 .57153 L
.9664 .57063 L
.96361 .56959 L
.96081 .56849 L
.95768 .56723 L
.95453 .56591 L
.95136 .56454 L
.94782 .56297 L
.94425 .56134 L
.94067 .55967 L
.93667 .55777 L
.93264 .55582 L
.92816 .55361 L
.92364 .55135 L
.91909 .54904 L
.91404 .54644 L
.90897 .54379 L
.90333 .54082 L
.89767 .5378 L
.892 .53475 L
.88573 .53135 L
.87945 .52792 L
.87319 .52447 L
.86629 .52064 L
.85942 .51681 L
.85187 .51258 L
.84437 .50835 L
.83694 .50414 L
.82881 .49952 L
.82078 .49493 L
.81288 .4904 L
.80427 .48545 L
.79582 .48057 L
.78667 .47528 L
.7777 .47007 L
.76894 .46498 L
.75951 .45948 L
.75033 .45412 L
.74048 .44835 L
.73093 .44275 L
.72169 .43732 L
.71184 .43153 L
.70234 .42593 L
.69322 .42055 L
.68353 .41483 L
.67425 .40934 L
.66445 .40354 L
Mistroke
.65509 .398 L
.64617 .39271 L
.63679 .38715 L
.62789 .38186 L
.61857 .37632 L
.60975 .37108 L
.60141 .36612 L
.59272 .36094 L
.58453 .35607 L
.57682 .35148 L
.56882 .34671 L
.5613 .34223 L
.55352 .33759 L
.54624 .33325 L
.53943 .32918 L
.5324 .32499 L
.52584 .32108 L
.51973 .31743 L
.51343 .31367 L
.50757 .31017 L
.50155 .30658 L
.49596 .30324 L
.49077 .30014 L
.48545 .29697 L
.48052 .29403 L
.47548 .29102 L
.47082 .28824 L
.46651 .28567 L
.46211 .28304 L
.45804 .28062 L
.45428 .27838 L
.45045 .27609 L
.44691 .27398 L
.44331 .27184 L
.43999 .26986 L
.43694 .26804 L
.43383 .26619 L
.43096 .26449 L
.42833 .26292 L
.42564 .26133 L
.42318 .25986 L
.42067 .25837 L
.41837 .257 L
.41625 .25575 L
.4141 .25447 L
.41213 .2533 L
.41013 .25212 L
.40829 .25103 L
.40661 .25003 L
.40493 .24904 L
Mistroke
Mfstroke
.97619 .60332 m
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
Mistroke
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
.97619 .60332 L
Mistroke
Mfstroke
.14276 .08823 m
.16066 .09929 L
s
% Start of user PostScript
0.12489656 0.12489656 0.14369564 0.14369564 MAarrowhead1
% End of user PostScript
.13776 .1097 m
.15512 .11948 L
s
% Start of user PostScript
0.1196431 0.16136758 0.13787275 0.17799268 MAarrowhead1
% End of user PostScript
.13274 .13089 m
.14955 .13937 L
s
% Start of user PostScript
0.11437714 0.19736633 0.13203155 0.21177297 MAarrowhead1
% End of user PostScript
.12771 .1518 m
.14398 .15894 L
s
% Start of user PostScript
0.10909995 0.23289308 0.12617391 0.24503694 MAarrowhead1
% End of user PostScript
.12268 .17243 m
.13838 .17822 L
s
% Start of user PostScript
0.10381288 0.26794837 0.12030175 0.27778542 MAarrowhead1
% End of user PostScript
.11764 .19279 m
.13278 .19719 L
s
% Start of user PostScript
0.098517133 0.30253282 0.11441692 0.31001943 MAarrowhead1
% End of user PostScript
.11258 .21287 m
.12716 .21586 L
s
% Start of user PostScript
0.093214016 0.33664736 0.1085213 0.34174031 MAarrowhead1
% End of user PostScript
.10753 .23267 m
.12154 .23423 L
s
% Start of user PostScript
0.087904763 0.37029305 0.10261672 0.37294967 MAarrowhead1
% End of user PostScript
.10247 .2522 m
.11591 .2523 L
s
% Start of user PostScript
0.082590629 0.40347117 0.096705031 0.40364944 MAarrowhead1
% End of user PostScript
.0974 .27145 m
.11027 .27008 L
s
% Start of user PostScript
0.077272827 0.43618316 0.090788028 0.43384173 MAarrowhead1
% End of user PostScript
.09234 .29044 m
.10464 .28755 L
s
% Start of user PostScript
0.071952613 0.46843069 0.084867533 0.463529 MAarrowhead1
% End of user PostScript
.08727 .30914 m
.099 .30473 L
s
% Start of user PostScript
0.066631174 0.50021559 0.078945293 0.49271388 MAarrowhead1
% End of user PostScript
.0822 .32758 m
.09336 .32161 L
s
% Start of user PostScript
0.061309691 0.53153984 0.073023049 0.5213993 MAarrowhead1
% End of user PostScript
.07713 .34575 m
.08772 .3382 L
s
% Start of user PostScript
0.055989347 0.56240564 0.06710252 0.5495884 MAarrowhead1
% End of user PostScript
.07207 .36365 m
.08208 .35451 L
s
% Start of user PostScript
0.050671301 0.59281533 0.061185387 0.57728452 MAarrowhead1
% End of user PostScript
.06701 .38128 m
.07645 .37052 L
s
% Start of user PostScript
0.045356686 0.62277138 0.05527331 0.60449128 MAarrowhead1
% End of user PostScript
.06195 .39865 m
.07083 .38625 L
s
% Start of user PostScript
0.040046626 0.65227645 0.049367909 0.63121244 MAarrowhead1
% End of user PostScript
.0569 .41575 m
.06521 .40169 L
s
% Start of user PostScript
0.034742219 0.68133334 0.043470774 0.65745199 MAarrowhead1
% End of user PostScript
.05185 .43259 m
.0596 .41686 L
s
% Start of user PostScript
0.029444553 0.70994502 0.037583454 0.6832141 MAarrowhead1
% End of user PostScript
.04681 .44917 m
.05401 .43174 L
s
% Start of user PostScript
0.02415468 0.73811454 0.03170746 0.70850309 MAarrowhead1
% End of user PostScript
.04178 .46549 m
.04842 .44635 L
s
% Start of user PostScript
0.018873639 0.76584512 0.025844275 0.7333235 MAarrowhead1
% End of user PostScript
.17749 .08514 m
.19333 .09587 L
s
% Start of user PostScript
0.16136758 0.1196431 0.17799268 0.13787275 MAarrowhead1
% End of user PostScript
.08134 .46992 m
.0863 .45097 L
s
% Start of user PostScript
0.060404277 0.7733691 0.065616441 0.74117274 MAarrowhead1
% End of user PostScript
.21178 .08204 m
.2255 .09243 L
s
% Start of user PostScript
0.19736633 0.11437714 0.21177297 0.13203155 MAarrowhead1
% End of user PostScript
.12139 .47452 m
.12472 .4558 L
s
% Start of user PostScript
0.10245788 0.78118339 0.10596111 0.74937266 MAarrowhead1
% End of user PostScript
.24561 .07893 m
.25718 .08898 L
s
% Start of user PostScript
0.23289308 0.10909995 0.24503694 0.12617391 MAarrowhead1
% End of user PostScript
.16197 .4793 m
.16373 .46085 L
s
% Start of user PostScript
0.14506448 0.78930462 0.14691623 0.75794651 MAarrowhead1
% End of user PostScript
.279 .07582 m
.28837 .08553 L
s
% Start of user PostScript
0.26794837 0.10381288 0.27778542 0.12030175 MAarrowhead1
% End of user PostScript
.2031 .48427 m
.20336 .46613 L
s
% Start of user PostScript
0.18825649 0.7977506 0.18852317 0.76691926 MAarrowhead1
% End of user PostScript
.31194 .0727 m
.31907 .08206 L
s
% Start of user PostScript
0.30253282 0.098517133 0.31001943 0.11441692 MAarrowhead1
% End of user PostScript
.24483 .48945 m
.24364 .47166 L
s
% Start of user PostScript
0.2320689 0.80654068 0.23082715 0.77631857 MAarrowhead1
% End of user PostScript
.34443 .06958 m
.34928 .07859 L
s
% Start of user PostScript
0.33664736 0.093214016 0.34174031 0.1085213 MAarrowhead1
% End of user PostScript
.28718 .49484 m
.28465 .47746 L
s
% Start of user PostScript
0.27653957 0.81569589 0.27387764 0.78617466 MAarrowhead1
% End of user PostScript
.37647 .06646 m
.379 .07512 L
s
% Start of user PostScript
0.37029305 0.087904763 0.37294967 0.10261672 MAarrowhead1
% End of user PostScript
.3302 .50045 m
.32641 .48355 L
s
% Start of user PostScript
0.32170951 0.82523897 0.31772902 0.79652083 MAarrowhead1
% End of user PostScript
.40807 .06333 m
.40824 .07164 L
s
% Start of user PostScript
0.40347117 0.082590629 0.40364944 0.096705031 MAarrowhead1
% End of user PostScript
.37393 .50631 m
.36899 .48995 L
s
% Start of user PostScript
0.36762329 0.83519474 0.36244112 0.80739386 MAarrowhead1
% End of user PostScript
.43922 .0602 m
.43699 .06815 L
s
% Start of user PostScript
0.43618316 0.077272827 0.43384173 0.090788028 MAarrowhead1
% End of user PostScript
.41841 .51243 m
.41246 .49668 L
s
% Start of user PostScript
0.41432934 0.84559018 0.40807994 0.81883429 MAarrowhead1
% End of user PostScript
.46993 .05707 m
.46527 .06467 L
s
% Start of user PostScript
0.46843069 0.071952613 0.463529 0.084867533 MAarrowhead1
% End of user PostScript
.4637 .51883 m
.45687 .50378 L
s
% Start of user PostScript
0.46188055 0.85645487 0.45471863 0.8308873 MAarrowhead1
% End of user PostScript
.50021 .05393 m
.49306 .06118 L
s
% Start of user PostScript
0.50021559 0.066631174 0.49271388 0.078945293 MAarrowhead1
% End of user PostScript
.50984 .52552 m
.50232 .51126 L
s
% Start of user PostScript
0.51033471 0.86782129 0.50243841 0.8436032 MAarrowhead1
% End of user PostScript
.53004 .0508 m
.52038 .0577 L
s
% Start of user PostScript
0.53153984 0.061309691 0.5213993 0.073023049 MAarrowhead1
% End of user PostScript
.55691 .53252 m
.54889 .51917 L
s
% Start of user PostScript
0.55975507 0.87972465 0.55132971 0.85703779 MAarrowhead1
% End of user PostScript
.55943 .04767 m
.54723 .05421 L
s
% Start of user PostScript
0.56240564 0.055989347 0.5495884 0.06710252 MAarrowhead1
% End of user PostScript
.60496 .53987 m
.59666 .52754 L
s
% Start of user PostScript
0.61021119 0.89220439 0.60149376 0.87125427 MAarrowhead1
% End of user PostScript
.5884 .04454 m
.5736 .05073 L
s
% Start of user PostScript
0.59281533 0.050671301 0.57728452 0.061185387 MAarrowhead1
% End of user PostScript
.65408 .54758 m
.64576 .53641 L
s
% Start of user PostScript
0.66177958 0.90530356 0.65304414 0.88632332 MAarrowhead1
% End of user PostScript
.61693 .04141 m
.59952 .04725 L
s
% Start of user PostScript
0.62277138 0.045356686 0.60449128 0.05527331 MAarrowhead1
% End of user PostScript
.70433 .55568 m
.69629 .54583 L
s
% Start of user PostScript
0.71454484 0.91907 0.70610888 0.90232496 MAarrowhead1
% End of user PostScript
.64503 .03829 m
.62496 .04377 L
s
% Start of user PostScript
0.65227645 0.040046626 0.63121244 0.049367909 MAarrowhead1
% End of user PostScript
.75581 .56421 m
.74841 .55585 L
s
% Start of user PostScript
0.76860055 0.93355673 0.76083284 0.91934994 MAarrowhead1
% End of user PostScript
.6727 .03516 m
.64995 .0403 L
s
% Start of user PostScript
0.68133334 0.034742219 0.65745199 0.043470774 MAarrowhead1
% End of user PostScript
.80862 .5732 m
.80227 .56653 L
s
% Start of user PostScript
0.8240508 0.9488229 0.81738088 0.93750183 MAarrowhead1
% End of user PostScript
.69995 .03205 m
.67449 .03684 L
s
% Start of user PostScript
0.70994502 0.029444553 0.6832141 0.037583454 MAarrowhead1
% End of user PostScript
.86287 .58268 m
.85804 .57795 L
s
% Start of user PostScript
0.88101157 0.96493452 0.8759414 0.95689928 MAarrowhead1
% End of user PostScript
.72678 .02893 m
.69857 .03338 L
s
% Start of user PostScript
0.73811454 0.02415468 0.70850309 0.03170746 MAarrowhead1
% End of user PostScript
.91868 .5927 m
.91593 .59018 L
s
% Start of user PostScript
0.93961269 0.98196573 0.93673095 0.97767911 MAarrowhead1
% End of user PostScript
.75319 .02582 m
.72221 .02993 L
s
% Start of user PostScript
0.76584512 0.018873639 0.7333235 0.025844275 MAarrowhead1
% End of user PostScript
.76035 .05027 m
.72969 .05334 L
s
% Start of user PostScript
0.7733691 0.060404277 0.74117274 0.065616441 MAarrowhead1
% End of user PostScript
.76779 .07502 m
.7375 .07708 L
s
% Start of user PostScript
0.78118339 0.10245788 0.74937266 0.10596111 MAarrowhead1
% End of user PostScript
.77553 .1001 m
.74566 .10119 L
s
% Start of user PostScript
0.78930462 0.14506448 0.75794651 0.14691623 MAarrowhead1
% End of user PostScript
.78357 .12552 m
.75421 .12568 L
s
% Start of user PostScript
0.7977506 0.18825649 0.76691926 0.18852317 MAarrowhead1
% End of user PostScript
.79194 .15131 m
.76316 .15058 L
s
% Start of user PostScript
0.80654068 0.2320689 0.77631857 0.23082715 MAarrowhead1
% End of user PostScript
.80066 .17749 m
.77255 .17592 L
s
% Start of user PostScript
0.81569589 0.27653957 0.78617466 0.27387764 MAarrowhead1
% End of user PostScript
.80975 .20407 m
.7824 .20173 L
s
% Start of user PostScript
0.82523897 0.32170951 0.79652083 0.31772902 MAarrowhead1
% End of user PostScript
.81923 .2311 m
.79276 .22805 L
s
% Start of user PostScript
0.83519474 0.36762329 0.80739386 0.36244112 MAarrowhead1
% End of user PostScript
.82913 .25859 m
.80365 .25491 L
s
% Start of user PostScript
0.84559018 0.41432934 0.81883429 0.40807994 MAarrowhead1
% End of user PostScript
.83948 .28658 m
.81513 .28236 L
s
% Start of user PostScript
0.85645487 0.46188055 0.8308873 0.45471863 MAarrowhead1
% End of user PostScript
.85031 .3151 m
.82724 .31045 L
s
% Start of user PostScript
0.86782129 0.51033471 0.8436032 0.50243841 MAarrowhead1
% End of user PostScript
.86164 .34419 m
.84004 .33923 L
s
% Start of user PostScript
0.87972465 0.55975507 0.85703779 0.55132971 MAarrowhead1
% End of user PostScript
.87353 .37389 m
.85358 .36876 L
s
% Start of user PostScript
0.89220439 0.61021119 0.87125427 0.60149376 MAarrowhead1
% End of user PostScript
.886 .40424 m
.86793 .3991 L
s
% Start of user PostScript
0.90530356 0.66177958 0.88632332 0.65304414 MAarrowhead1
% End of user PostScript
.89911 .4353 m
.88317 .43033 L
s
% Start of user PostScript
0.91907 0.71454484 0.90232496 0.70610888 MAarrowhead1
% End of user PostScript
.91291 .46712 m
.89938 .46254 L
s
% Start of user PostScript
0.93355673 0.76860055 0.91934994 0.76083284 MAarrowhead1
% End of user PostScript
.92745 .49975 m
.91667 .49583 L
s
% Start of user PostScript
0.9488229 0.8240508 0.93750183 0.81738088 MAarrowhead1
% End of user PostScript
.94279 .53328 m
.93514 .5303 L
s
% Start of user PostScript
0.96493452 0.88101157 0.95689928 0.8759414 MAarrowhead1
% End of user PostScript
.95901 .56777 m
.95493 .56608 L
s
% Start of user PostScript
0.98196573 0.93961269 0.97767911 0.93673095 MAarrowhead1
% End of user PostScript
.97619 .60332 m
.97619 .60332 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{520.25, 321.563},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Initialisation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "undertaken", 
    " ", "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob1", "=", "initialProb1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob2", "=", "initialProb2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfProb", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfProbabilitiesNumber", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numberOfDigitsOfnOfIterations", "=", 
     RowBox[{"Length", "[", 
      RowBox[{"IntegerDigits", "[", "nOfIterations", "]"}], "]"}]}], 
    ";"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Execution", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Draw", " ", "a", " ", "black", " ", "ball", " ", "with", " ", "number", 
    " ", "0", " ", "for", " ", "the", " ", "initial", " ", "conditions"}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"Disk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"initialProb1", ",", "initialProb2"}], "}"}], ",", "0.03"}], 
       "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"Text", "[", 
       RowBox[{"\"\<0\>\"", ",", 
        RowBox[{"Offset", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"initialProb1", ",", "initialProb2"}], "}"}]}], "]"}], ",",
         
        RowBox[{"TextStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "10"}], ",", 
           RowBox[{"FontWeight", "\[Rule]", "Bold"}], ",", 
           RowBox[{"FontColor", "\[Rule]", 
            RowBox[{"GrayLevel", "[", "1", "]"}]}]}], "}"}]}]}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProbabilitiesNumber", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "initialProb1"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"and", " ", "the", " ", "rest", " ", "of", " ", "them"}], 
     "..."}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "nOfIterations"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
         RowBox[{
          RowBox[{"decisions", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{"decisions", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "Cooperate"}], ",", 
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "=", "Defect"}], ",", 
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "=", "Cooperate"}]}], "]"}]}], 
        "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Random", "[", "]"}], "\[LessEqual]", "prob2"}], ",", 
         RowBox[{
          RowBox[{"decisions", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{"decisions", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Random", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "Cooperate"}], ",", 
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "=", "Defect"}], ",", 
           RowBox[{
            RowBox[{"decisions", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "=", "Cooperate"}]}], "]"}]}], 
        "]"}], ";", " ", "\[IndentingNewLine]", "\t", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"For", " ", "the", " ", "first", " ", "player"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob1", "=", 
        RowBox[{"prob1", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"For", " ", "the", " ", "second", " ", "player"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob2", "=", 
        RowBox[{"prob2", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob2"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"numberOfDigits", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"IntegerDigits", "[", "i", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", 
            RowBox[{"10", "^", 
             RowBox[{"(", 
              RowBox[{"numberOfDigits", "-", "1"}], ")"}]}]}], "]"}], 
          "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
           "This", " ", "condition", " ", "selects", " ", "the", " ", 
            RowBox[{"numbers", ":", " ", "1"}]}], ",", "2", ",", "3", ",", "...",
            ",", "9", ",", "10", ",", "20", ",", "30", ",", "...", ",", "90", 
           ",", "100", ",", "200", ",", "300", ",", "...", ",", "900", ",", 
           "1000"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"Draw", " ", "a", " ", "disk"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"listOfProb", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RGBColor", "[", 
               RowBox[{
                RowBox[{"0.6", "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", "0.6"}], ")"}], "*", 
                  RowBox[{"i", "/", "nOfIterations"}]}]}], ",", "0", ",", 
                "0"}], "]"}], ",", 
              RowBox[{"Disk", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"prob1", ",", "prob2"}], "}"}], ",", "0.03"}], 
               "]"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{"The", " ", "last", " ", "disk", " ", "is", " ", "red"}], 
           "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", "nOfIterations"}], ",", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"listOfProb", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                RowBox[{"Disk", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"prob1", ",", "prob2"}], "}"}], ",", "0.03"}], 
                 "]"}]}], "}"}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]",
           "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
           "Draw", " ", "a", " ", "black", " ", "circle", " ", "surrounding", 
            " ", "the", " ", "disk"}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"listOfProb", ",", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"prob1", ",", "prob2"}], "}"}], ",", "0.03"}], "]"}]}],
            "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"listOfProb", ",", 
            RowBox[{"Text", "[", 
             RowBox[{"i", ",", 
              RowBox[{"Offset", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"prob1", ",", "prob2"}], "}"}]}], "]"}], ",", 
              RowBox[{"TextStyle", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
                 RowBox[{"FontSize", "\[Rule]", "5"}], ",", 
                 RowBox[{"FontWeight", "\[Rule]", "Bold"}], ",", 
                 RowBox[{"FontColor", "\[Rule]", 
                  RowBox[{"GrayLevel", "[", "0", "]"}]}]}], "}"}]}]}], 
             "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"listOfProbabilitiesNumber", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "prob1"}], "}"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<End of iteration \>\"", ",", "i"}], "]"}], ";"}], "*)"}],
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"{", 
       RowBox[{"RGBColor", "[", 
        RowBox[{"0", ",", "0", ",", "0"}], "]"}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graphWithBalls", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", "listOfProb", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Show", "[", "graphWithBalls", "]"}], ";"}]}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.924642 0.0147151 0.57146 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.48613 .30045 m
matrix currentmatrix
0.0277393 0.0171438 scale
17.525 17.5253 1 0 365.73 arc
setmatrix F
gsave
.48613 .30045 -65.5 -10.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(0) show
68.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6 0 0 r
.54392 .33616 m
matrix currentmatrix
0.0277393 0.0171438 scale
19.6083 19.6083 1 0 365.73 arc
setmatrix F
0 g
.5 Mabswid
[ ] 0 setdash
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
19.6083 19.6083 1 0 365.73 arc
setmatrix s
gsave
.54392 .33616 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.6 0 0 r
.59449 .36741 m
matrix currentmatrix
0.0277393 0.0171438 scale
21.4314 21.4311 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
21.4314 21.4311 1 0 365.73 arc
setmatrix s
gsave
.59449 .36741 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 0 r
.45182 .27924 m
matrix currentmatrix
0.0277393 0.0171438 scale
16.2881 16.2881 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
16.2881 16.2881 1 0 365.73 arc
setmatrix s
gsave
.45182 .27924 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.6 0 0 r
.34482 .21311 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.4308 12.4307 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.4308 12.4307 1 0 365.73 arc
setmatrix s
gsave
.34482 .21311 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.6 0 0 r
.26456 .16351 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.53739 9.53756 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.53739 9.53756 1 0 365.73 arc
setmatrix s
gsave
.26456 .16351 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.6 0 0 r
.35005 .21634 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.6193 12.6191 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.6193 12.6191 1 0 365.73 arc
setmatrix s
gsave
.35005 .21634 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.6 0 0 r
.42485 .26257 m
matrix currentmatrix
0.0277393 0.0171438 scale
15.3158 15.3157 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
15.3158 15.3157 1 0 365.73 arc
setmatrix s
gsave
.42485 .26257 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.6 0 0 r
.32459 .20061 m
matrix currentmatrix
0.0277393 0.0171438 scale
11.7015 11.7016 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
11.7015 11.7016 1 0 365.73 arc
setmatrix s
gsave
.32459 .20061 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.6 0 0 r
.40257 .2488 m
matrix currentmatrix
0.0277393 0.0171438 scale
14.5127 14.5125 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
14.5127 14.5125 1 0 365.73 arc
setmatrix s
gsave
.40257 .2488 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.6 0 0 r
.47081 .29097 m
matrix currentmatrix
0.0277393 0.0171438 scale
16.9727 16.9723 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
16.9727 16.9723 1 0 365.73 arc
setmatrix s
gsave
.47081 .29097 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.601 0 0 r
.41787 .25826 m
matrix currentmatrix
0.0277393 0.0171438 scale
15.0642 15.0643 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
15.0642 15.0643 1 0 365.73 arc
setmatrix s
gsave
.41787 .25826 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.601 0 0 r
.17521 .10829 m
matrix currentmatrix
0.0277393 0.0171438 scale
6.31632 6.31657 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
6.31632 6.31657 1 0 365.73 arc
setmatrix s
gsave
.17521 .10829 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.602 0 0 r
.38976 .24089 m
matrix currentmatrix
0.0277393 0.0171438 scale
14.0509 14.0511 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
14.0509 14.0511 1 0 365.73 arc
setmatrix s
gsave
.38976 .24089 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.602 0 0 r
.25836 .15967 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.31388 9.31357 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.31388 9.31357 1 0 365.73 arc
setmatrix s
gsave
.25836 .15967 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.602 0 0 r
.26588 .16432 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.58497 9.58481 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.58497 9.58481 1 0 365.73 arc
setmatrix s
gsave
.26588 .16432 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.603 0 0 r
.32524 .20101 m
matrix currentmatrix
0.0277393 0.0171438 scale
11.7249 11.7249 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
11.7249 11.7249 1 0 365.73 arc
setmatrix s
gsave
.32524 .20101 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.603 0 0 r
.33553 .20737 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.0959 12.0959 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.0959 12.0959 1 0 365.73 arc
setmatrix s
gsave
.33553 .20737 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.604 0 0 r
.50994 .31516 m
matrix currentmatrix
0.0277393 0.0171438 scale
18.3833 18.3833 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
18.3833 18.3833 1 0 365.73 arc
setmatrix s
gsave
.50994 .31516 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
1.000 setlinewidth
grestore
.604 0 0 r
.2555 .15791 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.21078 9.21091 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.21078 9.21091 1 0 365.73 arc
setmatrix s
gsave
.2555 .15791 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.608 0 0 r
.37934 .23445 m
matrix currentmatrix
0.0277393 0.0171438 scale
13.6752 13.6755 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
13.6752 13.6755 1 0 365.73 arc
setmatrix s
gsave
.37934 .23445 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.612 0 0 r
.31588 .19522 m
matrix currentmatrix
0.0277393 0.0171438 scale
11.3875 11.3872 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
11.3875 11.3872 1 0 365.73 arc
setmatrix s
gsave
.31588 .19522 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.616 0 0 r
.35411 .21885 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.7657 12.7656 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.7657 12.7656 1 0 365.73 arc
setmatrix s
gsave
.35411 .21885 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.62 0 0 r
.39906 .24664 m
matrix currentmatrix
0.0277393 0.0171438 scale
14.3861 14.3865 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
14.3861 14.3865 1 0 365.73 arc
setmatrix s
gsave
.39906 .24664 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.624 0 0 r
.33573 .20749 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.1031 12.1029 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.1031 12.1029 1 0 365.73 arc
setmatrix s
gsave
.33573 .20749 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.628 0 0 r
.17286 .10683 m
matrix currentmatrix
0.0277393 0.0171438 scale
6.2316 6.23141 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
6.2316 6.23141 1 0 365.73 arc
setmatrix s
gsave
.17286 .10683 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(700) show
1.000 setlinewidth
grestore
.632 0 0 r
.42417 .26215 m
matrix currentmatrix
0.0277393 0.0171438 scale
15.2913 15.2912 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
15.2913 15.2912 1 0 365.73 arc
setmatrix s
gsave
.42417 .26215 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.636 0 0 r
.54579 .33731 m
matrix currentmatrix
0.0277393 0.0171438 scale
19.6757 19.6753 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
19.6757 19.6753 1 0 365.73 arc
setmatrix s
gsave
.54579 .33731 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
1.000 setlinewidth
grestore
.64 0 0 r
.2575 .15914 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.28287 9.28266 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.28287 9.28266 1 0 365.73 arc
setmatrix s
gsave
.2575 .15914 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.68 0 0 r
.34302 .212 m
matrix currentmatrix
0.0277393 0.0171438 scale
12.3659 12.366 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
12.3659 12.366 1 0 365.73 arc
setmatrix s
gsave
.34302 .212 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.72 0 0 r
.26035 .1609 m
matrix currentmatrix
0.0277393 0.0171438 scale
9.38562 9.38532 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
9.38562 9.38532 1 0 365.73 arc
setmatrix s
gsave
.26035 .1609 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
.76 0 0 r
.19731 .12194 m
matrix currentmatrix
0.0277393 0.0171438 scale
7.11303 7.11278 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
7.11303 7.11278 1 0 365.73 arc
setmatrix s
gsave
.19731 .12194 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.8 0 0 r
.2322 .14351 m
matrix currentmatrix
0.0277393 0.0171438 scale
8.37081 8.37096 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
8.37081 8.37096 1 0 365.73 arc
setmatrix s
gsave
.2322 .14351 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.84 0 0 r
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix s
gsave
.94845 .58618 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.88 0 0 r
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix s
gsave
.94845 .58618 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7000) show
1.000 setlinewidth
grestore
.92 0 0 r
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix s
gsave
.94845 .58618 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.96 0 0 r
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix s
gsave
.94845 .58618 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9000) show
1.000 setlinewidth
grestore
1 0 0 r
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
.94845 .58618 m
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix F
0 g
newpath
matrix currentmatrix
0.0277393 0.0171438 scale
34.1916 34.192 1 0 365.73 arc
setmatrix s
gsave
.94845 .58618 -69.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{371.938, 229.875},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 370.938}, {228.875, 0}} -> {-0.0266426, -0.0257554, \
0.0029204, 0.0047253}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figures - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"finalFigure", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "graphWithTrajectories", ",", "graphWithArrows", ",", 
        "graphWithBalls"}], "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.05"}], ",", 
         RowBox[{"-", "0.05"}]}], "}"}]}], ",", 
      RowBox[{"TextStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", " ", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"StyleForm", "[", 
          RowBox[{"\"\<       Propensity to cooperate, Player1\>\"", ",", 
           RowBox[{"FontSize", "\[Rule]", "13"}]}], "]"}], ",", 
         RowBox[{"StyleForm", "[", 
          RowBox[{"\"\<       Propensity to cooperate, Player2\>\"", ",", 
           RowBox[{"FontSize", "\[Rule]", "13"}]}], "]"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"FrameStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.14"}], ",", "1.03"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.14"}], ",", "1.03"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeSeriesFigure", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"listOfProbabilitiesNumber", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.02"}], ",", "1.02"}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"TextStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "8"}]}], "}"}]}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<Iteration\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}], ",", "None", ",", 
        RowBox[{"StyleForm", "[", 
         RowBox[{"\"\<Propensity to cooperate, Player1\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "8"}]}], "]"}], ",", "None"}], 
       "}"}]}], ",", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"1000", "*", "i"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"0.1", "*", "i"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", "None", 
        ",", "None"}], "}"}]}], ",", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1000", "*", "i"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Dashing", "[", 
               RowBox[{"{", 
                RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}], ",", 
              RowBox[{"GrayLevel", "[", "0.7", "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"0.1", "*", "i"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Dashing", "[", 
               RowBox[{"{", 
                RowBox[{"0.01", ",", "0.01"}], "}"}], "]"}], ",", 
              RowBox[{"GrayLevel", "[", "0.7", "]"}]}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.119658 0.854701 0.119658 0.854701 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -96.5938 -15.6875 ]
[.5 -0.0125 96.5938 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -15.6875 -96.5938 ]
[-0.01875 .5 0 96.5938 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.11966 .06442 -5 -15.6875 ]
[.11966 .06442 5 0 ]
[.2906 .06442 -9.5 -15.6875 ]
[.2906 .06442 9.5 0 ]
[.46154 .06442 -9.5 -15.6875 ]
[.46154 .06442 9.5 0 ]
[.63248 .06442 -9.5 -15.6875 ]
[.63248 .06442 9.5 0 ]
[.80342 .06442 -9.5 -15.6875 ]
[.80342 .06442 9.5 0 ]
[.97436 .06442 -5 -15.6875 ]
[.97436 .06442 5 0 ]
[.06442 .11966 -10 -7.84375 ]
[.06442 .11966 0 7.84375 ]
[.06442 .2906 -19 -7.84375 ]
[.06442 .2906 0 7.84375 ]
[.06442 .46154 -19 -7.84375 ]
[.06442 .46154 0 7.84375 ]
[.06442 .63248 -19 -7.84375 ]
[.06442 .63248 0 7.84375 ]
[.06442 .80342 -19 -7.84375 ]
[.06442 .80342 0 7.84375 ]
[.06442 .97436 -10 -7.84375 ]
[.06442 .97436 0 7.84375 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
1 1 1 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 g
gsave
.5 -0.0125 -157.594 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
85.313 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Propensity) show
143.313 15.813 moveto
(to) show
156.500 15.813 moveto
(cooperate) show
206.688 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player1) show
252.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 0 m
0 1 L
s
0 g
gsave
-0.01875 .5 -165.438 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
157.594 11.8438 translate
90 rotate
-157.594 -11.8438 translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
85.313 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Propensity) show
143.313 15.813 moveto
(to) show
156.500 15.813 moveto
(cooperate) show
206.688 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
213.063 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player2) show
252.188 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 1 1 r
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 g
.11966 .07692 m
.11966 .08317 L
s
gsave
.11966 .06442 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.2906 .07692 m
.2906 .08317 L
s
gsave
.2906 .06442 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.46154 .07692 m
.46154 .08317 L
s
gsave
.46154 .06442 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.63248 .07692 m
.63248 .08317 L
s
gsave
.63248 .06442 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.80342 .07692 m
.80342 .08317 L
s
gsave
.80342 .06442 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.97436 .07692 m
.97436 .08317 L
s
gsave
.97436 .06442 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.16239 .07692 m
.16239 .08067 L
s
.20513 .07692 m
.20513 .08067 L
s
.24786 .07692 m
.24786 .08067 L
s
.33333 .07692 m
.33333 .08067 L
s
.37607 .07692 m
.37607 .08067 L
s
.4188 .07692 m
.4188 .08067 L
s
.50427 .07692 m
.50427 .08067 L
s
.54701 .07692 m
.54701 .08067 L
s
.58974 .07692 m
.58974 .08067 L
s
.67521 .07692 m
.67521 .08067 L
s
.71795 .07692 m
.71795 .08067 L
s
.76068 .07692 m
.76068 .08067 L
s
.84615 .07692 m
.84615 .08067 L
s
.88889 .07692 m
.88889 .08067 L
s
.93162 .07692 m
.93162 .08067 L
s
.03419 .07692 m
.03419 .08067 L
s
.25 Mabswid
0 .07692 m
1 .07692 L
s
.07692 .11966 m
.08317 .11966 L
s
gsave
.06442 .11966 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.07692 .2906 m
.08317 .2906 L
s
gsave
.06442 .2906 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.07692 .46154 m
.08317 .46154 L
s
gsave
.06442 .46154 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.07692 .63248 m
.08317 .63248 L
s
gsave
.06442 .63248 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.07692 .80342 m
.08317 .80342 L
s
gsave
.06442 .80342 -80 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.07692 .97436 m
.08317 .97436 L
s
gsave
.06442 .97436 -71 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.07692 .16239 m
.08067 .16239 L
s
.07692 .20513 m
.08067 .20513 L
s
.07692 .24786 m
.08067 .24786 L
s
.07692 .33333 m
.08067 .33333 L
s
.07692 .37607 m
.08067 .37607 L
s
.07692 .4188 m
.08067 .4188 L
s
.07692 .50427 m
.08067 .50427 L
s
.07692 .54701 m
.08067 .54701 L
s
.07692 .58974 m
.08067 .58974 L
s
.07692 .67521 m
.08067 .67521 L
s
.07692 .71795 m
.08067 .71795 L
s
.07692 .76068 m
.08067 .76068 L
s
.07692 .84615 m
.08067 .84615 L
s
.07692 .88889 m
.08067 .88889 L
s
.07692 .93162 m
.08067 .93162 L
s
.07692 .03419 m
.08067 .03419 L
s
.25 Mabswid
.07692 0 m
.07692 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-15. 3. moveto 0 0 lineto
-15. -3. lineto
-9. 0 lineto fill
-15. 3. moveto 0 0 lineto
-15. -3. lineto
-9. 0 lineto
-15. 3. lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
currentlinewidth 1 Mabswid
currentlinewidth dup scale setlinewidth
0 0 Mdot
grestore
} def
% End of user PostScript
.5 Mabswid
.11966 .11966 m
.13869 .13869 L
.15801 .15801 L
.17487 .17487 L
.19001 .19001 L
.20505 .20505 L
.21854 .21854 L
.23192 .23192 L
.24393 .24393 L
.25474 .25474 L
.26548 .26548 L
.27515 .27515 L
.28387 .28387 L
.29257 .29257 L
.30042 .30042 L
.30823 .30823 L
.31529 .31529 L
.32166 .32166 L
.32803 .32803 L
.33379 .33379 L
.33953 .33953 L
.34473 .34473 L
.34944 .34944 L
.35414 .35414 L
.35841 .35841 L
.36228 .36228 L
.36616 .36616 L
.36968 .36968 L
.37321 .37321 L
.37641 .37641 L
.37932 .37932 L
.38224 .38224 L
.3849 .3849 L
.38731 .38731 L
.38974 .38974 L
.39195 .39195 L
.39417 .39417 L
.39619 .39619 L
.39802 .39802 L
.39987 .39987 L
.40156 .40156 L
.40325 .40325 L
.40479 .40479 L
.40619 .40619 L
.4076 .4076 L
.40889 .40889 L
.41006 .41006 L
.41125 .41125 L
.41232 .41232 L
.41341 .41341 L
Mistroke
.4144 .4144 L
.4153 .4153 L
.41621 .41621 L
.41704 .41704 L
.41787 .41787 L
.41864 .41864 L
.41933 .41933 L
.42003 .42003 L
.42067 .42067 L
.42125 .42125 L
.42184 .42184 L
.42238 .42238 L
.42292 .42292 L
.42341 .42341 L
.42386 .42386 L
.42431 .42431 L
.42473 .42473 L
.42511 .42511 L
.42549 .42549 L
.42584 .42584 L
.42619 .42619 L
.42651 .42651 L
.42681 .42681 L
.42711 .42711 L
.42738 .42738 L
.42765 .42765 L
.4279 .4279 L
.42813 .42813 L
.42836 .42836 L
.42857 .42857 L
.42876 .42876 L
.42895 .42895 L
.42913 .42913 L
.42931 .42931 L
.42947 .42947 L
.42962 .42962 L
.42977 .42977 L
.42991 .42991 L
.43003 .43003 L
.43016 .43016 L
.43027 .43027 L
.43039 .43039 L
.4305 .4305 L
.4306 .4306 L
.43069 .43069 L
.43078 .43078 L
.43088 .43088 L
.43096 .43096 L
.43103 .43103 L
.43111 .43111 L
Mistroke
Mfstroke
.11966 .16239 m
.13776 .17946 L
.15618 .19673 L
.17231 .21179 L
.18683 .22527 L
.20129 .23864 L
.21431 .25061 L
.22726 .26246 L
.23891 .27307 L
.24943 .28261 L
.25992 .29207 L
.2694 .30057 L
.27796 .30822 L
.28653 .31584 L
.29428 .3227 L
.30203 .32952 L
.30904 .33566 L
.3154 .3412 L
.32176 .34672 L
.32754 .35171 L
.33332 .35667 L
.33856 .36115 L
.34332 .36519 L
.3481 .36923 L
.35244 .37289 L
.35639 .37619 L
.36036 .3795 L
.36397 .3825 L
.36761 .38549 L
.37091 .3882 L
.37392 .39065 L
.37695 .39311 L
.37971 .39534 L
.38223 .39736 L
.38477 .3994 L
.38709 .40124 L
.38942 .40308 L
.39155 .40476 L
.3935 .40627 L
.39546 .4078 L
.39725 .40918 L
.39906 .41057 L
.40071 .41183 L
.40221 .41297 L
.40373 .41412 L
.40512 .41516 L
.40639 .4161 L
.40767 .41705 L
.40885 .41792 L
.41003 .41878 L
Mistroke
.41112 .41957 L
.41211 .42029 L
.41311 .42101 L
.41403 .42166 L
.41495 .42231 L
.4158 .42291 L
.41657 .42345 L
.41735 .42399 L
.41807 .42448 L
.41873 .42493 L
.41939 .42538 L
.42 .42579 L
.42061 .4262 L
.42118 .42657 L
.42169 .42691 L
.42221 .42725 L
.42269 .42755 L
.42313 .42783 L
.42357 .42812 L
.42398 .42837 L
.42439 .42863 L
.42477 .42886 L
.42511 .42907 L
.42546 .42929 L
.42578 .42948 L
.42611 .42967 L
.42641 .42985 L
.42668 .43001 L
.42696 .43017 L
.42721 .43031 L
.42744 .43044 L
.42768 .43058 L
.42789 .4307 L
.42811 .43082 L
.42831 .43092 L
.4285 .43102 L
.42869 .43112 L
.42886 .43121 L
.42901 .43129 L
.42917 .43137 L
.42932 .43145 L
.42947 .43152 L
.42961 .43159 L
.42973 .43165 L
.42986 .43171 L
.42997 .43176 L
.43009 .43182 L
.4302 .43187 L
.4303 .43191 L
.4304 .43195 L
Mistroke
Mfstroke
.11966 .20513 m
.13683 .22013 L
.15436 .23529 L
.16975 .24846 L
.18365 .26023 L
.19753 .27188 L
.21007 .2823 L
.22258 .29258 L
.23388 .30177 L
.24411 .31001 L
.25434 .31818 L
.26361 .32549 L
.27201 .33206 L
.28045 .33859 L
.28811 .34446 L
.29578 .35028 L
.30275 .3555 L
.30908 .36021 L
.31544 .36489 L
.32123 .3691 L
.32704 .37329 L
.33233 .37705 L
.33714 .38045 L
.34199 .38383 L
.3464 .38687 L
.35043 .38962 L
.35449 .39237 L
.3582 .39485 L
.36193 .39732 L
.36534 .39955 L
.36845 .40156 L
.37159 .40357 L
.37446 .40538 L
.37708 .40702 L
.37974 .40866 L
.38217 .41015 L
.38462 .41163 L
.38686 .41297 L
.38891 .41418 L
.39099 .41539 L
.39289 .41648 L
.39481 .41757 L
.39657 .41856 L
.39818 .41945 L
.39981 .42034 L
.4013 .42115 L
.40267 .42187 L
.40406 .4226 L
.40533 .42326 L
.40661 .42392 L
Mistroke
.40779 .42451 L
.40887 .42505 L
.40997 .42558 L
.41098 .42606 L
.41199 .42655 L
.41293 .42698 L
.41378 .42737 L
.41465 .42776 L
.41544 .42812 L
.41618 .42843 L
.41692 .42875 L
.4176 .42904 L
.41829 .42932 L
.41892 .42958 L
.4195 .42981 L
.42009 .43004 L
.42063 .43025 L
.42113 .43044 L
.42164 .43062 L
.4221 .43079 L
.42258 .43095 L
.42301 .4311 L
.42341 .43124 L
.42381 .43137 L
.42418 .43149 L
.42456 .43161 L
.42491 .43171 L
.42523 .4318 L
.42555 .4319 L
.42585 .43198 L
.42612 .43205 L
.4264 .43213 L
.42666 .43219 L
.42692 .43226 L
.42716 .43231 L
.42738 .43236 L
.4276 .43241 L
.42781 .43246 L
.428 .4325 L
.42819 .43253 L
.42837 .43257 L
.42855 .4326 L
.42871 .43263 L
.42887 .43265 L
.42902 .43268 L
.42917 .4327 L
.42931 .43272 L
.42944 .43274 L
.42957 .43275 L
.42969 .43277 L
Mistroke
Mfstroke
.11966 .24786 m
.1359 .26071 L
.15253 .27366 L
.16719 .28489 L
.18046 .2949 L
.19377 .30479 L
.20583 .3136 L
.21789 .32228 L
.22883 .33003 L
.23876 .33695 L
.24874 .34379 L
.2578 .34991 L
.26604 .35539 L
.27434 .36083 L
.28189 .36569 L
.28949 .37051 L
.29641 .37482 L
.30271 .37869 L
.30907 .38254 L
.31487 .38598 L
.32071 .38939 L
.32604 .39245 L
.3309 .3952 L
.33582 .39793 L
.3403 .40038 L
.34441 .40258 L
.34856 .40478 L
.35236 .40675 L
.35619 .4087 L
.3597 .41046 L
.36292 .41204 L
.36617 .41361 L
.36915 .41502 L
.37188 .41629 L
.37465 .41755 L
.37719 .41869 L
.37976 .41982 L
.38211 .42083 L
.38428 .42174 L
.38647 .42265 L
.38848 .42346 L
.39052 .42427 L
.39239 .42499 L
.3941 .42564 L
.39584 .42629 L
.39744 .42686 L
.39891 .42738 L
.4004 .42789 L
.40177 .42836 L
.40316 .42881 L
Mistroke
.40444 .42922 L
.40561 .42958 L
.4068 .42994 L
.4079 .43026 L
.40901 .43058 L
.41003 .43086 L
.41097 .43111 L
.41192 .43136 L
.4128 .43158 L
.4136 .43178 L
.41443 .43197 L
.41518 .43214 L
.41595 .4323 L
.41665 .43245 L
.4173 .43258 L
.41796 .43271 L
.41857 .43282 L
.41913 .43291 L
.4197 .43301 L
.42022 .43309 L
.42075 .43317 L
.42124 .43324 L
.42169 .4333 L
.42215 .43335 L
.42258 .4334 L
.42301 .43345 L
.42341 .43349 L
.42377 .43352 L
.42414 .43355 L
.42448 .43357 L
.4248 .43359 L
.42512 .43361 L
.42542 .43362 L
.42572 .43363 L
.42587 .43364 L
.426 .43364 L
.42613 .43364 L
.42625 .43365 L
.42637 .43365 L
.42644 .43365 L
.42651 .43365 L
.42657 .43365 L
.4266 .43365 L
.42663 .43365 L
.42665 .43365 L
.42665 .43365 L
.42666 .43365 L
.42667 .43365 L
.42668 .43365 L
.42668 .43365 L
Mistroke
.42669 .43365 L
.4267 .43365 L
.4267 .43365 L
.42671 .43365 L
.42671 .43365 L
.42672 .43365 L
.42673 .43365 L
.42673 .43365 L
.42674 .43365 L
.42676 .43365 L
.42677 .43365 L
.42679 .43365 L
.42682 .43365 L
.42687 .43365 L
.42694 .43365 L
.42699 .43365 L
.42711 .43365 L
.42721 .43365 L
.42743 .43364 L
.42763 .43363 L
.42783 .43363 L
.42801 .43362 L
.42819 .43361 L
.42836 .4336 L
.42852 .43358 L
.42869 .43357 L
.42884 .43356 L
.42898 .43354 L
.42899 .43354 L
Mfstroke
.11966 .2906 m
.13497 .30121 L
.15071 .31186 L
.16463 .32108 L
.17728 .32928 L
.19 .33735 L
.20157 .34452 L
.21319 .35157 L
.22377 .35784 L
.2334 .36343 L
.24311 .36893 L
.25196 .37384 L
.26004 .37822 L
.2682 .38255 L
.27565 .38641 L
.28316 .39022 L
.29003 .39362 L
.29631 .39666 L
.30266 .39966 L
.30847 .40235 L
.31433 .40499 L
.3197 .40735 L
.32462 .40946 L
.32959 .41155 L
.33415 .41341 L
.33833 .41507 L
.34257 .41672 L
.34646 .41819 L
.3504 .41964 L
.35401 .42094 L
.35733 .42209 L
.3607 .42323 L
.36378 .42425 L
.36662 .42516 L
.36951 .42606 L
.37216 .42686 L
.37485 .42765 L
.37732 .42835 L
.37959 .42897 L
.3819 .42958 L
.38403 .43013 L
.38618 .43066 L
.38817 .43113 L
.38999 .43154 L
.39184 .43195 L
.39355 .43231 L
.39512 .43263 L
.39671 .43294 L
.39818 .43321 L
.39968 .43347 L
Mistroke
.40105 .4337 L
.40232 .4339 L
.40361 .43409 L
.4048 .43426 L
.406 .43442 L
.40711 .43456 L
.40813 .43467 L
.40918 .43478 L
.41013 .43488 L
.41102 .43495 L
.41192 .43503 L
.41275 .43509 L
.41359 .43514 L
.41437 .43518 L
.41509 .43521 L
.41582 .43524 L
.41649 .43526 L
.41682 .43527 L
.41711 .43527 L
.41742 .43528 L
.41758 .43528 L
.41774 .43528 L
.41789 .43528 L
.41797 .43528 L
.41804 .43528 L
.41811 .43528 L
.41815 .43528 L
.41817 .43528 L
.41819 .43528 L
.4182 .43528 L
.41822 .43528 L
.41823 .43528 L
.41825 .43528 L
.41827 .43528 L
.41829 .43528 L
.4183 .43528 L
.41832 .43528 L
.41834 .43528 L
.41835 .43528 L
.41839 .43528 L
.41842 .43528 L
.41846 .43528 L
.41853 .43528 L
.41859 .43528 L
.41873 .43528 L
.41889 .43528 L
.41903 .43528 L
.41918 .43528 L
.41946 .43527 L
.42 .43526 L
Mistroke
.4205 .43524 L
.42096 .43523 L
.42143 .4352 L
.42187 .43518 L
.42231 .43515 L
.42272 .43512 L
.42309 .43509 L
.42348 .43506 L
.42383 .43502 L
.42419 .43498 L
.42452 .43495 L
.42483 .43491 L
.42514 .43487 L
.42543 .43483 L
.4257 .43479 L
.42597 .43475 L
.42623 .4347 L
.42648 .43466 L
.42672 .43462 L
.42694 .43458 L
.42716 .43453 L
.42737 .43449 L
.42756 .43445 L
.42775 .43441 L
.42793 .43437 L
.42812 .43432 L
.42828 .43428 L
Mfstroke
.11966 .33333 m
.13404 .34161 L
.14888 .34989 L
.16206 .35703 L
.17409 .36336 L
.18623 .36956 L
.19731 .37506 L
.20849 .38044 L
.2187 .38521 L
.22803 .38944 L
.23747 .39359 L
.2461 .39727 L
.25401 .40054 L
.26203 .40376 L
.26937 .40662 L
.27681 .40942 L
.28362 .4119 L
.28987 .41411 L
.29621 .41628 L
.30202 .4182 L
.30791 .42009 L
.31332 .42175 L
.31829 .42323 L
.32333 .42468 L
.32796 .42596 L
.33221 .4271 L
.33654 .42821 L
.34053 .42919 L
.34457 .43015 L
.34828 .43099 L
.3517 .43174 L
.35518 .43246 L
.35838 .4331 L
.36132 .43366 L
.36433 .4342 L
.36709 .43467 L
.3699 .43513 L
.37249 .43552 L
.37487 .43587 L
.3773 .4362 L
.37954 .43648 L
.38182 .43675 L
.38391 .43697 L
.38584 .43717 L
.38781 .43735 L
.38962 .4375 L
.39129 .43762 L
.393 .43773 L
.39457 .43783 L
.39617 .4379 L
Mistroke
.39765 .43796 L
.39901 .43801 L
.39974 .43803 L
.4004 .43804 L
.40107 .43805 L
.40168 .43806 L
.40197 .43806 L
.40229 .43807 L
.4026 .43807 L
.40277 .43807 L
.40285 .43807 L
.40293 .43807 L
.403 .43807 L
.40308 .43807 L
.40317 .43807 L
.40321 .43807 L
.40323 .43807 L
.40325 .43807 L
.40329 .43807 L
.40333 .43807 L
.40336 .43807 L
.40339 .43807 L
.40343 .43807 L
.40347 .43807 L
.40351 .43807 L
.40355 .43807 L
.40362 .43807 L
.40369 .43807 L
.40382 .43807 L
.40395 .43807 L
.4041 .43807 L
.4044 .43807 L
.40467 .43806 L
.40526 .43806 L
.40579 .43805 L
.40636 .43804 L
.40743 .43801 L
.40843 .43797 L
.40934 .43794 L
.41028 .43789 L
.41114 .43784 L
.41202 .43778 L
.41283 .43772 L
.41358 .43766 L
.41435 .43759 L
.41505 .43752 L
.41577 .43744 L
.41644 .43736 L
.41705 .43729 L
.41768 .43721 L
Mistroke
.41826 .43713 L
.41879 .43705 L
.41934 .43696 L
.41984 .43688 L
.42036 .43679 L
.42083 .43671 L
.42127 .43663 L
.42172 .43654 L
.42213 .43646 L
.42255 .43637 L
.42294 .43628 L
.42331 .4362 L
.42367 .43612 L
.42401 .43604 L
.42433 .43596 L
.42465 .43588 L
.42495 .4358 L
.42525 .43571 L
.42553 .43564 L
.42579 .43556 L
.42605 .43549 L
.4263 .43541 L
.42652 .43534 L
.42675 .43527 L
.42697 .4352 L
.42719 .43513 L
.42739 .43506 L
.42757 .435 L
.42758 .43499 L
Mfstroke
.11966 .37607 m
.13311 .38192 L
.14706 .38774 L
.1595 .39274 L
.1709 .39714 L
.18245 .40144 L
.19305 .40522 L
.20378 .4089 L
.21362 .41213 L
.22265 .41498 L
.23181 .41776 L
.24023 .42021 L
.24797 .42236 L
.25584 .42446 L
.26307 .42631 L
.27042 .4281 L
.27718 .42967 L
.2834 .43105 L
.28972 .43239 L
.29555 .43356 L
.30146 .43468 L
.30691 .43566 L
.31192 .43652 L
.31702 .43734 L
.32173 .43805 L
.32606 .43867 L
.33048 .43925 L
.33455 .43976 L
.33869 .44023 L
.34251 .44064 L
.34603 .44098 L
.34963 .44129 L
.35294 .44156 L
.35599 .44178 L
.35911 .44197 L
.36199 .44213 L
.36492 .44227 L
.36763 .44237 L
.37012 .44244 L
.37147 .44248 L
.37267 .4425 L
.3739 .44252 L
.37503 .44253 L
.3756 .44254 L
.37619 .44254 L
.3767 .44254 L
.37698 .44254 L
.37725 .44254 L
.3774 .44254 L
.37753 .44254 L
Mistroke
.37761 .44254 L
.37768 .44254 L
.37772 .44254 L
.37776 .44254 L
.3778 .44254 L
.37784 .44254 L
.3779 .44254 L
.37796 .44254 L
.37803 .44254 L
.3781 .44254 L
.37818 .44254 L
.37825 .44254 L
.37839 .44254 L
.37864 .44254 L
.37888 .44254 L
.3794 .44254 L
.37993 .44254 L
.38041 .44253 L
.3815 .44252 L
.38254 .4425 L
.38348 .44249 L
.38543 .44244 L
.38722 .44238 L
.38906 .4423 L
.39075 .44222 L
.39248 .44212 L
.39407 .44202 L
.39555 .44192 L
.39705 .4418 L
.39844 .44168 L
.39972 .44155 L
.40103 .44142 L
.40224 .44129 L
.40347 .44114 L
.40461 .441 L
.40567 .44086 L
.40674 .44071 L
.40774 .44056 L
.40865 .44042 L
.40959 .44027 L
.41046 .44012 L
.41135 .43996 L
.41217 .43981 L
.41293 .43967 L
.4137 .43951 L
.41442 .43937 L
.41514 .43921 L
.41582 .43906 L
.41644 .43892 L
.41708 .43877 L
Mistroke
.41767 .43863 L
.41821 .43849 L
.41877 .43835 L
.41929 .43821 L
.41981 .43807 L
.4203 .43793 L
.42075 .4378 L
.42121 .43767 L
.42163 .43754 L
.42207 .43741 L
.42247 .43728 L
.42284 .43716 L
.42322 .43704 L
.42357 .43692 L
.42389 .43681 L
.42423 .43669 L
.42453 .43659 L
.42485 .43647 L
.42514 .43636 L
.42541 .43626 L
.42568 .43616 L
.42593 .43606 L
.42617 .43597 L
.42641 .43587 L
.42663 .43578 L
.42686 .43568 L
.42689 .43567 L
Mfstroke
.11966 .4188 m
.13218 .42214 L
.14523 .42542 L
.15693 .42821 L
.1677 .43063 L
.17868 .43297 L
.18878 .435 L
.19906 .43694 L
.20853 .43862 L
.21725 .44007 L
.22615 .44146 L
.23434 .44265 L
.24191 .44368 L
.24963 .44466 L
.25676 .44549 L
.26402 .44627 L
.27072 .44693 L
.2769 .44748 L
.28321 .44799 L
.28904 .44841 L
.29498 .44879 L
.30046 .44909 L
.30552 .44933 L
.31069 .44953 L
.31546 .44968 L
.31987 .44978 L
.32207 .44982 L
.32438 .44986 L
.32548 .44987 L
.32667 .44988 L
.32778 .44989 L
.32827 .44989 L
.3288 .44989 L
.32932 .44989 L
.32955 .4499 L
.3298 .4499 L
.33002 .4499 L
.33026 .4499 L
.33039 .4499 L
.3305 .4499 L
.33061 .4499 L
.33073 .4499 L
.33087 .4499 L
.33094 .4499 L
.331 .4499 L
.33112 .4499 L
.33125 .4499 L
.33133 .4499 L
.3314 .4499 L
.33148 .4499 L
Mistroke
.33155 .4499 L
.33168 .4499 L
.33181 .4499 L
.33209 .4499 L
.33235 .4499 L
.33283 .4499 L
.33329 .44989 L
.3338 .44989 L
.33483 .44989 L
.33576 .44988 L
.33663 .44987 L
.33858 .44985 L
.34032 .44982 L
.34394 .44974 L
.34729 .44965 L
.35072 .44953 L
.35388 .44939 L
.35681 .44925 L
.3598 .44908 L
.36257 .4489 L
.36539 .4487 L
.368 .4485 L
.37042 .44829 L
.37288 .44807 L
.37517 .44784 L
.37749 .4476 L
.37965 .44736 L
.38163 .44712 L
.38367 .44687 L
.38555 .44662 L
.38728 .44638 L
.38906 .44612 L
.39071 .44586 L
.39238 .4456 L
.39394 .44534 L
.39537 .44509 L
.39684 .44483 L
.3982 .44457 L
.39945 .44433 L
.40074 .44407 L
.40192 .44383 L
.40314 .44357 L
.40426 .44332 L
.4053 .44309 L
.40636 .44284 L
.40735 .44261 L
.40835 .44236 L
.40928 .44212 L
.41014 .4419 L
.41102 .44167 L
Mistroke
.41183 .44144 L
.41258 .44123 L
.41335 .44102 L
.41406 .44081 L
.41479 .44059 L
.41546 .44038 L
.41608 .44019 L
.41672 .43999 L
.41731 .43979 L
.41791 .4396 L
.41847 .43941 L
.41898 .43923 L
.41951 .43904 L
.42 .43887 L
.42045 .43871 L
.42091 .43853 L
.42134 .43837 L
.42177 .43821 L
.42218 .43805 L
.42255 .4379 L
.42294 .43775 L
.42329 .4376 L
.42362 .43746 L
.42395 .43732 L
.42426 .43719 L
.42458 .43705 L
.42488 .43692 L
.42515 .4368 L
.42543 .43668 L
.42569 .43656 L
.42595 .43643 L
.4262 .43632 L
.4262 .43632 L
Mfstroke
.11966 .46154 m
.13125 .46226 L
.1434 .46293 L
.15436 .46343 L
.16451 .46383 L
.17489 .46416 L
.18451 .4644 L
.18927 .46449 L
.19433 .46457 L
.19911 .46463 L
.20135 .46465 L
.20343 .46467 L
.2056 .46468 L
.20757 .46469 L
.20869 .46469 L
.20974 .4647 L
.21085 .4647 L
.21147 .4647 L
.21175 .4647 L
.21205 .4647 L
.21232 .4647 L
.21247 .4647 L
.21262 .4647 L
.21289 .4647 L
.21314 .4647 L
.21329 .4647 L
.21345 .4647 L
.21361 .4647 L
.21375 .4647 L
.21402 .4647 L
.21416 .4647 L
.21431 .4647 L
.21484 .4647 L
.21513 .4647 L
.2154 .4647 L
.21642 .4647 L
.21733 .4647 L
.21832 .46469 L
.2203 .46468 L
.22242 .46467 L
.22432 .46466 L
.22853 .46461 L
.23231 .46456 L
.23633 .4645 L
.244 .46434 L
.2511 .46415 L
.25768 .46393 L
.26442 .46367 L
.27066 .4634 L
.27704 .46308 L
Mistroke
.28295 .46275 L
.28843 .46241 L
.29404 .46204 L
.29923 .46166 L
.30453 .46125 L
.30944 .46084 L
.31399 .46043 L
.31864 .45999 L
.32295 .45956 L
.32694 .45914 L
.33103 .45869 L
.33481 .45825 L
.33868 .45778 L
.34227 .45732 L
.34558 .45688 L
.34898 .45641 L
.35212 .45596 L
.35503 .45553 L
.35802 .45507 L
.36078 .45462 L
.3636 .45416 L
.36622 .45371 L
.36864 .45328 L
.37112 .45283 L
.37342 .4524 L
.37576 .45195 L
.37793 .45152 L
.37994 .4511 L
.382 .45067 L
.3839 .45026 L
.38567 .44987 L
.38747 .44946 L
.38914 .44907 L
.39085 .44867 L
.39243 .44828 L
.3939 .44791 L
.3954 .44753 L
.39678 .44717 L
.39807 .44682 L
.39938 .44646 L
.4006 .44613 L
.40185 .44577 L
.403 .44544 L
.40407 .44512 L
.40517 .44479 L
.40618 .44448 L
.40721 .44415 L
.40817 .44385 L
.40906 .44356 L
.40997 .44326 L
Mistroke
.41081 .44298 L
.41158 .44271 L
.41238 .44243 L
.41312 .44217 L
.41387 .4419 L
.41457 .44164 L
.41522 .4414 L
.41588 .44115 L
.41649 .44092 L
.41712 .44067 L
.4177 .44044 L
.41824 .44023 L
.41879 .44 L
.41929 .43979 L
.41977 .4396 L
.42025 .43939 L
.4207 .4392 L
.42115 .439 L
.42158 .43881 L
.42197 .43864 L
.42237 .43845 L
.42274 .43828 L
.42308 .43812 L
.42344 .43796 L
.42376 .4378 L
.4241 .43764 L
.42441 .43749 L
.4247 .43735 L
.42499 .4372 L
.42526 .43707 L
.42552 .43693 L
Mfstroke
.11966 .50427 m
.13032 .5023 L
.14158 .50025 L
.1518 .49842 L
.16131 .49673 L
.17111 .49501 L
.18023 .49342 L
.18961 .49179 L
.19833 .49028 L
.20644 .48888 L
.21478 .48743 L
.22254 .48609 L
.22975 .48484 L
.23718 .48355 L
.24408 .48235 L
.25116 .4811 L
.25774 .47994 L
.26386 .47884 L
.27014 .47771 L
.27598 .47665 L
.28196 .47555 L
.28751 .47452 L
.29267 .47355 L
.29796 .47254 L
.30288 .4716 L
.30744 .47071 L
.31212 .46978 L
.31647 .46891 L
.32092 .468 L
.32506 .46715 L
.32889 .46634 L
.33283 .4655 L
.33647 .46472 L
.33986 .46397 L
.34334 .4632 L
.34656 .46247 L
.34986 .46171 L
.35293 .46099 L
.35577 .46032 L
.35868 .45961 L
.36138 .45895 L
.36414 .45826 L
.36671 .45761 L
.36908 .457 L
.37151 .45636 L
.37377 .45576 L
.37586 .4552 L
.37801 .45461 L
.37999 .45405 L
.38203 .45348 L
Mistroke
.38391 .45293 L
.38566 .45242 L
.38745 .45189 L
.38911 .45139 L
.3908 .45087 L
.39238 .45038 L
.39383 .44992 L
.39532 .44944 L
.3967 .44899 L
.39798 .44856 L
.39929 .44812 L
.40051 .44771 L
.40175 .44728 L
.4029 .44687 L
.40397 .44649 L
.40506 .4461 L
.40607 .44573 L
.40701 .44538 L
.40797 .44502 L
.40886 .44468 L
.40977 .44433 L
.41062 .444 L
.4114 .44369 L
.4122 .44336 L
.41294 .44306 L
.4137 .44275 L
.4144 .44245 L
.41506 .44218 L
.41572 .44189 L
.41634 .44162 L
.41691 .44137 L
.4175 .44111 L
.41804 .44087 L
.4186 .44062 L
.41911 .44038 L
.41959 .44016 L
.42008 .43993 L
.42053 .43971 L
.42095 .43951 L
.42138 .4393 L
.42178 .4391 L
.42219 .4389 L
.42256 .43871 L
.42291 .43853 L
.42327 .43835 L
.42361 .43818 L
.42395 .438 L
.42426 .43783 L
.42455 .43768 L
.42485 .43752 L
Mistroke
Mfstroke
.11966 .54701 m
.12939 .54225 L
.13975 .53741 L
.14923 .53317 L
.15812 .52934 L
.16733 .52552 L
.17596 .52206 L
.18488 .5186 L
.19322 .51545 L
.20103 .5126 L
.20909 .50972 L
.21663 .50709 L
.22367 .50469 L
.23094 .50226 L
.23772 .50003 L
.24472 .49777 L
.25124 .4957 L
.25732 .49379 L
.26359 .49185 L
.26943 .49005 L
.27543 .48823 L
.28102 .48654 L
.28623 .48498 L
.29158 .48338 L
.29657 .4819 L
.3012 .48053 L
.30598 .47912 L
.31042 .47781 L
.31498 .47646 L
.31921 .47521 L
.32315 .47404 L
.3272 .47284 L
.33097 .47173 L
.33446 .47068 L
.33806 .4696 L
.3414 .4686 L
.34483 .46756 L
.34801 .46659 L
.35097 .46569 L
.354 .46475 L
.35682 .46387 L
.35971 .46297 L
.36239 .46212 L
.36488 .46133 L
.36743 .46051 L
.3698 .45974 L
.372 .45903 L
.37425 .45828 L
.37634 .45758 L
.37849 .45686 L
Mistroke
.38048 .45619 L
.38232 .45555 L
.38422 .4549 L
.38597 .45428 L
.38777 .45365 L
.38943 .45305 L
.39098 .45249 L
.39256 .45191 L
.39402 .45137 L
.39538 .45086 L
.39678 .45033 L
.39807 .44984 L
.3994 .44933 L
.40062 .44885 L
.40176 .4484 L
.40293 .44794 L
.40401 .4475 L
.40501 .44709 L
.40604 .44667 L
.40699 .44627 L
.40796 .44586 L
.40887 .44548 L
.4097 .44512 L
.41056 .44474 L
.41136 .44439 L
.41217 .44403 L
.41293 .44369 L
.41363 .44337 L
.41434 .44305 L
.41501 .44274 L
.41562 .44245 L
.41625 .44215 L
.41684 .44187 L
.41743 .44158 L
.41799 .44131 L
.4185 .44106 L
.41903 .4408 L
.41952 .44055 L
.41997 .44033 L
.42043 .44009 L
.42086 .43987 L
.4213 .43964 L
.42171 .43942 L
.42209 .43922 L
.42248 .43901 L
.42284 .43882 L
.42321 .43862 L
.42355 .43843 L
.42386 .43826 L
.42418 .43808 L
Mistroke
Mfstroke
.11966 .58974 m
.12846 .5821 L
.13792 .57439 L
.14666 .56768 L
.15492 .56166 L
.16354 .55569 L
.17168 .55032 L
.18015 .545 L
.18812 .5402 L
.19562 .53587 L
.2034 .53154 L
.21072 .52762 L
.21758 .52406 L
.2247 .52048 L
.23137 .51723 L
.23827 .51396 L
.24473 .51098 L
.25078 .50826 L
.25703 .50551 L
.26287 .50299 L
.2689 .50044 L
.27453 .49811 L
.27978 .49597 L
.2852 .49379 L
.29025 .49178 L
.29497 .48994 L
.29983 .48805 L
.30436 .48632 L
.30903 .48454 L
.31337 .4829 L
.31742 .48139 L
.32158 .47983 L
.32546 .4784 L
.32907 .47706 L
.33279 .47569 L
.33624 .47442 L
.3398 .47312 L
.3431 .4719 L
.34617 .47078 L
.34933 .46962 L
.35227 .46854 L
.35528 .46743 L
.35808 .46639 L
.36068 .46543 L
.36335 .46444 L
.36583 .46351 L
.36814 .46265 L
.37051 .46175 L
.37271 .46092 L
.37496 .46006 L
Mistroke
.37705 .45926 L
.379 .45851 L
.38099 .45774 L
.38284 .45702 L
.38474 .45627 L
.3865 .45557 L
.38813 .45492 L
.3898 .45425 L
.39136 .45362 L
.3928 .45303 L
.39428 .45242 L
.39565 .45185 L
.39705 .45127 L
.39836 .45072 L
.39956 .4502 L
.4008 .44967 L
.40195 .44917 L
.40302 .44871 L
.40411 .44823 L
.40513 .44778 L
.40616 .44731 L
.40713 .44687 L
.40802 .44647 L
.40894 .44605 L
.40979 .44565 L
.41066 .44524 L
.41146 .44486 L
.41221 .44451 L
.41297 .44414 L
.41368 .44379 L
.41434 .44347 L
.41502 .44314 L
.41564 .44282 L
.41628 .4425 L
.41688 .4422 L
.41743 .44192 L
.41799 .44163 L
.41851 .44136 L
.419 .4411 L
.4195 .44084 L
.41996 .44059 L
.42043 .44034 L
.42087 .4401 L
.42128 .43988 L
.42169 .43965 L
.42208 .43943 L
.42247 .43921 L
.42284 .439 L
.42318 .43881 L
.42352 .43861 L
Mistroke
Mfstroke
.11966 .63248 m
.12753 .62187 L
.1361 .6112 L
.14409 .60194 L
.15172 .59369 L
.15976 .58552 L
.1674 .57821 L
.17542 .57099 L
.18301 .56451 L
.1902 .55869 L
.19771 .55289 L
.2048 .54767 L
.21149 .54295 L
.21845 .53823 L
.22501 .53395 L
.23183 .52967 L
.23823 .52579 L
.24424 .52226 L
.25047 .5187 L
.25632 .51547 L
.26237 .51221 L
.26804 .50924 L
.27334 .50652 L
.27882 .50377 L
.28395 .50125 L
.28874 .49894 L
.29369 .4966 L
.29832 .49444 L
.30309 .49225 L
.30754 .49024 L
.31169 .48838 L
.31597 .48649 L
.31996 .48474 L
.32368 .48313 L
.32752 .48148 L
.3311 .47995 L
.33478 .47839 L
.3382 .47694 L
.34139 .4756 L
.34467 .47422 L
.34773 .47295 L
.35087 .47164 L
.35379 .47043 L
.3565 .4693 L
.35929 .46814 L
.36188 .46707 L
.36429 .46606 L
.36678 .46503 L
.36908 .46407 L
.37145 .46308 L
Mistroke
.37364 .46216 L
.37569 .4613 L
.37778 .46042 L
.37973 .45959 L
.38173 .45875 L
.38358 .45795 L
.3853 .45722 L
.38707 .45645 L
.3887 .45574 L
.39023 .45508 L
.39179 .45439 L
.39324 .45376 L
.39472 .4531 L
.3961 .45248 L
.39738 .4519 L
.39869 .45131 L
.39991 .45075 L
.40104 .45024 L
.4022 .4497 L
.40328 .4492 L
.40438 .44868 L
.4054 .4482 L
.40635 .44774 L
.40733 .44728 L
.40823 .44684 L
.40915 .44639 L
.41001 .44597 L
.4108 .44558 L
.41162 .44517 L
.41237 .44479 L
.41307 .44444 L
.41379 .44407 L
.41446 .44373 L
.41514 .44337 L
.41578 .44304 L
.41636 .44273 L
.41697 .44241 L
.41752 .44212 L
.41804 .44184 L
.41857 .44155 L
.41907 .44128 L
.41957 .441 L
.42004 .44074 L
.42047 .4405 L
.42092 .44025 L
.42133 .44001 L
.42175 .43977 L
.42214 .43955 L
.42251 .43933 L
.42287 .43912 L
Mistroke
Mfstroke
.11966 .67521 m
.1266 .66154 L
.13427 .64783 L
.14153 .63597 L
.14853 .62542 L
.15598 .61501 L
.16313 .60573 L
.17069 .59658 L
.17791 .5884 L
.18479 .58107 L
.19202 .57379 L
.19889 .56726 L
.2054 .56137 L
.21222 .5555 L
.21866 .55019 L
.22539 .54491 L
.23173 .54012 L
.23771 .53579 L
.24393 .53144 L
.24978 .52749 L
.25585 .52354 L
.26155 .51993 L
.26691 .51665 L
.27245 .51334 L
.27765 .51032 L
.28252 .50756 L
.28756 .50476 L
.29228 .5022 L
.29716 .4996 L
.30172 .49722 L
.30597 .49504 L
.31037 .49281 L
.31448 .49077 L
.31831 .48888 L
.32227 .48696 L
.32597 .48519 L
.32977 .48338 L
.33332 .48171 L
.33662 .48016 L
.34003 .47858 L
.34321 .47712 L
.34647 .47563 L
.34951 .47424 L
.35234 .47296 L
.35524 .47164 L
.35795 .47042 L
.36047 .46929 L
.36306 .46812 L
.36547 .46704 L
.36795 .46593 L
Mistroke
.37025 .4649 L
.37239 .46394 L
.37459 .46295 L
.37664 .46203 L
.37873 .46108 L
.38068 .4602 L
.38249 .45938 L
.38435 .45853 L
.38607 .45774 L
.38767 .45701 L
.38932 .45625 L
.39085 .45555 L
.39241 .45482 L
.39387 .45414 L
.39522 .45351 L
.3966 .45285 L
.39789 .45224 L
.39908 .45168 L
.40031 .45109 L
.40145 .45054 L
.40261 .44997 L
.40369 .44944 L
.4047 .44895 L
.40573 .44844 L
.40668 .44797 L
.40766 .44748 L
.40857 .44702 L
.40941 .44659 L
.41028 .44615 L
.41108 .44574 L
.41182 .44535 L
.41259 .44495 L
.41329 .44458 L
.41402 .4442 L
.41469 .44384 L
.41531 .4435 L
.41595 .44316 L
.41654 .44284 L
.41709 .44253 L
.41766 .44222 L
.41818 .44193 L
.41872 .44163 L
.41922 .44135 L
.41968 .44109 L
.42015 .44082 L
.42059 .44056 L
.42104 .4403 L
.42146 .44006 L
.42184 .43983 L
.42223 .4396 L
Mistroke
Mfstroke
.11966 .71795 m
.12567 .70112 L
.13244 .68428 L
.13896 .66976 L
.14533 .65686 L
.15219 .64417 L
.15885 .63288 L
.16596 .62177 L
.17281 .61187 L
.17938 .60301 L
.18634 .59424 L
.19299 .58638 L
.19932 .57932 L
.20599 .5723 L
.21232 .56597 L
.21896 .55968 L
.22524 .554 L
.23118 .54887 L
.23739 .54373 L
.24325 .53908 L
.24934 .53443 L
.25509 .53021 L
.26049 .52637 L
.2661 .52251 L
.27137 .519 L
.27632 .51579 L
.28145 .51256 L
.28627 .5096 L
.29125 .50661 L
.29591 .50387 L
.30028 .50137 L
.3048 .49882 L
.30902 .49649 L
.31297 .49434 L
.31705 .49216 L
.32086 .49015 L
.32479 .4881 L
.32846 .48622 L
.33188 .48448 L
.33541 .4827 L
.33871 .48106 L
.34209 .47939 L
.34525 .47784 L
.34819 .47641 L
.35122 .47494 L
.35404 .47359 L
.35667 .47233 L
.35937 .47104 L
.36189 .46984 L
.36448 .46861 L
Mistroke
.36688 .46747 L
.36912 .46641 L
.37143 .46533 L
.37357 .46431 L
.37576 .46328 L
.3778 .46231 L
.3797 .46141 L
.38165 .46049 L
.38346 .45963 L
.38514 .45883 L
.38687 .458 L
.38848 .45723 L
.39012 .45644 L
.39165 .45571 L
.39307 .45502 L
.39453 .45431 L
.39589 .45365 L
.39714 .45303 L
.39843 .4524 L
.39963 .4518 L
.40086 .45119 L
.402 .45062 L
.40306 .45009 L
.40415 .44954 L
.40516 .44903 L
.40619 .4485 L
.40715 .44801 L
.40804 .44755 L
.40895 .44707 L
.4098 .44663 L
.41058 .44622 L
.41139 .44579 L
.41214 .44539 L
.41291 .44498 L
.41362 .44459 L
.41428 .44423 L
.41495 .44386 L
.41558 .44352 L
.41616 .4432 L
.41676 .44286 L
.41731 .44255 L
.41788 .44223 L
.41841 .44193 L
.4189 .44165 L
.4194 .44136 L
.41986 .44109 L
.42034 .44081 L
.42078 .44055 L
.42119 .44031 L
.4216 .44006 L
Mistroke
Mfstroke
.11966 .76068 m
.12474 .74062 L
.13062 .72057 L
.13639 .70331 L
.14213 .68801 L
.14841 .67299 L
.15458 .65965 L
.16124 .64656 L
.16771 .63491 L
.17398 .62451 L
.18066 .61424 L
.18709 .60505 L
.19325 .59682 L
.19977 .58864 L
.20599 .58129 L
.21254 .57399 L
.21877 .56742 L
.22468 .5615 L
.23087 .55558 L
.23674 .55024 L
.24286 .5449 L
.24864 .54007 L
.25409 .53569 L
.25977 .53129 L
.26511 .5273 L
.27014 .52366 L
.27537 .51999 L
.28028 .51665 L
.28537 .51328 L
.29014 .5102 L
.29461 .50738 L
.29925 .50453 L
.30359 .50192 L
.30765 .49952 L
.31185 .49708 L
.31578 .49485 L
.31984 .49257 L
.32363 .49048 L
.32717 .48856 L
.33082 .48659 L
.33424 .48478 L
.33775 .48294 L
.34103 .48124 L
.34408 .47966 L
.34723 .47805 L
.35016 .47657 L
.3529 .47519 L
.35571 .47378 L
.35834 .47247 L
.36103 .47114 L
Mistroke
.36354 .4699 L
.36588 .46875 L
.36828 .46756 L
.37052 .46647 L
.37282 .46534 L
.37495 .4643 L
.37694 .46333 L
.37898 .46233 L
.38087 .4614 L
.38263 .46054 L
.38445 .45965 L
.38613 .45882 L
.38786 .45797 L
.38946 .45718 L
.39095 .45644 L
.39248 .45568 L
.3939 .45497 L
.39522 .45431 L
.39658 .45363 L
.39784 .453 L
.39913 .45234 L
.40033 .45173 L
.40145 .45117 L
.40259 .45058 L
.40365 .45003 L
.40474 .44947 L
.40575 .44894 L
.40668 .44845 L
.40764 .44795 L
.40854 .44747 L
.40936 .44703 L
.41021 .44658 L
.411 .44615 L
.41181 .44572 L
.41256 .44531 L
.41325 .44493 L
.41397 .44453 L
.41463 .44417 L
.41524 .44382 L
.41587 .44347 L
.41646 .44314 L
.41706 .4428 L
.41761 .44248 L
.41813 .44218 L
.41866 .44187 L
.41915 .44159 L
.41965 .44129 L
.42012 .44102 L
.42055 .44076 L
.42098 .4405 L
Mistroke
Mfstroke
.11966 .80342 m
.12381 .78002 L
.12879 .75668 L
.13382 .73663 L
.13894 .71888 L
.14463 .70148 L
.15031 .68606 L
.15652 .67096 L
.16262 .65754 L
.16858 .64558 L
.17499 .6338 L
.1812 .62328 L
.18719 .61386 L
.19356 .60452 L
.19968 .59615 L
.20614 .58786 L
.21231 .58041 L
.21819 .5737 L
.22438 .56701 L
.23025 .56098 L
.23639 .55497 L
.24222 .54954 L
.24772 .54462 L
.25347 .5397 L
.25889 .53523 L
.26399 .53117 L
.26931 .52708 L
.27432 .52336 L
.27951 .51962 L
.2844 .51621 L
.28898 .51309 L
.29373 .50994 L
.29819 .50706 L
.30236 .50442 L
.30668 .50174 L
.31073 .49929 L
.31492 .4968 L
.31883 .49451 L
.32249 .4924 L
.32627 .49026 L
.3298 .48829 L
.33344 .48628 L
.33683 .48443 L
.34 .48273 L
.34327 .48098 L
.34632 .47937 L
.34915 .47789 L
.35208 .47636 L
.35481 .47495 L
.35762 .47351 L
Mistroke
.36023 .47218 L
.36267 .47094 L
.36517 .46967 L
.36751 .46849 L
.3699 .46729 L
.37213 .46617 L
.3742 .46513 L
.37633 .46406 L
.37831 .46307 L
.38015 .46215 L
.38205 .4612 L
.38381 .46032 L
.38561 .45941 L
.38729 .45857 L
.38885 .45778 L
.39046 .45697 L
.39194 .45622 L
.39333 .45552 L
.39475 .4548 L
.39607 .45412 L
.39742 .45343 L
.39868 .45278 L
.39985 .45218 L
.40105 .45156 L
.40216 .45098 L
.4033 .45038 L
.40436 .44982 L
.40535 .44931 L
.40635 .44877 L
.40729 .44827 L
.40816 .44781 L
.40905 .44733 L
.40988 .44688 L
.41073 .44641 L
.41151 .44598 L
.41225 .44558 L
.41299 .44517 L
.41369 .44478 L
.41433 .44442 L
.415 .44404 L
.41561 .44369 L
.41624 .44333 L
.41683 .443 L
.41737 .44269 L
.41793 .44236 L
.41844 .44206 L
.41897 .44175 L
.41946 .44146 L
.41992 .44119 L
.42037 .44092 L
Mistroke
Mfstroke
.11966 .84615 m
.12288 .81933 L
.12697 .79261 L
.13126 .7697 L
.13575 .74945 L
.14086 .72964 L
.14605 .7121 L
.1518 .69496 L
.15754 .67975 L
.1632 .66622 L
.16934 .65291 L
.17533 .64105 L
.18115 .63046 L
.18738 .61997 L
.19338 .61058 L
.19976 .60129 L
.20588 .59296 L
.21173 .58547 L
.21791 .57802 L
.22379 .57131 L
.22996 .56464 L
.23583 .55862 L
.24138 .55317 L
.2472 .54773 L
.25269 .5428 L
.25788 .53833 L
.26329 .53384 L
.2684 .52975 L
.2737 .52565 L
.27869 .52191 L
.28338 .51851 L
.28825 .51507 L
.29282 .51193 L
.29711 .50906 L
.30156 .50615 L
.30572 .50348 L
.31004 .50078 L
.31407 .49831 L
.31785 .49603 L
.32175 .49372 L
.3254 .49159 L
.32916 .48943 L
.33268 .48744 L
.33596 .48561 L
.33935 .48374 L
.3425 .48201 L
.34545 .48042 L
.34849 .47879 L
.35132 .47728 L
.35424 .47574 L
Mistroke
.35696 .47432 L
.35949 .473 L
.3621 .47165 L
.36452 .4704 L
.36702 .46911 L
.36934 .46792 L
.3715 .46682 L
.37372 .46569 L
.37578 .46464 L
.3777 .46366 L
.37968 .46266 L
.38151 .46172 L
.3834 .46076 L
.38515 .45987 L
.38678 .45904 L
.38846 .45819 L
.39001 .45739 L
.39146 .45665 L
.39294 .45589 L
.39432 .45518 L
.39574 .45445 L
.39706 .45377 L
.39828 .45313 L
.39953 .45248 L
.4007 .45187 L
.40189 .45124 L
.403 .45066 L
.40403 .45011 L
.40508 .44955 L
.40606 .44903 L
.40697 .44854 L
.40791 .44803 L
.40877 .44756 L
.40966 .44708 L
.41049 .44662 L
.41125 .4462 L
.41204 .44577 L
.41277 .44536 L
.41344 .44498 L
.41414 .44459 L
.41478 .44422 L
.41544 .44385 L
.41606 .44349 L
.41662 .44317 L
.41721 .44283 L
.41775 .44251 L
.4183 .44218 L
.41882 .44188 L
.4193 .4416 L
.41977 .44131 L
Mistroke
Mfstroke
.11966 .88889 m
.12195 .85855 L
.12514 .82838 L
.12869 .80254 L
.13256 .77974 L
.13708 .75747 L
.14179 .73778 L
.14709 .71856 L
.15246 .70155 L
.15782 .68644 L
.16369 .6716 L
.16947 .65839 L
.17512 .64661 L
.18121 .63497 L
.18711 .62456 L
.19341 .61428 L
.19947 .60508 L
.2053 .59682 L
.21146 .58862 L
.21736 .58124 L
.22356 .57391 L
.22947 .56732 L
.23508 .56136 L
.24096 .55541 L
.24654 .55003 L
.25181 .54516 L
.25731 .54027 L
.26251 .53583 L
.26793 .53138 L
.27303 .52733 L
.27783 .52365 L
.28281 .51993 L
.2875 .51654 L
.2919 .51345 L
.29647 .51031 L
.30076 .50745 L
.3052 .50455 L
.30935 .50189 L
.31325 .49945 L
.31727 .49698 L
.32104 .4947 L
.32493 .4924 L
.32856 .49028 L
.33196 .48832 L
.33546 .48633 L
.33873 .4845 L
.34178 .4828 L
.34493 .48107 L
.34787 .47947 L
.3509 .47784 L
Mistroke
.35372 .47633 L
.35635 .47494 L
.35905 .47351 L
.36157 .47218 L
.36417 .47083 L
.36658 .46957 L
.36882 .46841 L
.37113 .46722 L
.37328 .46611 L
.37528 .46508 L
.37734 .46403 L
.37925 .46304 L
.38122 .46204 L
.38304 .4611 L
.38474 .46023 L
.38648 .45933 L
.38811 .4585 L
.38961 .45772 L
.39116 .45692 L
.3926 .45618 L
.39408 .45541 L
.39545 .4547 L
.39673 .45404 L
.39804 .45335 L
.39925 .45271 L
.4005 .45206 L
.40166 .45144 L
.40273 .45087 L
.40383 .45029 L
.40486 .44974 L
.40581 .44923 L
.40678 .4487 L
.40769 .44821 L
.40862 .4477 L
.40948 .44723 L
.41028 .44679 L
.4111 .44633 L
.41186 .44591 L
.41257 .44551 L
.41329 .4451 L
.41397 .44472 L
.41466 .44433 L
.4153 .44396 L
.41589 .44362 L
.4165 .44327 L
.41707 .44294 L
.41765 .4426 L
.41819 .44228 L
.41869 .44198 L
.41919 .44169 L
Mistroke
Mfstroke
.11966 .93162 m
.12023 .91471 L
.12102 .89768 L
.12202 .88118 L
.12331 .86397 L
.1262 .83449 L
.12954 .80854 L
.13361 .78332 L
.13795 .76109 L
.14248 .74143 L
.14761 .7222 L
.15281 .70516 L
.158 .69003 L
.1637 .67513 L
.16933 .66187 L
.17541 .64882 L
.18136 .63719 L
.18712 .62679 L
.19328 .6165 L
.19922 .60728 L
.20552 .59817 L
.21157 .58999 L
.21735 .58263 L
.22344 .57532 L
.22924 .56872 L
.23475 .56277 L
.24053 .55682 L
.24601 .55144 L
.25174 .54606 L
.25716 .54118 L
.26227 .53676 L
.2676 .53231 L
.27262 .52827 L
.27735 .52459 L
.28227 .52087 L
.28689 .51749 L
.29169 .51407 L
.29619 .51095 L
.30042 .50809 L
.3048 .5052 L
.3089 .50255 L
.31314 .49986 L
.31711 .4974 L
.32082 .49514 L
.32466 .49284 L
.32824 .49073 L
.33159 .48878 L
.33505 .4868 L
.33829 .48497 L
.34162 .4831 L
Mistroke
.34473 .48138 L
.34762 .47979 L
.35061 .47817 L
.3534 .47667 L
.35626 .47514 L
.35893 .47372 L
.36142 .4724 L
.36398 .47106 L
.36636 .46981 L
.36858 .46866 L
.37087 .46747 L
.37299 .46637 L
.37517 .46524 L
.3772 .46419 L
.37909 .46322 L
.38103 .46221 L
.38284 .46128 L
.38452 .46042 L
.38624 .45953 L
.38785 .4587 L
.3895 .45785 L
.39103 .45705 L
.39245 .45632 L
.39391 .45556 L
.39527 .45485 L
.39666 .45412 L
.39796 .45344 L
.39916 .45281 L
.40039 .45216 L
.40153 .45155 L
.4026 .45098 L
.40369 .4504 L
.4047 .44986 L
.40574 .4493 L
.4067 .44877 L
.4076 .44829 L
.40852 .44778 L
.40937 .44732 L
.41016 .44688 L
.41097 .44643 L
.41173 .44601 L
.4125 .44557 L
.41322 .44517 L
.41389 .44479 L
.41457 .4444 L
.4152 .44403 L
.41585 .44366 L
.41646 .44331 L
.41702 .44298 L
.41759 .44265 L
Mistroke
.41812 .44233 L
.41861 .44204 L
Mfstroke
.11966 .97436 m
.11966 .97316 L
.11966 .97208 L
.11966 .97082 L
.11966 .96965 L
.11967 .96756 L
.11968 .9653 L
.1197 .96283 L
.11972 .96023 L
.11976 .9556 L
.11982 .95088 L
.11989 .9465 L
.1201 .93671 L
.12036 .92697 L
.12065 .91827 L
.12149 .89938 L
.1224 .88372 L
.12358 .8674 L
.12639 .83753 L
.12967 .81126 L
.13368 .78574 L
.13799 .76324 L
.14249 .74336 L
.14759 .72391 L
.15277 .70669 L
.15795 .6914 L
.16365 .67635 L
.16927 .66295 L
.17535 .64979 L
.1813 .63805 L
.18707 .62756 L
.19323 .61718 L
.19918 .60789 L
.2049 .59955 L
.21095 .59125 L
.21675 .58379 L
.22286 .57638 L
.22868 .5697 L
.23421 .56367 L
.24001 .55764 L
.24552 .55219 L
.25127 .54675 L
.25671 .54181 L
.26184 .53734 L
.26719 .53285 L
.27224 .52876 L
.27699 .52504 L
.28193 .52129 L
.28657 .51787 L
.29139 .51442 L
Mistroke
.29592 .51127 L
.30016 .50839 L
.30456 .50547 L
.30868 .50279 L
.31294 .50009 L
.31692 .49761 L
.32065 .49533 L
.32451 .49301 L
.32811 .49089 L
.33147 .48893 L
.33495 .48693 L
.33819 .48509 L
.34154 .48321 L
.34466 .48148 L
.34757 .47988 L
.35057 .47825 L
.35336 .47674 L
.35597 .47534 L
.35866 .47391 L
.36116 .47258 L
.36374 .47123 L
.36614 .46997 L
.36837 .4688 L
.37067 .4676 L
.37281 .46649 L
.375 .46536 L
.37704 .4643 L
.37894 .46332 L
.3809 .46231 L
.38271 .46137 L
.3844 .4605 L
.38614 .4596 L
.38775 .45877 L
.38941 .45791 L
.39095 .45711 L
.39238 .45637 L
.39385 .45561 L
.39521 .45489 L
.39648 .45423 L
.39778 .45355 L
.39899 .45291 L
.40024 .45225 L
.40139 .45164 L
.40246 .45107 L
.40356 .45048 L
.40458 .44993 L
.40563 .44937 L
.4066 .44884 L
.4075 .44835 L
.40843 .44784 L
Mistroke
.40928 .44737 L
.41008 .44693 L
.4109 .44648 L
.41166 .44605 L
.41244 .44561 L
.41316 .44521 L
.41383 .44483 L
.41452 .44443 L
.41516 .44407 L
.41581 .44369 L
.41642 .44334 L
.41698 .44301 L
.41756 .44267 L
.41805 .44238 L
Mfstroke
.16239 .11966 m
.17946 .13776 L
.19673 .15618 L
.21179 .17231 L
.22527 .18683 L
.23864 .20129 L
.25061 .21431 L
.26246 .22726 L
.27307 .23891 L
.28261 .24943 L
.29207 .25992 L
.30057 .2694 L
.30822 .27796 L
.31584 .28653 L
.3227 .29428 L
.32952 .30203 L
.33566 .30904 L
.3412 .3154 L
.34672 .32176 L
.35171 .32754 L
.35667 .33332 L
.36115 .33856 L
.36519 .34332 L
.36923 .3481 L
.37289 .35244 L
.37619 .35639 L
.3795 .36036 L
.3825 .36397 L
.38549 .36761 L
.3882 .37091 L
.39065 .37392 L
.39311 .37695 L
.39534 .37971 L
.39736 .38223 L
.3994 .38477 L
.40124 .38709 L
.40308 .38942 L
.40476 .39155 L
.40627 .3935 L
.4078 .39546 L
.40918 .39725 L
.41057 .39906 L
.41183 .40071 L
.41297 .40221 L
.41412 .40373 L
.41516 .40512 L
.4161 .40639 L
.41705 .40767 L
.41792 .40885 L
.41878 .41003 L
Mistroke
.41957 .41112 L
.42029 .41211 L
.42101 .41311 L
.42166 .41403 L
.42231 .41495 L
.42291 .4158 L
.42345 .41657 L
.42399 .41735 L
.42448 .41807 L
.42493 .41873 L
.42538 .41939 L
.42579 .42 L
.4262 .42061 L
.42657 .42118 L
.42691 .42169 L
.42725 .42221 L
.42755 .42269 L
.42783 .42313 L
.42812 .42357 L
.42837 .42398 L
.42863 .42439 L
.42886 .42477 L
.42907 .42511 L
.42929 .42546 L
.42948 .42578 L
.42967 .42611 L
.42985 .42641 L
.43001 .42668 L
.43017 .42696 L
.43031 .42721 L
.43044 .42744 L
.43058 .42768 L
.4307 .42789 L
.43082 .42811 L
.43092 .42831 L
.43102 .4285 L
.43112 .42869 L
.43121 .42886 L
.43129 .42901 L
.43137 .42917 L
.43145 .42932 L
.43152 .42947 L
.43159 .42961 L
.43165 .42973 L
.43171 .42986 L
.43176 .42997 L
.43182 .43009 L
.43187 .4302 L
.43191 .4303 L
.43195 .4304 L
Mistroke
Mfstroke
.16239 .97436 m
.1622 .96575 L
.16203 .95651 L
.16197 .95193 L
.16192 .94708 L
.1619 .94474 L
.16188 .94255 L
.16187 .94044 L
.16186 .93848 L
.16186 .93735 L
.16185 .93632 L
.16185 .93518 L
.16185 .93456 L
.16185 .93396 L
.16185 .93339 L
.16185 .93279 L
.16185 .9317 L
.16185 .93103 L
.16185 .9304 L
.16185 .92984 L
.16185 .92923 L
.16185 .92822 L
.16185 .9271 L
.16186 .92486 L
.16187 .9228 L
.16189 .92089 L
.16193 .9162 L
.16198 .91198 L
.16214 .90265 L
.16232 .89469 L
.16253 .88747 L
.16313 .87165 L
.16382 .85802 L
.16473 .84359 L
.16693 .81718 L
.16953 .79378 L
.17274 .77086 L
.17622 .75054 L
.17987 .73246 L
.18404 .71466 L
.18828 .69881 L
.19301 .68322 L
.19774 .66931 L
.20241 .65688 L
.20749 .64458 L
.21247 .63357 L
.21731 .62369 L
.2225 .61387 L
.22751 .60504 L
.23285 .59626 L
Mistroke
.23798 .58837 L
.24289 .58125 L
.24808 .57414 L
.25303 .56771 L
.25824 .5613 L
.26319 .55551 L
.26789 .55025 L
.27281 .54498 L
.27747 .5402 L
.28187 .53585 L
.28646 .53147 L
.2908 .52748 L
.29531 .52346 L
.29956 .5198 L
.30356 .51646 L
.30772 .51308 L
.31162 .50999 L
.31528 .50716 L
.31909 .50429 L
.32265 .50166 L
.32634 .49899 L
.3298 .49655 L
.33304 .4943 L
.33639 .49201 L
.33952 .4899 L
.34275 .48776 L
.34578 .48579 L
.3486 .48398 L
.35151 .48213 L
.35423 .48042 L
.35677 .47884 L
.35939 .47723 L
.36183 .47574 L
.36435 .47422 L
.36669 .47281 L
.36888 .4715 L
.37113 .47017 L
.37323 .46893 L
.37518 .46779 L
.37719 .46661 L
.37907 .46552 L
.381 .4644 L
.38279 .46336 L
.38446 .4624 L
.38618 .46141 L
.38778 .46049 L
.38942 .45955 L
.39094 .45867 L
.39236 .45786 L
.39382 .45702 L
Mistroke
.39518 .45624 L
.39644 .45552 L
.39773 .45477 L
.39894 .45408 L
.40017 .45337 L
.40132 .4527 L
.40239 .45209 L
.40348 .45145 L
.4045 .45086 L
.40554 .45025 L
.40651 .44968 L
.40741 .44915 L
.40834 .44861 L
.4092 .4481 L
.40999 .44763 L
.41081 .44714 L
.41157 .44669 L
.41235 .44622 L
.41307 .44579 L
.41374 .44538 L
.41443 .44496 L
.41507 .44457 L
.41566 .44421 L
.41627 .44383 L
.41684 .44348 L
.41742 .44312 L
.41796 .44279 L
.41846 .44248 L
.41896 .44216 L
Mfstroke
.20513 .11966 m
.22013 .13683 L
.23529 .15436 L
.24846 .16975 L
.26023 .18365 L
.27188 .19753 L
.2823 .21007 L
.29258 .22258 L
.30177 .23388 L
.31001 .24411 L
.31818 .25434 L
.32549 .26361 L
.33206 .27201 L
.33859 .28045 L
.34446 .28811 L
.35028 .29578 L
.3555 .30275 L
.36021 .30908 L
.36489 .31544 L
.3691 .32123 L
.37329 .32704 L
.37705 .33233 L
.38045 .33714 L
.38383 .34199 L
.38687 .3464 L
.38962 .35043 L
.39237 .35449 L
.39485 .3582 L
.39732 .36193 L
.39955 .36534 L
.40156 .36845 L
.40357 .37159 L
.40538 .37446 L
.40702 .37708 L
.40866 .37974 L
.41015 .38217 L
.41163 .38462 L
.41297 .38686 L
.41418 .38891 L
.41539 .39099 L
.41648 .39289 L
.41757 .39481 L
.41856 .39657 L
.41945 .39818 L
.42034 .39981 L
.42115 .4013 L
.42187 .40267 L
.4226 .40406 L
.42326 .40533 L
.42392 .40661 L
Mistroke
.42451 .40779 L
.42505 .40887 L
.42558 .40997 L
.42606 .41098 L
.42655 .41199 L
.42698 .41293 L
.42737 .41378 L
.42776 .41465 L
.42812 .41544 L
.42843 .41618 L
.42875 .41692 L
.42904 .4176 L
.42932 .41829 L
.42958 .41892 L
.42981 .4195 L
.43004 .42009 L
.43025 .42063 L
.43044 .42113 L
.43062 .42164 L
.43079 .4221 L
.43095 .42258 L
.4311 .42301 L
.43124 .42341 L
.43137 .42381 L
.43149 .42418 L
.43161 .42456 L
.43171 .42491 L
.4318 .42523 L
.4319 .42555 L
.43198 .42585 L
.43205 .42612 L
.43213 .4264 L
.43219 .42666 L
.43226 .42692 L
.43231 .42716 L
.43236 .42738 L
.43241 .4276 L
.43246 .42781 L
.4325 .428 L
.43253 .42819 L
.43257 .42837 L
.4326 .42855 L
.43263 .42871 L
.43265 .42887 L
.43268 .42902 L
.4327 .42917 L
.43272 .42931 L
.43274 .42944 L
.43275 .42957 L
.43277 .42969 L
Mistroke
Mfstroke
.20513 .97436 m
.20435 .95742 L
.20372 .94025 L
.20326 .92352 L
.20308 .91434 L
.20302 .9103 L
.20297 .90596 L
.20293 .90173 L
.20291 .89989 L
.2029 .89787 L
.20289 .8961 L
.20288 .89421 L
.20288 .89317 L
.20288 .89222 L
.20287 .89127 L
.20287 .89037 L
.20287 .88949 L
.20287 .8887 L
.20287 .88779 L
.20287 .88694 L
.20288 .88614 L
.20288 .88542 L
.20288 .88378 L
.20289 .88213 L
.2029 .88033 L
.20293 .87672 L
.20297 .87296 L
.20302 .86943 L
.20313 .86292 L
.20329 .85604 L
.20349 .84871 L
.20398 .8358 L
.20462 .82263 L
.20612 .80027 L
.20813 .7782 L
.21043 .75851 L
.21323 .7391 L
.21622 .72177 L
.21933 .70626 L
.22286 .6909 L
.22644 .67715 L
.23042 .66354 L
.23439 .65134 L
.23831 .64037 L
.24256 .62947 L
.24672 .61966 L
.25077 .61082 L
.2551 .60199 L
.25929 .59403 L
.26375 .58608 L
Mistroke
.26804 .5789 L
.27214 .57239 L
.27648 .56588 L
.28062 .55997 L
.28498 .55406 L
.28912 .54869 L
.29305 .54382 L
.29717 .53891 L
.30107 .53445 L
.30476 .53038 L
.30862 .52627 L
.31225 .52252 L
.31604 .51874 L
.31961 .51529 L
.32297 .51213 L
.32646 .50893 L
.32974 .506 L
.33282 .50332 L
.33602 .50059 L
.33902 .49808 L
.34213 .49554 L
.34504 .49321 L
.34777 .49106 L
.35059 .48887 L
.35324 .48686 L
.35596 .48481 L
.35851 .48292 L
.3609 .48119 L
.36336 .47941 L
.36566 .47777 L
.3678 .47626 L
.37002 .47472 L
.37209 .47329 L
.37422 .47183 L
.3762 .47048 L
.37806 .46923 L
.37996 .46795 L
.38174 .46676 L
.3834 .46566 L
.38511 .46454 L
.3867 .46349 L
.38834 .46242 L
.38986 .46143 L
.39128 .46051 L
.39274 .45956 L
.3941 .45869 L
.3955 .45779 L
.39679 .45695 L
.398 .45618 L
.39924 .45538 L
Mistroke
.4004 .45464 L
.40147 .45395 L
.40258 .45324 L
.40361 .45258 L
.40466 .4519 L
.40564 .45127 L
.40655 .45069 L
.40749 .45008 L
.40836 .44952 L
.40925 .44895 L
.41008 .44841 L
.41085 .44791 L
.41164 .4474 L
.41237 .44692 L
.41306 .44648 L
.41376 .44602 L
.41441 .44559 L
.41508 .44515 L
.4157 .44474 L
.41627 .44436 L
.41686 .44397 L
.41741 .44361 L
.41792 .44327 L
.41844 .44292 L
.41893 .44259 L
.41943 .44225 L
.41988 .44195 L
Mfstroke
.24786 .11966 m
.26071 .1359 L
.27366 .15253 L
.28489 .16719 L
.2949 .18046 L
.30479 .19377 L
.3136 .20583 L
.32228 .21789 L
.33003 .22883 L
.33695 .23876 L
.34379 .24874 L
.34991 .2578 L
.35539 .26604 L
.36083 .27434 L
.36569 .28189 L
.37051 .28949 L
.37482 .29641 L
.37869 .30271 L
.38254 .30907 L
.38598 .31487 L
.38939 .32071 L
.39245 .32604 L
.3952 .3309 L
.39793 .33582 L
.40038 .3403 L
.40258 .34441 L
.40478 .34856 L
.40675 .35236 L
.4087 .35619 L
.41046 .3597 L
.41204 .36292 L
.41361 .36617 L
.41502 .36915 L
.41629 .37188 L
.41755 .37465 L
.41869 .37719 L
.41982 .37976 L
.42083 .38211 L
.42174 .38428 L
.42265 .38647 L
.42346 .38848 L
.42427 .39052 L
.42499 .39239 L
.42564 .3941 L
.42629 .39584 L
.42686 .39744 L
.42738 .39891 L
.42789 .4004 L
.42836 .40177 L
.42881 .40316 L
Mistroke
.42922 .40444 L
.42958 .40561 L
.42994 .4068 L
.43026 .4079 L
.43058 .40901 L
.43086 .41003 L
.43111 .41097 L
.43136 .41192 L
.43158 .4128 L
.43178 .4136 L
.43197 .41443 L
.43214 .41518 L
.4323 .41595 L
.43245 .41665 L
.43258 .4173 L
.43271 .41796 L
.43282 .41857 L
.43291 .41913 L
.43301 .4197 L
.43309 .42022 L
.43317 .42075 L
.43324 .42124 L
.4333 .42169 L
.43335 .42215 L
.4334 .42258 L
.43345 .42301 L
.43349 .42341 L
.43352 .42377 L
.43355 .42414 L
.43357 .42448 L
.43359 .4248 L
.43361 .42512 L
.43362 .42542 L
.43363 .42572 L
.43364 .42587 L
.43364 .426 L
.43364 .42613 L
.43365 .42625 L
.43365 .42637 L
.43365 .42644 L
.43365 .42651 L
.43365 .42657 L
.43365 .4266 L
.43365 .42663 L
.43365 .42665 L
.43365 .42665 L
.43365 .42666 L
.43365 .42667 L
.43365 .42668 L
.43365 .42668 L
Mistroke
.43365 .42669 L
.43365 .4267 L
.43365 .4267 L
.43365 .42671 L
.43365 .42671 L
.43365 .42672 L
.43365 .42673 L
.43365 .42673 L
.43365 .42674 L
.43365 .42676 L
.43365 .42677 L
.43365 .42679 L
.43365 .42682 L
.43365 .42687 L
.43365 .42694 L
.43365 .42699 L
.43365 .42711 L
.43365 .42721 L
.43364 .42743 L
.43363 .42763 L
.43363 .42783 L
.43362 .42801 L
.43361 .42819 L
.4336 .42836 L
.43358 .42852 L
.43357 .42869 L
.43356 .42884 L
.43354 .42898 L
.43354 .42899 L
Mfstroke
.24786 .97436 m
.24567 .94204 L
.24478 .92611 L
.24399 .90932 L
.24341 .89415 L
.24301 .88083 L
.24286 .87437 L
.24273 .86749 L
.24268 .86376 L
.24264 .86035 L
.2426 .85715 L
.24259 .8554 L
.24258 .85374 L
.24257 .85219 L
.24256 .8505 L
.24256 .84976 L
.24256 .84897 L
.24255 .84824 L
.24255 .84756 L
.24255 .84682 L
.24255 .84602 L
.24255 .84531 L
.24255 .84457 L
.24255 .8439 L
.24255 .84328 L
.24255 .8426 L
.24255 .84188 L
.24256 .84023 L
.24257 .83845 L
.24258 .83677 L
.24259 .83523 L
.24262 .83235 L
.24265 .82928 L
.24274 .82355 L
.24284 .81827 L
.24317 .80655 L
.24359 .79556 L
.24414 .78442 L
.24539 .76532 L
.24706 .74637 L
.24895 .72937 L
.25124 .71253 L
.25368 .69741 L
.25623 .68381 L
.25911 .67029 L
.26204 .65811 L
.26497 .64713 L
.2682 .63617 L
.2714 .62628 L
.27487 .61641 L
Mistroke
.27827 .6075 L
.28158 .59943 L
.28513 .59135 L
.28857 .58404 L
.29222 .57672 L
.29574 .57009 L
.29912 .56407 L
.30269 .55802 L
.3061 .55252 L
.30935 .54751 L
.31277 .54247 L
.31602 .53787 L
.31942 .53324 L
.32265 .52902 L
.32571 .52516 L
.3289 .52127 L
.33192 .5177 L
.33476 .51444 L
.33773 .51114 L
.34053 .50811 L
.34343 .50504 L
.34617 .50223 L
.34874 .49964 L
.35141 .49702 L
.35392 .49461 L
.35651 .49216 L
.35895 .48992 L
.36123 .48785 L
.36359 .48574 L
.3658 .4838 L
.36787 .48201 L
.37001 .48019 L
.37202 .4785 L
.37408 .47679 L
.37602 .47521 L
.37782 .47374 L
.37969 .47225 L
.38143 .47087 L
.38305 .46959 L
.38473 .46828 L
.38629 .46707 L
.38791 .46583 L
.38941 .46469 L
.39081 .46363 L
.39226 .46254 L
.3936 .46153 L
.39499 .4605 L
.39628 .45955 L
.39748 .45866 L
.39872 .45775 L
Mistroke
.39987 .45691 L
.40094 .45612 L
.40205 .45532 L
.40307 .45457 L
.40413 .45381 L
.40511 .4531 L
.40603 .45244 L
.40697 .45176 L
.40784 .45113 L
.40874 .45048 L
.40957 .44988 L
.41035 .44932 L
.41115 .44875 L
.41189 .44822 L
.41258 .44772 L
.41329 .44721 L
.41395 .44673 L
.41462 .44625 L
.41525 .44579 L
.41584 .44537 L
.41644 .44494 L
.41699 .44453 L
.41751 .44416 L
.41804 .44377 L
.41854 .44341 L
.41905 .44304 L
.41952 .4427 L
.41996 .44238 L
.42041 .44205 L
.42081 .44175 L
Mfstroke
.2906 .11966 m
.30121 .13497 L
.31186 .15071 L
.32108 .16463 L
.32928 .17728 L
.33735 .19 L
.34452 .20157 L
.35157 .21319 L
.35784 .22377 L
.36343 .2334 L
.36893 .24311 L
.37384 .25196 L
.37822 .26004 L
.38255 .2682 L
.38641 .27565 L
.39022 .28316 L
.39362 .29003 L
.39666 .29631 L
.39966 .30266 L
.40235 .30847 L
.40499 .31433 L
.40735 .3197 L
.40946 .32462 L
.41155 .32959 L
.41341 .33415 L
.41507 .33833 L
.41672 .34257 L
.41819 .34646 L
.41964 .3504 L
.42094 .35401 L
.42209 .35733 L
.42323 .3607 L
.42425 .36378 L
.42516 .36662 L
.42606 .36951 L
.42686 .37216 L
.42765 .37485 L
.42835 .37732 L
.42897 .37959 L
.42958 .3819 L
.43013 .38403 L
.43066 .38618 L
.43113 .38817 L
.43154 .38999 L
.43195 .39184 L
.43231 .39355 L
.43263 .39512 L
.43294 .39671 L
.43321 .39818 L
.43347 .39968 L
Mistroke
.4337 .40105 L
.4339 .40232 L
.43409 .40361 L
.43426 .4048 L
.43442 .406 L
.43456 .40711 L
.43467 .40813 L
.43478 .40918 L
.43488 .41013 L
.43495 .41102 L
.43503 .41192 L
.43509 .41275 L
.43514 .41359 L
.43518 .41437 L
.43521 .41509 L
.43524 .41582 L
.43526 .41649 L
.43527 .41682 L
.43527 .41711 L
.43528 .41742 L
.43528 .41758 L
.43528 .41774 L
.43528 .41789 L
.43528 .41797 L
.43528 .41804 L
.43528 .41811 L
.43528 .41815 L
.43528 .41817 L
.43528 .41819 L
.43528 .4182 L
.43528 .41822 L
.43528 .41823 L
.43528 .41825 L
.43528 .41827 L
.43528 .41829 L
.43528 .4183 L
.43528 .41832 L
.43528 .41834 L
.43528 .41835 L
.43528 .41839 L
.43528 .41842 L
.43528 .41846 L
.43528 .41853 L
.43528 .41859 L
.43528 .41873 L
.43528 .41889 L
.43528 .41903 L
.43528 .41918 L
.43527 .41946 L
.43526 .42 L
Mistroke
.43524 .4205 L
.43523 .42096 L
.4352 .42143 L
.43518 .42187 L
.43515 .42231 L
.43512 .42272 L
.43509 .42309 L
.43506 .42348 L
.43502 .42383 L
.43498 .42419 L
.43495 .42452 L
.43491 .42483 L
.43487 .42514 L
.43483 .42543 L
.43479 .4257 L
.43475 .42597 L
.4347 .42623 L
.43466 .42648 L
.43462 .42672 L
.43458 .42694 L
.43453 .42716 L
.43449 .42737 L
.43445 .42756 L
.43441 .42775 L
.43437 .42793 L
.43432 .42812 L
.43428 .42828 L
Mfstroke
.2906 .97436 m
.28772 .94384 L
.2852 .91273 L
.28337 .88545 L
.28207 .86088 L
.28152 .84786 L
.28114 .8364 L
.28099 .83084 L
.28085 .82489 L
.28074 .81942 L
.28067 .81436 L
.28061 .80924 L
.28059 .80656 L
.28058 .80507 L
.28057 .80369 L
.28056 .80227 L
.28056 .80152 L
.28056 .80073 L
.28056 .80037 L
.28056 .79997 L
.28056 .79963 L
.28056 .79926 L
.28056 .79893 L
.28056 .79857 L
.28056 .79794 L
.28056 .79726 L
.28056 .79664 L
.28056 .79629 L
.28056 .79592 L
.28056 .79525 L
.28056 .79395 L
.28057 .79276 L
.28058 .7904 L
.2806 .78788 L
.28065 .78337 L
.28073 .7781 L
.28083 .77335 L
.28107 .76443 L
.28141 .755 L
.28231 .73742 L
.28343 .72157 L
.28488 .70579 L
.28649 .69156 L
.28822 .67871 L
.29024 .66587 L
.29232 .65427 L
.29445 .64376 L
.29682 .63324 L
.29919 .62371 L
.3018 .61417 L
Mistroke
.30438 .60553 L
.30691 .59769 L
.30964 .58982 L
.3123 .58266 L
.31515 .5755 L
.31791 .56898 L
.32057 .56305 L
.3234 .55708 L
.32611 .55165 L
.32871 .54669 L
.33145 .54168 L
.33406 .53711 L
.33681 .53251 L
.33942 .5283 L
.34191 .52446 L
.34451 .52057 L
.34697 .51701 L
.3493 .51374 L
.35174 .51043 L
.35404 .5074 L
.35643 .50432 L
.35869 .5015 L
.36082 .49891 L
.36304 .49628 L
.36512 .49386 L
.36728 .4914 L
.36931 .48914 L
.37122 .48707 L
.37319 .48495 L
.37505 .483 L
.37678 .48121 L
.37858 .47938 L
.38027 .47769 L
.38201 .47597 L
.38365 .47438 L
.38517 .47291 L
.38675 .47142 L
.38822 .47003 L
.3896 .46876 L
.39103 .46745 L
.39236 .46624 L
.39373 .465 L
.39501 .46386 L
.39621 .4628 L
.39744 .46172 L
.39859 .46071 L
.39978 .45969 L
.40088 .45874 L
.40191 .45786 L
.40297 .45696 L
Mistroke
.40396 .45612 L
.40488 .45534 L
.40583 .45455 L
.40672 .45381 L
.40763 .45305 L
.40848 .45235 L
.40927 .4517 L
.41008 .45103 L
.41084 .45041 L
.41161 .44978 L
.41233 .44919 L
.41301 .44864 L
.4137 .44808 L
.41434 .44755 L
.41494 .44707 L
.41556 .44657 L
.41613 .44611 L
.41672 .44563 L
.41727 .44519 L
.41777 .44478 L
.4183 .44436 L
.41878 .44396 L
.41924 .4436 L
.4197 .44322 L
.42013 .44287 L
.42058 .44252 L
.42099 .44218 L
.42138 .44187 L
.42176 .44156 L
Mfstroke
.33333 .11966 m
.34161 .13404 L
.34989 .14888 L
.35703 .16206 L
.36336 .17409 L
.36956 .18623 L
.37506 .19731 L
.38044 .20849 L
.38521 .2187 L
.38944 .22803 L
.39359 .23747 L
.39727 .2461 L
.40054 .25401 L
.40376 .26203 L
.40662 .26937 L
.40942 .27681 L
.4119 .28362 L
.41411 .28987 L
.41628 .29621 L
.4182 .30202 L
.42009 .30791 L
.42175 .31332 L
.42323 .31829 L
.42468 .32333 L
.42596 .32796 L
.4271 .33221 L
.42821 .33654 L
.42919 .34053 L
.43015 .34457 L
.43099 .34828 L
.43174 .3517 L
.43246 .35518 L
.4331 .35838 L
.43366 .36132 L
.4342 .36433 L
.43467 .36709 L
.43513 .3699 L
.43552 .37249 L
.43587 .37487 L
.4362 .3773 L
.43648 .37954 L
.43675 .38182 L
.43697 .38391 L
.43717 .38584 L
.43735 .38781 L
.4375 .38962 L
.43762 .39129 L
.43773 .393 L
.43783 .39457 L
.4379 .39617 L
Mistroke
.43796 .39765 L
.43801 .39901 L
.43803 .39974 L
.43804 .4004 L
.43805 .40107 L
.43806 .40168 L
.43806 .40197 L
.43807 .40229 L
.43807 .4026 L
.43807 .40277 L
.43807 .40285 L
.43807 .40293 L
.43807 .403 L
.43807 .40308 L
.43807 .40317 L
.43807 .40321 L
.43807 .40323 L
.43807 .40325 L
.43807 .40329 L
.43807 .40333 L
.43807 .40336 L
.43807 .40339 L
.43807 .40343 L
.43807 .40347 L
.43807 .40351 L
.43807 .40355 L
.43807 .40362 L
.43807 .40369 L
.43807 .40382 L
.43807 .40395 L
.43807 .4041 L
.43807 .4044 L
.43806 .40467 L
.43806 .40526 L
.43805 .40579 L
.43804 .40636 L
.43801 .40743 L
.43797 .40843 L
.43794 .40934 L
.43789 .41028 L
.43784 .41114 L
.43778 .41202 L
.43772 .41283 L
.43766 .41358 L
.43759 .41435 L
.43752 .41505 L
.43744 .41577 L
.43736 .41644 L
.43729 .41705 L
.43721 .41768 L
Mistroke
.43713 .41826 L
.43705 .41879 L
.43696 .41934 L
.43688 .41984 L
.43679 .42036 L
.43671 .42083 L
.43663 .42127 L
.43654 .42172 L
.43646 .42213 L
.43637 .42255 L
.43628 .42294 L
.4362 .42331 L
.43612 .42367 L
.43604 .42401 L
.43596 .42433 L
.43588 .42465 L
.4358 .42495 L
.43571 .42525 L
.43564 .42553 L
.43556 .42579 L
.43549 .42605 L
.43541 .4263 L
.43534 .42652 L
.43527 .42675 L
.4352 .42697 L
.43513 .42719 L
.43506 .42739 L
.435 .42757 L
.43499 .42758 L
Mfstroke
.33333 .97436 m
.32987 .94565 L
.32661 .91618 L
.324 .89017 L
.3219 .86659 L
.32007 .84296 L
.31869 .82156 L
.31759 .80018 L
.31718 .78997 L
.31687 .78082 L
.31665 .77219 L
.31656 .76787 L
.31648 .76329 L
.31642 .75881 L
.31638 .75477 L
.31636 .75284 L
.31636 .75183 L
.31635 .75076 L
.31635 .74974 L
.31635 .74881 L
.31635 .74836 L
.31634 .74788 L
.31634 .74742 L
.31634 .74701 L
.31634 .74648 L
.31634 .74598 L
.31634 .74553 L
.31634 .74505 L
.31635 .74452 L
.31635 .74397 L
.31635 .74297 L
.31635 .74205 L
.31636 .74119 L
.31637 .73925 L
.31638 .73715 L
.3164 .73524 L
.31646 .73098 L
.31652 .72715 L
.3166 .72364 L
.31681 .71585 L
.31708 .70838 L
.31737 .70179 L
.31815 .68823 L
.31906 .67594 L
.32021 .66361 L
.32146 .65242 L
.32278 .64226 L
.3243 .63205 L
.32586 .62277 L
.32761 .61345 L
Mistroke
.32938 .60498 L
.33114 .59728 L
.33308 .58952 L
.33498 .58246 L
.33705 .57537 L
.33906 .5689 L
.34103 .56301 L
.34313 .55706 L
.34516 .55164 L
.34712 .54669 L
.34921 .54168 L
.35121 .5371 L
.35332 .53248 L
.35534 .52825 L
.35727 .52438 L
.3593 .52046 L
.36123 .51688 L
.36306 .51359 L
.36499 .51025 L
.36681 .50718 L
.36872 .50408 L
.37052 .50122 L
.37222 .49861 L
.374 .49594 L
.37568 .4935 L
.37743 .49101 L
.37907 .48873 L
.38062 .48663 L
.38223 .48449 L
.38374 .48252 L
.38516 .48071 L
.38663 .47885 L
.38802 .47715 L
.38945 .47541 L
.3908 .47381 L
.39206 .47233 L
.39336 .47082 L
.39459 .46943 L
.39573 .46814 L
.39692 .46683 L
.39803 .46561 L
.39917 .46437 L
.40024 .46322 L
.40124 .46216 L
.40228 .46107 L
.40325 .46007 L
.40424 .45904 L
.40517 .45809 L
.40604 .45721 L
.40694 .45631 L
Mistroke
.40777 .45547 L
.40855 .4547 L
.40936 .45391 L
.41011 .45318 L
.41088 .45242 L
.4116 .45173 L
.41228 .45108 L
.41297 .45042 L
.41361 .44981 L
.41428 .44918 L
.4149 .44859 L
.41547 .44805 L
.41606 .4475 L
.41662 .44698 L
.41713 .44651 L
.41766 .44602 L
.41815 .44556 L
.41866 .4451 L
.41913 .44466 L
.41957 .44426 L
.42002 .44385 L
.42044 .44346 L
.42083 .44311 L
.42124 .44274 L
.42161 .4424 L
.422 .44205 L
.42235 .44173 L
.42269 .44143 L
.42273 .44139 L
Mfstroke
.37607 .11966 m
.38192 .13311 L
.38774 .14706 L
.39274 .1595 L
.39714 .1709 L
.40144 .18245 L
.40522 .19305 L
.4089 .20378 L
.41213 .21362 L
.41498 .22265 L
.41776 .23181 L
.42021 .24023 L
.42236 .24797 L
.42446 .25584 L
.42631 .26307 L
.4281 .27042 L
.42967 .27718 L
.43105 .2834 L
.43239 .28972 L
.43356 .29555 L
.43468 .30146 L
.43566 .30691 L
.43652 .31192 L
.43734 .31702 L
.43805 .32173 L
.43867 .32606 L
.43925 .33048 L
.43976 .33455 L
.44023 .33869 L
.44064 .34251 L
.44098 .34603 L
.44129 .34963 L
.44156 .35294 L
.44178 .35599 L
.44197 .35911 L
.44213 .36199 L
.44227 .36492 L
.44237 .36763 L
.44244 .37012 L
.44248 .37147 L
.4425 .37267 L
.44252 .3739 L
.44253 .37503 L
.44254 .3756 L
.44254 .37619 L
.44254 .3767 L
.44254 .37698 L
.44254 .37725 L
.44254 .3774 L
.44254 .37753 L
Mistroke
.44254 .37761 L
.44254 .37768 L
.44254 .37772 L
.44254 .37776 L
.44254 .3778 L
.44254 .37784 L
.44254 .3779 L
.44254 .37796 L
.44254 .37803 L
.44254 .3781 L
.44254 .37818 L
.44254 .37825 L
.44254 .37839 L
.44254 .37864 L
.44254 .37888 L
.44254 .3794 L
.44254 .37993 L
.44253 .38041 L
.44252 .3815 L
.4425 .38254 L
.44249 .38348 L
.44244 .38543 L
.44238 .38722 L
.4423 .38906 L
.44222 .39075 L
.44212 .39248 L
.44202 .39407 L
.44192 .39555 L
.4418 .39705 L
.44168 .39844 L
.44155 .39972 L
.44142 .40103 L
.44129 .40224 L
.44114 .40347 L
.441 .40461 L
.44086 .40567 L
.44071 .40674 L
.44056 .40774 L
.44042 .40865 L
.44027 .40959 L
.44012 .41046 L
.43996 .41135 L
.43981 .41217 L
.43967 .41293 L
.43951 .4137 L
.43937 .41442 L
.43921 .41514 L
.43906 .41582 L
.43892 .41644 L
.43877 .41708 L
Mistroke
.43863 .41767 L
.43849 .41821 L
.43835 .41877 L
.43821 .41929 L
.43807 .41981 L
.43793 .4203 L
.4378 .42075 L
.43767 .42121 L
.43754 .42163 L
.43741 .42207 L
.43728 .42247 L
.43716 .42284 L
.43704 .42322 L
.43692 .42357 L
.43681 .42389 L
.43669 .42423 L
.43659 .42453 L
.43647 .42485 L
.43636 .42514 L
.43626 .42541 L
.43616 .42568 L
.43606 .42593 L
.43597 .42617 L
.43587 .42641 L
.43578 .42663 L
.43568 .42686 L
.43567 .42689 L
Mfstroke
.37607 .97436 m
.37211 .94747 L
.36821 .91968 L
.36493 .89498 L
.36211 .87245 L
.35946 .84973 L
.35724 .82903 L
.3552 .80823 L
.35355 .78929 L
.35223 .77205 L
.3511 .75471 L
.35026 .73892 L
.34967 .72455 L
.34945 .71747 L
.34926 .71006 L
.34919 .70656 L
.34913 .70279 L
.34908 .69928 L
.34905 .69606 L
.34904 .6944 L
.34903 .69352 L
.34903 .6926 L
.34903 .6918 L
.34903 .69138 L
.34903 .69093 L
.34902 .69051 L
.34902 .69013 L
.34902 .68975 L
.34902 .68939 L
.34902 .68905 L
.34902 .68867 L
.34902 .68828 L
.34902 .68791 L
.34902 .68757 L
.34902 .68726 L
.34903 .68655 L
.34903 .68584 L
.34903 .68506 L
.34904 .68351 L
.34905 .68186 L
.34906 .68032 L
.34909 .67747 L
.34914 .67443 L
.3492 .67119 L
.34934 .66541 L
.34953 .65946 L
.34996 .64917 L
.35056 .6388 L
.35125 .62934 L
.35209 .61983 L
Mistroke
.35301 .61116 L
.35396 .60325 L
.35506 .59527 L
.35618 .58798 L
.35743 .58065 L
.35869 .57396 L
.35994 .56784 L
.36132 .56167 L
.36267 .55603 L
.36399 .55087 L
.36542 .54565 L
.3668 .54087 L
.36829 .53604 L
.36973 .53162 L
.37112 .52757 L
.37259 .52346 L
.374 .5197 L
.37536 .51626 L
.37679 .51275 L
.37816 .50954 L
.3796 .50628 L
.38097 .50329 L
.38227 .50054 L
.38364 .49774 L
.38493 .49517 L
.38629 .49257 L
.38758 .49017 L
.38879 .48797 L
.39006 .48573 L
.39126 .48366 L
.39239 .48176 L
.39356 .47983 L
.39467 .47804 L
.39583 .47623 L
.39691 .47455 L
.39793 .47301 L
.39899 .47143 L
.39999 .46998 L
.40092 .46864 L
.4019 .46727 L
.40281 .466 L
.40375 .46471 L
.40464 .46352 L
.40546 .46242 L
.40632 .46129 L
.40713 .46025 L
.40796 .45919 L
.40874 .45821 L
.40946 .4573 L
.41022 .45637 L
Mistroke
.41092 .45552 L
.41158 .45472 L
.41226 .45391 L
.41289 .45315 L
.41355 .45238 L
.41416 .45167 L
.41473 .45101 L
.41532 .45033 L
.41587 .44971 L
.41644 .44906 L
.41697 .44847 L
.41747 .44792 L
.41797 .44736 L
.41845 .44684 L
.41889 .44635 L
.41935 .44585 L
.41977 .44539 L
.42021 .44492 L
.42062 .44449 L
.421 .44408 L
.42139 .44366 L
.42176 .44328 L
.4221 .44292 L
.42245 .44255 L
.42278 .44221 L
.42312 .44186 L
.42343 .44154 L
.42371 .44124 L
Mfstroke
.4188 .11966 m
.42214 .13218 L
.42542 .14523 L
.42821 .15693 L
.43063 .1677 L
.43297 .17868 L
.435 .18878 L
.43694 .19906 L
.43862 .20853 L
.44007 .21725 L
.44146 .22615 L
.44265 .23434 L
.44368 .24191 L
.44466 .24963 L
.44549 .25676 L
.44627 .26402 L
.44693 .27072 L
.44748 .2769 L
.44799 .28321 L
.44841 .28904 L
.44879 .29498 L
.44909 .30046 L
.44933 .30552 L
.44953 .31069 L
.44968 .31546 L
.44978 .31987 L
.44982 .32207 L
.44986 .32438 L
.44987 .32548 L
.44988 .32667 L
.44989 .32778 L
.44989 .32827 L
.44989 .3288 L
.44989 .32932 L
.4499 .32955 L
.4499 .3298 L
.4499 .33002 L
.4499 .33026 L
.4499 .33039 L
.4499 .3305 L
.4499 .33061 L
.4499 .33073 L
.4499 .33087 L
.4499 .33094 L
.4499 .331 L
.4499 .33112 L
.4499 .33125 L
.4499 .33133 L
.4499 .3314 L
.4499 .33148 L
Mistroke
.4499 .33155 L
.4499 .33168 L
.4499 .33181 L
.4499 .33209 L
.4499 .33235 L
.4499 .33283 L
.44989 .33329 L
.44989 .3338 L
.44989 .33483 L
.44988 .33576 L
.44987 .33663 L
.44985 .33858 L
.44982 .34032 L
.44974 .34394 L
.44965 .34729 L
.44953 .35072 L
.44939 .35388 L
.44925 .35681 L
.44908 .3598 L
.4489 .36257 L
.4487 .36539 L
.4485 .368 L
.44829 .37042 L
.44807 .37288 L
.44784 .37517 L
.4476 .37749 L
.44736 .37965 L
.44712 .38163 L
.44687 .38367 L
.44662 .38555 L
.44638 .38728 L
.44612 .38906 L
.44586 .39071 L
.4456 .39238 L
.44534 .39394 L
.44509 .39537 L
.44483 .39684 L
.44457 .3982 L
.44433 .39945 L
.44407 .40074 L
.44383 .40192 L
.44357 .40314 L
.44332 .40426 L
.44309 .4053 L
.44284 .40636 L
.44261 .40735 L
.44236 .40835 L
.44212 .40928 L
.4419 .41014 L
.44167 .41102 L
Mistroke
.44144 .41183 L
.44123 .41258 L
.44102 .41335 L
.44081 .41406 L
.44059 .41479 L
.44038 .41546 L
.44019 .41608 L
.43999 .41672 L
.43979 .41731 L
.4396 .41791 L
.43941 .41847 L
.43923 .41898 L
.43904 .41951 L
.43887 .42 L
.43871 .42045 L
.43853 .42091 L
.43837 .42134 L
.43821 .42177 L
.43805 .42218 L
.4379 .42255 L
.43775 .42294 L
.4376 .42329 L
.43746 .42362 L
.43732 .42395 L
.43719 .42426 L
.43705 .42458 L
.43692 .42488 L
.4368 .42515 L
.43668 .42543 L
.43656 .42569 L
.43643 .42595 L
.43632 .4262 L
.43632 .4262 L
Mfstroke
.4188 .97436 m
.41446 .9493 L
.41003 .92323 L
.40616 .89989 L
.40271 .87846 L
.39932 .85672 L
.39633 .83679 L
.39344 .81664 L
.39092 .79819 L
.38874 .7813 L
.38666 .76422 L
.38489 .7486 L
.38339 .7343 L
.382 .71983 L
.38086 .7066 L
.37984 .69325 L
.37904 .68104 L
.37842 .66988 L
.37792 .6586 L
.37758 .64829 L
.37745 .64286 L
.3774 .64043 L
.37736 .63789 L
.37732 .63558 L
.3773 .63307 L
.37729 .63198 L
.37728 .63082 L
.37727 .62973 L
.37727 .62874 L
.37727 .62821 L
.37727 .62763 L
.37727 .62734 L
.37727 .62718 L
.37727 .62702 L
.37727 .62673 L
.37727 .62646 L
.37727 .62621 L
.37727 .62594 L
.37727 .62569 L
.37727 .62546 L
.37727 .62519 L
.37727 .6249 L
.37727 .62437 L
.37727 .62381 L
.37727 .62319 L
.37728 .62195 L
.37729 .62081 L
.37729 .61975 L
.37732 .61747 L
.37735 .61534 L
Mistroke
.37742 .61142 L
.37752 .60732 L
.37763 .60362 L
.37794 .59601 L
.37834 .58833 L
.37881 .58131 L
.37933 .57488 L
.37993 .56839 L
.38057 .56244 L
.38123 .55699 L
.38198 .55147 L
.38273 .54641 L
.38356 .54129 L
.38439 .5366 L
.38521 .53231 L
.38611 .52795 L
.38699 .52395 L
.38784 .52028 L
.38876 .51656 L
.38966 .51313 L
.39061 .50967 L
.39153 .50648 L
.39242 .50355 L
.39336 .50058 L
.39427 .49784 L
.39522 .49507 L
.39613 .49252 L
.39701 .49018 L
.39792 .48779 L
.3988 .4856 L
.39963 .48358 L
.4005 .48152 L
.40133 .47963 L
.40219 .4777 L
.40301 .47592 L
.40379 .47429 L
.4046 .47262 L
.40536 .47108 L
.40608 .46967 L
.40684 .46822 L
.40755 .46688 L
.40829 .46552 L
.40898 .46427 L
.40964 .46311 L
.41032 .46192 L
.41096 .46083 L
.41162 .45972 L
.41225 .45869 L
.41283 .45774 L
.41344 .45676 L
Mistroke
.41401 .45587 L
.41454 .45504 L
.4151 .45419 L
.41562 .4534 L
.41615 .4526 L
.41666 .45186 L
.41713 .45118 L
.41762 .45047 L
.41807 .44983 L
.41855 .44916 L
.41899 .44855 L
.4194 .44798 L
.41983 .4474 L
.42022 .44686 L
.4206 .44637 L
.42098 .44586 L
.42134 .44538 L
.42171 .4449 L
.42206 .44445 L
.42238 .44404 L
.42272 .44361 L
.42303 .44322 L
.42332 .44285 L
.42362 .44248 L
.4239 .44213 L
.42419 .44178 L
.42446 .44145 L
.42471 .44114 L
.42473 .44112 L
Mfstroke
.46154 .11966 m
.46226 .13125 L
.46293 .1434 L
.46343 .15436 L
.46383 .16451 L
.46416 .17489 L
.4644 .18451 L
.46449 .18927 L
.46457 .19433 L
.46463 .19911 L
.46465 .20135 L
.46467 .20343 L
.46468 .2056 L
.46469 .20757 L
.46469 .20869 L
.4647 .20974 L
.4647 .21085 L
.4647 .21147 L
.4647 .21175 L
.4647 .21205 L
.4647 .21232 L
.4647 .21247 L
.4647 .21262 L
.4647 .21289 L
.4647 .21314 L
.4647 .21329 L
.4647 .21345 L
.4647 .21361 L
.4647 .21375 L
.4647 .21402 L
.4647 .21416 L
.4647 .21431 L
.4647 .21484 L
.4647 .21513 L
.4647 .2154 L
.4647 .21642 L
.4647 .21733 L
.46469 .21832 L
.46468 .2203 L
.46467 .22242 L
.46466 .22432 L
.46461 .22853 L
.46456 .23231 L
.4645 .23633 L
.46434 .244 L
.46415 .2511 L
.46393 .25768 L
.46367 .26442 L
.4634 .27066 L
.46308 .27704 L
Mistroke
.46275 .28295 L
.46241 .28843 L
.46204 .29404 L
.46166 .29923 L
.46125 .30453 L
.46084 .30944 L
.46043 .31399 L
.45999 .31864 L
.45956 .32295 L
.45914 .32694 L
.45869 .33103 L
.45825 .33481 L
.45778 .33868 L
.45732 .34227 L
.45688 .34558 L
.45641 .34898 L
.45596 .35212 L
.45553 .35503 L
.45507 .35802 L
.45462 .36078 L
.45416 .3636 L
.45371 .36622 L
.45328 .36864 L
.45283 .37112 L
.4524 .37342 L
.45195 .37576 L
.45152 .37793 L
.4511 .37994 L
.45067 .382 L
.45026 .3839 L
.44987 .38567 L
.44946 .38747 L
.44907 .38914 L
.44867 .39085 L
.44828 .39243 L
.44791 .3939 L
.44753 .3954 L
.44717 .39678 L
.44682 .39807 L
.44646 .39938 L
.44613 .4006 L
.44577 .40185 L
.44544 .403 L
.44512 .40407 L
.44479 .40517 L
.44448 .40618 L
.44415 .40721 L
.44385 .40817 L
.44356 .40906 L
.44326 .40997 L
Mistroke
.44298 .41081 L
.44271 .41158 L
.44243 .41238 L
.44217 .41312 L
.4419 .41387 L
.44164 .41457 L
.4414 .41522 L
.44115 .41588 L
.44092 .41649 L
.44067 .41712 L
.44044 .4177 L
.44023 .41824 L
.44 .41879 L
.43979 .41929 L
.4396 .41977 L
.43939 .42025 L
.4392 .4207 L
.439 .42115 L
.43881 .42158 L
.43864 .42197 L
.43845 .42237 L
.43828 .42274 L
.43812 .42308 L
.43796 .42344 L
.4378 .42376 L
.43764 .4241 L
.43749 .42441 L
.43735 .4247 L
.4372 .42499 L
.43707 .42526 L
.43693 .42552 L
Mfstroke
.46154 .97436 m
.4569 .95115 L
.45205 .92683 L
.4477 .9049 L
.44372 .88464 L
.43969 .86395 L
.43602 .84486 L
.43235 .82543 L
.42903 .80755 L
.42605 .79108 L
.42308 .77433 L
.42043 .75893 L
.41807 .74476 L
.41575 .73036 L
.41369 .71713 L
.4117 .70371 L
.40995 .6914 L
.40843 .68009 L
.40697 .66862 L
.40571 .6581 L
.40453 .64745 L
.40353 .63769 L
.4027 .62873 L
.40193 .61966 L
.4013 .61134 L
.4008 .60371 L
.40036 .59596 L
.40004 .58886 L
.39978 .58167 L
.39968 .57821 L
.39961 .57508 L
.39956 .57211 L
.39954 .57062 L
.39952 .56903 L
.39951 .56827 L
.39951 .56748 L
.3995 .56675 L
.3995 .56607 L
.3995 .56543 L
.39949 .56508 L
.39949 .56476 L
.39949 .56441 L
.39949 .56421 L
.39949 .56403 L
.39949 .56387 L
.39949 .5637 L
.39949 .56352 L
.39949 .56335 L
.39949 .56316 L
.39949 .56306 L
Mistroke
.39949 .56297 L
.39949 .56262 L
.39949 .56242 L
.39949 .56221 L
.3995 .56182 L
.3995 .56108 L
.3995 .5604 L
.39951 .55911 L
.39952 .55776 L
.39956 .55503 L
.39961 .55254 L
.39975 .54744 L
.39995 .54227 L
.40019 .53752 L
.40045 .53317 L
.40078 .52875 L
.40112 .52469 L
.40148 .52096 L
.40188 .51717 L
.4023 .51369 L
.40276 .51016 L
.40323 .50692 L
.40369 .50393 L
.40419 .5009 L
.40469 .49811 L
.40523 .49529 L
.40575 .49269 L
.40627 .49029 L
.40682 .48786 L
.40735 .48562 L
.40786 .48356 L
.40841 .48147 L
.40893 .47954 L
.40949 .47757 L
.41002 .47576 L
.41053 .4741 L
.41107 .4724 L
.41158 .47084 L
.41207 .4694 L
.41259 .46793 L
.41308 .46657 L
.41359 .46519 L
.41408 .46392 L
.41454 .46274 L
.41502 .46154 L
.41548 .46044 L
.41596 .45931 L
.41641 .45827 L
.41684 .45731 L
.41728 .45633 L
Mistroke
.4177 .45543 L
.41809 .45459 L
.41851 .45374 L
.41889 .45295 L
.4193 .45215 L
.41968 .4514 L
.42003 .45072 L
.4204 .45001 L
.42075 .44936 L
.42111 .4487 L
.42145 .44809 L
.42177 .44752 L
.4221 .44695 L
.42241 .44641 L
.4227 .44592 L
.423 .44541 L
.42328 .44494 L
.42357 .44446 L
.42384 .44402 L
.4241 .44361 L
.42436 .44319 L
.42461 .4428 L
.42484 .44245 L
.42508 .44208 L
.42531 .44174 L
.42554 .44139 L
.42575 .44106 L
.42578 .44102 L
Mfstroke
.50427 .11966 m
.5023 .13032 L
.50025 .14158 L
.49842 .1518 L
.49673 .16131 L
.49501 .17111 L
.49342 .18023 L
.49179 .18961 L
.49028 .19833 L
.48888 .20644 L
.48743 .21478 L
.48609 .22254 L
.48484 .22975 L
.48355 .23718 L
.48235 .24408 L
.4811 .25116 L
.47994 .25774 L
.47884 .26386 L
.47771 .27014 L
.47665 .27598 L
.47555 .28196 L
.47452 .28751 L
.47355 .29267 L
.47254 .29796 L
.4716 .30288 L
.47071 .30744 L
.46978 .31212 L
.46891 .31647 L
.468 .32092 L
.46715 .32506 L
.46634 .32889 L
.4655 .33283 L
.46472 .33647 L
.46397 .33986 L
.4632 .34334 L
.46247 .34656 L
.46171 .34986 L
.46099 .35293 L
.46032 .35577 L
.45961 .35868 L
.45895 .36138 L
.45826 .36414 L
.45761 .36671 L
.457 .36908 L
.45636 .37151 L
.45576 .37377 L
.4552 .37586 L
.45461 .37801 L
.45405 .37999 L
.45348 .38203 L
Mistroke
.45293 .38391 L
.45242 .38566 L
.45189 .38745 L
.45139 .38911 L
.45087 .3908 L
.45038 .39238 L
.44992 .39383 L
.44944 .39532 L
.44899 .3967 L
.44856 .39798 L
.44812 .39929 L
.44771 .40051 L
.44728 .40175 L
.44687 .4029 L
.44649 .40397 L
.4461 .40506 L
.44573 .40607 L
.44538 .40701 L
.44502 .40797 L
.44468 .40886 L
.44433 .40977 L
.444 .41062 L
.44369 .4114 L
.44336 .4122 L
.44306 .41294 L
.44275 .4137 L
.44245 .4144 L
.44218 .41506 L
.44189 .41572 L
.44162 .41634 L
.44137 .41691 L
.44111 .4175 L
.44087 .41804 L
.44062 .4186 L
.44038 .41911 L
.44016 .41959 L
.43993 .42008 L
.43971 .42053 L
.43951 .42095 L
.4393 .42138 L
.4391 .42178 L
.4389 .42219 L
.43871 .42256 L
.43853 .42291 L
.43835 .42327 L
.43818 .42361 L
.438 .42395 L
.43783 .42426 L
.43768 .42455 L
.43752 .42485 L
Mistroke
Mfstroke
.50427 .97436 m
.49944 .95301 L
.49428 .93048 L
.48956 .91002 L
.48514 .89099 L
.48058 .87142 L
.47633 .85325 L
.47198 .83464 L
.46795 .8174 L
.46424 .80142 L
.46046 .78509 L
.45699 .76998 L
.45381 .75601 L
.4506 .74173 L
.44767 .72855 L
.44474 .71512 L
.44208 .70273 L
.43967 .69132 L
.43726 .67968 L
.4351 .66897 L
.43296 .65808 L
.43105 .64806 L
.42933 .63885 L
.42765 .62948 L
.42616 .62086 L
.42484 .61293 L
.42355 .60487 L
.42241 .59745 L
.42131 .58993 L
.42036 .58302 L
.41953 .57666 L
.41874 .57021 L
.41806 .56427 L
.41748 .55882 L
.41694 .55327 L
.41648 .54817 L
.41607 .543 L
.41573 .53824 L
.41545 .53387 L
.41522 .52943 L
.41504 .52535 L
.4149 .52121 L
.41484 .51921 L
.4148 .5174 L
.41477 .51568 L
.41476 .51482 L
.41475 .5139 L
.41474 .513 L
.41474 .51218 L
.41474 .51179 L
Mistroke
.41474 .51159 L
.41473 .51137 L
.41473 .51116 L
.41473 .51097 L
.41473 .51088 L
.41473 .51079 L
.41473 .51069 L
.41473 .51061 L
.41473 .5105 L
.41473 .51041 L
.41473 .5103 L
.41473 .51024 L
.41473 .51019 L
.41473 .5101 L
.41473 .51 L
.41473 .5099 L
.41473 .5098 L
.41473 .50958 L
.41473 .50938 L
.41474 .50893 L
.41474 .50852 L
.41474 .50808 L
.41475 .5072 L
.41476 .50636 L
.41477 .50562 L
.4148 .50398 L
.41483 .5025 L
.41487 .50094 L
.41497 .49798 L
.4151 .49526 L
.41523 .49276 L
.4154 .49021 L
.41558 .48786 L
.41578 .48548 L
.41599 .48329 L
.41621 .48127 L
.41645 .47921 L
.41669 .47732 L
.41693 .47558 L
.41719 .47381 L
.41744 .47217 L
.41772 .47051 L
.418 .46898 L
.41826 .46757 L
.41855 .46613 L
.41882 .4648 L
.41912 .46345 L
.4194 .46221 L
.41968 .46107 L
.41997 .4599 L
Mistroke
.42024 .45882 L
.42051 .45783 L
.42079 .45682 L
.42106 .45588 L
.42134 .45493 L
.42161 .45405 L
.42187 .45324 L
.42214 .45241 L
.4224 .45165 L
.42267 .45087 L
.42292 .45015 L
.42316 .44949 L
.42341 .44881 L
.42365 .44819 L
.42388 .44761 L
.42411 .44702 L
.42434 .44648 L
.42457 .44592 L
.42479 .44541 L
.42499 .44493 L
.42521 .44445 L
.42541 .444 L
.4256 .44359 L
.4258 .44316 L
.42598 .44277 L
.42617 .44237 L
.42636 .442 L
.42653 .44166 L
.4267 .44131 L
.42687 .44099 L
.42688 .44097 L
Mfstroke
.54701 .11966 m
.54225 .12939 L
.53741 .13975 L
.53317 .14923 L
.52934 .15812 L
.52552 .16733 L
.52206 .17596 L
.5186 .18488 L
.51545 .19322 L
.5126 .20103 L
.50972 .20909 L
.50709 .21663 L
.50469 .22367 L
.50226 .23094 L
.50003 .23772 L
.49777 .24472 L
.4957 .25124 L
.49379 .25732 L
.49185 .26359 L
.49005 .26943 L
.48823 .27543 L
.48654 .28102 L
.48498 .28623 L
.48338 .29158 L
.4819 .29657 L
.48053 .3012 L
.47912 .30598 L
.47781 .31042 L
.47646 .31498 L
.47521 .31921 L
.47404 .32315 L
.47284 .3272 L
.47173 .33097 L
.47068 .33446 L
.4696 .33806 L
.4686 .3414 L
.46756 .34483 L
.46659 .34801 L
.46569 .35097 L
.46475 .354 L
.46387 .35682 L
.46297 .35971 L
.46212 .36239 L
.46133 .36488 L
.46051 .36743 L
.45974 .3698 L
.45903 .372 L
.45828 .37425 L
.45758 .37634 L
.45686 .37849 L
Mistroke
.45619 .38048 L
.45555 .38232 L
.4549 .38422 L
.45428 .38597 L
.45365 .38777 L
.45305 .38943 L
.45249 .39098 L
.45191 .39256 L
.45137 .39402 L
.45086 .39538 L
.45033 .39678 L
.44984 .39807 L
.44933 .3994 L
.44885 .40062 L
.4484 .40176 L
.44794 .40293 L
.4475 .40401 L
.44709 .40501 L
.44667 .40604 L
.44627 .40699 L
.44586 .40796 L
.44548 .40887 L
.44512 .4097 L
.44474 .41056 L
.44439 .41136 L
.44403 .41217 L
.44369 .41293 L
.44337 .41363 L
.44305 .41434 L
.44274 .41501 L
.44245 .41562 L
.44215 .41625 L
.44187 .41684 L
.44158 .41743 L
.44131 .41799 L
.44106 .4185 L
.4408 .41903 L
.44055 .41952 L
.44033 .41997 L
.44009 .42043 L
.43987 .42086 L
.43964 .4213 L
.43942 .42171 L
.43922 .42209 L
.43901 .42248 L
.43882 .42284 L
.43862 .42321 L
.43843 .42355 L
.43826 .42386 L
.43808 .42418 L
Mistroke
Mfstroke
.54701 .97436 m
.54209 .95489 L
.53674 .93418 L
.53175 .91525 L
.527 .89751 L
.52201 .87915 L
.51729 .86199 L
.51237 .84429 L
.50773 .82778 L
.50338 .8124 L
.49888 .79656 L
.49467 .78183 L
.49074 .76813 L
.4867 .75405 L
.48296 .74098 L
.47912 .7276 L
.47558 .71519 L
.47232 .7037 L
.46899 .69194 L
.46594 .68106 L
.46285 .66997 L
.46002 .65971 L
.45743 .65024 L
.45483 .64058 L
.45246 .63166 L
.4503 .62343 L
.44813 .61504 L
.44617 .6073 L
.44421 .59942 L
.44244 .59217 L
.44084 .58548 L
.43926 .57867 L
.43783 .57241 L
.43655 .56664 L
.43528 .56075 L
.43414 .55534 L
.43302 .54984 L
.43203 .54477 L
.43115 .54011 L
.43028 .53537 L
.42952 .53101 L
.42877 .52658 L
.42812 .52251 L
.42755 .51876 L
.427 .51495 L
.42652 .51145 L
.42611 .50822 L
.42571 .50494 L
.42537 .50192 L
.42505 .49886 L
Mistroke
.42478 .49604 L
.42456 .49344 L
.42435 .4908 L
.42419 .48837 L
.42404 .48591 L
.42392 .48364 L
.42383 .48155 L
.42376 .47943 L
.42374 .47841 L
.42372 .47748 L
.4237 .4766 L
.42369 .47568 L
.42369 .47521 L
.42369 .47497 L
.42368 .47471 L
.42368 .47449 L
.42368 .47437 L
.42368 .47424 L
.42368 .47412 L
.42368 .47402 L
.42368 .47392 L
.42368 .47387 L
.42368 .47381 L
.42368 .47378 L
.42368 .47375 L
.42368 .4737 L
.42368 .47364 L
.42368 .47361 L
.42368 .47358 L
.42368 .47352 L
.42368 .47347 L
.42368 .47336 L
.42368 .47326 L
.42368 .47315 L
.42368 .47295 L
.42368 .47273 L
.42368 .47249 L
.42369 .47206 L
.42369 .47167 L
.4237 .47125 L
.42371 .4705 L
.42372 .4697 L
.42375 .46888 L
.42379 .46744 L
.42385 .46597 L
.42392 .46462 L
.424 .46325 L
.42409 .46198 L
.42418 .46082 L
.42429 .45963 L
Mistroke
.42439 .45854 L
.4245 .45753 L
.42462 .4565 L
.42474 .45556 L
.42487 .45459 L
.425 .45371 L
.42513 .45289 L
.42526 .45205 L
.4254 .45128 L
.42554 .4505 L
.42568 .44978 L
.42581 .44911 L
.42595 .44843 L
.42609 .4478 L
.42622 .44723 L
.42636 .44664 L
.4265 .44609 L
.42664 .44554 L
.42678 .44502 L
.42691 .44455 L
.42704 .44407 L
.42717 .44362 L
.42729 .44321 L
.42742 .44279 L
.42755 .4424 L
.42768 .44201 L
.4278 .44164 L
.42791 .4413 L
.42803 .44097 L
Mfstroke
.58974 .11966 m
.5821 .12846 L
.57439 .13792 L
.56768 .14666 L
.56166 .15492 L
.55569 .16354 L
.55032 .17168 L
.545 .18015 L
.5402 .18812 L
.53587 .19562 L
.53154 .2034 L
.52762 .21072 L
.52406 .21758 L
.52048 .2247 L
.51723 .23137 L
.51396 .23827 L
.51098 .24473 L
.50826 .25078 L
.50551 .25703 L
.50299 .26287 L
.50044 .2689 L
.49811 .27453 L
.49597 .27978 L
.49379 .2852 L
.49178 .29025 L
.48994 .29497 L
.48805 .29983 L
.48632 .30436 L
.48454 .30903 L
.4829 .31337 L
.48139 .31742 L
.47983 .32158 L
.4784 .32546 L
.47706 .32907 L
.47569 .33279 L
.47442 .33624 L
.47312 .3398 L
.4719 .3431 L
.47078 .34617 L
.46962 .34933 L
.46854 .35227 L
.46743 .35528 L
.46639 .35808 L
.46543 .36068 L
.46444 .36335 L
.46351 .36583 L
.46265 .36814 L
.46175 .37051 L
.46092 .37271 L
.46006 .37496 L
Mistroke
.45926 .37705 L
.45851 .379 L
.45774 .38099 L
.45702 .38284 L
.45627 .38474 L
.45557 .3865 L
.45492 .38813 L
.45425 .3898 L
.45362 .39136 L
.45303 .3928 L
.45242 .39428 L
.45185 .39565 L
.45127 .39705 L
.45072 .39836 L
.4502 .39956 L
.44967 .4008 L
.44917 .40195 L
.44871 .40302 L
.44823 .40411 L
.44778 .40513 L
.44731 .40616 L
.44687 .40713 L
.44647 .40802 L
.44605 .40894 L
.44565 .40979 L
.44524 .41066 L
.44486 .41146 L
.44451 .41221 L
.44414 .41297 L
.44379 .41368 L
.44347 .41434 L
.44314 .41502 L
.44282 .41564 L
.4425 .41628 L
.4422 .41688 L
.44192 .41743 L
.44163 .41799 L
.44136 .41851 L
.4411 .419 L
.44084 .4195 L
.44059 .41996 L
.44034 .42043 L
.4401 .42087 L
.43988 .42128 L
.43965 .42169 L
.43943 .42208 L
.43921 .42247 L
.439 .42284 L
.43881 .42318 L
.43861 .42352 L
Mistroke
Mfstroke
.58974 .97436 m
.58483 .95677 L
.57941 .93794 L
.57428 .92059 L
.56932 .90422 L
.56403 .88716 L
.55896 .87109 L
.55359 .85442 L
.54845 .83875 L
.54357 .82405 L
.53844 .80882 L
.53358 .79456 L
.529 .78123 L
.52421 .76744 L
.51971 .75456 L
.51505 .7413 L
.51068 .72895 L
.5066 .71744 L
.50239 .70561 L
.49847 .69461 L
.49445 .68333 L
.49072 .67286 L
.48727 .66316 L
.48374 .65321 L
.48048 .644 L
.47748 .63547 L
.47442 .62674 L
.47161 .61866 L
.46876 .61042 L
.46614 .6028 L
.46375 .59577 L
.46133 .58858 L
.45912 .58195 L
.4571 .57583 L
.45507 .56959 L
.45321 .56382 L
.45135 .55795 L
.44966 .55254 L
.44813 .54756 L
.44659 .54248 L
.4452 .5378 L
.44381 .53304 L
.44256 .52866 L
.44143 .52463 L
.4403 .52053 L
.43929 .51675 L
.43838 .51327 L
.43748 .50973 L
.43667 .50647 L
.43586 .50316 L
Mistroke
.43515 .50011 L
.43451 .49731 L
.43388 .49446 L
.43332 .49183 L
.43277 .48917 L
.43228 .48671 L
.43185 .48446 L
.43143 .48217 L
.43106 .48006 L
.43074 .47812 L
.43042 .47614 L
.43014 .47432 L
.42988 .47247 L
.42965 .47078 L
.42945 .46921 L
.42927 .46762 L
.4291 .46616 L
.42897 .46481 L
.42884 .46343 L
.42873 .46217 L
.42864 .46088 L
.42856 .4597 L
.42849 .45861 L
.42844 .4575 L
.4284 .45648 L
.42836 .45544 L
.42835 .45494 L
.42834 .45449 L
.42834 .45405 L
.42833 .45384 L
.42833 .45361 L
.42833 .45338 L
.42833 .45317 L
.42833 .45307 L
.42833 .45302 L
.42833 .45297 L
.42833 .45292 L
.42833 .45287 L
.42833 .45284 L
.42833 .45282 L
.42833 .4528 L
.42833 .45278 L
.42833 .45275 L
.42833 .45272 L
.42833 .4527 L
.42833 .45268 L
.42833 .45267 L
.42833 .45265 L
.42833 .45262 L
.42833 .4526 L
Mistroke
.42833 .45257 L
.42833 .45252 L
.42833 .45246 L
.42833 .45235 L
.42833 .45224 L
.42833 .45212 L
.42833 .45191 L
.42833 .4517 L
.42833 .45151 L
.42834 .4511 L
.42835 .45072 L
.42836 .45033 L
.42838 .44958 L
.42841 .44888 L
.42844 .44825 L
.42848 .44759 L
.42852 .44699 L
.42856 .44638 L
.42861 .44582 L
.42866 .4453 L
.42872 .44477 L
.42877 .44428 L
.42883 .44383 L
.42889 .44338 L
.42894 .44295 L
.42901 .44252 L
.42907 .44212 L
.42913 .44175 L
.4292 .44138 L
.42926 .44104 L
Mfstroke
.63248 .11966 m
.62187 .12753 L
.6112 .1361 L
.60194 .14409 L
.59369 .15172 L
.58552 .15976 L
.57821 .1674 L
.57099 .17542 L
.56451 .18301 L
.55869 .1902 L
.55289 .19771 L
.54767 .2048 L
.54295 .21149 L
.53823 .21845 L
.53395 .22501 L
.52967 .23183 L
.52579 .23823 L
.52226 .24424 L
.5187 .25047 L
.51547 .25632 L
.51221 .26237 L
.50924 .26804 L
.50652 .27334 L
.50377 .27882 L
.50125 .28395 L
.49894 .28874 L
.4966 .29369 L
.49444 .29832 L
.49225 .30309 L
.49024 .30754 L
.48838 .31169 L
.48649 .31597 L
.48474 .31996 L
.48313 .32368 L
.48148 .32752 L
.47995 .3311 L
.47839 .33478 L
.47694 .3382 L
.4756 .34139 L
.47422 .34467 L
.47295 .34773 L
.47164 .35087 L
.47043 .35379 L
.4693 .3565 L
.46814 .35929 L
.46707 .36188 L
.46606 .36429 L
.46503 .36678 L
.46407 .36908 L
.46308 .37145 L
Mistroke
.46216 .37364 L
.4613 .37569 L
.46042 .37778 L
.45959 .37973 L
.45875 .38173 L
.45795 .38358 L
.45722 .3853 L
.45645 .38707 L
.45574 .3887 L
.45508 .39023 L
.45439 .39179 L
.45376 .39324 L
.4531 .39472 L
.45248 .3961 L
.4519 .39738 L
.45131 .39869 L
.45075 .39991 L
.45024 .40104 L
.4497 .4022 L
.4492 .40328 L
.44868 .40438 L
.4482 .4054 L
.44774 .40635 L
.44728 .40733 L
.44684 .40823 L
.44639 .40915 L
.44597 .41001 L
.44558 .4108 L
.44517 .41162 L
.44479 .41237 L
.44444 .41307 L
.44407 .41379 L
.44373 .41446 L
.44337 .41514 L
.44304 .41578 L
.44273 .41636 L
.44241 .41697 L
.44212 .41752 L
.44184 .41804 L
.44155 .41857 L
.44128 .41907 L
.441 .41957 L
.44074 .42004 L
.4405 .42047 L
.44025 .42092 L
.44001 .42133 L
.43977 .42175 L
.43955 .42214 L
.43933 .42251 L
.43912 .42287 L
Mistroke
Mfstroke
.63248 .97436 m
.62768 .95867 L
.62232 .94175 L
.61716 .92604 L
.61211 .91112 L
.60667 .89545 L
.60137 .88059 L
.59569 .86505 L
.59019 .85035 L
.5849 .83645 L
.57928 .82196 L
.57389 .80829 L
.56874 .79543 L
.56332 .78204 L
.55816 .76946 L
.55275 .75643 L
.54763 .7442 L
.54279 .73276 L
.53776 .72092 L
.53302 .70986 L
.52811 .69846 L
.5235 .68782 L
.5192 .67791 L
.51476 .66771 L
.51062 .65822 L
.50676 .6494 L
.5028 .64034 L
.49912 .63192 L
.49536 .62329 L
.49188 .6153 L
.48865 .60789 L
.48537 .6003 L
.48234 .59328 L
.47954 .58678 L
.4767 .58013 L
.47408 .57398 L
.47143 .5677 L
.46899 .56191 L
.46676 .55655 L
.4645 .55109 L
.46243 .54605 L
.46035 .54092 L
.45844 .53619 L
.45671 .53182 L
.45496 .52738 L
.45336 .52328 L
.45191 .51951 L
.45045 .51566 L
.44912 .51212 L
.44779 .50852 L
Mistroke
.44658 .5052 L
.44548 .50215 L
.44438 .49904 L
.44339 .49618 L
.4424 .49328 L
.4415 .49061 L
.44069 .48815 L
.43988 .48565 L
.43916 .48335 L
.4385 .48123 L
.43785 .47908 L
.43726 .4771 L
.43668 .47509 L
.43616 .47324 L
.43569 .47154 L
.43522 .46981 L
.43481 .46821 L
.43444 .46675 L
.43407 .46526 L
.43374 .46388 L
.43342 .46249 L
.43313 .46121 L
.43288 .46003 L
.43263 .45883 L
.43241 .45772 L
.43219 .4566 L
.43201 .45557 L
.43184 .45462 L
.43168 .45365 L
.43154 .45276 L
.43141 .45195 L
.43129 .45111 L
.43119 .45035 L
.43109 .44957 L
.43101 .44885 L
.43094 .44819 L
.43087 .44752 L
.43081 .4469 L
.43077 .44633 L
.43072 .44575 L
.43069 .44521 L
.43066 .44467 L
.43063 .44416 L
.43061 .4437 L
.4306 .44323 L
.43059 .44302 L
.43059 .4428 L
.43059 .44257 L
.43058 .44247 L
.43058 .44236 L
Mistroke
.43058 .44225 L
.43058 .44215 L
.43058 .4421 L
.43058 .44205 L
.43058 .44202 L
.43058 .44201 L
.43058 .44199 L
.43058 .44199 L
.43058 .44198 L
.43058 .44197 L
.43058 .44196 L
.43058 .44195 L
.43058 .44194 L
.43058 .44193 L
.43058 .44192 L
.43058 .44191 L
.43058 .44189 L
.43058 .44187 L
.43058 .44184 L
.43058 .4418 L
.43058 .44176 L
.43058 .44171 L
.43058 .44166 L
.43058 .44156 L
.43058 .44147 L
.43059 .44137 L
.43059 .4412 L
Mfstroke
.67521 .11966 m
.66154 .1266 L
.64783 .13427 L
.63597 .14153 L
.62542 .14853 L
.61501 .15598 L
.60573 .16313 L
.59658 .17069 L
.5884 .17791 L
.58107 .18479 L
.57379 .19202 L
.56726 .19889 L
.56137 .2054 L
.5555 .21222 L
.55019 .21866 L
.54491 .22539 L
.54012 .23173 L
.53579 .23771 L
.53144 .24393 L
.52749 .24978 L
.52354 .25585 L
.51993 .26155 L
.51665 .26691 L
.51334 .27245 L
.51032 .27765 L
.50756 .28252 L
.50476 .28756 L
.5022 .29228 L
.4996 .29716 L
.49722 .30172 L
.49504 .30597 L
.49281 .31037 L
.49077 .31448 L
.48888 .31831 L
.48696 .32227 L
.48519 .32597 L
.48338 .32977 L
.48171 .33332 L
.48016 .33662 L
.47858 .34003 L
.47712 .34321 L
.47563 .34647 L
.47424 .34951 L
.47296 .35234 L
.47164 .35524 L
.47042 .35795 L
.46929 .36047 L
.46812 .36306 L
.46704 .36547 L
.46593 .36795 L
Mistroke
.4649 .37025 L
.46394 .37239 L
.46295 .37459 L
.46203 .37664 L
.46108 .37873 L
.4602 .38068 L
.45938 .38249 L
.45853 .38435 L
.45774 .38607 L
.45701 .38767 L
.45625 .38932 L
.45555 .39085 L
.45482 .39241 L
.45414 .39387 L
.45351 .39522 L
.45285 .3966 L
.45224 .39789 L
.45168 .39908 L
.45109 .40031 L
.45054 .40145 L
.44997 .40261 L
.44944 .40369 L
.44895 .4047 L
.44844 .40573 L
.44797 .40668 L
.44748 .40766 L
.44702 .40857 L
.44659 .40941 L
.44615 .41028 L
.44574 .41108 L
.44535 .41182 L
.44495 .41259 L
.44458 .41329 L
.4442 .41402 L
.44384 .41469 L
.4435 .41531 L
.44316 .41595 L
.44284 .41654 L
.44253 .41709 L
.44222 .41766 L
.44193 .41818 L
.44163 .41872 L
.44135 .41922 L
.44109 .41968 L
.44082 .42015 L
.44056 .42059 L
.4403 .42104 L
.44006 .42146 L
.43983 .42184 L
.4396 .42223 L
Mistroke
Mfstroke
.67521 .97436 m
.67064 .96059 L
.66545 .94562 L
.6604 .93162 L
.65541 .91822 L
.64994 .90405 L
.64457 .89051 L
.63874 .87624 L
.63304 .86263 L
.62748 .84967 L
.62152 .83606 L
.61575 .82313 L
.61017 .81087 L
.60424 .79803 L
.59854 .78588 L
.5925 .77319 L
.58673 .76122 L
.58123 .74994 L
.57545 .7382 L
.56996 .72716 L
.56423 .71572 L
.5588 .70498 L
.55368 .69492 L
.54836 .68451 L
.54335 .67478 L
.53866 .66569 L
.53379 .6563 L
.52924 .64754 L
.52455 .63854 L
.52017 .63015 L
.5161 .62235 L
.51191 .61434 L
.50802 .6069 L
.50441 .59999 L
.50071 .59289 L
.49728 .58632 L
.49378 .57959 L
.49054 .57336 L
.48756 .56759 L
.48451 .56169 L
.48171 .55623 L
.47886 .55066 L
.47625 .54552 L
.47384 .54077 L
.4714 .53593 L
.46916 .53146 L
.46711 .52734 L
.46503 .52313 L
.46313 .51925 L
.4612 .5153 L
Mistroke
.45944 .51166 L
.45784 .50831 L
.45622 .50489 L
.45474 .50174 L
.45325 .49855 L
.45189 .49561 L
.45065 .4929 L
.44941 .49015 L
.44828 .48762 L
.44725 .48529 L
.44622 .48292 L
.44528 .48073 L
.44434 .47852 L
.44348 .47648 L
.44271 .47461 L
.44193 .4727 L
.44123 .47095 L
.44059 .46934 L
.43995 .4677 L
.43937 .46619 L
.4388 .46466 L
.43828 .46325 L
.4378 .46195 L
.43733 .46063 L
.43691 .45942 L
.43649 .45819 L
.43611 .45706 L
.43577 .45603 L
.43543 .45497 L
.43512 .454 L
.43485 .45311 L
.43458 .4522 L
.43433 .45137 L
.43409 .45052 L
.43388 .44974 L
.43368 .44902 L
.43349 .44829 L
.43332 .44762 L
.43317 .447 L
.43302 .44638 L
.43289 .4458 L
.43276 .44521 L
.43264 .44467 L
.43254 .44417 L
.43244 .44367 L
.43235 .4432 L
.43226 .44273 L
.43219 .44229 L
.43212 .44189 L
.43206 .44149 L
Mistroke
Mfstroke
.71795 .11966 m
.70112 .12567 L
.68428 .13244 L
.66976 .13896 L
.65686 .14533 L
.64417 .15219 L
.63288 .15885 L
.62177 .16596 L
.61187 .17281 L
.60301 .17938 L
.59424 .18634 L
.58638 .19299 L
.57932 .19932 L
.5723 .20599 L
.56597 .21232 L
.55968 .21896 L
.554 .22524 L
.54887 .23118 L
.54373 .23739 L
.53908 .24325 L
.53443 .24934 L
.53021 .25509 L
.52637 .26049 L
.52251 .2661 L
.519 .27137 L
.51579 .27632 L
.51256 .28145 L
.5096 .28627 L
.50661 .29125 L
.50387 .29591 L
.50137 .30028 L
.49882 .3048 L
.49649 .30902 L
.49434 .31297 L
.49216 .31705 L
.49015 .32086 L
.4881 .32479 L
.48622 .32846 L
.48448 .33188 L
.4827 .33541 L
.48106 .33871 L
.47939 .34209 L
.47784 .34525 L
.47641 .34819 L
.47494 .35122 L
.47359 .35404 L
.47233 .35667 L
.47104 .35937 L
.46984 .36189 L
.46861 .36448 L
Mistroke
.46747 .36688 L
.46641 .36912 L
.46533 .37143 L
.46431 .37357 L
.46328 .37576 L
.46231 .3778 L
.46141 .3797 L
.46049 .38165 L
.45963 .38346 L
.45883 .38514 L
.458 .38687 L
.45723 .38848 L
.45644 .39012 L
.45571 .39165 L
.45502 .39307 L
.45431 .39453 L
.45365 .39589 L
.45303 .39714 L
.4524 .39843 L
.4518 .39963 L
.45119 .40086 L
.45062 .402 L
.45009 .40306 L
.44954 .40415 L
.44903 .40516 L
.4485 .40619 L
.44801 .40715 L
.44755 .40804 L
.44707 .40895 L
.44663 .4098 L
.44622 .41058 L
.44579 .41139 L
.44539 .41214 L
.44498 .41291 L
.44459 .41362 L
.44423 .41428 L
.44386 .41495 L
.44352 .41558 L
.4432 .41616 L
.44286 .41676 L
.44255 .41731 L
.44223 .41788 L
.44193 .41841 L
.44165 .4189 L
.44136 .4194 L
.44109 .41986 L
.44081 .42034 L
.44055 .42078 L
.44031 .42119 L
.44006 .4216 L
Mistroke
Mfstroke
.71795 .97436 m
.7137 .96251 L
.70882 .94954 L
.70402 .93731 L
.69921 .92553 L
.6939 .91297 L
.68862 .90087 L
.68282 .88802 L
.67709 .87566 L
.67145 .8638 L
.66533 .85125 L
.65935 .83922 L
.65351 .82774 L
.64724 .81561 L
.64116 .80405 L
.63466 .79189 L
.62839 .78033 L
.62235 .76935 L
.61595 .75785 L
.60983 .74696 L
.60336 .73559 L
.5972 .72485 L
.59134 .71472 L
.58519 .70419 L
.57937 .69427 L
.57387 .68496 L
.56812 .67529 L
.56271 .66623 L
.55709 .65685 L
.55181 .64809 L
.54686 .63989 L
.54174 .63144 L
.53696 .62355 L
.53249 .6162 L
.52788 .60863 L
.52359 .60158 L
.51918 .59435 L
.51508 .58762 L
.51128 .58138 L
.50738 .57498 L
.50377 .56904 L
.50008 .56297 L
.49667 .55735 L
.49353 .55215 L
.49032 .54683 L
.48736 .54192 L
.48463 .53737 L
.48185 .53273 L
.47929 .52844 L
.4767 .52406 L
Mistroke
.47432 .52003 L
.47213 .51631 L
.46991 .51251 L
.46787 .50902 L
.46581 .50546 L
.46392 .50219 L
.4622 .49917 L
.46045 .4961 L
.45885 .49327 L
.45739 .49067 L
.45592 .48802 L
.45457 .48559 L
.45321 .48311 L
.45197 .48083 L
.45084 .47874 L
.4497 .47661 L
.44866 .47465 L
.44772 .47285 L
.44676 .47102 L
.44589 .46934 L
.44502 .46763 L
.44422 .46605 L
.4435 .46461 L
.44277 .46314 L
.44211 .46179 L
.44145 .46042 L
.44085 .45917 L
.4403 .45801 L
.43976 .45684 L
.43926 .45576 L
.43881 .45477 L
.43836 .45376 L
.43795 .45283 L
.43754 .4519 L
.43717 .45103 L
.43684 .45024 L
.4365 .44943 L
.4362 .44869 L
.43593 .44801 L
.43565 .44732 L
.43541 .44669 L
.43516 .44604 L
.43494 .44545 L
.43474 .4449 L
.43454 .44435 L
.43436 .44384 L
.43418 .44332 L
.43402 .44285 L
.43387 .44241 L
.43373 .44197 L
Mistroke
Mfstroke
.76068 .11966 m
.74062 .12474 L
.72057 .13062 L
.70331 .13639 L
.68801 .14213 L
.67299 .14841 L
.65965 .15458 L
.64656 .16124 L
.63491 .16771 L
.62451 .17398 L
.61424 .18066 L
.60505 .18709 L
.59682 .19325 L
.58864 .19977 L
.58129 .20599 L
.57399 .21254 L
.56742 .21877 L
.5615 .22468 L
.55558 .23087 L
.55024 .23674 L
.5449 .24286 L
.54007 .24864 L
.53569 .25409 L
.53129 .25977 L
.5273 .26511 L
.52366 .27014 L
.51999 .27537 L
.51665 .28028 L
.51328 .28537 L
.5102 .29014 L
.50738 .29461 L
.50453 .29925 L
.50192 .30359 L
.49952 .30765 L
.49708 .31185 L
.49485 .31578 L
.49257 .31984 L
.49048 .32363 L
.48856 .32717 L
.48659 .33082 L
.48478 .33424 L
.48294 .33775 L
.48124 .34103 L
.47966 .34408 L
.47805 .34723 L
.47657 .35016 L
.47519 .3529 L
.47378 .35571 L
.47247 .35834 L
.47114 .36103 L
Mistroke
.4699 .36354 L
.46875 .36588 L
.46756 .36828 L
.46647 .37052 L
.46534 .37282 L
.4643 .37495 L
.46333 .37694 L
.46233 .37898 L
.4614 .38087 L
.46054 .38263 L
.45965 .38445 L
.45882 .38613 L
.45797 .38786 L
.45718 .38946 L
.45644 .39095 L
.45568 .39248 L
.45497 .3939 L
.45431 .39522 L
.45363 .39658 L
.453 .39784 L
.45234 .39913 L
.45173 .40033 L
.45117 .40145 L
.45058 .40259 L
.45003 .40365 L
.44947 .40474 L
.44894 .40575 L
.44845 .40668 L
.44795 .40764 L
.44747 .40854 L
.44703 .40936 L
.44658 .41021 L
.44615 .411 L
.44572 .41181 L
.44531 .41256 L
.44493 .41325 L
.44453 .41397 L
.44417 .41463 L
.44382 .41524 L
.44347 .41587 L
.44314 .41646 L
.4428 .41706 L
.44248 .41761 L
.44218 .41813 L
.44187 .41866 L
.44159 .41915 L
.44129 .41965 L
.44102 .42012 L
.44076 .42055 L
.4405 .42098 L
Mistroke
Mfstroke
.76068 .97436 m
.75687 .96445 L
.75244 .95352 L
.74803 .94314 L
.74357 .93306 L
.73858 .92222 L
.73357 .9117 L
.72802 .90044 L
.72247 .88951 L
.71695 .87894 L
.7109 .86764 L
.70492 .85673 L
.69904 .84623 L
.69266 .83504 L
.68641 .82428 L
.67966 .81288 L
.67309 .80193 L
.66671 .79146 L
.65988 .7804 L
.65327 .76983 L
.64625 .75872 L
.63949 .74814 L
.63301 .73809 L
.62616 .72756 L
.61961 .71757 L
.61337 .70813 L
.60681 .69827 L
.60059 .68896 L
.59407 .67927 L
.58791 .67015 L
.5821 .66159 L
.57604 .6527 L
.57033 .64436 L
.56498 .63656 L
.55942 .62847 L
.55421 .62092 L
.54883 .61313 L
.5438 .60586 L
.53911 .59908 L
.53427 .59211 L
.52977 .58561 L
.52514 .57895 L
.52085 .57277 L
.51687 .56702 L
.51278 .56113 L
.509 .55568 L
.5055 .55062 L
.50192 .54544 L
.49861 .54064 L
.49523 .53574 L
Mistroke
.49212 .53122 L
.48925 .52703 L
.48633 .52276 L
.48363 .51882 L
.4809 .5148 L
.47839 .5111 L
.47608 .50768 L
.47374 .50421 L
.47158 .501 L
.46961 .49805 L
.4676 .49504 L
.46577 .49227 L
.46391 .48945 L
.4622 .48686 L
.46065 .48448 L
.45907 .48205 L
.45762 .47982 L
.4563 .47777 L
.45497 .47569 L
.45374 .47377 L
.45251 .47182 L
.45139 .47003 L
.45036 .46838 L
.44932 .46671 L
.44837 .46517 L
.44742 .46361 L
.44655 .46218 L
.44576 .46087 L
.44496 .45953 L
.44423 .45831 L
.44357 .45718 L
.4429 .45604 L
.44229 .45499 L
.44168 .45393 L
.44112 .45295 L
.44061 .45205 L
.44011 .45114 L
.43964 .4503 L
.43922 .44953 L
.4388 .44875 L
.43841 .44803 L
.43802 .44731 L
.43767 .44664 L
.43735 .44603 L
.43703 .4454 L
.43674 .44483 L
.43645 .44425 L
.43619 .44372 L
.43595 .44323 L
.43571 .44274 L
Mistroke
Mfstroke
.80342 .11966 m
.78002 .12381 L
.75668 .12879 L
.73663 .13382 L
.71888 .13894 L
.70148 .14463 L
.68606 .15031 L
.67096 .15652 L
.65754 .16262 L
.64558 .16858 L
.6338 .17499 L
.62328 .1812 L
.61386 .18719 L
.60452 .19356 L
.59615 .19968 L
.58786 .20614 L
.58041 .21231 L
.5737 .21819 L
.56701 .22438 L
.56098 .23025 L
.55497 .23639 L
.54954 .24222 L
.54462 .24772 L
.5397 .25347 L
.53523 .25889 L
.53117 .26399 L
.52708 .26931 L
.52336 .27432 L
.51962 .27951 L
.51621 .2844 L
.51309 .28898 L
.50994 .29373 L
.50706 .29819 L
.50442 .30236 L
.50174 .30668 L
.49929 .31073 L
.4968 .31492 L
.49451 .31883 L
.4924 .32249 L
.49026 .32627 L
.48829 .3298 L
.48628 .33344 L
.48443 .33683 L
.48273 .34 L
.48098 .34327 L
.47937 .34632 L
.47789 .34915 L
.47636 .35208 L
.47495 .35481 L
.47351 .35762 L
Mistroke
.47218 .36023 L
.47094 .36267 L
.46967 .36517 L
.46849 .36751 L
.46729 .3699 L
.46617 .37213 L
.46513 .3742 L
.46406 .37633 L
.46307 .37831 L
.46215 .38015 L
.4612 .38205 L
.46032 .38381 L
.45941 .38561 L
.45857 .38729 L
.45778 .38885 L
.45697 .39046 L
.45622 .39194 L
.45552 .39333 L
.4548 .39475 L
.45412 .39607 L
.45343 .39742 L
.45278 .39868 L
.45218 .39985 L
.45156 .40105 L
.45098 .40216 L
.45038 .4033 L
.44982 .40436 L
.44931 .40535 L
.44877 .40635 L
.44827 .40729 L
.44781 .40816 L
.44733 .40905 L
.44688 .40988 L
.44641 .41073 L
.44598 .41151 L
.44558 .41225 L
.44517 .41299 L
.44478 .41369 L
.44442 .41433 L
.44404 .415 L
.44369 .41561 L
.44333 .41624 L
.443 .41683 L
.44269 .41737 L
.44236 .41793 L
.44206 .41844 L
.44175 .41897 L
.44146 .41946 L
.44119 .41992 L
.44092 .42037 L
Mistroke
Mfstroke
.80342 .97436 m
.80015 .96641 L
.7963 .95756 L
.79244 .9491 L
.78848 .94082 L
.78402 .93184 L
.77949 .92305 L
.77442 .91355 L
.76929 .90426 L
.76414 .89519 L
.75844 .8854 L
.75275 .87587 L
.7471 .8666 L
.74089 .85663 L
.73475 .84696 L
.72806 .8366 L
.72147 .82657 L
.71502 .81688 L
.70804 .80654 L
.70122 .79658 L
.6939 .78601 L
.68678 .77584 L
.67989 .76609 L
.67253 .75579 L
.66544 .74593 L
.65863 .73654 L
.6514 .72664 L
.64448 .71723 L
.63717 .70735 L
.63021 .69799 L
.62358 .68912 L
.61662 .67986 L
.61002 .67111 L
.60378 .66286 L
.59726 .65427 L
.5911 .64619 L
.5847 .63781 L
.57867 .62995 L
.57302 .62258 L
.56715 .61496 L
.56166 .60783 L
.55599 .60048 L
.5507 .59362 L
.54576 .58723 L
.54067 .58065 L
.53593 .57452 L
.53153 .56883 L
.527 .56298 L
.52279 .55755 L
.51849 .55198 L
Mistroke
.5145 .54682 L
.51081 .54204 L
.50703 .53715 L
.50354 .53262 L
.49998 .528 L
.4967 .52373 L
.49367 .51979 L
.49059 .51576 L
.48775 .51205 L
.48513 .50862 L
.48246 .50513 L
.48001 .5019 L
.47752 .49862 L
.47524 .4956 L
.47314 .49282 L
.47101 .48999 L
.46905 .48738 L
.46726 .48498 L
.46543 .48254 L
.46376 .48029 L
.46207 .47801 L
.46052 .47591 L
.4591 .47398 L
.45767 .47202 L
.45635 .47021 L
.45503 .46839 L
.45381 .46671 L
.4527 .46517 L
.45158 .4636 L
.45056 .46217 L
.44962 .46085 L
.44867 .45951 L
.44781 .45828 L
.44693 .45703 L
.44614 .45589 L
.44541 .45484 L
.44468 .45377 L
.44401 .45279 L
.4434 .4519 L
.44278 .45099 L
.44222 .45015 L
.44165 .4493 L
.44113 .44852 L
.44066 .44781 L
.44019 .44708 L
.43975 .44642 L
.43932 .44575 L
.43892 .44513 L
.43856 .44456 L
.43821 .444 L
Mistroke
Mfstroke
.84615 .11966 m
.81933 .12288 L
.79261 .12697 L
.7697 .13126 L
.74945 .13575 L
.72964 .14086 L
.7121 .14605 L
.69496 .1518 L
.67975 .15754 L
.66622 .1632 L
.65291 .16934 L
.64105 .17533 L
.63046 .18115 L
.61997 .18738 L
.61058 .19338 L
.60129 .19976 L
.59296 .20588 L
.58547 .21173 L
.57802 .21791 L
.57131 .22379 L
.56464 .22996 L
.55862 .23583 L
.55317 .24138 L
.54773 .2472 L
.5428 .25269 L
.53833 .25788 L
.53384 .26329 L
.52975 .2684 L
.52565 .2737 L
.52191 .27869 L
.51851 .28338 L
.51507 .28825 L
.51193 .29282 L
.50906 .29711 L
.50615 .30156 L
.50348 .30572 L
.50078 .31004 L
.49831 .31407 L
.49603 .31785 L
.49372 .32175 L
.49159 .3254 L
.48943 .32916 L
.48744 .33268 L
.48561 .33596 L
.48374 .33935 L
.48201 .3425 L
.48042 .34545 L
.47879 .34849 L
.47728 .35132 L
.47574 .35424 L
Mistroke
.47432 .35696 L
.473 .35949 L
.47165 .3621 L
.4704 .36452 L
.46911 .36702 L
.46792 .36934 L
.46682 .3715 L
.46569 .37372 L
.46464 .37578 L
.46366 .3777 L
.46266 .37968 L
.46172 .38151 L
.46076 .3834 L
.45987 .38515 L
.45904 .38678 L
.45819 .38846 L
.45739 .39001 L
.45665 .39146 L
.45589 .39294 L
.45518 .39432 L
.45445 .39574 L
.45377 .39706 L
.45313 .39828 L
.45248 .39953 L
.45187 .4007 L
.45124 .40189 L
.45066 .403 L
.45011 .40403 L
.44955 .40508 L
.44903 .40606 L
.44854 .40697 L
.44803 .40791 L
.44756 .40877 L
.44708 .40966 L
.44662 .41049 L
.4462 .41125 L
.44577 .41204 L
.44536 .41277 L
.44498 .41344 L
.44459 .41414 L
.44422 .41478 L
.44385 .41544 L
.44349 .41606 L
.44317 .41662 L
.44283 .41721 L
.44251 .41775 L
.44218 .4183 L
.44188 .41882 L
.4416 .4193 L
.44131 .41977 L
Mistroke
Mfstroke
.84615 .97436 m
.84353 .96837 L
.84042 .96167 L
.83726 .9552 L
.83399 .94881 L
.83027 .94184 L
.82645 .93495 L
.82212 .92743 L
.81771 .92 L
.81323 .91268 L
.80822 .90471 L
.80316 .89686 L
.79808 .88915 L
.79244 .88078 L
.7868 .87256 L
.78059 .86367 L
.7744 .85495 L
.76827 .84644 L
.76156 .83727 L
.75493 .82832 L
.74773 .81871 L
.74065 .80937 L
.73373 .80031 L
.72625 .79063 L
.71895 .78127 L
.71187 .77225 L
.70427 .76265 L
.69692 .75342 L
.68909 .74363 L
.68153 .73426 L
.67427 .7253 L
.66658 .71584 L
.65921 .70683 L
.65217 .69826 L
.64475 .68926 L
.63769 .68071 L
.63028 .67178 L
.62324 .66333 L
.61659 .65535 L
.60964 .64703 L
.60308 .6392 L
.59625 .63107 L
.58983 .62343 L
.5838 .61627 L
.57754 .60885 L
.57168 .60191 L
.5662 .59542 L
.56053 .58872 L
.55524 .58246 L
.54979 .57603 L
Mistroke
.54471 .57003 L
.53999 .56446 L
.53514 .55873 L
.53063 .55341 L
.52601 .54796 L
.52173 .5429 L
.51777 .53822 L
.51371 .53343 L
.50996 .52899 L
.50649 .52489 L
.50295 .52069 L
.49968 .51681 L
.49635 .51286 L
.49328 .50921 L
.49045 .50585 L
.48756 .50241 L
.48491 .49925 L
.48247 .49633 L
.47998 .49336 L
.47769 .49062 L
.47537 .48783 L
.47324 .48527 L
.47128 .48291 L
.4693 .48051 L
.46747 .47831 L
.46563 .47607 L
.46393 .47401 L
.46238 .47212 L
.46081 .4702 L
.45937 .46844 L
.45805 .46682 L
.45671 .46518 L
.45549 .46367 L
.45425 .46214 L
.45312 .46073 L
.45208 .45944 L
.45103 .45813 L
.45007 .45693 L
.44919 .45583 L
.44831 .45471 L
.44749 .45369 L
.44667 .45265 L
.44592 .45169 L
.44524 .45082 L
.44455 .44993 L
.44392 .44912 L
.44328 .4483 L
.4427 .44754 L
.44217 .44685 L
.44164 .44616 L
Mistroke
Mfstroke
.88889 .11966 m
.85855 .12195 L
.82838 .12514 L
.80254 .12869 L
.77974 .13256 L
.75747 .13708 L
.73778 .14179 L
.71856 .14709 L
.70155 .15246 L
.68644 .15782 L
.6716 .16369 L
.65839 .16947 L
.64661 .17512 L
.63497 .18121 L
.62456 .18711 L
.61428 .19341 L
.60508 .19947 L
.59682 .2053 L
.58862 .21146 L
.58124 .21736 L
.57391 .22356 L
.56732 .22947 L
.56136 .23508 L
.55541 .24096 L
.55003 .24654 L
.54516 .25181 L
.54027 .25731 L
.53583 .26251 L
.53138 .26793 L
.52733 .27303 L
.52365 .27783 L
.51993 .28281 L
.51654 .2875 L
.51345 .2919 L
.51031 .29647 L
.50745 .30076 L
.50455 .3052 L
.50189 .30935 L
.49945 .31325 L
.49698 .31727 L
.4947 .32104 L
.4924 .32493 L
.49028 .32856 L
.48832 .33196 L
.48633 .33546 L
.4845 .33873 L
.4828 .34178 L
.48107 .34493 L
.47947 .34787 L
.47784 .3509 L
Mistroke
.47633 .35372 L
.47494 .35635 L
.47351 .35905 L
.47218 .36157 L
.47083 .36417 L
.46957 .36658 L
.46841 .36882 L
.46722 .37113 L
.46611 .37328 L
.46508 .37528 L
.46403 .37734 L
.46304 .37925 L
.46204 .38122 L
.4611 .38304 L
.46023 .38474 L
.45933 .38648 L
.4585 .38811 L
.45772 .38961 L
.45692 .39116 L
.45618 .3926 L
.45541 .39408 L
.4547 .39545 L
.45404 .39673 L
.45335 .39804 L
.45271 .39925 L
.45206 .4005 L
.45144 .40166 L
.45087 .40273 L
.45029 .40383 L
.44974 .40486 L
.44923 .40581 L
.4487 .40678 L
.44821 .40769 L
.4477 .40862 L
.44723 .40948 L
.44679 .41028 L
.44633 .4111 L
.44591 .41186 L
.44551 .41257 L
.4451 .41329 L
.44472 .41397 L
.44433 .41466 L
.44396 .4153 L
.44362 .41589 L
.44327 .4165 L
.44294 .41707 L
.4426 .41765 L
.44228 .41819 L
.44198 .41869 L
.44169 .41919 L
Mistroke
Mfstroke
.88889 .97436 m
.88703 .97035 L
.8848 .96583 L
.88251 .96144 L
.88012 .95706 L
.87737 .95224 L
.87452 .94743 L
.87126 .94214 L
.86789 .93685 L
.86444 .93159 L
.86054 .92579 L
.85654 .92002 L
.85249 .91429 L
.84794 .90798 L
.84334 .90172 L
.83819 .89486 L
.833 .88805 L
.8278 .88131 L
.82202 .87394 L
.81624 .86666 L
.80988 .85872 L
.80352 .8509 L
.79722 .84321 L
.79032 .83486 L
.78349 .82668 L
.77677 .81868 L
.76945 .81004 L
.76228 .80161 L
.75451 .79256 L
.74692 .78375 L
.73953 .77522 L
.73158 .76609 L
.72386 .75726 L
.7164 .74876 L
.70843 .73971 L
.70074 .73102 L
.69257 .72181 L
.68472 .71298 L
.67721 .70456 L
.66926 .69567 L
.66167 .6872 L
.65369 .67831 L
.6461 .66987 L
.63889 .66188 L
.63134 .65352 L
.6242 .64562 L
.61745 .63817 L
.61041 .6304 L
.60378 .6231 L
.5969 .61552 L
Mistroke
.59043 .6084 L
.58437 .60174 L
.57809 .59484 L
.57221 .58839 L
.56616 .58174 L
.5605 .57553 L
.55523 .56975 L
.5498 .5638 L
.54475 .55827 L
.54006 .55312 L
.53524 .54783 L
.53076 .54293 L
.52618 .5379 L
.52194 .53325 L
.51801 .52894 L
.51399 .52453 L
.51027 .52045 L
.50684 .51667 L
.50333 .51282 L
.50009 .50925 L
.49679 .50562 L
.49375 .50227 L
.49094 .49918 L
.48809 .49604 L
.48546 .49313 L
.48279 .49019 L
.48033 .48747 L
.47807 .48497 L
.47578 .48243 L
.47367 .4801 L
.47174 .47795 L
.46977 .47577 L
.46797 .47376 L
.46614 .47172 L
.46446 .46985 L
.46292 .46813 L
.46136 .46639 L
.45993 .46479 L
.45862 .46332 L
.45729 .46182 L
.45607 .46045 L
.45484 .45906 L
.45371 .45779 L
.45267 .45662 L
.45162 .45543 L
.45067 .45434 L
.4497 .45324 L
.44881 .45224 L
.448 .45131 L
.4472 .4504 L
Mistroke
Mfstroke
.93162 .11966 m
.91471 .12023 L
.89768 .12102 L
.88118 .12202 L
.86397 .12331 L
.83449 .1262 L
.80854 .12954 L
.78332 .13361 L
.76109 .13795 L
.74143 .14248 L
.7222 .14761 L
.70516 .15281 L
.69003 .158 L
.67513 .1637 L
.66187 .16933 L
.64882 .17541 L
.63719 .18136 L
.62679 .18712 L
.6165 .19328 L
.60728 .19922 L
.59817 .20552 L
.58999 .21157 L
.58263 .21735 L
.57532 .22344 L
.56872 .22924 L
.56277 .23475 L
.55682 .24053 L
.55144 .24601 L
.54606 .25174 L
.54118 .25716 L
.53676 .26227 L
.53231 .2676 L
.52827 .27262 L
.52459 .27735 L
.52087 .28227 L
.51749 .28689 L
.51407 .29169 L
.51095 .29619 L
.50809 .30042 L
.5052 .3048 L
.50255 .3089 L
.49986 .31314 L
.4974 .31711 L
.49514 .32082 L
.49284 .32466 L
.49073 .32824 L
.48878 .33159 L
.4868 .33505 L
.48497 .33829 L
.4831 .34162 L
Mistroke
.48138 .34473 L
.47979 .34762 L
.47817 .35061 L
.47667 .3534 L
.47514 .35626 L
.47372 .35893 L
.4724 .36142 L
.47106 .36398 L
.46981 .36636 L
.46866 .36858 L
.46747 .37087 L
.46637 .37299 L
.46524 .37517 L
.46419 .3772 L
.46322 .37909 L
.46221 .38103 L
.46128 .38284 L
.46042 .38452 L
.45953 .38624 L
.4587 .38785 L
.45785 .3895 L
.45705 .39103 L
.45632 .39245 L
.45556 .39391 L
.45485 .39527 L
.45412 .39666 L
.45344 .39796 L
.45281 .39916 L
.45216 .40039 L
.45155 .40153 L
.45098 .4026 L
.4504 .40369 L
.44986 .4047 L
.4493 .40574 L
.44877 .4067 L
.44829 .4076 L
.44778 .40852 L
.44732 .40937 L
.44688 .41016 L
.44643 .41097 L
.44601 .41173 L
.44557 .4125 L
.44517 .41322 L
.44479 .41389 L
.4444 .41457 L
.44403 .4152 L
.44366 .41585 L
.44331 .41646 L
.44298 .41702 L
.44265 .41759 L
Mistroke
.44233 .41812 L
.44204 .41861 L
Mfstroke
.93162 .97436 m
.93064 .97235 L
.92944 .97006 L
.9282 .96782 L
.9269 .96557 L
.92538 .96307 L
.92379 .96055 L
.92195 .95775 L
.92003 .95492 L
.91804 .95207 L
.91576 .9489 L
.91341 .9457 L
.91098 .94248 L
.90822 .93889 L
.90539 .93528 L
.90218 .93125 L
.89889 .9272 L
.89554 .92312 L
.89176 .91859 L
.88792 .91403 L
.8836 .90898 L
.87922 .90389 L
.87479 .8988 L
.86985 .89317 L
.86487 .88754 L
.85986 .88192 L
.85431 .87573 L
.84875 .86957 L
.8426 .86279 L
.83646 .85606 L
.83034 .84939 L
.82363 .8421 L
.81697 .83489 L
.81039 .8278 L
.8032 .82007 L
.79612 .81249 L
.78843 .80427 L
.78087 .79622 L
.77348 .78837 L
.76549 .7799 L
.7577 .77166 L
.74933 .76282 L
.7412 .75425 L
.73332 .74596 L
.7249 .73712 L
.71678 .72859 L
.70896 .72041 L
.70066 .71171 L
.69269 .70339 L
.68427 .69459 L
Mistroke
.67621 .68619 L
.66854 .67819 L
.66046 .66977 L
.65278 .66178 L
.64474 .65342 L
.63713 .6455 L
.62992 .63802 L
.62241 .63022 L
.61533 .62287 L
.60867 .61595 L
.60174 .60877 L
.59523 .60202 L
.5885 .59504 L
.58219 .58851 L
.57629 .5824 L
.5702 .57609 L
.56452 .5702 L
.55922 .56472 L
.55376 .55906 L
.54868 .5538 L
.54347 .5484 L
.53862 .54338 L
.53413 .53873 L
.52951 .53395 L
.52524 .52953 L
.52088 .52501 L
.51684 .52082 L
.5131 .51695 L
.50929 .513 L
.50577 .50935 L
.50252 .50598 L
.4992 .50254 L
.49614 .49936 L
.49302 .49613 L
.49015 .49316 L
.48751 .49041 L
.48482 .48762 L
.48235 .48505 L
.48007 .48269 L
.47776 .48028 L
.47563 .47806 L
.47347 .47581 L
.47148 .47375 L
.46966 .47185 L
.4678 .46992 L
.4661 .46815 L
.46438 .46635 L
.4628 .46471 L
.46136 .46319 L
.45992 .46169 L
Mistroke
Mfstroke
.97436 .11966 m
.97316 .11966 L
.97208 .11966 L
.97082 .11966 L
.96965 .11966 L
.96756 .11967 L
.9653 .11968 L
.96283 .1197 L
.96023 .11972 L
.9556 .11976 L
.95088 .11982 L
.9465 .11989 L
.93671 .1201 L
.92697 .12036 L
.91827 .12065 L
.89938 .12149 L
.88372 .1224 L
.8674 .12358 L
.83753 .12639 L
.81126 .12967 L
.78574 .13368 L
.76324 .13799 L
.74336 .14249 L
.72391 .14759 L
.70669 .15277 L
.6914 .15795 L
.67635 .16365 L
.66295 .16927 L
.64979 .17535 L
.63805 .1813 L
.62756 .18707 L
.61718 .19323 L
.60789 .19918 L
.59955 .2049 L
.59125 .21095 L
.58379 .21675 L
.57638 .22286 L
.5697 .22868 L
.56367 .23421 L
.55764 .24001 L
.55219 .24552 L
.54675 .25127 L
.54181 .25671 L
.53734 .26184 L
.53285 .26719 L
.52876 .27224 L
.52504 .27699 L
.52129 .28193 L
.51787 .28657 L
.51442 .29139 L
Mistroke
.51127 .29592 L
.50839 .30016 L
.50547 .30456 L
.50279 .30868 L
.50009 .31294 L
.49761 .31692 L
.49533 .32065 L
.49301 .32451 L
.49089 .32811 L
.48893 .33147 L
.48693 .33495 L
.48509 .33819 L
.48321 .34154 L
.48148 .34466 L
.47988 .34757 L
.47825 .35057 L
.47674 .35336 L
.47534 .35597 L
.47391 .35866 L
.47258 .36116 L
.47123 .36374 L
.46997 .36614 L
.4688 .36837 L
.4676 .37067 L
.46649 .37281 L
.46536 .375 L
.4643 .37704 L
.46332 .37894 L
.46231 .3809 L
.46137 .38271 L
.4605 .3844 L
.4596 .38614 L
.45877 .38775 L
.45791 .38941 L
.45711 .39095 L
.45637 .39238 L
.45561 .39385 L
.45489 .39521 L
.45423 .39648 L
.45355 .39778 L
.45291 .39899 L
.45225 .40024 L
.45164 .40139 L
.45107 .40246 L
.45048 .40356 L
.44993 .40458 L
.44937 .40563 L
.44884 .4066 L
.44835 .4075 L
.44784 .40843 L
Mistroke
.44737 .40928 L
.44693 .41008 L
.44648 .4109 L
.44605 .41166 L
.44561 .41244 L
.44521 .41316 L
.44483 .41383 L
.44443 .41452 L
.44407 .41516 L
.44369 .41581 L
.44334 .41642 L
.44301 .41698 L
.44267 .41756 L
.44238 .41805 L
Mfstroke
.97436 .16239 m
.96575 .1622 L
.95651 .16203 L
.95193 .16197 L
.94708 .16192 L
.94474 .1619 L
.94255 .16188 L
.94044 .16187 L
.93848 .16186 L
.93735 .16186 L
.93632 .16185 L
.93518 .16185 L
.93456 .16185 L
.93396 .16185 L
.93339 .16185 L
.93279 .16185 L
.9317 .16185 L
.93103 .16185 L
.9304 .16185 L
.92984 .16185 L
.92923 .16185 L
.92822 .16185 L
.9271 .16185 L
.92486 .16186 L
.9228 .16187 L
.92089 .16189 L
.9162 .16193 L
.91198 .16198 L
.90265 .16214 L
.89469 .16232 L
.88747 .16253 L
.87165 .16313 L
.85802 .16382 L
.84359 .16473 L
.81718 .16693 L
.79378 .16953 L
.77086 .17274 L
.75054 .17622 L
.73246 .17987 L
.71466 .18404 L
.69881 .18828 L
.68322 .19301 L
.66931 .19774 L
.65688 .20241 L
.64458 .20749 L
.63357 .21247 L
.62369 .21731 L
.61387 .2225 L
.60504 .22751 L
.59626 .23285 L
Mistroke
.58837 .23798 L
.58125 .24289 L
.57414 .24808 L
.56771 .25303 L
.5613 .25824 L
.55551 .26319 L
.55025 .26789 L
.54498 .27281 L
.5402 .27747 L
.53585 .28187 L
.53147 .28646 L
.52748 .2908 L
.52346 .29531 L
.5198 .29956 L
.51646 .30356 L
.51308 .30772 L
.50999 .31162 L
.50716 .31528 L
.50429 .31909 L
.50166 .32265 L
.49899 .32634 L
.49655 .3298 L
.4943 .33304 L
.49201 .33639 L
.4899 .33952 L
.48776 .34275 L
.48579 .34578 L
.48398 .3486 L
.48213 .35151 L
.48042 .35423 L
.47884 .35677 L
.47723 .35939 L
.47574 .36183 L
.47422 .36435 L
.47281 .36669 L
.4715 .36888 L
.47017 .37113 L
.46893 .37323 L
.46779 .37518 L
.46661 .37719 L
.46552 .37907 L
.4644 .381 L
.46336 .38279 L
.4624 .38446 L
.46141 .38618 L
.46049 .38778 L
.45955 .38942 L
.45867 .39094 L
.45786 .39236 L
.45702 .39382 L
Mistroke
.45624 .39518 L
.45552 .39644 L
.45477 .39773 L
.45408 .39894 L
.45337 .40017 L
.4527 .40132 L
.45209 .40239 L
.45145 .40348 L
.45086 .4045 L
.45025 .40554 L
.44968 .40651 L
.44915 .40741 L
.44861 .40834 L
.4481 .4092 L
.44763 .40999 L
.44714 .41081 L
.44669 .41157 L
.44622 .41235 L
.44579 .41307 L
.44538 .41374 L
.44496 .41443 L
.44457 .41507 L
.44421 .41566 L
.44383 .41627 L
.44348 .41684 L
.44312 .41742 L
.44279 .41796 L
.44248 .41846 L
.44216 .41896 L
Mfstroke
.97436 .20513 m
.95742 .20435 L
.94025 .20372 L
.92352 .20326 L
.91434 .20308 L
.9103 .20302 L
.90596 .20297 L
.90173 .20293 L
.89989 .20291 L
.89787 .2029 L
.8961 .20289 L
.89421 .20288 L
.89317 .20288 L
.89222 .20288 L
.89127 .20287 L
.89037 .20287 L
.88949 .20287 L
.8887 .20287 L
.88779 .20287 L
.88694 .20287 L
.88614 .20288 L
.88542 .20288 L
.88378 .20288 L
.88213 .20289 L
.88033 .2029 L
.87672 .20293 L
.87296 .20297 L
.86943 .20302 L
.86292 .20313 L
.85604 .20329 L
.84871 .20349 L
.8358 .20398 L
.82263 .20462 L
.80027 .20612 L
.7782 .20813 L
.75851 .21043 L
.7391 .21323 L
.72177 .21622 L
.70626 .21933 L
.6909 .22286 L
.67715 .22644 L
.66354 .23042 L
.65134 .23439 L
.64037 .23831 L
.62947 .24256 L
.61966 .24672 L
.61082 .25077 L
.60199 .2551 L
.59403 .25929 L
.58608 .26375 L
Mistroke
.5789 .26804 L
.57239 .27214 L
.56588 .27648 L
.55997 .28062 L
.55406 .28498 L
.54869 .28912 L
.54382 .29305 L
.53891 .29717 L
.53445 .30107 L
.53038 .30476 L
.52627 .30862 L
.52252 .31225 L
.51874 .31604 L
.51529 .31961 L
.51213 .32297 L
.50893 .32646 L
.506 .32974 L
.50332 .33282 L
.50059 .33602 L
.49808 .33902 L
.49554 .34213 L
.49321 .34504 L
.49106 .34777 L
.48887 .35059 L
.48686 .35324 L
.48481 .35596 L
.48292 .35851 L
.48119 .3609 L
.47941 .36336 L
.47777 .36566 L
.47626 .3678 L
.47472 .37002 L
.47329 .37209 L
.47183 .37422 L
.47048 .3762 L
.46923 .37806 L
.46795 .37996 L
.46676 .38174 L
.46566 .3834 L
.46454 .38511 L
.46349 .3867 L
.46242 .38834 L
.46143 .38986 L
.46051 .39128 L
.45956 .39274 L
.45869 .3941 L
.45779 .3955 L
.45695 .39679 L
.45618 .398 L
.45538 .39924 L
Mistroke
.45464 .4004 L
.45395 .40147 L
.45324 .40258 L
.45258 .40361 L
.4519 .40466 L
.45127 .40564 L
.45069 .40655 L
.45008 .40749 L
.44952 .40836 L
.44895 .40925 L
.44841 .41008 L
.44791 .41085 L
.4474 .41164 L
.44692 .41237 L
.44648 .41306 L
.44602 .41376 L
.44559 .41441 L
.44515 .41508 L
.44474 .4157 L
.44436 .41627 L
.44397 .41686 L
.44361 .41741 L
.44327 .41792 L
.44292 .41844 L
.44259 .41893 L
.44225 .41943 L
.44195 .41988 L
Mfstroke
.97436 .24786 m
.94204 .24567 L
.92611 .24478 L
.90932 .24399 L
.89415 .24341 L
.88083 .24301 L
.87437 .24286 L
.86749 .24273 L
.86376 .24268 L
.86035 .24264 L
.85715 .2426 L
.8554 .24259 L
.85374 .24258 L
.85219 .24257 L
.8505 .24256 L
.84976 .24256 L
.84897 .24256 L
.84824 .24255 L
.84756 .24255 L
.84682 .24255 L
.84602 .24255 L
.84531 .24255 L
.84457 .24255 L
.8439 .24255 L
.84328 .24255 L
.8426 .24255 L
.84188 .24255 L
.84023 .24256 L
.83845 .24257 L
.83677 .24258 L
.83523 .24259 L
.83235 .24262 L
.82928 .24265 L
.82355 .24274 L
.81827 .24284 L
.80655 .24317 L
.79556 .24359 L
.78442 .24414 L
.76532 .24539 L
.74637 .24706 L
.72937 .24895 L
.71253 .25124 L
.69741 .25368 L
.68381 .25623 L
.67029 .25911 L
.65811 .26204 L
.64713 .26497 L
.63617 .2682 L
.62628 .2714 L
.61641 .27487 L
Mistroke
.6075 .27827 L
.59943 .28158 L
.59135 .28513 L
.58404 .28857 L
.57672 .29222 L
.57009 .29574 L
.56407 .29912 L
.55802 .30269 L
.55252 .3061 L
.54751 .30935 L
.54247 .31277 L
.53787 .31602 L
.53324 .31942 L
.52902 .32265 L
.52516 .32571 L
.52127 .3289 L
.5177 .33192 L
.51444 .33476 L
.51114 .33773 L
.50811 .34053 L
.50504 .34343 L
.50223 .34617 L
.49964 .34874 L
.49702 .35141 L
.49461 .35392 L
.49216 .35651 L
.48992 .35895 L
.48785 .36123 L
.48574 .36359 L
.4838 .3658 L
.48201 .36787 L
.48019 .37001 L
.4785 .37202 L
.47679 .37408 L
.47521 .37602 L
.47374 .37782 L
.47225 .37969 L
.47087 .38143 L
.46959 .38305 L
.46828 .38473 L
.46707 .38629 L
.46583 .38791 L
.46469 .38941 L
.46363 .39081 L
.46254 .39226 L
.46153 .3936 L
.4605 .39499 L
.45955 .39628 L
.45866 .39748 L
.45775 .39872 L
Mistroke
.45691 .39987 L
.45612 .40094 L
.45532 .40205 L
.45457 .40307 L
.45381 .40413 L
.4531 .40511 L
.45244 .40603 L
.45176 .40697 L
.45113 .40784 L
.45048 .40874 L
.44988 .40957 L
.44932 .41035 L
.44875 .41115 L
.44822 .41189 L
.44772 .41258 L
.44721 .41329 L
.44673 .41395 L
.44625 .41462 L
.44579 .41525 L
.44537 .41584 L
.44494 .41644 L
.44453 .41699 L
.44416 .41751 L
.44377 .41804 L
.44341 .41854 L
.44304 .41905 L
.4427 .41952 L
.44238 .41996 L
.44205 .42041 L
.44175 .42081 L
Mfstroke
.97436 .2906 m
.94384 .28772 L
.91273 .2852 L
.88545 .28337 L
.86088 .28207 L
.84786 .28152 L
.8364 .28114 L
.83084 .28099 L
.82489 .28085 L
.81942 .28074 L
.81436 .28067 L
.80924 .28061 L
.80656 .28059 L
.80507 .28058 L
.80369 .28057 L
.80227 .28056 L
.80152 .28056 L
.80073 .28056 L
.80037 .28056 L
.79997 .28056 L
.79963 .28056 L
.79926 .28056 L
.79893 .28056 L
.79857 .28056 L
.79794 .28056 L
.79726 .28056 L
.79664 .28056 L
.79629 .28056 L
.79592 .28056 L
.79525 .28056 L
.79395 .28056 L
.79276 .28057 L
.7904 .28058 L
.78788 .2806 L
.78337 .28065 L
.7781 .28073 L
.77335 .28083 L
.76443 .28107 L
.755 .28141 L
.73742 .28231 L
.72157 .28343 L
.70579 .28488 L
.69156 .28649 L
.67871 .28822 L
.66587 .29024 L
.65427 .29232 L
.64376 .29445 L
.63324 .29682 L
.62371 .29919 L
.61417 .3018 L
Mistroke
.60553 .30438 L
.59769 .30691 L
.58982 .30964 L
.58266 .3123 L
.5755 .31515 L
.56898 .31791 L
.56305 .32057 L
.55708 .3234 L
.55165 .32611 L
.54669 .32871 L
.54168 .33145 L
.53711 .33406 L
.53251 .33681 L
.5283 .33942 L
.52446 .34191 L
.52057 .34451 L
.51701 .34697 L
.51374 .3493 L
.51043 .35174 L
.5074 .35404 L
.50432 .35643 L
.5015 .35869 L
.49891 .36082 L
.49628 .36304 L
.49386 .36512 L
.4914 .36728 L
.48914 .36931 L
.48707 .37122 L
.48495 .37319 L
.483 .37505 L
.48121 .37678 L
.47938 .37858 L
.47769 .38027 L
.47597 .38201 L
.47438 .38365 L
.47291 .38517 L
.47142 .38675 L
.47003 .38822 L
.46876 .3896 L
.46745 .39103 L
.46624 .39236 L
.465 .39373 L
.46386 .39501 L
.4628 .39621 L
.46172 .39744 L
.46071 .39859 L
.45969 .39978 L
.45874 .40088 L
.45786 .40191 L
.45696 .40297 L
Mistroke
.45612 .40396 L
.45534 .40488 L
.45455 .40583 L
.45381 .40672 L
.45305 .40763 L
.45235 .40848 L
.4517 .40927 L
.45103 .41008 L
.45041 .41084 L
.44978 .41161 L
.44919 .41233 L
.44864 .41301 L
.44808 .4137 L
.44755 .41434 L
.44707 .41494 L
.44657 .41556 L
.44611 .41613 L
.44563 .41672 L
.44519 .41727 L
.44478 .41777 L
.44436 .4183 L
.44396 .41878 L
.4436 .41924 L
.44322 .4197 L
.44287 .42013 L
.44252 .42058 L
.44218 .42099 L
.44187 .42138 L
.44156 .42176 L
Mfstroke
.97436 .33333 m
.94565 .32987 L
.91618 .32661 L
.89017 .324 L
.86659 .3219 L
.84296 .32007 L
.82156 .31869 L
.80018 .31759 L
.78997 .31718 L
.78082 .31687 L
.77219 .31665 L
.76787 .31656 L
.76329 .31648 L
.75881 .31642 L
.75477 .31638 L
.75284 .31636 L
.75183 .31636 L
.75076 .31635 L
.74974 .31635 L
.74881 .31635 L
.74836 .31635 L
.74788 .31634 L
.74742 .31634 L
.74701 .31634 L
.74648 .31634 L
.74598 .31634 L
.74553 .31634 L
.74505 .31634 L
.74452 .31635 L
.74397 .31635 L
.74297 .31635 L
.74205 .31635 L
.74119 .31636 L
.73925 .31637 L
.73715 .31638 L
.73524 .3164 L
.73098 .31646 L
.72715 .31652 L
.72364 .3166 L
.71585 .31681 L
.70838 .31708 L
.70179 .31737 L
.68823 .31815 L
.67594 .31906 L
.66361 .32021 L
.65242 .32146 L
.64226 .32278 L
.63205 .3243 L
.62277 .32586 L
.61345 .32761 L
Mistroke
.60498 .32938 L
.59728 .33114 L
.58952 .33308 L
.58246 .33498 L
.57537 .33705 L
.5689 .33906 L
.56301 .34103 L
.55706 .34313 L
.55164 .34516 L
.54669 .34712 L
.54168 .34921 L
.5371 .35121 L
.53248 .35332 L
.52825 .35534 L
.52438 .35727 L
.52046 .3593 L
.51688 .36123 L
.51359 .36306 L
.51025 .36499 L
.50718 .36681 L
.50408 .36872 L
.50122 .37052 L
.49861 .37222 L
.49594 .374 L
.4935 .37568 L
.49101 .37743 L
.48873 .37907 L
.48663 .38062 L
.48449 .38223 L
.48252 .38374 L
.48071 .38516 L
.47885 .38663 L
.47715 .38802 L
.47541 .38945 L
.47381 .3908 L
.47233 .39206 L
.47082 .39336 L
.46943 .39459 L
.46814 .39573 L
.46683 .39692 L
.46561 .39803 L
.46437 .39917 L
.46322 .40024 L
.46216 .40124 L
.46107 .40228 L
.46007 .40325 L
.45904 .40424 L
.45809 .40517 L
.45721 .40604 L
.45631 .40694 L
Mistroke
.45547 .40777 L
.4547 .40855 L
.45391 .40936 L
.45318 .41011 L
.45242 .41088 L
.45173 .4116 L
.45108 .41228 L
.45042 .41297 L
.44981 .41361 L
.44918 .41428 L
.44859 .4149 L
.44805 .41547 L
.4475 .41606 L
.44698 .41662 L
.44651 .41713 L
.44602 .41766 L
.44556 .41815 L
.4451 .41866 L
.44466 .41913 L
.44426 .41957 L
.44385 .42002 L
.44346 .42044 L
.44311 .42083 L
.44274 .42124 L
.4424 .42161 L
.44205 .422 L
.44173 .42235 L
.44143 .42269 L
.44139 .42273 L
Mfstroke
.97436 .37607 m
.94747 .37211 L
.91968 .36821 L
.89498 .36493 L
.87245 .36211 L
.84973 .35946 L
.82903 .35724 L
.80823 .3552 L
.78929 .35355 L
.77205 .35223 L
.75471 .3511 L
.73892 .35026 L
.72455 .34967 L
.71747 .34945 L
.71006 .34926 L
.70656 .34919 L
.70279 .34913 L
.69928 .34908 L
.69606 .34905 L
.6944 .34904 L
.69352 .34903 L
.6926 .34903 L
.6918 .34903 L
.69138 .34903 L
.69093 .34903 L
.69051 .34902 L
.69013 .34902 L
.68975 .34902 L
.68939 .34902 L
.68905 .34902 L
.68867 .34902 L
.68828 .34902 L
.68791 .34902 L
.68757 .34902 L
.68726 .34902 L
.68655 .34903 L
.68584 .34903 L
.68506 .34903 L
.68351 .34904 L
.68186 .34905 L
.68032 .34906 L
.67747 .34909 L
.67443 .34914 L
.67119 .3492 L
.66541 .34934 L
.65946 .34953 L
.64917 .34996 L
.6388 .35056 L
.62934 .35125 L
.61983 .35209 L
Mistroke
.61116 .35301 L
.60325 .35396 L
.59527 .35506 L
.58798 .35618 L
.58065 .35743 L
.57396 .35869 L
.56784 .35994 L
.56167 .36132 L
.55603 .36267 L
.55087 .36399 L
.54565 .36542 L
.54087 .3668 L
.53604 .36829 L
.53162 .36973 L
.52757 .37112 L
.52346 .37259 L
.5197 .374 L
.51626 .37536 L
.51275 .37679 L
.50954 .37816 L
.50628 .3796 L
.50329 .38097 L
.50054 .38227 L
.49774 .38364 L
.49517 .38493 L
.49257 .38629 L
.49017 .38758 L
.48797 .38879 L
.48573 .39006 L
.48366 .39126 L
.48176 .39239 L
.47983 .39356 L
.47804 .39467 L
.47623 .39583 L
.47455 .39691 L
.47301 .39793 L
.47143 .39899 L
.46998 .39999 L
.46864 .40092 L
.46727 .4019 L
.466 .40281 L
.46471 .40375 L
.46352 .40464 L
.46242 .40546 L
.46129 .40632 L
.46025 .40713 L
.45919 .40796 L
.45821 .40874 L
.4573 .40946 L
.45637 .41022 L
Mistroke
.45552 .41092 L
.45472 .41158 L
.45391 .41226 L
.45315 .41289 L
.45238 .41355 L
.45167 .41416 L
.45101 .41473 L
.45033 .41532 L
.44971 .41587 L
.44906 .41644 L
.44847 .41697 L
.44792 .41747 L
.44736 .41797 L
.44684 .41845 L
.44635 .41889 L
.44585 .41935 L
.44539 .41977 L
.44492 .42021 L
.44449 .42062 L
.44408 .421 L
.44366 .42139 L
.44328 .42176 L
.44292 .4221 L
.44255 .42245 L
.44221 .42278 L
.44186 .42312 L
.44154 .42343 L
.44124 .42371 L
Mfstroke
.97436 .4188 m
.9493 .41446 L
.92323 .41003 L
.89989 .40616 L
.87846 .40271 L
.85672 .39932 L
.83679 .39633 L
.81664 .39344 L
.79819 .39092 L
.7813 .38874 L
.76422 .38666 L
.7486 .38489 L
.7343 .38339 L
.71983 .382 L
.7066 .38086 L
.69325 .37984 L
.68104 .37904 L
.66988 .37842 L
.6586 .37792 L
.64829 .37758 L
.64286 .37745 L
.64043 .3774 L
.63789 .37736 L
.63558 .37732 L
.63307 .3773 L
.63198 .37729 L
.63082 .37728 L
.62973 .37727 L
.62874 .37727 L
.62821 .37727 L
.62763 .37727 L
.62734 .37727 L
.62718 .37727 L
.62702 .37727 L
.62673 .37727 L
.62646 .37727 L
.62621 .37727 L
.62594 .37727 L
.62569 .37727 L
.62546 .37727 L
.62519 .37727 L
.6249 .37727 L
.62437 .37727 L
.62381 .37727 L
.62319 .37727 L
.62195 .37728 L
.62081 .37729 L
.61975 .37729 L
.61747 .37732 L
.61534 .37735 L
Mistroke
.61142 .37742 L
.60732 .37752 L
.60362 .37763 L
.59601 .37794 L
.58833 .37834 L
.58131 .37881 L
.57488 .37933 L
.56839 .37993 L
.56244 .38057 L
.55699 .38123 L
.55147 .38198 L
.54641 .38273 L
.54129 .38356 L
.5366 .38439 L
.53231 .38521 L
.52795 .38611 L
.52395 .38699 L
.52028 .38784 L
.51656 .38876 L
.51313 .38966 L
.50967 .39061 L
.50648 .39153 L
.50355 .39242 L
.50058 .39336 L
.49784 .39427 L
.49507 .39522 L
.49252 .39613 L
.49018 .39701 L
.48779 .39792 L
.4856 .3988 L
.48358 .39963 L
.48152 .4005 L
.47963 .40133 L
.4777 .40219 L
.47592 .40301 L
.47429 .40379 L
.47262 .4046 L
.47108 .40536 L
.46967 .40608 L
.46822 .40684 L
.46688 .40755 L
.46552 .40829 L
.46427 .40898 L
.46311 .40964 L
.46192 .41032 L
.46083 .41096 L
.45972 .41162 L
.45869 .41225 L
.45774 .41283 L
.45676 .41344 L
Mistroke
.45587 .41401 L
.45504 .41454 L
.45419 .4151 L
.4534 .41562 L
.4526 .41615 L
.45186 .41666 L
.45118 .41713 L
.45047 .41762 L
.44983 .41807 L
.44916 .41855 L
.44855 .41899 L
.44798 .4194 L
.4474 .41983 L
.44686 .42022 L
.44637 .4206 L
.44586 .42098 L
.44538 .42134 L
.4449 .42171 L
.44445 .42206 L
.44404 .42238 L
.44361 .42272 L
.44322 .42303 L
.44285 .42332 L
.44248 .42362 L
.44213 .4239 L
.44178 .42419 L
.44145 .42446 L
.44114 .42471 L
.44112 .42473 L
Mfstroke
.97436 .46154 m
.95115 .4569 L
.92683 .45205 L
.9049 .4477 L
.88464 .44372 L
.86395 .43969 L
.84486 .43602 L
.82543 .43235 L
.80755 .42903 L
.79108 .42605 L
.77433 .42308 L
.75893 .42043 L
.74476 .41807 L
.73036 .41575 L
.71713 .41369 L
.70371 .4117 L
.6914 .40995 L
.68009 .40843 L
.66862 .40697 L
.6581 .40571 L
.64745 .40453 L
.63769 .40353 L
.62873 .4027 L
.61966 .40193 L
.61134 .4013 L
.60371 .4008 L
.59596 .40036 L
.58886 .40004 L
.58167 .39978 L
.57821 .39968 L
.57508 .39961 L
.57211 .39956 L
.57062 .39954 L
.56903 .39952 L
.56827 .39951 L
.56748 .39951 L
.56675 .3995 L
.56607 .3995 L
.56543 .3995 L
.56508 .39949 L
.56476 .39949 L
.56441 .39949 L
.56421 .39949 L
.56403 .39949 L
.56387 .39949 L
.5637 .39949 L
.56352 .39949 L
.56335 .39949 L
.56316 .39949 L
.56306 .39949 L
Mistroke
.56297 .39949 L
.56262 .39949 L
.56242 .39949 L
.56221 .39949 L
.56182 .3995 L
.56108 .3995 L
.5604 .3995 L
.55911 .39951 L
.55776 .39952 L
.55503 .39956 L
.55254 .39961 L
.54744 .39975 L
.54227 .39995 L
.53752 .40019 L
.53317 .40045 L
.52875 .40078 L
.52469 .40112 L
.52096 .40148 L
.51717 .40188 L
.51369 .4023 L
.51016 .40276 L
.50692 .40323 L
.50393 .40369 L
.5009 .40419 L
.49811 .40469 L
.49529 .40523 L
.49269 .40575 L
.49029 .40627 L
.48786 .40682 L
.48562 .40735 L
.48356 .40786 L
.48147 .40841 L
.47954 .40893 L
.47757 .40949 L
.47576 .41002 L
.4741 .41053 L
.4724 .41107 L
.47084 .41158 L
.4694 .41207 L
.46793 .41259 L
.46657 .41308 L
.46519 .41359 L
.46392 .41408 L
.46274 .41454 L
.46154 .41502 L
.46044 .41548 L
.45931 .41596 L
.45827 .41641 L
.45731 .41684 L
.45633 .41728 L
Mistroke
.45543 .4177 L
.45459 .41809 L
.45374 .41851 L
.45295 .41889 L
.45215 .4193 L
.4514 .41968 L
.45072 .42003 L
.45001 .4204 L
.44936 .42075 L
.4487 .42111 L
.44809 .42145 L
.44752 .42177 L
.44695 .4221 L
.44641 .42241 L
.44592 .4227 L
.44541 .423 L
.44494 .42328 L
.44446 .42357 L
.44402 .42384 L
.44361 .4241 L
.44319 .42436 L
.4428 .42461 L
.44245 .42484 L
.44208 .42508 L
.44174 .42531 L
.44139 .42554 L
.44106 .42575 L
.44102 .42578 L
Mfstroke
.97436 .50427 m
.95301 .49944 L
.93048 .49428 L
.91002 .48956 L
.89099 .48514 L
.87142 .48058 L
.85325 .47633 L
.83464 .47198 L
.8174 .46795 L
.80142 .46424 L
.78509 .46046 L
.76998 .45699 L
.75601 .45381 L
.74173 .4506 L
.72855 .44767 L
.71512 .44474 L
.70273 .44208 L
.69132 .43967 L
.67968 .43726 L
.66897 .4351 L
.65808 .43296 L
.64806 .43105 L
.63885 .42933 L
.62948 .42765 L
.62086 .42616 L
.61293 .42484 L
.60487 .42355 L
.59745 .42241 L
.58993 .42131 L
.58302 .42036 L
.57666 .41953 L
.57021 .41874 L
.56427 .41806 L
.55882 .41748 L
.55327 .41694 L
.54817 .41648 L
.543 .41607 L
.53824 .41573 L
.53387 .41545 L
.52943 .41522 L
.52535 .41504 L
.52121 .4149 L
.51921 .41484 L
.5174 .4148 L
.51568 .41477 L
.51482 .41476 L
.5139 .41475 L
.513 .41474 L
.51218 .41474 L
.51179 .41474 L
Mistroke
.51159 .41474 L
.51137 .41473 L
.51116 .41473 L
.51097 .41473 L
.51088 .41473 L
.51079 .41473 L
.51069 .41473 L
.51061 .41473 L
.5105 .41473 L
.51041 .41473 L
.5103 .41473 L
.51024 .41473 L
.51019 .41473 L
.5101 .41473 L
.51 .41473 L
.5099 .41473 L
.5098 .41473 L
.50958 .41473 L
.50938 .41473 L
.50893 .41474 L
.50852 .41474 L
.50808 .41474 L
.5072 .41475 L
.50636 .41476 L
.50562 .41477 L
.50398 .4148 L
.5025 .41483 L
.50094 .41487 L
.49798 .41497 L
.49526 .4151 L
.49276 .41523 L
.49021 .4154 L
.48786 .41558 L
.48548 .41578 L
.48329 .41599 L
.48127 .41621 L
.47921 .41645 L
.47732 .41669 L
.47558 .41693 L
.47381 .41719 L
.47217 .41744 L
.47051 .41772 L
.46898 .418 L
.46757 .41826 L
.46613 .41855 L
.4648 .41882 L
.46345 .41912 L
.46221 .4194 L
.46107 .41968 L
.4599 .41997 L
Mistroke
.45882 .42024 L
.45783 .42051 L
.45682 .42079 L
.45588 .42106 L
.45493 .42134 L
.45405 .42161 L
.45324 .42187 L
.45241 .42214 L
.45165 .4224 L
.45087 .42267 L
.45015 .42292 L
.44949 .42316 L
.44881 .42341 L
.44819 .42365 L
.44761 .42388 L
.44702 .42411 L
.44648 .42434 L
.44592 .42457 L
.44541 .42479 L
.44493 .42499 L
.44445 .42521 L
.444 .42541 L
.44359 .4256 L
.44316 .4258 L
.44277 .42598 L
.44237 .42617 L
.442 .42636 L
.44166 .42653 L
.44131 .4267 L
.44099 .42687 L
.44097 .42688 L
Mfstroke
.97436 .54701 m
.95489 .54209 L
.93418 .53674 L
.91525 .53175 L
.89751 .527 L
.87915 .52201 L
.86199 .51729 L
.84429 .51237 L
.82778 .50773 L
.8124 .50338 L
.79656 .49888 L
.78183 .49467 L
.76813 .49074 L
.75405 .4867 L
.74098 .48296 L
.7276 .47912 L
.71519 .47558 L
.7037 .47232 L
.69194 .46899 L
.68106 .46594 L
.66997 .46285 L
.65971 .46002 L
.65024 .45743 L
.64058 .45483 L
.63166 .45246 L
.62343 .4503 L
.61504 .44813 L
.6073 .44617 L
.59942 .44421 L
.59217 .44244 L
.58548 .44084 L
.57867 .43926 L
.57241 .43783 L
.56664 .43655 L
.56075 .43528 L
.55534 .43414 L
.54984 .43302 L
.54477 .43203 L
.54011 .43115 L
.53537 .43028 L
.53101 .42952 L
.52658 .42877 L
.52251 .42812 L
.51876 .42755 L
.51495 .427 L
.51145 .42652 L
.50822 .42611 L
.50494 .42571 L
.50192 .42537 L
.49886 .42505 L
Mistroke
.49604 .42478 L
.49344 .42456 L
.4908 .42435 L
.48837 .42419 L
.48591 .42404 L
.48364 .42392 L
.48155 .42383 L
.47943 .42376 L
.47841 .42374 L
.47748 .42372 L
.4766 .4237 L
.47568 .42369 L
.47521 .42369 L
.47497 .42369 L
.47471 .42368 L
.47449 .42368 L
.47437 .42368 L
.47424 .42368 L
.47412 .42368 L
.47402 .42368 L
.47392 .42368 L
.47387 .42368 L
.47381 .42368 L
.47378 .42368 L
.47375 .42368 L
.4737 .42368 L
.47364 .42368 L
.47361 .42368 L
.47358 .42368 L
.47352 .42368 L
.47347 .42368 L
.47336 .42368 L
.47326 .42368 L
.47315 .42368 L
.47295 .42368 L
.47273 .42368 L
.47249 .42368 L
.47206 .42369 L
.47167 .42369 L
.47125 .4237 L
.4705 .42371 L
.4697 .42372 L
.46888 .42375 L
.46744 .42379 L
.46597 .42385 L
.46462 .42392 L
.46325 .424 L
.46198 .42409 L
.46082 .42418 L
.45963 .42429 L
Mistroke
.45854 .42439 L
.45753 .4245 L
.4565 .42462 L
.45556 .42474 L
.45459 .42487 L
.45371 .425 L
.45289 .42513 L
.45205 .42526 L
.45128 .4254 L
.4505 .42554 L
.44978 .42568 L
.44911 .42581 L
.44843 .42595 L
.4478 .42609 L
.44723 .42622 L
.44664 .42636 L
.44609 .4265 L
.44554 .42664 L
.44502 .42678 L
.44455 .42691 L
.44407 .42704 L
.44362 .42717 L
.44321 .42729 L
.44279 .42742 L
.4424 .42755 L
.44201 .42768 L
.44164 .4278 L
.4413 .42791 L
.44097 .42803 L
Mfstroke
.97436 .58974 m
.95677 .58483 L
.93794 .57941 L
.92059 .57428 L
.90422 .56932 L
.88716 .56403 L
.87109 .55896 L
.85442 .55359 L
.83875 .54845 L
.82405 .54357 L
.80882 .53844 L
.79456 .53358 L
.78123 .529 L
.76744 .52421 L
.75456 .51971 L
.7413 .51505 L
.72895 .51068 L
.71744 .5066 L
.70561 .50239 L
.69461 .49847 L
.68333 .49445 L
.67286 .49072 L
.66316 .48727 L
.65321 .48374 L
.644 .48048 L
.63547 .47748 L
.62674 .47442 L
.61866 .47161 L
.61042 .46876 L
.6028 .46614 L
.59577 .46375 L
.58858 .46133 L
.58195 .45912 L
.57583 .4571 L
.56959 .45507 L
.56382 .45321 L
.55795 .45135 L
.55254 .44966 L
.54756 .44813 L
.54248 .44659 L
.5378 .4452 L
.53304 .44381 L
.52866 .44256 L
.52463 .44143 L
.52053 .4403 L
.51675 .43929 L
.51327 .43838 L
.50973 .43748 L
.50647 .43667 L
.50316 .43586 L
Mistroke
.50011 .43515 L
.49731 .43451 L
.49446 .43388 L
.49183 .43332 L
.48917 .43277 L
.48671 .43228 L
.48446 .43185 L
.48217 .43143 L
.48006 .43106 L
.47812 .43074 L
.47614 .43042 L
.47432 .43014 L
.47247 .42988 L
.47078 .42965 L
.46921 .42945 L
.46762 .42927 L
.46616 .4291 L
.46481 .42897 L
.46343 .42884 L
.46217 .42873 L
.46088 .42864 L
.4597 .42856 L
.45861 .42849 L
.4575 .42844 L
.45648 .4284 L
.45544 .42836 L
.45494 .42835 L
.45449 .42834 L
.45405 .42834 L
.45384 .42833 L
.45361 .42833 L
.45338 .42833 L
.45317 .42833 L
.45307 .42833 L
.45302 .42833 L
.45297 .42833 L
.45292 .42833 L
.45287 .42833 L
.45284 .42833 L
.45282 .42833 L
.4528 .42833 L
.45278 .42833 L
.45275 .42833 L
.45272 .42833 L
.4527 .42833 L
.45268 .42833 L
.45267 .42833 L
.45265 .42833 L
.45262 .42833 L
.4526 .42833 L
Mistroke
.45257 .42833 L
.45252 .42833 L
.45246 .42833 L
.45235 .42833 L
.45224 .42833 L
.45212 .42833 L
.45191 .42833 L
.4517 .42833 L
.45151 .42833 L
.4511 .42834 L
.45072 .42835 L
.45033 .42836 L
.44958 .42838 L
.44888 .42841 L
.44825 .42844 L
.44759 .42848 L
.44699 .42852 L
.44638 .42856 L
.44582 .42861 L
.4453 .42866 L
.44477 .42872 L
.44428 .42877 L
.44383 .42883 L
.44338 .42889 L
.44295 .42894 L
.44252 .42901 L
.44212 .42907 L
.44175 .42913 L
.44138 .4292 L
.44104 .42926 L
Mfstroke
.97436 .63248 m
.95867 .62768 L
.94175 .62232 L
.92604 .61716 L
.91112 .61211 L
.89545 .60667 L
.88059 .60137 L
.86505 .59569 L
.85035 .59019 L
.83645 .5849 L
.82196 .57928 L
.80829 .57389 L
.79543 .56874 L
.78204 .56332 L
.76946 .55816 L
.75643 .55275 L
.7442 .54763 L
.73276 .54279 L
.72092 .53776 L
.70986 .53302 L
.69846 .52811 L
.68782 .5235 L
.67791 .5192 L
.66771 .51476 L
.65822 .51062 L
.6494 .50676 L
.64034 .5028 L
.63192 .49912 L
.62329 .49536 L
.6153 .49188 L
.60789 .48865 L
.6003 .48537 L
.59328 .48234 L
.58678 .47954 L
.58013 .4767 L
.57398 .47408 L
.5677 .47143 L
.56191 .46899 L
.55655 .46676 L
.55109 .4645 L
.54605 .46243 L
.54092 .46035 L
.53619 .45844 L
.53182 .45671 L
.52738 .45496 L
.52328 .45336 L
.51951 .45191 L
.51566 .45045 L
.51212 .44912 L
.50852 .44779 L
Mistroke
.5052 .44658 L
.50215 .44548 L
.49904 .44438 L
.49618 .44339 L
.49328 .4424 L
.49061 .4415 L
.48815 .44069 L
.48565 .43988 L
.48335 .43916 L
.48123 .4385 L
.47908 .43785 L
.4771 .43726 L
.47509 .43668 L
.47324 .43616 L
.47154 .43569 L
.46981 .43522 L
.46821 .43481 L
.46675 .43444 L
.46526 .43407 L
.46388 .43374 L
.46249 .43342 L
.46121 .43313 L
.46003 .43288 L
.45883 .43263 L
.45772 .43241 L
.4566 .43219 L
.45557 .43201 L
.45462 .43184 L
.45365 .43168 L
.45276 .43154 L
.45195 .43141 L
.45111 .43129 L
.45035 .43119 L
.44957 .43109 L
.44885 .43101 L
.44819 .43094 L
.44752 .43087 L
.4469 .43081 L
.44633 .43077 L
.44575 .43072 L
.44521 .43069 L
.44467 .43066 L
.44416 .43063 L
.4437 .43061 L
.44323 .4306 L
.44302 .43059 L
.4428 .43059 L
.44257 .43059 L
.44247 .43058 L
.44236 .43058 L
Mistroke
.44225 .43058 L
.44215 .43058 L
.4421 .43058 L
.44205 .43058 L
.44202 .43058 L
.44201 .43058 L
.44199 .43058 L
.44199 .43058 L
.44198 .43058 L
.44197 .43058 L
.44196 .43058 L
.44195 .43058 L
.44194 .43058 L
.44193 .43058 L
.44192 .43058 L
.44191 .43058 L
.44189 .43058 L
.44187 .43058 L
.44184 .43058 L
.4418 .43058 L
.44176 .43058 L
.44171 .43058 L
.44166 .43058 L
.44156 .43058 L
.44147 .43058 L
.44137 .43059 L
.4412 .43059 L
Mfstroke
.97436 .67521 m
.96059 .67064 L
.94562 .66545 L
.93162 .6604 L
.91822 .65541 L
.90405 .64994 L
.89051 .64457 L
.87624 .63874 L
.86263 .63304 L
.84967 .62748 L
.83606 .62152 L
.82313 .61575 L
.81087 .61017 L
.79803 .60424 L
.78588 .59854 L
.77319 .5925 L
.76122 .58673 L
.74994 .58123 L
.7382 .57545 L
.72716 .56996 L
.71572 .56423 L
.70498 .5588 L
.69492 .55368 L
.68451 .54836 L
.67478 .54335 L
.66569 .53866 L
.6563 .53379 L
.64754 .52924 L
.63854 .52455 L
.63015 .52017 L
.62235 .5161 L
.61434 .51191 L
.6069 .50802 L
.59999 .50441 L
.59289 .50071 L
.58632 .49728 L
.57959 .49378 L
.57336 .49054 L
.56759 .48756 L
.56169 .48451 L
.55623 .48171 L
.55066 .47886 L
.54552 .47625 L
.54077 .47384 L
.53593 .4714 L
.53146 .46916 L
.52734 .46711 L
.52313 .46503 L
.51925 .46313 L
.5153 .4612 L
Mistroke
.51166 .45944 L
.50831 .45784 L
.50489 .45622 L
.50174 .45474 L
.49855 .45325 L
.49561 .45189 L
.4929 .45065 L
.49015 .44941 L
.48762 .44828 L
.48529 .44725 L
.48292 .44622 L
.48073 .44528 L
.47852 .44434 L
.47648 .44348 L
.47461 .44271 L
.4727 .44193 L
.47095 .44123 L
.46934 .44059 L
.4677 .43995 L
.46619 .43937 L
.46466 .4388 L
.46325 .43828 L
.46195 .4378 L
.46063 .43733 L
.45942 .43691 L
.45819 .43649 L
.45706 .43611 L
.45603 .43577 L
.45497 .43543 L
.454 .43512 L
.45311 .43485 L
.4522 .43458 L
.45137 .43433 L
.45052 .43409 L
.44974 .43388 L
.44902 .43368 L
.44829 .43349 L
.44762 .43332 L
.447 .43317 L
.44638 .43302 L
.4458 .43289 L
.44521 .43276 L
.44467 .43264 L
.44417 .43254 L
.44367 .43244 L
.4432 .43235 L
.44273 .43226 L
.44229 .43219 L
.44189 .43212 L
.44149 .43206 L
Mistroke
Mfstroke
.97436 .71795 m
.96251 .7137 L
.94954 .70882 L
.93731 .70402 L
.92553 .69921 L
.91297 .6939 L
.90087 .68862 L
.88802 .68282 L
.87566 .67709 L
.8638 .67145 L
.85125 .66533 L
.83922 .65935 L
.82774 .65351 L
.81561 .64724 L
.80405 .64116 L
.79189 .63466 L
.78033 .62839 L
.76935 .62235 L
.75785 .61595 L
.74696 .60983 L
.73559 .60336 L
.72485 .5972 L
.71472 .59134 L
.70419 .58519 L
.69427 .57937 L
.68496 .57387 L
.67529 .56812 L
.66623 .56271 L
.65685 .55709 L
.64809 .55181 L
.63989 .54686 L
.63144 .54174 L
.62355 .53696 L
.6162 .53249 L
.60863 .52788 L
.60158 .52359 L
.59435 .51918 L
.58762 .51508 L
.58138 .51128 L
.57498 .50738 L
.56904 .50377 L
.56297 .50008 L
.55735 .49667 L
.55215 .49353 L
.54683 .49032 L
.54192 .48736 L
.53737 .48463 L
.53273 .48185 L
.52844 .47929 L
.52406 .4767 L
Mistroke
.52003 .47432 L
.51631 .47213 L
.51251 .46991 L
.50902 .46787 L
.50546 .46581 L
.50219 .46392 L
.49917 .4622 L
.4961 .46045 L
.49327 .45885 L
.49067 .45739 L
.48802 .45592 L
.48559 .45457 L
.48311 .45321 L
.48083 .45197 L
.47874 .45084 L
.47661 .4497 L
.47465 .44866 L
.47285 .44772 L
.47102 .44676 L
.46934 .44589 L
.46763 .44502 L
.46605 .44422 L
.46461 .4435 L
.46314 .44277 L
.46179 .44211 L
.46042 .44145 L
.45917 .44085 L
.45801 .4403 L
.45684 .43976 L
.45576 .43926 L
.45477 .43881 L
.45376 .43836 L
.45283 .43795 L
.4519 .43754 L
.45103 .43717 L
.45024 .43684 L
.44943 .4365 L
.44869 .4362 L
.44801 .43593 L
.44732 .43565 L
.44669 .43541 L
.44604 .43516 L
.44545 .43494 L
.4449 .43474 L
.44435 .43454 L
.44384 .43436 L
.44332 .43418 L
.44285 .43402 L
.44241 .43387 L
.44197 .43373 L
Mistroke
Mfstroke
.97436 .76068 m
.96445 .75687 L
.95352 .75244 L
.94314 .74803 L
.93306 .74357 L
.92222 .73858 L
.9117 .73357 L
.90044 .72802 L
.88951 .72247 L
.87894 .71695 L
.86764 .7109 L
.85673 .70492 L
.84623 .69904 L
.83504 .69266 L
.82428 .68641 L
.81288 .67966 L
.80193 .67309 L
.79146 .66671 L
.7804 .65988 L
.76983 .65327 L
.75872 .64625 L
.74814 .63949 L
.73809 .63301 L
.72756 .62616 L
.71757 .61961 L
.70813 .61337 L
.69827 .60681 L
.68896 .60059 L
.67927 .59407 L
.67015 .58791 L
.66159 .5821 L
.6527 .57604 L
.64436 .57033 L
.63656 .56498 L
.62847 .55942 L
.62092 .55421 L
.61313 .54883 L
.60586 .5438 L
.59908 .53911 L
.59211 .53427 L
.58561 .52977 L
.57895 .52514 L
.57277 .52085 L
.56702 .51687 L
.56113 .51278 L
.55568 .509 L
.55062 .5055 L
.54544 .50192 L
.54064 .49861 L
.53574 .49523 L
Mistroke
.53122 .49212 L
.52703 .48925 L
.52276 .48633 L
.51882 .48363 L
.5148 .4809 L
.5111 .47839 L
.50768 .47608 L
.50421 .47374 L
.501 .47158 L
.49805 .46961 L
.49504 .4676 L
.49227 .46577 L
.48945 .46391 L
.48686 .4622 L
.48448 .46065 L
.48205 .45907 L
.47982 .45762 L
.47777 .4563 L
.47569 .45497 L
.47377 .45374 L
.47182 .45251 L
.47003 .45139 L
.46838 .45036 L
.46671 .44932 L
.46517 .44837 L
.46361 .44742 L
.46218 .44655 L
.46087 .44576 L
.45953 .44496 L
.45831 .44423 L
.45718 .44357 L
.45604 .4429 L
.45499 .44229 L
.45393 .44168 L
.45295 .44112 L
.45205 .44061 L
.45114 .44011 L
.4503 .43964 L
.44953 .43922 L
.44875 .4388 L
.44803 .43841 L
.44731 .43802 L
.44664 .43767 L
.44603 .43735 L
.4454 .43703 L
.44483 .43674 L
.44425 .43645 L
.44372 .43619 L
.44323 .43595 L
.44274 .43571 L
Mistroke
Mfstroke
.97436 .80342 m
.96641 .80015 L
.95756 .7963 L
.9491 .79244 L
.94082 .78848 L
.93184 .78402 L
.92305 .77949 L
.91355 .77442 L
.90426 .76929 L
.89519 .76414 L
.8854 .75844 L
.87587 .75275 L
.8666 .7471 L
.85663 .74089 L
.84696 .73475 L
.8366 .72806 L
.82657 .72147 L
.81688 .71502 L
.80654 .70804 L
.79658 .70122 L
.78601 .6939 L
.77584 .68678 L
.76609 .67989 L
.75579 .67253 L
.74593 .66544 L
.73654 .65863 L
.72664 .6514 L
.71723 .64448 L
.70735 .63717 L
.69799 .63021 L
.68912 .62358 L
.67986 .61662 L
.67111 .61002 L
.66286 .60378 L
.65427 .59726 L
.64619 .5911 L
.63781 .5847 L
.62995 .57867 L
.62258 .57302 L
.61496 .56715 L
.60783 .56166 L
.60048 .55599 L
.59362 .5507 L
.58723 .54576 L
.58065 .54067 L
.57452 .53593 L
.56883 .53153 L
.56298 .527 L
.55755 .52279 L
.55198 .51849 L
Mistroke
.54682 .5145 L
.54204 .51081 L
.53715 .50703 L
.53262 .50354 L
.528 .49998 L
.52373 .4967 L
.51979 .49367 L
.51576 .49059 L
.51205 .48775 L
.50862 .48513 L
.50513 .48246 L
.5019 .48001 L
.49862 .47752 L
.4956 .47524 L
.49282 .47314 L
.48999 .47101 L
.48738 .46905 L
.48498 .46726 L
.48254 .46543 L
.48029 .46376 L
.47801 .46207 L
.47591 .46052 L
.47398 .4591 L
.47202 .45767 L
.47021 .45635 L
.46839 .45503 L
.46671 .45381 L
.46517 .4527 L
.4636 .45158 L
.46217 .45056 L
.46085 .44962 L
.45951 .44867 L
.45828 .44781 L
.45703 .44693 L
.45589 .44614 L
.45484 .44541 L
.45377 .44468 L
.45279 .44401 L
.4519 .4434 L
.45099 .44278 L
.45015 .44222 L
.4493 .44165 L
.44852 .44113 L
.44781 .44066 L
.44708 .44019 L
.44642 .43975 L
.44575 .43932 L
.44513 .43892 L
.44456 .43856 L
.444 .43821 L
Mistroke
Mfstroke
.97436 .84615 m
.96837 .84353 L
.96167 .84042 L
.9552 .83726 L
.94881 .83399 L
.94184 .83027 L
.93495 .82645 L
.92743 .82212 L
.92 .81771 L
.91268 .81323 L
.90471 .80822 L
.89686 .80316 L
.88915 .79808 L
.88078 .79244 L
.87256 .7868 L
.86367 .78059 L
.85495 .7744 L
.84644 .76827 L
.83727 .76156 L
.82832 .75493 L
.81871 .74773 L
.80937 .74065 L
.80031 .73373 L
.79063 .72625 L
.78127 .71895 L
.77225 .71187 L
.76265 .70427 L
.75342 .69692 L
.74363 .68909 L
.73426 .68153 L
.7253 .67427 L
.71584 .66658 L
.70683 .65921 L
.69826 .65217 L
.68926 .64475 L
.68071 .63769 L
.67178 .63028 L
.66333 .62324 L
.65535 .61659 L
.64703 .60964 L
.6392 .60308 L
.63107 .59625 L
.62343 .58983 L
.61627 .5838 L
.60885 .57754 L
.60191 .57168 L
.59542 .5662 L
.58872 .56053 L
.58246 .55524 L
.57603 .54979 L
Mistroke
.57003 .54471 L
.56446 .53999 L
.55873 .53514 L
.55341 .53063 L
.54796 .52601 L
.5429 .52173 L
.53822 .51777 L
.53343 .51371 L
.52899 .50996 L
.52489 .50649 L
.52069 .50295 L
.51681 .49968 L
.51286 .49635 L
.50921 .49328 L
.50585 .49045 L
.50241 .48756 L
.49925 .48491 L
.49633 .48247 L
.49336 .47998 L
.49062 .47769 L
.48783 .47537 L
.48527 .47324 L
.48291 .47128 L
.48051 .4693 L
.47831 .46747 L
.47607 .46563 L
.47401 .46393 L
.47212 .46238 L
.4702 .46081 L
.46844 .45937 L
.46682 .45805 L
.46518 .45671 L
.46367 .45549 L
.46214 .45425 L
.46073 .45312 L
.45944 .45208 L
.45813 .45103 L
.45693 .45007 L
.45583 .44919 L
.45471 .44831 L
.45369 .44749 L
.45265 .44667 L
.45169 .44592 L
.45082 .44524 L
.44993 .44455 L
.44912 .44392 L
.4483 .44328 L
.44754 .4427 L
.44685 .44217 L
.44616 .44164 L
Mistroke
Mfstroke
.97436 .88889 m
.97035 .88703 L
.96583 .8848 L
.96144 .88251 L
.95706 .88012 L
.95224 .87737 L
.94743 .87452 L
.94214 .87126 L
.93685 .86789 L
.93159 .86444 L
.92579 .86054 L
.92002 .85654 L
.91429 .85249 L
.90798 .84794 L
.90172 .84334 L
.89486 .83819 L
.88805 .833 L
.88131 .8278 L
.87394 .82202 L
.86666 .81624 L
.85872 .80988 L
.8509 .80352 L
.84321 .79722 L
.83486 .79032 L
.82668 .78349 L
.81868 .77677 L
.81004 .76945 L
.80161 .76228 L
.79256 .75451 L
.78375 .74692 L
.77522 .73953 L
.76609 .73158 L
.75726 .72386 L
.74876 .7164 L
.73971 .70843 L
.73102 .70074 L
.72181 .69257 L
.71298 .68472 L
.70456 .67721 L
.69567 .66926 L
.6872 .66167 L
.67831 .65369 L
.66987 .6461 L
.66188 .63889 L
.65352 .63134 L
.64562 .6242 L
.63817 .61745 L
.6304 .61041 L
.6231 .60378 L
.61552 .5969 L
Mistroke
.6084 .59043 L
.60174 .58437 L
.59484 .57809 L
.58839 .57221 L
.58174 .56616 L
.57553 .5605 L
.56975 .55523 L
.5638 .5498 L
.55827 .54475 L
.55312 .54006 L
.54783 .53524 L
.54293 .53076 L
.5379 .52618 L
.53325 .52194 L
.52894 .51801 L
.52453 .51399 L
.52045 .51027 L
.51667 .50684 L
.51282 .50333 L
.50925 .50009 L
.50562 .49679 L
.50227 .49375 L
.49918 .49094 L
.49604 .48809 L
.49313 .48546 L
.49019 .48279 L
.48747 .48033 L
.48497 .47807 L
.48243 .47578 L
.4801 .47367 L
.47795 .47174 L
.47577 .46977 L
.47376 .46797 L
.47172 .46614 L
.46985 .46446 L
.46813 .46292 L
.46639 .46136 L
.46479 .45993 L
.46332 .45862 L
.46182 .45729 L
.46045 .45607 L
.45906 .45484 L
.45779 .45371 L
.45662 .45267 L
.45543 .45162 L
.45434 .45067 L
.45324 .4497 L
.45224 .44881 L
.45131 .448 L
.4504 .4472 L
Mistroke
Mfstroke
.97436 .93162 m
.97235 .93064 L
.97006 .92944 L
.96782 .9282 L
.96557 .9269 L
.96307 .92538 L
.96055 .92379 L
.95775 .92195 L
.95492 .92003 L
.95207 .91804 L
.9489 .91576 L
.9457 .91341 L
.94248 .91098 L
.93889 .90822 L
.93528 .90539 L
.93125 .90218 L
.9272 .89889 L
.92312 .89554 L
.91859 .89176 L
.91403 .88792 L
.90898 .8836 L
.90389 .87922 L
.8988 .87479 L
.89317 .86985 L
.88754 .86487 L
.88192 .85986 L
.87573 .85431 L
.86957 .84875 L
.86279 .8426 L
.85606 .83646 L
.84939 .83034 L
.8421 .82363 L
.83489 .81697 L
.8278 .81039 L
.82007 .8032 L
.81249 .79612 L
.80427 .78843 L
.79622 .78087 L
.78837 .77348 L
.7799 .76549 L
.77166 .7577 L
.76282 .74933 L
.75425 .7412 L
.74596 .73332 L
.73712 .7249 L
.72859 .71678 L
.72041 .70896 L
.71171 .70066 L
.70339 .69269 L
.69459 .68427 L
Mistroke
.68619 .67621 L
.67819 .66854 L
.66977 .66046 L
.66178 .65278 L
.65342 .64474 L
.6455 .63713 L
.63802 .62992 L
.63022 .62241 L
.62287 .61533 L
.61595 .60867 L
.60877 .60174 L
.60202 .59523 L
.59504 .5885 L
.58851 .58219 L
.5824 .57629 L
.57609 .5702 L
.5702 .56452 L
.56472 .55922 L
.55906 .55376 L
.5538 .54868 L
.5484 .54347 L
.54338 .53862 L
.53873 .53413 L
.53395 .52951 L
.52953 .52524 L
.52501 .52088 L
.52082 .51684 L
.51695 .5131 L
.513 .50929 L
.50935 .50577 L
.50598 .50252 L
.50254 .4992 L
.49936 .49614 L
.49613 .49302 L
.49316 .49015 L
.49041 .48751 L
.48762 .48482 L
.48505 .48235 L
.48269 .48007 L
.48028 .47776 L
.47806 .47563 L
.47581 .47347 L
.47375 .47148 L
.47185 .46966 L
.46992 .4678 L
.46815 .4661 L
.46635 .46438 L
.46471 .4628 L
.46319 .46136 L
.46169 .45992 L
Mistroke
Mfstroke
.97436 .97436 m
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
Mistroke
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
.97436 .97436 L
Mistroke
Mfstroke
.22641 .22641 m
.24247 .24247 L
s
% Start of user PostScript
0.12489656 0.12489656 0.14369564 0.14369564 MAarrowhead1
% End of user PostScript
.22192 .25758 m
.2375 .27179 L
s
% Start of user PostScript
0.1196431 0.16136758 0.13787275 0.17799268 MAarrowhead1
% End of user PostScript
.21742 .28835 m
.23251 .30066 L
s
% Start of user PostScript
0.11437714 0.19736633 0.13203155 0.21177297 MAarrowhead1
% End of user PostScript
.21291 .31871 m
.2275 .32909 L
s
% Start of user PostScript
0.10909995 0.23289308 0.12617391 0.24503694 MAarrowhead1
% End of user PostScript
.20839 .34867 m
.22248 .35708 L
s
% Start of user PostScript
0.10381288 0.26794837 0.12030175 0.27778542 MAarrowhead1
% End of user PostScript
.20386 .37823 m
.21745 .38463 L
s
% Start of user PostScript
0.098517133 0.30253282 0.11441692 0.31001943 MAarrowhead1
% End of user PostScript
.19933 .40739 m
.21241 .41174 L
s
% Start of user PostScript
0.093214016 0.33664736 0.1085213 0.34174031 MAarrowhead1
% End of user PostScript
.19479 .43615 m
.20736 .43842 L
s
% Start of user PostScript
0.087904763 0.37029305 0.10261672 0.37294967 MAarrowhead1
% End of user PostScript
.19025 .46451 m
.20231 .46466 L
s
% Start of user PostScript
0.082590629 0.40347117 0.096705031 0.40364944 MAarrowhead1
% End of user PostScript
.1857 .49246 m
.19725 .49046 L
s
% Start of user PostScript
0.077272827 0.43618316 0.090788028 0.43384173 MAarrowhead1
% End of user PostScript
.18116 .52003 m
.19219 .51584 L
s
% Start of user PostScript
0.071952613 0.46843069 0.084867533 0.463529 MAarrowhead1
% End of user PostScript
.17661 .54719 m
.18713 .54078 L
s
% Start of user PostScript
0.066631174 0.50021559 0.078945293 0.49271388 MAarrowhead1
% End of user PostScript
.17206 .57397 m
.18207 .5653 L
s
% Start of user PostScript
0.061309691 0.53153984 0.073023049 0.5213993 MAarrowhead1
% End of user PostScript
.16751 .60035 m
.17701 .58939 L
s
% Start of user PostScript
0.055989347 0.56240564 0.06710252 0.5495884 MAarrowhead1
% End of user PostScript
.16297 .62634 m
.17195 .61306 L
s
% Start of user PostScript
0.050671301 0.59281533 0.061185387 0.57728452 MAarrowhead1
% End of user PostScript
.15842 .65194 m
.1669 .63632 L
s
% Start of user PostScript
0.045356686 0.62277138 0.05527331 0.60449128 MAarrowhead1
% End of user PostScript
.15389 .67716 m
.16185 .65916 L
s
% Start of user PostScript
0.040046626 0.65227645 0.049367909 0.63121244 MAarrowhead1
% End of user PostScript
.14935 .70199 m
.15681 .68158 L
s
% Start of user PostScript
0.034742219 0.68133334 0.043470774 0.65745199 MAarrowhead1
% End of user PostScript
.14482 .72645 m
.15178 .7036 L
s
% Start of user PostScript
0.029444553 0.70994502 0.037583454 0.6832141 MAarrowhead1
% End of user PostScript
.1403 .75053 m
.14676 .72522 L
s
% Start of user PostScript
0.02415468 0.73811454 0.03170746 0.70850309 MAarrowhead1
% End of user PostScript
.13579 .77423 m
.14175 .74643 L
s
% Start of user PostScript
0.018873639 0.76584512 0.025844275 0.7333235 MAarrowhead1
% End of user PostScript
.25758 .22192 m
.27179 .2375 L
s
% Start of user PostScript
0.16136758 0.1196431 0.17799268 0.13787275 MAarrowhead1
% End of user PostScript
.17129 .78066 m
.17574 .75314 L
s
% Start of user PostScript
0.060404277 0.7733691 0.065616441 0.74117274 MAarrowhead1
% End of user PostScript
.28835 .21742 m
.30066 .23251 L
s
% Start of user PostScript
0.19736633 0.11437714 0.21177297 0.13203155 MAarrowhead1
% End of user PostScript
.20723 .78734 m
.21022 .76015 L
s
% Start of user PostScript
0.10245788 0.78118339 0.10596111 0.74937266 MAarrowhead1
% End of user PostScript
.31871 .21291 m
.32909 .2275 L
s
% Start of user PostScript
0.23289308 0.10909995 0.24503694 0.12617391 MAarrowhead1
% End of user PostScript
.24364 .79428 m
.24523 .76748 L
s
% Start of user PostScript
0.14506448 0.78930462 0.14691623 0.75794651 MAarrowhead1
% End of user PostScript
.34867 .20839 m
.35708 .22248 L
s
% Start of user PostScript
0.26794837 0.10381288 0.27778542 0.12030175 MAarrowhead1
% End of user PostScript
.28056 .8015 m
.28079 .77514 L
s
% Start of user PostScript
0.18825649 0.7977506 0.18852317 0.76691926 MAarrowhead1
% End of user PostScript
.37823 .20386 m
.38463 .21745 L
s
% Start of user PostScript
0.30253282 0.098517133 0.31001943 0.11441692 MAarrowhead1
% End of user PostScript
.31801 .80901 m
.31695 .78318 L
s
% Start of user PostScript
0.2320689 0.80654068 0.23082715 0.77631857 MAarrowhead1
% End of user PostScript
.40739 .19933 m
.41174 .21241 L
s
% Start of user PostScript
0.33664736 0.093214016 0.34174031 0.1085213 MAarrowhead1
% End of user PostScript
.35602 .81683 m
.35374 .7916 L
s
% Start of user PostScript
0.27653957 0.81569589 0.27387764 0.78617466 MAarrowhead1
% End of user PostScript
.43615 .19479 m
.43842 .20736 L
s
% Start of user PostScript
0.37029305 0.087904763 0.37294967 0.10261672 MAarrowhead1
% End of user PostScript
.39462 .82499 m
.39122 .80045 L
s
% Start of user PostScript
0.32170951 0.82523897 0.31772902 0.79652083 MAarrowhead1
% End of user PostScript
.46451 .19025 m
.46466 .20231 L
s
% Start of user PostScript
0.40347117 0.082590629 0.40364944 0.096705031 MAarrowhead1
% End of user PostScript
.43387 .8335 m
.42944 .80974 L
s
% Start of user PostScript
0.36762329 0.83519474 0.36244112 0.80739386 MAarrowhead1
% End of user PostScript
.49246 .1857 m
.49046 .19725 L
s
% Start of user PostScript
0.43618316 0.077272827 0.43384173 0.090788028 MAarrowhead1
% End of user PostScript
.47379 .84238 m
.46844 .81952 L
s
% Start of user PostScript
0.41432934 0.84559018 0.40807994 0.81883429 MAarrowhead1
% End of user PostScript
.52003 .18116 m
.51584 .19219 L
s
% Start of user PostScript
0.46843069 0.071952613 0.463529 0.084867533 MAarrowhead1
% End of user PostScript
.51443 .85167 m
.50831 .82982 L
s
% Start of user PostScript
0.46188055 0.85645487 0.45471863 0.8308873 MAarrowhead1
% End of user PostScript
.54719 .17661 m
.54078 .18713 L
s
% Start of user PostScript
0.50021559 0.066631174 0.49271388 0.078945293 MAarrowhead1
% End of user PostScript
.55584 .86139 m
.54909 .84069 L
s
% Start of user PostScript
0.51033471 0.86782129 0.50243841 0.8436032 MAarrowhead1
% End of user PostScript
.57397 .17206 m
.5653 .18207 L
s
% Start of user PostScript
0.53153984 0.061309691 0.5213993 0.073023049 MAarrowhead1
% End of user PostScript
.59808 .87156 m
.59088 .85217 L
s
% Start of user PostScript
0.55975507 0.87972465 0.55132971 0.85703779 MAarrowhead1
% End of user PostScript
.60035 .16751 m
.58939 .17701 L
s
% Start of user PostScript
0.56240564 0.055989347 0.5495884 0.06710252 MAarrowhead1
% End of user PostScript
.64121 .88223 m
.63376 .86432 L
s
% Start of user PostScript
0.61021119 0.89220439 0.60149376 0.87125427 MAarrowhead1
% End of user PostScript
.62634 .16297 m
.61306 .17195 L
s
% Start of user PostScript
0.59281533 0.050671301 0.57728452 0.061185387 MAarrowhead1
% End of user PostScript
.68528 .89342 m
.67782 .8772 L
s
% Start of user PostScript
0.66177958 0.90530356 0.65304414 0.88632332 MAarrowhead1
% End of user PostScript
.65194 .15842 m
.63632 .1669 L
s
% Start of user PostScript
0.62277138 0.045356686 0.60449128 0.05527331 MAarrowhead1
% End of user PostScript
.73038 .90519 m
.72317 .89088 L
s
% Start of user PostScript
0.71454484 0.91907 0.70610888 0.90232496 MAarrowhead1
% End of user PostScript
.67716 .15389 m
.65916 .16185 L
s
% Start of user PostScript
0.65227645 0.040046626 0.63121244 0.049367909 MAarrowhead1
% End of user PostScript
.77658 .91757 m
.76994 .90543 L
s
% Start of user PostScript
0.76860055 0.93355673 0.76083284 0.91934994 MAarrowhead1
% End of user PostScript
.70199 .14935 m
.68158 .15681 L
s
% Start of user PostScript
0.68133334 0.034742219 0.65745199 0.043470774 MAarrowhead1
% End of user PostScript
.82398 .93062 m
.81827 .92094 L
s
% Start of user PostScript
0.8240508 0.9488229 0.81738088 0.93750183 MAarrowhead1
% End of user PostScript
.72645 .14482 m
.7036 .15178 L
s
% Start of user PostScript
0.70994502 0.029444553 0.6832141 0.037583454 MAarrowhead1
% End of user PostScript
.87266 .94439 m
.86833 .93752 L
s
% Start of user PostScript
0.88101157 0.96493452 0.8759414 0.95689928 MAarrowhead1
% End of user PostScript
.75053 .1403 m
.72522 .14676 L
s
% Start of user PostScript
0.73811454 0.02415468 0.70850309 0.03170746 MAarrowhead1
% End of user PostScript
.92275 .95895 m
.92028 .95528 L
s
% Start of user PostScript
0.93961269 0.98196573 0.93673095 0.97767911 MAarrowhead1
% End of user PostScript
.77423 .13579 m
.74643 .14175 L
s
% Start of user PostScript
0.76584512 0.018873639 0.7333235 0.025844275 MAarrowhead1
% End of user PostScript
.78066 .17129 m
.75314 .17574 L
s
% Start of user PostScript
0.7733691 0.060404277 0.74117274 0.065616441 MAarrowhead1
% End of user PostScript
.78734 .20723 m
.76015 .21022 L
s
% Start of user PostScript
0.78118339 0.10245788 0.74937266 0.10596111 MAarrowhead1
% End of user PostScript
.79428 .24364 m
.76748 .24523 L
s
% Start of user PostScript
0.78930462 0.14506448 0.75794651 0.14691623 MAarrowhead1
% End of user PostScript
.8015 .28056 m
.77514 .28079 L
s
% Start of user PostScript
0.7977506 0.18825649 0.76691926 0.18852317 MAarrowhead1
% End of user PostScript
.80901 .31801 m
.78318 .31695 L
s
% Start of user PostScript
0.80654068 0.2320689 0.77631857 0.23082715 MAarrowhead1
% End of user PostScript
.81683 .35602 m
.7916 .35374 L
s
% Start of user PostScript
0.81569589 0.27653957 0.78617466 0.27387764 MAarrowhead1
% End of user PostScript
.82499 .39462 m
.80045 .39122 L
s
% Start of user PostScript
0.82523897 0.32170951 0.79652083 0.31772902 MAarrowhead1
% End of user PostScript
.8335 .43387 m
.80974 .42944 L
s
% Start of user PostScript
0.83519474 0.36762329 0.80739386 0.36244112 MAarrowhead1
% End of user PostScript
.84238 .47379 m
.81952 .46844 L
s
% Start of user PostScript
0.84559018 0.41432934 0.81883429 0.40807994 MAarrowhead1
% End of user PostScript
.85167 .51443 m
.82982 .50831 L
s
% Start of user PostScript
0.85645487 0.46188055 0.8308873 0.45471863 MAarrowhead1
% End of user PostScript
.86139 .55584 m
.84069 .54909 L
s
% Start of user PostScript
0.86782129 0.51033471 0.8436032 0.50243841 MAarrowhead1
% End of user PostScript
.87156 .59808 m
.85217 .59088 L
s
% Start of user PostScript
0.87972465 0.55975507 0.85703779 0.55132971 MAarrowhead1
% End of user PostScript
.88223 .64121 m
.86432 .63376 L
s
% Start of user PostScript
0.89220439 0.61021119 0.87125427 0.60149376 MAarrowhead1
% End of user PostScript
.89342 .68528 m
.8772 .67782 L
s
% Start of user PostScript
0.90530356 0.66177958 0.88632332 0.65304414 MAarrowhead1
% End of user PostScript
.90519 .73038 m
.89088 .72317 L
s
% Start of user PostScript
0.91907 0.71454484 0.90232496 0.70610888 MAarrowhead1
% End of user PostScript
.91757 .77658 m
.90543 .76994 L
s
% Start of user PostScript
0.93355673 0.76860055 0.91934994 0.76083284 MAarrowhead1
% End of user PostScript
.93062 .82398 m
.92094 .81827 L
s
% Start of user PostScript
0.9488229 0.8240508 0.93750183 0.81738088 MAarrowhead1
% End of user PostScript
.94439 .87266 m
.93752 .86833 L
s
% Start of user PostScript
0.96493452 0.88101157 0.95689928 0.8759414 MAarrowhead1
% End of user PostScript
.95895 .92275 m
.95528 .92028 L
s
% Start of user PostScript
0.98196573 0.93961269 0.97767911 0.93673095 MAarrowhead1
% End of user PostScript
.97436 .97436 m
.97436 .97436 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
.54701 .54701 m
.54701 .54701 .02564 0 365.73 arc
F
gsave
.54701 .54701 -65.5 -10.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
(0) show
68.000 14.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 1.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.6 0 0 r
.60043 .60043 m
.60043 .60043 .02564 0 365.73 arc
F
0 g
newpath
.60043 .60043 .02564 0 365.73 arc
s
gsave
.60043 .60043 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.6 0 0 r
.64717 .64717 m
.64717 .64717 .02564 0 365.73 arc
F
0 g
newpath
.64717 .64717 .02564 0 365.73 arc
s
gsave
.64717 .64717 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.6 0 0 r
.51529 .51529 m
.51529 .51529 .02564 0 365.73 arc
F
0 g
newpath
.51529 .51529 .02564 0 365.73 arc
s
gsave
.51529 .51529 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.6 0 0 r
.41638 .41638 m
.41638 .41638 .02564 0 365.73 arc
F
0 g
newpath
.41638 .41638 .02564 0 365.73 arc
s
gsave
.41638 .41638 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.6 0 0 r
.3422 .3422 m
.3422 .3422 .02564 0 365.73 arc
F
0 g
newpath
.3422 .3422 .02564 0 365.73 arc
s
gsave
.3422 .3422 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.6 0 0 r
.42122 .42122 m
.42122 .42122 .02564 0 365.73 arc
F
0 g
newpath
.42122 .42122 .02564 0 365.73 arc
s
gsave
.42122 .42122 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.6 0 0 r
.49036 .49036 m
.49036 .49036 .02564 0 365.73 arc
F
0 g
newpath
.49036 .49036 .02564 0 365.73 arc
s
gsave
.49036 .49036 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.6 0 0 r
.39769 .39769 m
.39769 .39769 .02564 0 365.73 arc
F
0 g
newpath
.39769 .39769 .02564 0 365.73 arc
s
gsave
.39769 .39769 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.6 0 0 r
.46977 .46977 m
.46977 .46977 .02564 0 365.73 arc
F
0 g
newpath
.46977 .46977 .02564 0 365.73 arc
s
gsave
.46977 .46977 -64.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.6 0 0 r
.53284 .53284 m
.53284 .53284 .02564 0 365.73 arc
F
0 g
newpath
.53284 .53284 .02564 0 365.73 arc
s
gsave
.53284 .53284 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.601 0 0 r
.48391 .48391 m
.48391 .48391 .02564 0 365.73 arc
F
0 g
newpath
.48391 .48391 .02564 0 365.73 arc
s
gsave
.48391 .48391 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.601 0 0 r
.25961 .25961 m
.25961 .25961 .02564 0 365.73 arc
F
0 g
newpath
.25961 .25961 .02564 0 365.73 arc
s
gsave
.25961 .25961 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.602 0 0 r
.45793 .45793 m
.45793 .45793 .02564 0 365.73 arc
F
0 g
newpath
.45793 .45793 .02564 0 365.73 arc
s
gsave
.45793 .45793 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.602 0 0 r
.33646 .33646 m
.33646 .33646 .02564 0 365.73 arc
F
0 g
newpath
.33646 .33646 .02564 0 365.73 arc
s
gsave
.33646 .33646 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.602 0 0 r
.34342 .34342 m
.34342 .34342 .02564 0 365.73 arc
F
0 g
newpath
.34342 .34342 .02564 0 365.73 arc
s
gsave
.34342 .34342 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.603 0 0 r
.39828 .39828 m
.39828 .39828 .02564 0 365.73 arc
F
0 g
newpath
.39828 .39828 .02564 0 365.73 arc
s
gsave
.39828 .39828 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.603 0 0 r
.4078 .4078 m
.4078 .4078 .02564 0 365.73 arc
F
0 g
newpath
.4078 .4078 .02564 0 365.73 arc
s
gsave
.4078 .4078 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.604 0 0 r
.56902 .56902 m
.56902 .56902 .02564 0 365.73 arc
F
0 g
newpath
.56902 .56902 .02564 0 365.73 arc
s
gsave
.56902 .56902 -65.5 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(90) show
1.000 setlinewidth
grestore
.604 0 0 r
.33382 .33382 m
.33382 .33382 .02564 0 365.73 arc
F
0 g
newpath
.33382 .33382 .02564 0 365.73 arc
s
gsave
.33382 .33382 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.608 0 0 r
.4483 .4483 m
.4483 .4483 .02564 0 365.73 arc
F
0 g
newpath
.4483 .4483 .02564 0 365.73 arc
s
gsave
.4483 .4483 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.612 0 0 r
.38964 .38964 m
.38964 .38964 .02564 0 365.73 arc
F
0 g
newpath
.38964 .38964 .02564 0 365.73 arc
s
gsave
.38964 .38964 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.616 0 0 r
.42497 .42497 m
.42497 .42497 .02564 0 365.73 arc
F
0 g
newpath
.42497 .42497 .02564 0 365.73 arc
s
gsave
.42497 .42497 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.62 0 0 r
.46653 .46653 m
.46653 .46653 .02564 0 365.73 arc
F
0 g
newpath
.46653 .46653 .02564 0 365.73 arc
s
gsave
.46653 .46653 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.624 0 0 r
.40799 .40799 m
.40799 .40799 .02564 0 365.73 arc
F
0 g
newpath
.40799 .40799 .02564 0 365.73 arc
s
gsave
.40799 .40799 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.628 0 0 r
.25743 .25743 m
.25743 .25743 .02564 0 365.73 arc
F
0 g
newpath
.25743 .25743 .02564 0 365.73 arc
s
gsave
.25743 .25743 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(700) show
1.000 setlinewidth
grestore
.632 0 0 r
.48974 .48974 m
.48974 .48974 .02564 0 365.73 arc
F
0 g
newpath
.48974 .48974 .02564 0 365.73 arc
s
gsave
.48974 .48974 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.636 0 0 r
.60215 .60215 m
.60215 .60215 .02564 0 365.73 arc
F
0 g
newpath
.60215 .60215 .02564 0 365.73 arc
s
gsave
.60215 .60215 -66.75 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(900) show
1.000 setlinewidth
grestore
.64 0 0 r
.33567 .33567 m
.33567 .33567 .02564 0 365.73 arc
F
0 g
newpath
.33567 .33567 .02564 0 365.73 arc
s
gsave
.33567 .33567 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.68 0 0 r
.41472 .41472 m
.41472 .41472 .02564 0 365.73 arc
F
0 g
newpath
.41472 .41472 .02564 0 365.73 arc
s
gsave
.41472 .41472 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.72 0 0 r
.3383 .3383 m
.3383 .3383 .02564 0 365.73 arc
F
0 g
newpath
.3383 .3383 .02564 0 365.73 arc
s
gsave
.3383 .3383 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
.76 0 0 r
.28003 .28003 m
.28003 .28003 .02564 0 365.73 arc
F
0 g
newpath
.28003 .28003 .02564 0 365.73 arc
s
gsave
.28003 .28003 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.8 0 0 r
.31228 .31228 m
.31228 .31228 .02564 0 365.73 arc
F
0 g
newpath
.31228 .31228 .02564 0 365.73 arc
s
gsave
.31228 .31228 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.84 0 0 r
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
0 g
newpath
.97436 .97436 .02564 0 365.73 arc
s
gsave
.97436 .97436 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.88 0 0 r
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
0 g
newpath
.97436 .97436 .02564 0 365.73 arc
s
gsave
.97436 .97436 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7000) show
1.000 setlinewidth
grestore
.92 0 0 r
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
0 g
newpath
.97436 .97436 .02564 0 365.73 arc
s
gsave
.97436 .97436 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.96 0 0 r
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
0 g
newpath
.97436 .97436 .02564 0 365.73 arc
s
gsave
.97436 .97436 -68 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9000) show
1.000 setlinewidth
grestore
1 0 0 r
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
.97436 .97436 m
.97436 .97436 .02564 0 365.73 arc
F
0 g
newpath
.97436 .97436 .02564 0 365.73 arc
s
gsave
.97436 .97436 -69.25 -7.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 15.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 9.688 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 5.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{456, 456},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 455}, {455, 0}} -> {-0.204519, -0.201032, 0.00271399, \
0.00271399}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-005 0.0118853 0.594263 [
[.02381 -0.0125 -4.03125 -11.0625 ]
[.02381 -0.0125 4.03125 0 ]
[.11905 -0.0125 -10.125 -11.0625 ]
[.11905 -0.0125 10.125 0 ]
[.21429 -0.0125 -10.125 -11.0625 ]
[.21429 -0.0125 10.125 0 ]
[.30952 -0.0125 -10.125 -11.0625 ]
[.30952 -0.0125 10.125 0 ]
[.40476 -0.0125 -10.125 -11.0625 ]
[.40476 -0.0125 10.125 0 ]
[.5 -0.0125 -10.125 -11.0625 ]
[.5 -0.0125 10.125 0 ]
[.59524 -0.0125 -10.125 -11.0625 ]
[.59524 -0.0125 10.125 0 ]
[.69048 -0.0125 -10.125 -11.0625 ]
[.69048 -0.0125 10.125 0 ]
[.78571 -0.0125 -10.125 -11.0625 ]
[.78571 -0.0125 10.125 0 ]
[.88095 -0.0125 -10.125 -11.0625 ]
[.88095 -0.0125 10.125 0 ]
[.97619 -0.0125 -12.1563 -11.0625 ]
[.97619 -0.0125 12.1563 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -15.375 -22.125 ]
[.5 -0.0125 15.375 -11.0625 ]
[-0.0125 .01189 -8.0625 -5.53125 ]
[-0.0125 .01189 0 5.53125 ]
[-0.0125 .07131 -14.125 -5.53125 ]
[-0.0125 .07131 0 5.53125 ]
[-0.0125 .13074 -14.125 -5.53125 ]
[-0.0125 .13074 0 5.53125 ]
[-0.0125 .19016 -14.125 -5.53125 ]
[-0.0125 .19016 0 5.53125 ]
[-0.0125 .24959 -14.125 -5.53125 ]
[-0.0125 .24959 0 5.53125 ]
[-0.0125 .30902 -14.125 -5.53125 ]
[-0.0125 .30902 0 5.53125 ]
[-0.0125 .36844 -14.125 -5.53125 ]
[-0.0125 .36844 0 5.53125 ]
[-0.0125 .42787 -14.125 -5.53125 ]
[-0.0125 .42787 0 5.53125 ]
[-0.0125 .4873 -14.125 -5.53125 ]
[-0.0125 .4873 0 5.53125 ]
[-0.0125 .54672 -14.125 -5.53125 ]
[-0.0125 .54672 0 5.53125 ]
[-0.0125 .60615 -8.0625 -5.53125 ]
[-0.0125 .60615 0 5.53125 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -53.5313 0 ]
[.5 .63053 53.5313 11.0625 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
.7 g
.25 Mabswid
[ .01 .01 ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.11905 0 m
.11905 .61803 L
s
.21429 0 m
.21429 .61803 L
s
.30952 0 m
.30952 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.5 0 m
.5 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.69048 0 m
.69048 .61803 L
s
.78571 0 m
.78571 .61803 L
s
.88095 0 m
.88095 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .01189 m
1 .01189 L
s
0 .07131 m
1 .07131 L
s
0 .13074 m
1 .13074 L
s
0 .19016 m
1 .19016 L
s
0 .24959 m
1 .24959 L
s
0 .30902 m
1 .30902 L
s
0 .36844 m
1 .36844 L
s
0 .42787 m
1 .42787 L
s
0 .4873 m
1 .4873 L
s
0 .54672 m
1 .54672 L
s
0 .60615 m
1 .60615 L
s
0 g
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65.0313 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.11905 0 m
.11905 .00625 L
s
gsave
.11905 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3000) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4000) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5000) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6000) show
1.000 setlinewidth
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7000) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -71.125 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9000) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -73.1563 -15.0625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -76.375 -26.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iteration) show
89.750 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01189 m
.00625 .01189 L
s
gsave
-0.0125 .01189 -69.0625 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .07131 m
.00625 .07131 L
s
gsave
-0.0125 .07131 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
0 .13074 m
.00625 .13074 L
s
gsave
-0.0125 .13074 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
0 .19016 m
.00625 .19016 L
s
gsave
-0.0125 .19016 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
0 .24959 m
.00625 .24959 L
s
gsave
-0.0125 .24959 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .30902 m
.00625 .30902 L
s
gsave
-0.0125 .30902 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .36844 m
.00625 .36844 L
s
gsave
-0.0125 .36844 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .42787 m
.00625 .42787 L
s
gsave
-0.0125 .42787 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .4873 m
.00625 .4873 L
s
gsave
-0.0125 .4873 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .54672 m
.00625 .54672 L
s
gsave
-0.0125 .54672 -75.125 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -69.0625 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -114.531 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Propensity) show
99.000 12.188 moveto
(to) show
107.188 12.188 moveto
(cooperate) show
138.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
142.000 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Player1) show
166.063 12.188 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .30902 Mdot
.0239 .34616 Mdot
.024 .37866 Mdot
.0241 .28696 Mdot
.02419 .21819 Mdot
.02429 .16662 Mdot
.02438 .22156 Mdot
.02448 .26963 Mdot
.02457 .2052 Mdot
.02467 .25531 Mdot
.02476 .29917 Mdot
.02486 .33754 Mdot
.02495 .37112 Mdot
.02505 .28131 Mdot
.02514 .21395 Mdot
.02524 .16344 Mdot
.02533 .12555 Mdot
.02543 .09713 Mdot
.02552 .16076 Mdot
.02562 .21643 Mdot
.02571 .26515 Mdot
.02581 .30777 Mdot
.0259 .34507 Mdot
.026 .26177 Mdot
.0261 .1993 Mdot
.02619 .25016 Mdot
.02629 .19059 Mdot
.02638 .24253 Mdot
.02648 .18487 Mdot
.02657 .14163 Mdot
.02667 .10919 Mdot
.02676 .17131 Mdot
.02686 .22566 Mdot
.02695 .17222 Mdot
.02705 .22646 Mdot
.02714 .27392 Mdot
.02724 .31545 Mdot
.02733 .23956 Mdot
.02743 .28538 Mdot
.02752 .32548 Mdot
.02762 .24708 Mdot
.02771 .18828 Mdot
.02781 .14418 Mdot
.0279 .20193 Mdot
.028 .25246 Mdot
.0281 .29667 Mdot
.02819 .33535 Mdot
.02829 .3692 Mdot
.02838 .27987 Mdot
.02848 .21288 Mdot
.02857 .16263 Mdot
.02867 .21807 Mdot
.02876 .16652 Mdot
.02886 .22148 Mdot
.02895 .26956 Mdot
.02905 .31163 Mdot
.02914 .34845 Mdot
.02924 .38066 Mdot
.02933 .28847 Mdot
.02943 .21932 Mdot
.02952 .16746 Mdot
.02962 .12857 Mdot
.02971 .18827 Mdot
.02981 .14417 Mdot
.0299 .1111 Mdot
.03 .0863 Mdot
.0301 .06769 Mdot
.03019 .135 Mdot
.03029 .19389 Mdot
.03038 .14839 Mdot
.03048 .20561 Mdot
.03057 .25568 Mdot
.03067 .19473 Mdot
.03076 .14902 Mdot
.03086 .11474 Mdot
.03095 .08902 Mdot
.03105 .15366 Mdot
.03114 .11822 Mdot
.03124 .09164 Mdot
.03133 .15595 Mdot
.03143 .21222 Mdot
.03152 .26147 Mdot
.03162 .19907 Mdot
.03171 .24995 Mdot
.03181 .29448 Mdot
.0319 .22383 Mdot
.032 .27162 Mdot
.0321 .31344 Mdot
.03219 .23805 Mdot
.03229 .28406 Mdot
.03238 .32432 Mdot
.03248 .24621 Mdot
.03257 .2912 Mdot
.03267 .22137 Mdot
.03276 .169 Mdot
.03286 .12972 Mdot
.03295 .10026 Mdot
.03305 .1635 Mdot
.03314 .1256 Mdot
.03324 .09717 Mdot
.03333 .16079 Mdot
.03343 .21646 Mdot
.03352 .26517 Mdot
.03362 .30779 Mdot
.03371 .34509 Mdot
.03381 .37772 Mdot
.0339 .28626 Mdot
.034 .32625 Mdot
.0341 .24766 Mdot
.03419 .18871 Mdot
.03429 .24089 Mdot
.03438 .28655 Mdot
.03448 .3265 Mdot
.03457 .24785 Mdot
.03467 .18886 Mdot
.03476 .24102 Mdot
.03486 .18373 Mdot
.03495 .23654 Mdot
.03505 .28274 Mdot
.03514 .21502 Mdot
.03524 .16424 Mdot
.03533 .21948 Mdot
.03543 .26781 Mdot
.03552 .20383 Mdot
.03562 .25412 Mdot
.03571 .29812 Mdot
.03581 .22656 Mdot
.0359 .27401 Mdot
.036 .31553 Mdot
.0361 .23962 Mdot
.03619 .18269 Mdot
.03629 .23562 Mdot
.03638 .28193 Mdot
.03648 .32246 Mdot
.03657 .35792 Mdot
.03667 .27141 Mdot
.03676 .31325 Mdot
.03686 .34987 Mdot
.03695 .3819 Mdot
.03705 .40993 Mdot
.03714 .43446 Mdot
.03724 .45592 Mdot
.03733 .34491 Mdot
.03743 .37757 Mdot
.03752 .28615 Mdot
.03762 .21758 Mdot
.03771 .16616 Mdot
.03781 .12759 Mdot
.0379 .09866 Mdot
.038 .07697 Mdot
.0381 .14312 Mdot
.03819 .201 Mdot
.03829 .15372 Mdot
.03838 .11826 Mdot
.03848 .17925 Mdot
.03857 .23261 Mdot
.03867 .17743 Mdot
.03876 .23102 Mdot
.03886 .27791 Mdot
.03895 .2114 Mdot
.03905 .16152 Mdot
.03914 .2171 Mdot
.03924 .26573 Mdot
.03933 .20227 Mdot
.03943 .15467 Mdot
.03952 .21111 Mdot
.03962 .26049 Mdot
.03971 .3037 Mdot
.03981 .23074 Mdot
.0399 .17603 Mdot
.04 .13499 Mdot
.0401 .19389 Mdot
.04019 .24542 Mdot
.04029 .29051 Mdot
.04038 .32997 Mdot
.04048 .25045 Mdot
.04057 .29491 Mdot
.04067 .33381 Mdot
.04076 .36786 Mdot
.04086 .39764 Mdot
.04095 .42371 Mdot
.04105 .44651 Mdot
.04114 .33785 Mdot
.04124 .37139 Mdot
.04133 .28151 Mdot
.04143 .32209 Mdot
.04152 .3576 Mdot
.04162 .38867 Mdot
.04171 .29447 Mdot
.04181 .33343 Mdot
.0419 .25305 Mdot
.042 .29718 Mdot
.0421 .22586 Mdot
.04219 .2734 Mdot
.04229 .31499 Mdot
.04238 .23921 Mdot
.04248 .28508 Mdot
.04257 .32521 Mdot
.04267 .24688 Mdot
.04276 .18813 Mdot
.04286 .24038 Mdot
.04295 .28611 Mdot
.04305 .21755 Mdot
.04314 .16613 Mdot
.04324 .22114 Mdot
.04333 .26926 Mdot
.04343 .31137 Mdot
.04352 .34822 Mdot
.04362 .38046 Mdot
.04371 .40867 Mdot
.04381 .43336 Mdot
.0439 .32799 Mdot
.044 .36276 Mdot
.0441 .39318 Mdot
.04419 .4198 Mdot
.04429 .31782 Mdot
.04438 .24134 Mdot
.04448 .18398 Mdot
.04457 .14095 Mdot
.04467 .1991 Mdot
.04476 .1523 Mdot
.04486 .20903 Mdot
.04495 .25867 Mdot
.04505 .19697 Mdot
.04514 .24812 Mdot
.04524 .29287 Mdot
.04533 .22263 Mdot
.04543 .27057 Mdot
.04552 .2059 Mdot
.04562 .15739 Mdot
.04571 .12102 Mdot
.04581 .18166 Mdot
.0459 .23472 Mdot
.046 .28115 Mdot
.0461 .32177 Mdot
.04619 .2443 Mdot
.04629 .28953 Mdot
.04638 .32911 Mdot
.04648 .2498 Mdot
.04657 .29435 Mdot
.04667 .33332 Mdot
.04676 .36743 Mdot
.04686 .27854 Mdot
.04695 .21188 Mdot
.04705 .16188 Mdot
.04714 .12438 Mdot
.04724 .09626 Mdot
.04733 .15999 Mdot
.04743 .12297 Mdot
.04752 .18336 Mdot
.04762 .14049 Mdot
.04771 .1987 Mdot
.04781 .24963 Mdot
.0479 .2942 Mdot
.048 .22362 Mdot
.0481 .27144 Mdot
.04819 .20655 Mdot
.04829 .2565 Mdot
.04838 .3002 Mdot
.04848 .22812 Mdot
.04857 .17406 Mdot
.04867 .13352 Mdot
.04876 .10311 Mdot
.04886 .0803 Mdot
.04895 .14604 Mdot
.04905 .20355 Mdot
.04914 .15563 Mdot
.04924 .1197 Mdot
.04933 .1805 Mdot
.04943 .13835 Mdot
.04952 .19682 Mdot
.04962 .24799 Mdot
.04971 .18896 Mdot
.04981 .14469 Mdot
.0499 .11149 Mdot
.05 .17332 Mdot
.0501 .13296 Mdot
.05019 .19211 Mdot
.05029 .14706 Mdot
.05038 .11326 Mdot
.05048 .17487 Mdot
.05057 .13413 Mdot
.05067 .10357 Mdot
.05076 .16639 Mdot
.05086 .22136 Mdot
.05095 .16899 Mdot
.05105 .12971 Mdot
.05114 .18927 Mdot
.05124 .14492 Mdot
.05133 .20258 Mdot
.05143 .25302 Mdot
.05152 .19274 Mdot
.05162 .24441 Mdot
.05171 .28963 Mdot
.05181 .3292 Mdot
.0519 .24987 Mdot
.052 .19037 Mdot
.0521 .24234 Mdot
.05219 .18473 Mdot
.05229 .14152 Mdot
.05238 .1996 Mdot
.05248 .25042 Mdot
.05257 .29488 Mdot
.05267 .33379 Mdot
.05276 .25331 Mdot
.05286 .29742 Mdot
.05295 .22604 Mdot
.05305 .27355 Mdot
.05314 .31512 Mdot
.05324 .23931 Mdot
.05333 .28517 Mdot
.05343 .21685 Mdot
.05352 .26551 Mdot
.05362 .2021 Mdot
.05371 .25261 Mdot
.05381 .19243 Mdot
.0539 .24414 Mdot
.054 .28939 Mdot
.0541 .32899 Mdot
.05419 .24971 Mdot
.05429 .29427 Mdot
.05438 .33325 Mdot
.05448 .25291 Mdot
.05457 .29707 Mdot
.05467 .3357 Mdot
.05476 .36951 Mdot
.05486 .39909 Mdot
.05495 .42497 Mdot
.05505 .44762 Mdot
.05514 .46743 Mdot
.05524 .35355 Mdot
.05533 .38512 Mdot
.05543 .29181 Mdot
.05552 .22183 Mdot
.05562 .16934 Mdot
.05571 .12998 Mdot
.05581 .10046 Mdot
.0559 .16367 Mdot
.056 .21898 Mdot
.0561 .26737 Mdot
.05619 .30972 Mdot
.05629 .23526 Mdot
.05638 .17942 Mdot
.05648 .23276 Mdot
.05657 .17754 Mdot
.05667 .23112 Mdot
.05676 .17631 Mdot
.05686 .1352 Mdot
.05695 .19407 Mdot
.05705 .14852 Mdot
.05714 .11436 Mdot
.05724 .17584 Mdot
.05733 .22963 Mdot
.05743 .27669 Mdot
.05752 .21049 Mdot
.05762 .16084 Mdot
.05771 .1236 Mdot
.05781 .18392 Mdot
.0579 .14091 Mdot
.058 .10865 Mdot
.0581 .17084 Mdot
.05819 .22525 Mdot
.05829 .27287 Mdot
.05838 .31453 Mdot
.05848 .35098 Mdot
.05857 .38288 Mdot
.05867 .41078 Mdot
.05876 .43521 Mdot
.05886 .45657 Mdot
.05895 .3454 Mdot
.05905 .26202 Mdot
.05914 .30504 Mdot
.05924 .23175 Mdot
.05933 .27855 Mdot
.05943 .21188 Mdot
.05952 .26117 Mdot
.05962 .30429 Mdot
.05971 .34202 Mdot
.05981 .37504 Mdot
.0599 .28425 Mdot
.06 .32449 Mdot
.0601 .24634 Mdot
.06019 .18772 Mdot
.06029 .24003 Mdot
.06038 .28579 Mdot
.06048 .32584 Mdot
.06057 .36088 Mdot
.06067 .27363 Mdot
.06076 .20819 Mdot
.06086 .15912 Mdot
.06095 .12231 Mdot
.06105 .18279 Mdot
.06114 .23571 Mdot
.06124 .28201 Mdot
.06133 .21448 Mdot
.06143 .16383 Mdot
.06152 .21912 Mdot
.06162 .16731 Mdot
.06171 .22217 Mdot
.06181 .1696 Mdot
.0619 .22417 Mdot
.062 .1711 Mdot
.0621 .22548 Mdot
.06219 .27306 Mdot
.06229 .3147 Mdot
.06238 .35113 Mdot
.06248 .26632 Mdot
.06257 .20271 Mdot
.06267 .155 Mdot
.06276 .2114 Mdot
.06286 .26074 Mdot
.06295 .30392 Mdot
.06305 .23091 Mdot
.06314 .17615 Mdot
.06324 .2299 Mdot
.06333 .1754 Mdot
.06343 .13452 Mdot
.06352 .19347 Mdot
.06362 .14808 Mdot
.06371 .11403 Mdot
.06381 .17554 Mdot
.0639 .13463 Mdot
.064 .10394 Mdot
.0641 .16672 Mdot
.06419 .12801 Mdot
.06429 .09898 Mdot
.06438 .07721 Mdot
.06448 .14332 Mdot
.06457 .20118 Mdot
.06467 .2518 Mdot
.06476 .29609 Mdot
.06486 .22504 Mdot
.06495 .17175 Mdot
.06505 .22605 Mdot
.06514 .17251 Mdot
.06524 .13235 Mdot
.06533 .19158 Mdot
.06543 .2434 Mdot
.06552 .18552 Mdot
.06562 .2381 Mdot
.06571 .28411 Mdot
.06581 .32436 Mdot
.0659 .24624 Mdot
.066 .29123 Mdot
.0661 .22139 Mdot
.06619 .16902 Mdot
.06629 .12973 Mdot
.06638 .18929 Mdot
.06648 .14494 Mdot
.06657 .11167 Mdot
.06667 .08673 Mdot
.06676 .15165 Mdot
.06686 .20847 Mdot
.06695 .15932 Mdot
.06705 .12246 Mdot
.06714 .18292 Mdot
.06724 .23583 Mdot
.06733 .17984 Mdot
.06743 .23313 Mdot
.06752 .27976 Mdot
.06762 .21279 Mdot
.06771 .16256 Mdot
.06781 .21801 Mdot
.0679 .26653 Mdot
.068 .30898 Mdot
.0681 .34613 Mdot
.06819 .37863 Mdot
.06829 .28694 Mdot
.06838 .21818 Mdot
.06848 .16661 Mdot
.06857 .22155 Mdot
.06867 .26962 Mdot
.06876 .31169 Mdot
.06886 .3485 Mdot
.06895 .26434 Mdot
.06905 .30707 Mdot
.06914 .23327 Mdot
.06924 .27988 Mdot
.06933 .32067 Mdot
.06943 .35635 Mdot
.06952 .38758 Mdot
.06962 .4149 Mdot
.06971 .4388 Mdot
.06981 .33207 Mdot
.0699 .25203 Mdot
.07 .29629 Mdot
.0701 .22519 Mdot
.07019 .17186 Mdot
.07029 .13187 Mdot
.07038 .19115 Mdot
.07048 .24303 Mdot
.07057 .18524 Mdot
.07067 .23786 Mdot
.07076 .18136 Mdot
.07086 .13899 Mdot
.07095 .19739 Mdot
.07105 .24848 Mdot
.07114 .18933 Mdot
.07124 .14497 Mdot
.07133 .20262 Mdot
.07143 .25306 Mdot
.07152 .19277 Mdot
.07162 .14755 Mdot
.07171 .20487 Mdot
.07181 .15662 Mdot
.0719 .12044 Mdot
.072 .0933 Mdot
.0721 .15741 Mdot
.07219 .2135 Mdot
.07229 .26258 Mdot
.07238 .19991 Mdot
.07248 .25069 Mdot
.07257 .19099 Mdot
.07267 .14621 Mdot
.07276 .2037 Mdot
.07286 .15575 Mdot
.07295 .21205 Mdot
.07305 .16201 Mdot
.07314 .21753 Mdot
.07324 .2661 Mdot
.07333 .20255 Mdot
.07343 .253 Mdot
.07352 .19272 Mdot
.07362 .14751 Mdot
.07371 .11361 Mdot
.07381 .17517 Mdot
.0739 .22905 Mdot
.074 .27618 Mdot
.0741 .31743 Mdot
.07419 .35352 Mdot
.07429 .3851 Mdot
.07438 .41273 Mdot
.07448 .43691 Mdot
.07457 .45806 Mdot
.07467 .47657 Mdot
.07476 .49277 Mdot
.07486 .37255 Mdot
.07495 .28238 Mdot
.07505 .32285 Mdot
.07514 .24511 Mdot
.07524 .29024 Mdot
.07533 .22065 Mdot
.07543 .26884 Mdot
.07552 .2046 Mdot
.07562 .15642 Mdot
.07571 .21264 Mdot
.07581 .26183 Mdot
.0759 .19934 Mdot
.076 .15248 Mdot
.0761 .11733 Mdot
.07619 .17843 Mdot
.07629 .2319 Mdot
.07638 .17689 Mdot
.07648 .23055 Mdot
.07657 .17588 Mdot
.07667 .22967 Mdot
.07676 .17522 Mdot
.07686 .22909 Mdot
.07695 .27622 Mdot
.07705 .31746 Mdot
.07714 .35355 Mdot
.07724 .38512 Mdot
.07733 .29181 Mdot
.07743 .33111 Mdot
.07752 .2513 Mdot
.07762 .29566 Mdot
.07771 .22471 Mdot
.07781 .27239 Mdot
.0779 .31411 Mdot
.078 .35062 Mdot
.0781 .26593 Mdot
.07819 .30846 Mdot
.07829 .34567 Mdot
.07838 .37823 Mdot
.07848 .40672 Mdot
.07857 .43165 Mdot
.07867 .32671 Mdot
.07876 .36164 Mdot
.07886 .2742 Mdot
.07895 .31569 Mdot
.07905 .23974 Mdot
.07914 .28554 Mdot
.07924 .32562 Mdot
.07933 .36068 Mdot
.07943 .27348 Mdot
.07952 .20808 Mdot
.07962 .25784 Mdot
.07971 .19635 Mdot
.07981 .15024 Mdot
.0799 .20723 Mdot
.08 .25709 Mdot
.0801 .19579 Mdot
.08019 .14981 Mdot
.08029 .20686 Mdot
.08038 .15811 Mdot
.08048 .21412 Mdot
.08057 .26312 Mdot
.08067 .306 Mdot
.08076 .23247 Mdot
.08086 .27918 Mdot
.08095 .21236 Mdot
.08105 .16224 Mdot
.08114 .12465 Mdot
.08124 .09646 Mdot
.08133 .07532 Mdot
.08143 .14167 Mdot
.08152 .19973 Mdot
.08162 .25053 Mdot
.08171 .29498 Mdot
.08181 .22421 Mdot
.0819 .27195 Mdot
.082 .31373 Mdot
.0821 .35028 Mdot
.08219 .38226 Mdot
.08229 .28967 Mdot
.08238 .32923 Mdot
.08248 .24989 Mdot
.08257 .19039 Mdot
.08267 .14576 Mdot
.08276 .11229 Mdot
.08286 .17403 Mdot
.08295 .22804 Mdot
.08305 .174 Mdot
.08314 .22802 Mdot
.08324 .17399 Mdot
.08333 .13346 Mdot
.08343 .19255 Mdot
.08352 .24425 Mdot
.08362 .18616 Mdot
.08371 .23866 Mdot
.08381 .18196 Mdot
.0839 .23499 Mdot
.084 .17921 Mdot
.0841 .23258 Mdot
.08419 .17741 Mdot
.08429 .231 Mdot
.08438 .27789 Mdot
.08448 .31892 Mdot
.08457 .35483 Mdot
.08467 .26909 Mdot
.08476 .31122 Mdot
.08486 .23639 Mdot
.08495 .28261 Mdot
.08505 .32305 Mdot
.08514 .35844 Mdot
.08524 .2718 Mdot
.08533 .20682 Mdot
.08543 .25674 Mdot
.08552 .30041 Mdot
.08562 .33863 Mdot
.08571 .37207 Mdot
.08581 .28202 Mdot
.0859 .21449 Mdot
.086 .16384 Mdot
.0861 .21913 Mdot
.08619 .2675 Mdot
.08629 .30984 Mdot
.08638 .34687 Mdot
.08648 .37928 Mdot
.08657 .40764 Mdot
.08667 .43246 Mdot
.08676 .32731 Mdot
.08686 .24846 Mdot
.08695 .18931 Mdot
.08705 .14496 Mdot
.08714 .11169 Mdot
.08724 .08674 Mdot
.08733 .15166 Mdot
.08743 .20847 Mdot
.08752 .25818 Mdot
.08762 .19661 Mdot
.08771 .15043 Mdot
.08781 .11579 Mdot
.0879 .17709 Mdot
.088 .13579 Mdot
.0881 .19458 Mdot
.08819 .14891 Mdot
.08829 .11465 Mdot
.08838 .17609 Mdot
.08848 .13504 Mdot
.08857 .10425 Mdot
.08867 .16699 Mdot
.08876 .22188 Mdot
.08886 .26992 Mdot
.08895 .31194 Mdot
.08905 .23693 Mdot
.08914 .28308 Mdot
.08924 .32347 Mdot
.08933 .24557 Mdot
.08943 .18715 Mdot
.08952 .23952 Mdot
.08962 .18261 Mdot
.08971 .13993 Mdot
.08981 .10792 Mdot
.0899 .08391 Mdot
.09 .06591 Mdot
.0901 .0524 Mdot
.09019 .12162 Mdot
.09029 .18218 Mdot
.09038 .13961 Mdot
.09048 .10768 Mdot
.09057 .08373 Mdot
.09067 .14903 Mdot
.09076 .20617 Mdot
.09086 .1576 Mdot
.09095 .21367 Mdot
.09105 .26273 Mdot
.09114 .30566 Mdot
.09124 .23221 Mdot
.09133 .17713 Mdot
.09143 .13582 Mdot
.09152 .19461 Mdot
.09162 .14893 Mdot
.09171 .11467 Mdot
.09181 .1761 Mdot
.0919 .13505 Mdot
.092 .19394 Mdot
.0921 .24546 Mdot
.09219 .29055 Mdot
.09229 .33 Mdot
.09238 .36452 Mdot
.09248 .27636 Mdot
.09257 .21024 Mdot
.09267 .25973 Mdot
.09276 .19777 Mdot
.09286 .24882 Mdot
.09295 .29348 Mdot
.09305 .22308 Mdot
.09314 .27097 Mdot
.09324 .31286 Mdot
.09333 .34952 Mdot
.09343 .26511 Mdot
.09352 .20181 Mdot
.09362 .15433 Mdot
.09371 .11872 Mdot
.09381 .17965 Mdot
.0939 .23296 Mdot
.094 .27961 Mdot
.0941 .21268 Mdot
.09419 .26186 Mdot
.09429 .19937 Mdot
.09438 .25021 Mdot
.09448 .29471 Mdot
.09457 .33364 Mdot
.09467 .3677 Mdot
.09476 .27875 Mdot
.09486 .21203 Mdot
.09495 .16199 Mdot
.09505 .12447 Mdot
.09514 .18468 Mdot
.09524 .23736 Mdot
.09533 .18099 Mdot
.09543 .23414 Mdot
.09552 .28064 Mdot
.09562 .21345 Mdot
.09571 .26254 Mdot
.09581 .19987 Mdot
.0959 .25066 Mdot
.096 .29509 Mdot
.0961 .22429 Mdot
.09619 .17119 Mdot
.09629 .22556 Mdot
.09638 .27313 Mdot
.09648 .31476 Mdot
.09657 .23904 Mdot
.09667 .28493 Mdot
.09676 .32508 Mdot
.09686 .24678 Mdot
.09695 .2917 Mdot
.09705 .22175 Mdot
.09714 .16928 Mdot
.09724 .22389 Mdot
.09733 .27167 Mdot
.09743 .20673 Mdot
.09752 .25665 Mdot
.09762 .19546 Mdot
.09771 .2468 Mdot
.09781 .29172 Mdot
.0979 .22176 Mdot
.098 .26981 Mdot
.0981 .20533 Mdot
.09819 .15697 Mdot
.09829 .21311 Mdot
.09838 .26224 Mdot
.09848 .30523 Mdot
.09857 .34285 Mdot
.09867 .26011 Mdot
.09876 .19805 Mdot
.09886 .15151 Mdot
.09895 .20834 Mdot
.09905 .25807 Mdot
.09914 .30158 Mdot
.09924 .33965 Mdot
.09933 .37296 Mdot
.09943 .40211 Mdot
.09952 .42761 Mdot
.09962 .32368 Mdot
.09971 .24573 Mdot
.09981 .29078 Mdot
.0999 .22106 Mdot
.1 .2692 Mdot
.1001 .31131 Mdot
.10019 .34817 Mdot
.10029 .38042 Mdot
.10038 .28828 Mdot
.10048 .32802 Mdot
.10057 .36278 Mdot
.10067 .3932 Mdot
.10076 .29787 Mdot
.10086 .33641 Mdot
.10095 .25528 Mdot
.10105 .29914 Mdot
.10114 .33751 Mdot
.10124 .37109 Mdot
.10133 .40047 Mdot
.10143 .42618 Mdot
.10152 .44868 Mdot
.10162 .46836 Mdot
.10171 .35424 Mdot
.10181 .26865 Mdot
.1019 .20446 Mdot
.102 .25467 Mdot
.1021 .19398 Mdot
.10219 .2455 Mdot
.10229 .29058 Mdot
.10238 .22091 Mdot
.10248 .26906 Mdot
.10257 .20477 Mdot
.10267 .25494 Mdot
.10276 .29884 Mdot
.10286 .33725 Mdot
.10295 .37087 Mdot
.10305 .40028 Mdot
.10314 .30318 Mdot
.10324 .23036 Mdot
.10333 .17574 Mdot
.10343 .22954 Mdot
.10352 .17513 Mdot
.10362 .13432 Mdot
.10371 .10371 Mdot
.10381 .16651 Mdot
.1039 .22147 Mdot
.104 .26955 Mdot
.1041 .31163 Mdot
.10419 .23669 Mdot
.10429 .28287 Mdot
.10438 .21513 Mdot
.10448 .16432 Mdot
.10457 .21955 Mdot
.10467 .26787 Mdot
.10476 .20387 Mdot
.10486 .25416 Mdot
.10495 .29816 Mdot
.10505 .33666 Mdot
.10514 .25546 Mdot
.10524 .19457 Mdot
.10533 .24602 Mdot
.10543 .29103 Mdot
.10552 .22125 Mdot
.10562 .26936 Mdot
.10571 .20499 Mdot
.10581 .25514 Mdot
.1059 .29901 Mdot
.106 .3374 Mdot
.1061 .25602 Mdot
.10619 .19499 Mdot
.10629 .14921 Mdot
.10638 .20633 Mdot
.10648 .25631 Mdot
.10657 .30004 Mdot
.10667 .3383 Mdot
.10676 .37178 Mdot
.10686 .40108 Mdot
.10695 .30378 Mdot
.10705 .34158 Mdot
.10714 .37465 Mdot
.10724 .40359 Mdot
.10733 .42891 Mdot
.10743 .45106 Mdot
.10752 .47045 Mdot
.10762 .35581 Mdot
.10771 .3871 Mdot
.10781 .41448 Mdot
.1079 .43844 Mdot
.108 .4594 Mdot
.1081 .47775 Mdot
.10819 .4938 Mdot
.10829 .50784 Mdot
.10838 .52013 Mdot
.10848 .53088 Mdot
.10857 .54029 Mdot
.10867 .54852 Mdot
.10876 .55573 Mdot
.10886 .56203 Mdot
.10895 .56754 Mdot
.10905 .57237 Mdot
.10914 .57659 Mdot
.10924 .58029 Mdot
.10933 .43819 Mdot
.10943 .45918 Mdot
.10952 .34736 Mdot
.10962 .26349 Mdot
.10971 .20059 Mdot
.10981 .15341 Mdot
.1099 .11803 Mdot
.11 .17905 Mdot
.1101 .13726 Mdot
.11019 .19587 Mdot
.11029 .24715 Mdot
.11038 .29203 Mdot
.11048 .22199 Mdot
.11057 .16946 Mdot
.11067 .22405 Mdot
.11076 .27181 Mdot
.11086 .3136 Mdot
.11095 .35017 Mdot
.11105 .38217 Mdot
.11114 .2896 Mdot
.11124 .22017 Mdot
.11133 .26842 Mdot
.11143 .31063 Mdot
.11152 .34757 Mdot
.11162 .26365 Mdot
.11171 .30646 Mdot
.11181 .23282 Mdot
.1119 .17759 Mdot
.112 .13616 Mdot
.1121 .10509 Mdot
.11219 .16772 Mdot
.11229 .22253 Mdot
.11238 .27048 Mdot
.11248 .20583 Mdot
.11257 .15734 Mdot
.11267 .21345 Mdot
.11276 .26253 Mdot
.11286 .19987 Mdot
.11295 .25066 Mdot
.11305 .29509 Mdot
.11314 .22429 Mdot
.11324 .17119 Mdot
.11333 .13136 Mdot
.11343 .10149 Mdot
.11352 .07909 Mdot
.11362 .14497 Mdot
.11371 .20262 Mdot
.11381 .25306 Mdot
.1139 .19277 Mdot
.114 .14755 Mdot
.1141 .11363 Mdot
.11419 .1752 Mdot
.11429 .22907 Mdot
.11438 .2762 Mdot
.11448 .21012 Mdot
.11457 .25963 Mdot
.11467 .19769 Mdot
.11476 .15124 Mdot
.11486 .2081 Mdot
.11495 .25786 Mdot
.11505 .30139 Mdot
.11514 .22902 Mdot
.11524 .27616 Mdot
.11533 .31741 Mdot
.11543 .3535 Mdot
.11552 .38508 Mdot
.11562 .29178 Mdot
.11571 .22181 Mdot
.11581 .16933 Mdot
.1159 .12997 Mdot
.116 .18949 Mdot
.1161 .14509 Mdot
.11619 .20272 Mdot
.11629 .25315 Mdot
.11638 .29727 Mdot
.11648 .22593 Mdot
.11657 .17242 Mdot
.11667 .13228 Mdot
.11676 .19152 Mdot
.11686 .14661 Mdot
.11695 .11293 Mdot
.11705 .08767 Mdot
.11714 .15248 Mdot
.11724 .11733 Mdot
.11733 .17843 Mdot
.11743 .2319 Mdot
.11752 .17689 Mdot
.11762 .23055 Mdot
.11771 .17588 Mdot
.11781 .22967 Mdot
.1179 .17522 Mdot
.118 .22909 Mdot
.1181 .17479 Mdot
.11819 .22871 Mdot
.11829 .1745 Mdot
.11838 .22846 Mdot
.11848 .17431 Mdot
.11857 .13371 Mdot
.11867 .10325 Mdot
.11876 .16611 Mdot
.11886 .12756 Mdot
.11895 .09864 Mdot
.11905 .16208 Mdot
.11914 .12453 Mdot
.11924 .09637 Mdot
.11933 .16009 Mdot
.11943 .21585 Mdot
.11952 .26464 Mdot
.11962 .20145 Mdot
.11971 .25204 Mdot
.11981 .2963 Mdot
.1199 .2252 Mdot
.12 .27282 Mdot
.1201 .31448 Mdot
.12019 .35094 Mdot
.12029 .26618 Mdot
.12038 .30867 Mdot
.12048 .34586 Mdot
.12057 .26236 Mdot
.12067 .30534 Mdot
.12076 .23197 Mdot
.12086 .27875 Mdot
.12095 .31967 Mdot
.12105 .24272 Mdot
.12114 .28815 Mdot
.12124 .21909 Mdot
.12133 .26747 Mdot
.12143 .3098 Mdot
.12152 .23532 Mdot
.12162 .17946 Mdot
.12171 .13757 Mdot
.12181 .10615 Mdot
.1219 .16865 Mdot
.122 .22334 Mdot
.1221 .27119 Mdot
.12219 .20636 Mdot
.12229 .15774 Mdot
.12238 .21379 Mdot
.12248 .26284 Mdot
.12257 .30575 Mdot
.12267 .3433 Mdot
.12276 .26045 Mdot
.12286 .19831 Mdot
.12295 .24929 Mdot
.12305 .29389 Mdot
.12314 .22339 Mdot
.12324 .27124 Mdot
.12333 .2064 Mdot
.12343 .25637 Mdot
.12352 .19525 Mdot
.12362 .14941 Mdot
.12371 .2065 Mdot
.12381 .15785 Mdot
.1239 .21388 Mdot
.124 .16338 Mdot
.1241 .21873 Mdot
.12419 .26716 Mdot
.12429 .20334 Mdot
.12438 .15548 Mdot
.12448 .11958 Mdot
.12457 .1804 Mdot
.12467 .13827 Mdot
.12476 .19676 Mdot
.12486 .24793 Mdot
.12495 .29271 Mdot
.12505 .2225 Mdot
.12514 .27046 Mdot
.12524 .20581 Mdot
.12533 .25586 Mdot
.12543 .29964 Mdot
.12552 .33796 Mdot
.12562 .37148 Mdot
.12571 .40081 Mdot
.12581 .42648 Mdot
.1259 .32283 Mdot
.126 .2451 Mdot
.1261 .18679 Mdot
.12619 .23921 Mdot
.12629 .28508 Mdot
.12638 .21678 Mdot
.12648 .16556 Mdot
.12657 .22063 Mdot
.12667 .16844 Mdot
.12676 .22316 Mdot
.12686 .17034 Mdot
.12695 .22482 Mdot
.12705 .27248 Mdot
.12714 .31419 Mdot
.12724 .35069 Mdot
.12733 .38262 Mdot
.12743 .28994 Mdot
.12752 .22042 Mdot
.12762 .16829 Mdot
.12771 .22302 Mdot
.12781 .27091 Mdot
.1279 .20616 Mdot
.128 .25615 Mdot
.1281 .2999 Mdot
.12819 .2279 Mdot
.12829 .1739 Mdot
.12838 .22793 Mdot
.12848 .17392 Mdot
.12857 .13341 Mdot
.12867 .10303 Mdot
.12876 .16592 Mdot
.12886 .22095 Mdot
.12895 .2691 Mdot
.12905 .31123 Mdot
.12914 .34809 Mdot
.12924 .38035 Mdot
.12933 .28823 Mdot
.12943 .32797 Mdot
.12952 .36275 Mdot
.12962 .27503 Mdot
.12971 .31642 Mdot
.12981 .24029 Mdot
.1299 .18319 Mdot
.13 .14036 Mdot
.1301 .19858 Mdot
.13019 .15191 Mdot
.13029 .20869 Mdot
.13038 .15949 Mdot
.13048 .12259 Mdot
.13057 .18303 Mdot
.13067 .23592 Mdot
.13076 .2822 Mdot
.13086 .32269 Mdot
.13095 .35813 Mdot
.13105 .38913 Mdot
.13114 .41626 Mdot
.13124 .43999 Mdot
.13133 .33297 Mdot
.13143 .36711 Mdot
.13152 .27831 Mdot
.13162 .31929 Mdot
.13171 .35514 Mdot
.13181 .26933 Mdot
.1319 .20497 Mdot
.132 .25512 Mdot
.1321 .299 Mdot
.13219 .22722 Mdot
.13229 .17338 Mdot
.13238 .13301 Mdot
.13248 .19215 Mdot
.13257 .14709 Mdot
.13267 .11329 Mdot
.13276 .08794 Mdot
.13286 .15271 Mdot
.13295 .20939 Mdot
.13305 .16002 Mdot
.13314 .12298 Mdot
.13324 .18338 Mdot
.13333 .14051 Mdot
.13343 .19871 Mdot
.13352 .152 Mdot
.13362 .20877 Mdot
.13371 .15955 Mdot
.13381 .21538 Mdot
.1339 .26422 Mdot
.134 .30696 Mdot
.1341 .23319 Mdot
.13419 .27981 Mdot
.13429 .21283 Mdot
.13438 .16259 Mdot
.13448 .12492 Mdot
.13457 .18507 Mdot
.13467 .23771 Mdot
.13476 .28376 Mdot
.13486 .21579 Mdot
.13495 .26459 Mdot
.13505 .20141 Mdot
.13514 .252 Mdot
.13524 .29627 Mdot
.13533 .22518 Mdot
.13543 .2728 Mdot
.13552 .31447 Mdot
.13562 .35093 Mdot
.13571 .26617 Mdot
.13581 .2026 Mdot
.1359 .25304 Mdot
.136 .29718 Mdot
.1361 .22586 Mdot
.13619 .27339 Mdot
.13629 .31499 Mdot
.13638 .35138 Mdot
.13648 .38323 Mdot
.13657 .41109 Mdot
.13667 .43547 Mdot
.13676 .32958 Mdot
.13686 .36415 Mdot
.13695 .3944 Mdot
.13705 .29877 Mdot
.13714 .33719 Mdot
.13724 .25587 Mdot
.13733 .29965 Mdot
.13743 .22771 Mdot
.13752 .27501 Mdot
.13762 .20923 Mdot
.13771 .1599 Mdot
.13781 .21568 Mdot
.1379 .26449 Mdot
.138 .20134 Mdot
.1381 .25194 Mdot
.13819 .19192 Mdot
.13829 .2437 Mdot
.13838 .28901 Mdot
.13848 .21973 Mdot
.13857 .16777 Mdot
.13867 .22256 Mdot
.13876 .16989 Mdot
.13886 .13039 Mdot
.13895 .18986 Mdot
.13905 .2419 Mdot
.13914 .28743 Mdot
.13924 .21854 Mdot
.13933 .26699 Mdot
.13943 .20322 Mdot
.13952 .15538 Mdot
.13962 .21173 Mdot
.13971 .16177 Mdot
.13981 .1243 Mdot
.1399 .18453 Mdot
.14 .14137 Mdot
.1401 .109 Mdot
.14019 .08472 Mdot
.14029 .1499 Mdot
.14038 .20693 Mdot
.14048 .25683 Mdot
.14057 .3005 Mdot
.14067 .3387 Mdot
.14076 .257 Mdot
.14086 .30064 Mdot
.14095 .22845 Mdot
.14105 .17431 Mdot
.14114 .1337 Mdot
.14124 .19276 Mdot
.14133 .24443 Mdot
.14143 .1863 Mdot
.14152 .23878 Mdot
.14162 .2847 Mdot
.14171 .2165 Mdot
.14181 .2652 Mdot
.1419 .30782 Mdot
.142 .23384 Mdot
.1421 .17835 Mdot
.14219 .23182 Mdot
.14229 .17684 Mdot
.14238 .2305 Mdot
.14248 .17585 Mdot
.14257 .13486 Mdot
.14267 .10411 Mdot
.14276 .16687 Mdot
.14286 .22178 Mdot
.14295 .16931 Mdot
.14305 .22391 Mdot
.14314 .27169 Mdot
.14324 .3135 Mdot
.14333 .23809 Mdot
.14343 .2841 Mdot
.14352 .32436 Mdot
.14362 .35958 Mdot
.14371 .27266 Mdot
.14381 .31434 Mdot
.1439 .35082 Mdot
.144 .38274 Mdot
.1441 .29002 Mdot
.14419 .22049 Mdot
.14429 .16834 Mdot
.14438 .22306 Mdot
.14448 .27095 Mdot
.14457 .20618 Mdot
.14467 .15761 Mdot
.14476 .21368 Mdot
.14486 .16323 Mdot
.14495 .12539 Mdot
.14505 .09702 Mdot
.14514 .16066 Mdot
.14524 .21634 Mdot
.14533 .26507 Mdot
.14543 .20177 Mdot
.14552 .1543 Mdot
.14562 .21078 Mdot
.14571 .2602 Mdot
.14581 .19812 Mdot
.1459 .15156 Mdot
.146 .11664 Mdot
.1461 .17783 Mdot
.14619 .23137 Mdot
.14629 .1765 Mdot
.14638 .23021 Mdot
.14648 .17563 Mdot
.14657 .22944 Mdot
.14667 .17505 Mdot
.14676 .13426 Mdot
.14686 .19325 Mdot
.14695 .24486 Mdot
.14705 .18662 Mdot
.14714 .23906 Mdot
.14724 .28494 Mdot
.14733 .21668 Mdot
.14743 .16548 Mdot
.14752 .22056 Mdot
.14762 .16839 Mdot
.14771 .22311 Mdot
.14781 .27099 Mdot
.1479 .20622 Mdot
.148 .25621 Mdot
.1481 .19513 Mdot
.14819 .2465 Mdot
.14829 .29146 Mdot
.14838 .22157 Mdot
.14848 .26964 Mdot
.14857 .2052 Mdot
.14867 .15687 Mdot
.14876 .21303 Mdot
.14886 .26217 Mdot
.14895 .1996 Mdot
.14905 .15267 Mdot
.14914 .20936 Mdot
.14924 .15999 Mdot
.14933 .12296 Mdot
.14943 .18336 Mdot
.14952 .14049 Mdot
.14962 .10834 Mdot
.14971 .17057 Mdot
.14981 .1309 Mdot
.1499 .10114 Mdot
.15 .16427 Mdot
.1501 .12617 Mdot
.15019 .0976 Mdot
.15029 .16117 Mdot
.15038 .12385 Mdot
.15048 .18414 Mdot
.15057 .23689 Mdot
.15067 .18064 Mdot
.15076 .23383 Mdot
.15086 .17834 Mdot
.15095 .13673 Mdot
.15105 .1954 Mdot
.15114 .24675 Mdot
.15124 .29167 Mdot
.15133 .33098 Mdot
.15143 .36538 Mdot
.15152 .277 Mdot
.15162 .21072 Mdot
.15171 .26015 Mdot
.15181 .19809 Mdot
.1519 .24909 Mdot
.152 .18979 Mdot
.1521 .24184 Mdot
.15219 .18435 Mdot
.15229 .14123 Mdot
.15238 .1089 Mdot
.15248 .17105 Mdot
.15257 .22544 Mdot
.15267 .17205 Mdot
.15276 .22631 Mdot
.15286 .17271 Mdot
.15295 .1325 Mdot
.15305 .19171 Mdot
.15314 .24351 Mdot
.15324 .18561 Mdot
.15333 .23817 Mdot
.15343 .28417 Mdot
.15352 .32442 Mdot
.15362 .35963 Mdot
.15371 .39045 Mdot
.15381 .41741 Mdot
.1539 .441 Mdot
.154 .46165 Mdot
.1541 .34921 Mdot
.15419 .26488 Mdot
.15429 .20163 Mdot
.15438 .25219 Mdot
.15448 .29644 Mdot
.15457 .33515 Mdot
.15467 .25433 Mdot
.15476 .29831 Mdot
.15486 .33679 Mdot
.15495 .37046 Mdot
.15505 .39992 Mdot
.15514 .4257 Mdot
.15524 .32225 Mdot
.15533 .35773 Mdot
.15543 .38879 Mdot
.15552 .29456 Mdot
.15562 .33351 Mdot
.15571 .36759 Mdot
.15581 .27866 Mdot
.1559 .21197 Mdot
.156 .26124 Mdot
.1561 .1989 Mdot
.15619 .15215 Mdot
.15629 .11708 Mdot
.15638 .17822 Mdot
.15648 .13663 Mdot
.15657 .19532 Mdot
.15667 .24668 Mdot
.15676 .18798 Mdot
.15686 .14395 Mdot
.15695 .20173 Mdot
.15705 .15427 Mdot
.15714 .11867 Mdot
.15724 .09198 Mdot
.15733 .15625 Mdot
.15743 .21248 Mdot
.15752 .26169 Mdot
.15762 .30475 Mdot
.15771 .34242 Mdot
.15781 .25979 Mdot
.1579 .19781 Mdot
.158 .15133 Mdot
.1581 .20818 Mdot
.15819 .15911 Mdot
.15829 .21499 Mdot
.15838 .26388 Mdot
.15848 .30667 Mdot
.15857 .3441 Mdot
.15867 .26105 Mdot
.15876 .30419 Mdot
.15886 .23111 Mdot
.15895 .1763 Mdot
.15905 .23003 Mdot
.15914 .1755 Mdot
.15924 .22933 Mdot
.15933 .17497 Mdot
.15943 .1342 Mdot
.15952 .19319 Mdot
.15962 .24481 Mdot
.15971 .18658 Mdot
.15981 .23903 Mdot
.1599 .28492 Mdot
.16 .32507 Mdot
.1601 .3602 Mdot
.16019 .39095 Mdot
.16029 .41785 Mdot
.16038 .44139 Mdot
.16048 .33401 Mdot
.16057 .25348 Mdot
.16067 .29756 Mdot
.16076 .33614 Mdot
.16086 .36989 Mdot
.16095 .28039 Mdot
.16105 .21326 Mdot
.16114 .16292 Mdot
.16124 .21832 Mdot
.16133 .16671 Mdot
.16143 .12801 Mdot
.16152 .18777 Mdot
.16162 .24007 Mdot
.16171 .28583 Mdot
.16181 .21734 Mdot
.1619 .16598 Mdot
.162 .221 Mdot
.1621 .16872 Mdot
.16219 .12951 Mdot
.16229 .10011 Mdot
.16238 .07805 Mdot
.16248 .14406 Mdot
.16257 .20182 Mdot
.16267 .25236 Mdot
.16276 .29659 Mdot
.16286 .33528 Mdot
.16295 .25443 Mdot
.16305 .1938 Mdot
.16314 .14832 Mdot
.16324 .20555 Mdot
.16333 .15713 Mdot
.16343 .12082 Mdot
.16352 .18149 Mdot
.16362 .13909 Mdot
.16371 .10729 Mdot
.16381 .08344 Mdot
.1639 .14877 Mdot
.164 .20595 Mdot
.1641 .25597 Mdot
.16419 .19495 Mdot
.16429 .14918 Mdot
.16438 .2063 Mdot
.16448 .1577 Mdot
.16457 .21376 Mdot
.16467 .16329 Mdot
.16476 .21865 Mdot
.16486 .16696 Mdot
.16495 .22185 Mdot
.16505 .16936 Mdot
.16514 .22396 Mdot
.16524 .17094 Mdot
.16533 .22534 Mdot
.16543 .27294 Mdot
.16552 .20768 Mdot
.16562 .25749 Mdot
.16571 .19609 Mdot
.16581 .15004 Mdot
.1659 .20705 Mdot
.166 .25694 Mdot
.1661 .30059 Mdot
.16619 .33878 Mdot
.16629 .3722 Mdot
.16638 .40145 Mdot
.16648 .42704 Mdot
.16657 .44942 Mdot
.16667 .46902 Mdot
.16676 .48616 Mdot
.16686 .50116 Mdot
.16695 .37884 Mdot
.16705 .2871 Mdot
.16714 .32698 Mdot
.16724 .24821 Mdot
.16733 .18913 Mdot
.16743 .14482 Mdot
.16752 .20248 Mdot
.16762 .25294 Mdot
.16771 .19268 Mdot
.16781 .24436 Mdot
.1679 .18624 Mdot
.168 .14265 Mdot
.1681 .20059 Mdot
.16819 .15341 Mdot
.16829 .21001 Mdot
.16838 .25952 Mdot
.16848 .19761 Mdot
.16857 .24868 Mdot
.16867 .18948 Mdot
.16876 .24157 Mdot
.16886 .18415 Mdot
.16895 .2369 Mdot
.16905 .28305 Mdot
.16914 .32344 Mdot
.16924 .24555 Mdot
.16933 .29063 Mdot
.16943 .33007 Mdot
.16952 .36458 Mdot
.16962 .39477 Mdot
.16971 .42119 Mdot
.16981 .44431 Mdot
.1699 .33621 Mdot
.17 .36995 Mdot
.1701 .28043 Mdot
.17019 .2133 Mdot
.17029 .2624 Mdot
.17038 .30537 Mdot
.17048 .232 Mdot
.17057 .27877 Mdot
.17067 .31969 Mdot
.17076 .3555 Mdot
.17086 .26959 Mdot
.17095 .20517 Mdot
.17105 .25529 Mdot
.17114 .29915 Mdot
.17124 .33752 Mdot
.17133 .3711 Mdot
.17143 .2813 Mdot
.17152 .3219 Mdot
.17162 .2444 Mdot
.17171 .28962 Mdot
.17181 .32918 Mdot
.1719 .3638 Mdot
.172 .3941 Mdot
.1721 .29854 Mdot
.17219 .22688 Mdot
.17229 .27429 Mdot
.17238 .31577 Mdot
.17248 .35207 Mdot
.17257 .26702 Mdot
.17267 .20324 Mdot
.17276 .1554 Mdot
.17286 .21174 Mdot
.17295 .16178 Mdot
.17305 .12431 Mdot
.17314 .18454 Mdot
.17324 .14137 Mdot
.17333 .19947 Mdot
.17343 .15257 Mdot
.17352 .1174 Mdot
.17362 .1785 Mdot
.17371 .23195 Mdot
.17381 .17694 Mdot
.1739 .23059 Mdot
.174 .17591 Mdot
.1741 .22969 Mdot
.17419 .27675 Mdot
.17429 .31792 Mdot
.17438 .24141 Mdot
.17448 .18403 Mdot
.17457 .141 Mdot
.17467 .19914 Mdot
.17476 .15233 Mdot
.17486 .20905 Mdot
.17495 .15976 Mdot
.17505 .21556 Mdot
.17514 .26438 Mdot
.17524 .20126 Mdot
.17533 .15392 Mdot
.17543 .21044 Mdot
.17552 .25991 Mdot
.17562 .1979 Mdot
.17571 .1514 Mdot
.17581 .20824 Mdot
.1759 .15915 Mdot
.176 .21503 Mdot
.1761 .26392 Mdot
.17619 .3067 Mdot
.17629 .34413 Mdot
.17638 .26107 Mdot
.17648 .3042 Mdot
.17657 .34195 Mdot
.17667 .37497 Mdot
.17676 .40387 Mdot
.17686 .42915 Mdot
.17695 .32484 Mdot
.17705 .2466 Mdot
.17714 .18792 Mdot
.17724 .14391 Mdot
.17733 .20169 Mdot
.17743 .15424 Mdot
.17752 .11865 Mdot
.17762 .09196 Mdot
.17771 .15623 Mdot
.17781 .21247 Mdot
.1779 .26168 Mdot
.178 .19923 Mdot
.1781 .2501 Mdot
.17819 .19054 Mdot
.17829 .24249 Mdot
.17838 .28795 Mdot
.17848 .21894 Mdot
.17857 .16717 Mdot
.17867 .22204 Mdot
.17876 .27006 Mdot
.17886 .31207 Mdot
.17895 .34883 Mdot
.17905 .38099 Mdot
.17914 .40914 Mdot
.17924 .30983 Mdot
.17933 .34687 Mdot
.17943 .26312 Mdot
.17952 .306 Mdot
.17962 .34352 Mdot
.17971 .26061 Mdot
.17981 .19843 Mdot
.1799 .24939 Mdot
.18 .19002 Mdot
.1801 .24203 Mdot
.18019 .1845 Mdot
.18029 .2372 Mdot
.18038 .28332 Mdot
.18048 .21546 Mdot
.18057 .2643 Mdot
.18067 .30703 Mdot
.18076 .34442 Mdot
.18086 .37714 Mdot
.18095 .40576 Mdot
.18105 .30729 Mdot
.18114 .23344 Mdot
.18124 .28003 Mdot
.18133 .21299 Mdot
.18143 .16272 Mdot
.18152 .21815 Mdot
.18162 .26665 Mdot
.18171 .30908 Mdot
.18181 .23478 Mdot
.1819 .2812 Mdot
.182 .21387 Mdot
.1821 .16338 Mdot
.18219 .21872 Mdot
.18229 .26715 Mdot
.18238 .30953 Mdot
.18248 .3466 Mdot
.18257 .26292 Mdot
.18267 .30583 Mdot
.18276 .34337 Mdot
.18286 .37622 Mdot
.18295 .28513 Mdot
.18305 .21682 Mdot
.18314 .16559 Mdot
.18324 .22066 Mdot
.18333 .16846 Mdot
.18343 .22317 Mdot
.18352 .27105 Mdot
.18362 .31293 Mdot
.18371 .34959 Mdot
.18381 .38166 Mdot
.1839 .40972 Mdot
.184 .43427 Mdot
.1841 .32868 Mdot
.18419 .24948 Mdot
.18429 .19008 Mdot
.18438 .14553 Mdot
.18448 .20311 Mdot
.18457 .1553 Mdot
.18467 .21166 Mdot
.18476 .26097 Mdot
.18486 .30412 Mdot
.18495 .34187 Mdot
.18505 .25937 Mdot
.18514 .30272 Mdot
.18524 .23001 Mdot
.18533 .17548 Mdot
.18543 .22931 Mdot
.18552 .27642 Mdot
.18562 .31763 Mdot
.18571 .2412 Mdot
.18581 .28682 Mdot
.1859 .32673 Mdot
.186 .24802 Mdot
.1861 .18899 Mdot
.18619 .24113 Mdot
.18629 .28676 Mdot
.18638 .21804 Mdot
.18648 .26655 Mdot
.18657 .309 Mdot
.18667 .23472 Mdot
.18676 .28115 Mdot
.18686 .32178 Mdot
.18695 .2443 Mdot
.18705 .1862 Mdot
.18714 .14262 Mdot
.18724 .10994 Mdot
.18733 .17196 Mdot
.18743 .13194 Mdot
.18752 .19122 Mdot
.18762 .14639 Mdot
.18771 .11276 Mdot
.18781 .17443 Mdot
.1879 .2284 Mdot
.188 .27562 Mdot
.1881 .31693 Mdot
.18819 .35309 Mdot
.18829 .26779 Mdot
.18838 .20381 Mdot
.18848 .2541 Mdot
.18857 .19355 Mdot
.18867 .24512 Mdot
.18876 .29025 Mdot
.18886 .22066 Mdot
.18895 .26885 Mdot
.18905 .31101 Mdot
.18914 .23623 Mdot
.18924 .28247 Mdot
.18933 .32293 Mdot
.18943 .24517 Mdot
.18952 .18685 Mdot
.18962 .23926 Mdot
.18971 .28512 Mdot
.18981 .32525 Mdot
.1899 .36036 Mdot
.19 .39109 Mdot
.1901 .41797 Mdot
.19019 .31645 Mdot
.19029 .35266 Mdot
.19038 .38435 Mdot
.19048 .41207 Mdot
.19057 .43633 Mdot
.19067 .45756 Mdot
.19076 .34614 Mdot
.19086 .26258 Mdot
.19095 .30552 Mdot
.19105 .3431 Mdot
.19114 .37598 Mdot
.19124 .40475 Mdot
.19133 .30654 Mdot
.19143 .34399 Mdot
.19152 .37676 Mdot
.19162 .28554 Mdot
.19171 .32562 Mdot
.19181 .36068 Mdot
.1919 .39137 Mdot
.192 .41821 Mdot
.1921 .44171 Mdot
.19219 .46226 Mdot
.19229 .48025 Mdot
.19238 .49598 Mdot
.19248 .50976 Mdot
.19257 .38529 Mdot
.19267 .29194 Mdot
.19276 .22192 Mdot
.19286 .26995 Mdot
.19295 .31198 Mdot
.19305 .34875 Mdot
.19314 .26453 Mdot
.19324 .30723 Mdot
.19333 .3446 Mdot
.19343 .37729 Mdot
.19352 .4059 Mdot
.19362 .43093 Mdot
.19371 .45283 Mdot
.19381 .472 Mdot
.1939 .35697 Mdot
.194 .38812 Mdot
.1941 .41537 Mdot
.19419 .43922 Mdot
.19429 .33238 Mdot
.19438 .25226 Mdot
.19448 .19217 Mdot
.19457 .1471 Mdot
.19467 .20448 Mdot
.19476 .25469 Mdot
.19486 .29862 Mdot
.19495 .22694 Mdot
.19505 .27434 Mdot
.19514 .20872 Mdot
.19524 .2584 Mdot
.19533 .19677 Mdot
.19543 .24795 Mdot
.19552 .18893 Mdot
.19562 .14467 Mdot
.19571 .20235 Mdot
.19581 .15474 Mdot
.1959 .21116 Mdot
.196 .16134 Mdot
.1961 .21694 Mdot
.19619 .16568 Mdot
.19629 .22074 Mdot
.19638 .26891 Mdot
.19648 .20466 Mdot
.19657 .25484 Mdot
.19667 .1941 Mdot
.19676 .24561 Mdot
.19686 .18718 Mdot
.19695 .23955 Mdot
.19705 .28537 Mdot
.19714 .32547 Mdot
.19724 .24707 Mdot
.19733 .18828 Mdot
.19743 .24051 Mdot
.19752 .18335 Mdot
.19762 .14049 Mdot
.19771 .1987 Mdot
.19781 .24963 Mdot
.1979 .29419 Mdot
.198 .33319 Mdot
.1981 .25286 Mdot
.19819 .19262 Mdot
.19829 .24431 Mdot
.19838 .28954 Mdot
.19848 .22013 Mdot
.19857 .16807 Mdot
.19867 .12902 Mdot
.19876 .18866 Mdot
.19886 .14447 Mdot
.19895 .11132 Mdot
.19905 .17318 Mdot
.19914 .2273 Mdot
.19924 .17344 Mdot
.19933 .22753 Mdot
.19943 .27486 Mdot
.19952 .31627 Mdot
.19962 .24017 Mdot
.19971 .28592 Mdot
.19981 .32595 Mdot
.1999 .24743 Mdot
.2 .18855 Mdot
.2001 .24075 Mdot
.20019 .28642 Mdot
.20029 .32639 Mdot
.20038 .24776 Mdot
.20048 .29256 Mdot
.20057 .33176 Mdot
.20067 .36606 Mdot
.20076 .39607 Mdot
.20086 .30002 Mdot
.20095 .22799 Mdot
.20105 .17396 Mdot
.20114 .22799 Mdot
.20124 .27526 Mdot
.20133 .31662 Mdot
.20143 .35281 Mdot
.20152 .26758 Mdot
.20162 .3099 Mdot
.20171 .2354 Mdot
.20181 .17952 Mdot
.2019 .23285 Mdot
.202 .17761 Mdot
.2021 .23117 Mdot
.20219 .27805 Mdot
.20229 .21151 Mdot
.20238 .26084 Mdot
.20248 .1986 Mdot
.20257 .24954 Mdot
.20267 .29412 Mdot
.20276 .22356 Mdot
.20286 .27138 Mdot
.20295 .20651 Mdot
.20305 .25646 Mdot
.20314 .30017 Mdot
.20324 .33842 Mdot
.20333 .37189 Mdot
.20343 .40117 Mdot
.20352 .30385 Mdot
.20362 .34164 Mdot
.20371 .3747 Mdot
.20381 .40363 Mdot
.2039 .42895 Mdot
.204 .4511 Mdot
.2041 .34129 Mdot
.20419 .25894 Mdot
.20429 .30234 Mdot
.20438 .34032 Mdot
.20448 .25821 Mdot
.20457 .19663 Mdot
.20467 .24782 Mdot
.20476 .18884 Mdot
.20486 .241 Mdot
.20495 .28664 Mdot
.20505 .32658 Mdot
.20514 .36153 Mdot
.20524 .3921 Mdot
.20533 .41886 Mdot
.20543 .44227 Mdot
.20552 .46276 Mdot
.20562 .48068 Mdot
.20571 .49636 Mdot
.20581 .51009 Mdot
.2059 .52209 Mdot
.206 .5326 Mdot
.2061 .54179 Mdot
.20619 .40932 Mdot
.20629 .30996 Mdot
.20638 .23544 Mdot
.20648 .28178 Mdot
.20657 .21431 Mdot
.20667 .1637 Mdot
.20676 .12575 Mdot
.20686 .1858 Mdot
.20695 .14232 Mdot
.20705 .10971 Mdot
.20714 .17177 Mdot
.20724 .22606 Mdot
.20733 .17252 Mdot
.20743 .22672 Mdot
.20752 .27415 Mdot
.20762 .20858 Mdot
.20771 .25828 Mdot
.20781 .19668 Mdot
.2079 .15048 Mdot
.208 .20744 Mdot
.2081 .15855 Mdot
.20819 .2145 Mdot
.20829 .16385 Mdot
.20838 .21914 Mdot
.20848 .26751 Mdot
.20857 .30984 Mdot
.20867 .23535 Mdot
.20876 .2817 Mdot
.20886 .32226 Mdot
.20895 .35774 Mdot
.20905 .27128 Mdot
.20914 .31314 Mdot
.20924 .34976 Mdot
.20933 .26529 Mdot
.20943 .20194 Mdot
.20952 .15443 Mdot
.20962 .11879 Mdot
.20971 .09207 Mdot
.20981 .07202 Mdot
.2099 .13879 Mdot
.21 .10706 Mdot
.2101 .16945 Mdot
.21019 .13006 Mdot
.21029 .18957 Mdot
.21038 .24164 Mdot
.21048 .1842 Mdot
.21057 .23695 Mdot
.21067 .2831 Mdot
.21076 .21529 Mdot
.21086 .16444 Mdot
.21095 .1263 Mdot
.21105 .18628 Mdot
.21114 .23877 Mdot
.21124 .28469 Mdot
.21133 .32487 Mdot
.21143 .24662 Mdot
.21152 .18794 Mdot
.21162 .24022 Mdot
.21171 .18313 Mdot
.21181 .23601 Mdot
.2119 .28228 Mdot
.212 .21468 Mdot
.2121 .26361 Mdot
.21219 .20068 Mdot
.21229 .15348 Mdot
.21238 .21007 Mdot
.21248 .16052 Mdot
.21257 .21622 Mdot
.21267 .26496 Mdot
.21276 .20169 Mdot
.21286 .25225 Mdot
.21295 .19216 Mdot
.21305 .24391 Mdot
.21314 .28919 Mdot
.21324 .21986 Mdot
.21333 .26815 Mdot
.21343 .3104 Mdot
.21352 .34737 Mdot
.21362 .37971 Mdot
.21371 .40802 Mdot
.21381 .43279 Mdot
.2139 .45446 Mdot
.214 .34381 Mdot
.2141 .37661 Mdot
.21419 .28543 Mdot
.21429 .21704 Mdot
.21438 .16575 Mdot
.21448 .2208 Mdot
.21457 .16857 Mdot
.21467 .22327 Mdot
.21476 .17042 Mdot
.21486 .22489 Mdot
.21495 .27255 Mdot
.21505 .31425 Mdot
.21514 .23866 Mdot
.21524 .18196 Mdot
.21533 .13944 Mdot
.21543 .19778 Mdot
.21552 .24883 Mdot
.21562 .18959 Mdot
.21571 .24166 Mdot
.21581 .28722 Mdot
.2159 .32709 Mdot
.216 .24829 Mdot
.2161 .18919 Mdot
.21619 .24131 Mdot
.21629 .28691 Mdot
.21638 .21816 Mdot
.21648 .16659 Mdot
.21657 .22153 Mdot
.21667 .26961 Mdot
.21676 .31168 Mdot
.21686 .34849 Mdot
.21695 .38069 Mdot
.21705 .28849 Mdot
.21714 .3282 Mdot
.21724 .24912 Mdot
.21733 .29375 Mdot
.21743 .3328 Mdot
.21752 .36697 Mdot
.21762 .2782 Mdot
.21771 .31919 Mdot
.21781 .24236 Mdot
.2179 .28784 Mdot
.218 .21885 Mdot
.2181 .16711 Mdot
.21819 .22199 Mdot
.21829 .27001 Mdot
.21838 .31203 Mdot
.21848 .23699 Mdot
.21857 .18071 Mdot
.21867 .23389 Mdot
.21876 .17839 Mdot
.21886 .13677 Mdot
.21895 .19544 Mdot
.21905 .24678 Mdot
.21914 .18805 Mdot
.21924 .14401 Mdot
.21933 .20178 Mdot
.21943 .15431 Mdot
.21952 .1187 Mdot
.21962 .092 Mdot
.21971 .15627 Mdot
.21981 .12017 Mdot
.2199 .18092 Mdot
.22 .23407 Mdot
.2201 .28058 Mdot
.22019 .32128 Mdot
.22029 .35689 Mdot
.22038 .27064 Mdot
.22048 .20595 Mdot
.22057 .15743 Mdot
.22067 .21352 Mdot
.22076 .2626 Mdot
.22086 .19992 Mdot
.22095 .2507 Mdot
.22105 .29513 Mdot
.22114 .22432 Mdot
.22124 .17121 Mdot
.22133 .13138 Mdot
.22143 .19073 Mdot
.22152 .24265 Mdot
.22162 .18496 Mdot
.22171 .23761 Mdot
.22181 .18118 Mdot
.2219 .2343 Mdot
.222 .28078 Mdot
.2221 .21356 Mdot
.22219 .16314 Mdot
.22229 .21852 Mdot
.22238 .26697 Mdot
.22248 .2032 Mdot
.22257 .25357 Mdot
.22267 .29764 Mdot
.22276 .3362 Mdot
.22286 .25512 Mdot
.22295 .19431 Mdot
.22305 .14871 Mdot
.22314 .20589 Mdot
.22324 .25592 Mdot
.22333 .2997 Mdot
.22343 .338 Mdot
.22352 .25647 Mdot
.22362 .30018 Mdot
.22371 .33843 Mdot
.22381 .25679 Mdot
.2239 .30046 Mdot
.224 .22832 Mdot
.2241 .17421 Mdot
.22419 .13363 Mdot
.22429 .19269 Mdot
.22438 .14749 Mdot
.22448 .11359 Mdot
.22457 .17516 Mdot
.22467 .13434 Mdot
.22476 .19332 Mdot
.22486 .24492 Mdot
.22495 .29007 Mdot
.22505 .32958 Mdot
.22514 .25016 Mdot
.22524 .29466 Mdot
.22533 .22396 Mdot
.22543 .17094 Mdot
.22552 .22535 Mdot
.22562 .27295 Mdot
.22571 .20768 Mdot
.22581 .25749 Mdot
.2259 .30107 Mdot
.226 .22878 Mdot
.2261 .17455 Mdot
.22619 .2285 Mdot
.22629 .27571 Mdot
.22638 .31701 Mdot
.22648 .24073 Mdot
.22657 .18352 Mdot
.22667 .23635 Mdot
.22676 .18023 Mdot
.22686 .13815 Mdot
.22695 .19665 Mdot
.22705 .24783 Mdot
.22714 .18885 Mdot
.22724 .24101 Mdot
.22733 .28665 Mdot
.22743 .21796 Mdot
.22752 .26648 Mdot
.22762 .30894 Mdot
.22771 .23468 Mdot
.22781 .28111 Mdot
.2279 .21381 Mdot
.228 .16333 Mdot
.2281 .21868 Mdot
.22819 .26711 Mdot
.22829 .30949 Mdot
.22838 .34657 Mdot
.22848 .37902 Mdot
.22857 .28724 Mdot
.22867 .3271 Mdot
.22876 .2483 Mdot
.22886 .29303 Mdot
.22895 .22274 Mdot
.22905 .27067 Mdot
.22914 .3126 Mdot
.22924 .3493 Mdot
.22933 .3814 Mdot
.22943 .28902 Mdot
.22952 .21974 Mdot
.22962 .16778 Mdot
.22971 .22257 Mdot
.22981 .27052 Mdot
.2299 .20586 Mdot
.23 .2559 Mdot
.2301 .19489 Mdot
.23019 .14914 Mdot
.23029 .20627 Mdot
.23038 .15767 Mdot
.23048 .21373 Mdot
.23057 .26278 Mdot
.23067 .3057 Mdot
.23076 .34326 Mdot
.23086 .37612 Mdot
.23095 .40487 Mdot
.23105 .30663 Mdot
.23114 .23294 Mdot
.23124 .27959 Mdot
.23133 .32041 Mdot
.23143 .24328 Mdot
.23152 .18543 Mdot
.23162 .23802 Mdot
.23171 .28404 Mdot
.23181 .216 Mdot
.2319 .26477 Mdot
.232 .20155 Mdot
.2321 .25212 Mdot
.23219 .29638 Mdot
.23229 .22525 Mdot
.23238 .27287 Mdot
.23248 .20762 Mdot
.23257 .25744 Mdot
.23267 .19605 Mdot
.23276 .15001 Mdot
.23286 .11548 Mdot
.23295 .17681 Mdot
.23305 .13558 Mdot
.23314 .1944 Mdot
.23324 .24587 Mdot
.23333 .18737 Mdot
.23343 .1435 Mdot
.23352 .20133 Mdot
.23362 .25193 Mdot
.23371 .19192 Mdot
.23381 .14691 Mdot
.2339 .20432 Mdot
.234 .25455 Mdot
.2341 .2985 Mdot
.23419 .33695 Mdot
.23429 .25569 Mdot
.23438 .29949 Mdot
.23448 .33783 Mdot
.23457 .25634 Mdot
.23467 .30007 Mdot
.23476 .22802 Mdot
.23486 .17399 Mdot
.23495 .22801 Mdot
.23505 .17398 Mdot
.23514 .228 Mdot
.23524 .27527 Mdot
.23533 .31663 Mdot
.23543 .35282 Mdot
.23552 .26758 Mdot
.23562 .30991 Mdot
.23571 .34694 Mdot
.23581 .26317 Mdot
.2359 .30604 Mdot
.236 .34356 Mdot
.2361 .37638 Mdot
.23619 .4051 Mdot
.23629 .43023 Mdot
.23638 .45222 Mdot
.23648 .47146 Mdot
.23657 .4883 Mdot
.23667 .50303 Mdot
.23676 .51592 Mdot
.23686 .5272 Mdot
.23695 .53707 Mdot
.23705 .5457 Mdot
.23714 .55326 Mdot
.23724 .55987 Mdot
.23733 .56565 Mdot
.23743 .57072 Mdot
.23752 .43101 Mdot
.23762 .32623 Mdot
.23771 .36122 Mdot
.23781 .39183 Mdot
.2379 .29685 Mdot
.238 .33551 Mdot
.2381 .2546 Mdot
.23819 .29855 Mdot
.23829 .337 Mdot
.23838 .25572 Mdot
.23848 .19476 Mdot
.23857 .24618 Mdot
.23867 .18761 Mdot
.23876 .14368 Mdot
.23886 .20149 Mdot
.23895 .15409 Mdot
.23905 .11854 Mdot
.23914 .17949 Mdot
.23924 .23282 Mdot
.23933 .17759 Mdot
.23943 .23116 Mdot
.23952 .27803 Mdot
.23962 .21149 Mdot
.23971 .26083 Mdot
.23981 .30399 Mdot
.2399 .34176 Mdot
.24 .37481 Mdot
.2401 .28408 Mdot
.24019 .32434 Mdot
.24029 .35956 Mdot
.24038 .27264 Mdot
.24048 .20745 Mdot
.24057 .25729 Mdot
.24067 .3009 Mdot
.24076 .33905 Mdot
.24086 .25726 Mdot
.24095 .19592 Mdot
.24105 .2472 Mdot
.24114 .29207 Mdot
.24124 .33133 Mdot
.24133 .25147 Mdot
.24143 .19157 Mdot
.24152 .24339 Mdot
.24162 .18552 Mdot
.24171 .14211 Mdot
.24181 .20011 Mdot
.2419 .25087 Mdot
.242 .29528 Mdot
.2421 .33414 Mdot
.24219 .36814 Mdot
.24229 .39789 Mdot
.24238 .30139 Mdot
.24248 .33948 Mdot
.24257 .25758 Mdot
.24267 .19616 Mdot
.24276 .24741 Mdot
.24286 .29225 Mdot
.24295 .33149 Mdot
.24305 .36582 Mdot
.24314 .39586 Mdot
.24324 .42215 Mdot
.24333 .31958 Mdot
.24343 .24266 Mdot
.24352 .18496 Mdot
.24362 .23761 Mdot
.24371 .28368 Mdot
.24381 .21573 Mdot
.2439 .26453 Mdot
.244 .30724 Mdot
.2441 .2334 Mdot
.24419 .17802 Mdot
.24429 .23154 Mdot
.24438 .17662 Mdot
.24448 .13544 Mdot
.24457 .10455 Mdot
.24467 .16725 Mdot
.24476 .12841 Mdot
.24486 .18813 Mdot
.24495 .14407 Mdot
.24505 .20183 Mdot
.24514 .25237 Mdot
.24524 .19225 Mdot
.24533 .24398 Mdot
.24543 .18596 Mdot
.24552 .23848 Mdot
.24562 .18183 Mdot
.24571 .13935 Mdot
.24581 .10748 Mdot
.2459 .16981 Mdot
.246 .22436 Mdot
.2461 .27208 Mdot
.24619 .20703 Mdot
.24629 .25692 Mdot
.24638 .30057 Mdot
.24648 .33877 Mdot
.24657 .37219 Mdot
.24667 .40144 Mdot
.24676 .30405 Mdot
.24686 .23101 Mdot
.24695 .17623 Mdot
.24705 .13514 Mdot
.24714 .19402 Mdot
.24724 .14848 Mdot
.24733 .20569 Mdot
.24743 .15724 Mdot
.24752 .21335 Mdot
.24762 .26245 Mdot
.24771 .30542 Mdot
.24781 .34301 Mdot
.2479 .3759 Mdot
.248 .40468 Mdot
.2481 .42986 Mdot
.24819 .4519 Mdot
.24829 .47118 Mdot
.24838 .35636 Mdot
.24848 .38758 Mdot
.24857 .4149 Mdot
.24867 .43881 Mdot
.24876 .45973 Mdot
.24886 .47803 Mdot
.24895 .49404 Mdot
.24905 .3735 Mdot
.24914 .2831 Mdot
.24924 .2153 Mdot
.24933 .26415 Mdot
.24943 .3069 Mdot
.24952 .34431 Mdot
.24962 .2612 Mdot
.24971 .19887 Mdot
.24981 .15213 Mdot
.2499 .20888 Mdot
.25 .25854 Mdot
.2501 .30199 Mdot
.25019 .34001 Mdot
.25029 .25798 Mdot
.25038 .19645 Mdot
.25048 .24767 Mdot
.25057 .18872 Mdot
.25067 .2409 Mdot
.25076 .28656 Mdot
.25086 .21789 Mdot
.25095 .26642 Mdot
.25105 .20279 Mdot
.25114 .25321 Mdot
.25124 .29732 Mdot
.25133 .33593 Mdot
.25143 .36971 Mdot
.25152 .39926 Mdot
.25162 .30242 Mdot
.25171 .34038 Mdot
.25181 .3736 Mdot
.2519 .28317 Mdot
.252 .32355 Mdot
.2521 .24563 Mdot
.25219 .18719 Mdot
.25229 .14337 Mdot
.25238 .20121 Mdot
.25248 .15388 Mdot
.25257 .21042 Mdot
.25267 .16078 Mdot
.25276 .21645 Mdot
.25286 .16531 Mdot
.25295 .22042 Mdot
.25305 .26863 Mdot
.25314 .31082 Mdot
.25324 .34774 Mdot
.25333 .26377 Mdot
.25343 .30657 Mdot
.25352 .34402 Mdot
.25362 .37679 Mdot
.25371 .40546 Mdot
.25381 .43054 Mdot
.2539 .45249 Mdot
.254 .4717 Mdot
.2541 .48851 Mdot
.25419 .50321 Mdot
.25429 .38038 Mdot
.25438 .4086 Mdot
.25448 .30942 Mdot
.25457 .34651 Mdot
.25467 .26286 Mdot
.25476 .20011 Mdot
.25486 .25087 Mdot
.25495 .19112 Mdot
.25505 .243 Mdot
.25514 .18522 Mdot
.25524 .23784 Mdot
.25533 .28388 Mdot
.25543 .21588 Mdot
.25552 .26466 Mdot
.25562 .30735 Mdot
.25571 .3447 Mdot
.25581 .37738 Mdot
.2559 .40598 Mdot
.256 .431 Mdot
.2561 .45289 Mdot
.25619 .47205 Mdot
.25629 .35701 Mdot
.25638 .38815 Mdot
.25648 .29408 Mdot
.25657 .33309 Mdot
.25667 .36722 Mdot
.25676 .39709 Mdot
.25686 .30079 Mdot
.25695 .22856 Mdot
.25705 .17439 Mdot
.25714 .22836 Mdot
.25724 .17424 Mdot
.25733 .13365 Mdot
.25743 .10321 Mdot
.25752 .16608 Mdot
.25762 .22109 Mdot
.25771 .26922 Mdot
.25781 .20489 Mdot
.2579 .15664 Mdot
.258 .12045 Mdot
.2581 .09331 Mdot
.25819 .07295 Mdot
.25829 .1396 Mdot
.25838 .19792 Mdot
.25848 .15141 Mdot
.25857 .11653 Mdot
.25867 .17773 Mdot
.25876 .23128 Mdot
.25886 .27814 Mdot
.25895 .31914 Mdot
.25905 .24233 Mdot
.25914 .18472 Mdot
.25924 .14151 Mdot
.25933 .19959 Mdot
.25943 .25041 Mdot
.25952 .19078 Mdot
.25962 .2427 Mdot
.25971 .28813 Mdot
.25981 .21907 Mdot
.2599 .26745 Mdot
.26 .30979 Mdot
.2601 .34684 Mdot
.26019 .37925 Mdot
.26029 .40761 Mdot
.26038 .43243 Mdot
.26048 .32729 Mdot
.26057 .24844 Mdot
.26067 .29315 Mdot
.26076 .22284 Mdot
.26086 .27075 Mdot
.26095 .20603 Mdot
.26105 .1575 Mdot
.26114 .21358 Mdot
.26124 .26265 Mdot
.26133 .19996 Mdot
.26143 .15294 Mdot
.26152 .11768 Mdot
.26162 .09123 Mdot
.26171 .15559 Mdot
.26181 .11967 Mdot
.2619 .18048 Mdot
.262 .23369 Mdot
.2621 .28024 Mdot
.26219 .21315 Mdot
.26229 .16284 Mdot
.26238 .21825 Mdot
.26248 .16666 Mdot
.26257 .12797 Mdot
.26267 .09895 Mdot
.26276 .16235 Mdot
.26286 .21782 Mdot
.26295 .26636 Mdot
.26305 .20274 Mdot
.26314 .25317 Mdot
.26324 .29729 Mdot
.26333 .3359 Mdot
.26343 .2549 Mdot
.26352 .2988 Mdot
.26362 .22707 Mdot
.26371 .27446 Mdot
.26381 .31592 Mdot
.2639 .3522 Mdot
.264 .26712 Mdot
.2641 .20331 Mdot
.26419 .25367 Mdot
.26429 .19322 Mdot
.26438 .14789 Mdot
.26448 .20517 Mdot
.26457 .25529 Mdot
.26467 .29915 Mdot
.26476 .22733 Mdot
.26486 .27469 Mdot
.26495 .31612 Mdot
.26505 .35237 Mdot
.26514 .38409 Mdot
.26524 .29104 Mdot
.26533 .22125 Mdot
.26543 .16891 Mdot
.26552 .12965 Mdot
.26562 .10021 Mdot
.26571 .16345 Mdot
.26581 .21879 Mdot
.2659 .26721 Mdot
.266 .30958 Mdot
.2661 .34665 Mdot
.26619 .37909 Mdot
.26629 .40747 Mdot
.26638 .30857 Mdot
.26648 .34577 Mdot
.26657 .37832 Mdot
.26667 .4068 Mdot
.26676 .43172 Mdot
.26686 .32676 Mdot
.26695 .24804 Mdot
.26705 .189 Mdot
.26714 .24114 Mdot
.26724 .18383 Mdot
.26733 .14084 Mdot
.26743 .19901 Mdot
.26752 .2499 Mdot
.26762 .1904 Mdot
.26771 .24237 Mdot
.26781 .28784 Mdot
.2679 .32763 Mdot
.268 .36244 Mdot
.2681 .2748 Mdot
.26819 .20907 Mdot
.26829 .15978 Mdot
.26838 .21557 Mdot
.26848 .16465 Mdot
.26857 .21984 Mdot
.26867 .16785 Mdot
.26876 .22264 Mdot
.26886 .16995 Mdot
.26895 .22447 Mdot
.26905 .27218 Mdot
.26914 .20711 Mdot
.26924 .25699 Mdot
.26933 .19571 Mdot
.26943 .24702 Mdot
.26952 .18823 Mdot
.26962 .24047 Mdot
.26971 .28618 Mdot
.26981 .32618 Mdot
.2699 .24761 Mdot
.27 .18868 Mdot
.2701 .24086 Mdot
.27019 .18362 Mdot
.27029 .23643 Mdot
.27038 .28265 Mdot
.27048 .32308 Mdot
.27057 .24528 Mdot
.27067 .18694 Mdot
.27076 .23934 Mdot
.27086 .18247 Mdot
.27095 .13983 Mdot
.27105 .19812 Mdot
.27114 .24912 Mdot
.27124 .29375 Mdot
.27133 .22328 Mdot
.27143 .17043 Mdot
.27152 .2249 Mdot
.27162 .17164 Mdot
.27171 .22596 Mdot
.27181 .27348 Mdot
.2719 .31507 Mdot
.272 .35145 Mdot
.2721 .38329 Mdot
.27219 .29044 Mdot
.27229 .3299 Mdot
.27238 .2504 Mdot
.27248 .29487 Mdot
.27257 .22412 Mdot
.27267 .17106 Mdot
.27276 .22545 Mdot
.27286 .27304 Mdot
.27295 .20775 Mdot
.27305 .25755 Mdot
.27314 .30112 Mdot
.27324 .33925 Mdot
.27333 .25741 Mdot
.27343 .19603 Mdot
.27352 .24729 Mdot
.27362 .18844 Mdot
.27371 .24065 Mdot
.27381 .28634 Mdot
.2739 .21773 Mdot
.274 .16627 Mdot
.2741 .22125 Mdot
.27419 .26936 Mdot
.27429 .31146 Mdot
.27438 .3483 Mdot
.27448 .38053 Mdot
.27457 .28837 Mdot
.27467 .32809 Mdot
.27476 .24904 Mdot
.27486 .18975 Mdot
.27495 .14528 Mdot
.27505 .20289 Mdot
.27514 .2533 Mdot
.27524 .29741 Mdot
.27533 .22603 Mdot
.27543 .17249 Mdot
.27552 .2267 Mdot
.27562 .17299 Mdot
.27571 .22714 Mdot
.27581 .27452 Mdot
.2759 .31597 Mdot
.276 .23995 Mdot
.2761 .18293 Mdot
.27619 .23583 Mdot
.27629 .28212 Mdot
.27638 .32263 Mdot
.27648 .35807 Mdot
.27657 .38908 Mdot
.27667 .29478 Mdot
.27676 .22406 Mdot
.27686 .27182 Mdot
.27695 .31361 Mdot
.27705 .35018 Mdot
.27714 .38217 Mdot
.27724 .2896 Mdot
.27733 .32917 Mdot
.27743 .36379 Mdot
.27752 .39409 Mdot
.27762 .29854 Mdot
.27771 .33699 Mdot
.27781 .37063 Mdot
.2779 .40007 Mdot
.278 .30303 Mdot
.2781 .34092 Mdot
.27819 .25866 Mdot
.27829 .19697 Mdot
.27838 .1507 Mdot
.27848 .20763 Mdot
.27857 .15869 Mdot
.27867 .21462 Mdot
.27876 .26356 Mdot
.27886 .30639 Mdot
.27895 .34386 Mdot
.27905 .26086 Mdot
.27914 .19862 Mdot
.27924 .15194 Mdot
.27933 .20871 Mdot
.27943 .25839 Mdot
.27952 .19677 Mdot
.27962 .24794 Mdot
.27971 .18893 Mdot
.27981 .14467 Mdot
.2799 .20235 Mdot
.28 .25283 Mdot
.2801 .19259 Mdot
.28019 .14741 Mdot
.28029 .11353 Mdot
.28038 .08812 Mdot
.28048 .15287 Mdot
.28057 .20953 Mdot
.28067 .16012 Mdot
.28076 .21587 Mdot
.28086 .26466 Mdot
.28095 .20147 Mdot
.28105 .25205 Mdot
.28114 .19201 Mdot
.28124 .14698 Mdot
.28133 .20437 Mdot
.28143 .2546 Mdot
.28152 .19392 Mdot
.28162 .14841 Mdot
.28171 .20563 Mdot
.28181 .25569 Mdot
.2819 .19474 Mdot
.282 .24617 Mdot
.2821 .1876 Mdot
.28219 .23992 Mdot
.28229 .28569 Mdot
.28238 .32575 Mdot
.28248 .3608 Mdot
.28257 .39147 Mdot
.28267 .4183 Mdot
.28276 .3167 Mdot
.28286 .35288 Mdot
.28295 .38454 Mdot
.28305 .41224 Mdot
.28314 .43648 Mdot
.28324 .33033 Mdot
.28333 .25072 Mdot
.28343 .29515 Mdot
.28352 .33402 Mdot
.28362 .25349 Mdot
.28371 .29757 Mdot
.28381 .22615 Mdot
.2839 .17258 Mdot
.284 .22678 Mdot
.2841 .2742 Mdot
.28419 .31569 Mdot
.28429 .23974 Mdot
.28438 .18278 Mdot
.28448 .14005 Mdot
.28457 .19832 Mdot
.28467 .2493 Mdot
.28476 .18994 Mdot
.28486 .24197 Mdot
.28495 .18445 Mdot
.28505 .23716 Mdot
.28514 .28328 Mdot
.28524 .21543 Mdot
.28533 .16455 Mdot
.28543 .12638 Mdot
.28552 .18635 Mdot
.28562 .14274 Mdot
.28571 .20066 Mdot
.28581 .25135 Mdot
.2859 .2957 Mdot
.286 .22474 Mdot
.2861 .17153 Mdot
.28619 .13162 Mdot
.28629 .19094 Mdot
.28638 .24284 Mdot
.28648 .1851 Mdot
.28657 .23773 Mdot
.28667 .18127 Mdot
.28676 .13892 Mdot
.28686 .10716 Mdot
.28695 .08334 Mdot
.28705 .14869 Mdot
.28714 .20588 Mdot
.28724 .25591 Mdot
.28733 .1949 Mdot
.28743 .24631 Mdot
.28752 .1877 Mdot
.28762 .14375 Mdot
.28771 .11078 Mdot
.28781 .1727 Mdot
.2879 .22688 Mdot
.288 .17313 Mdot
.2881 .22726 Mdot
.28819 .17342 Mdot
.28829 .22751 Mdot
.28838 .27484 Mdot
.28848 .2091 Mdot
.28857 .1598 Mdot
.28867 .12282 Mdot
.28876 .09509 Mdot
.28886 .15897 Mdot
.28895 .21487 Mdot
.28905 .16412 Mdot
.28914 .12606 Mdot
.28924 .18607 Mdot
.28933 .23858 Mdot
.28943 .28453 Mdot
.28952 .21637 Mdot
.28962 .16525 Mdot
.28971 .12691 Mdot
.28981 .09815 Mdot
.2899 .16165 Mdot
.29 .12421 Mdot
.2901 .18445 Mdot
.29019 .23716 Mdot
.29029 .18084 Mdot
.29038 .1386 Mdot
.29048 .19705 Mdot
.29057 .24819 Mdot
.29067 .18911 Mdot
.29076 .24124 Mdot
.29086 .28685 Mdot
.29095 .21811 Mdot
.29105 .26662 Mdot
.29114 .30906 Mdot
.29124 .34619 Mdot
.29133 .26262 Mdot
.29143 .30556 Mdot
.29152 .23214 Mdot
.29162 .17708 Mdot
.29171 .23071 Mdot
.29181 .176 Mdot
.2919 .22977 Mdot
.292 .27682 Mdot
.2921 .21059 Mdot
.29219 .16091 Mdot
.29229 .12365 Mdot
.29238 .18397 Mdot
.29248 .14095 Mdot
.29257 .1991 Mdot
.29267 .15229 Mdot
.29276 .11719 Mdot
.29286 .17831 Mdot
.29295 .1367 Mdot
.29305 .19539 Mdot
.29314 .24673 Mdot
.29324 .29166 Mdot
.29333 .33097 Mdot
.29343 .36537 Mdot
.29352 .277 Mdot
.29362 .21072 Mdot
.29371 .26015 Mdot
.29381 .19808 Mdot
.2939 .24909 Mdot
.294 .18979 Mdot
.2941 .14531 Mdot
.29419 .20292 Mdot
.29429 .15516 Mdot
.29438 .11934 Mdot
.29448 .09248 Mdot
.29457 .15669 Mdot
.29467 .12049 Mdot
.29476 .18119 Mdot
.29486 .23431 Mdot
.29495 .17871 Mdot
.29505 .23214 Mdot
.29514 .27889 Mdot
.29524 .21214 Mdot
.29533 .16207 Mdot
.29543 .12453 Mdot
.29552 .09637 Mdot
.29562 .16009 Mdot
.29571 .12304 Mdot
.29581 .18343 Mdot
.2959 .23627 Mdot
.296 .2825 Mdot
.2961 .21485 Mdot
.29619 .16411 Mdot
.29629 .12605 Mdot
.29638 .18606 Mdot
.29648 .23857 Mdot
.29657 .28452 Mdot
.29667 .32472 Mdot
.29676 .3599 Mdot
.29686 .39068 Mdot
.29695 .41762 Mdot
.29705 .44118 Mdot
.29714 .4618 Mdot
.29724 .47985 Mdot
.29733 .49563 Mdot
.29743 .50945 Mdot
.29752 .38506 Mdot
.29762 .29176 Mdot
.29771 .33106 Mdot
.29781 .25127 Mdot
.2979 .19142 Mdot
.298 .24326 Mdot
.2981 .18542 Mdot
.29819 .14204 Mdot
.29829 .20005 Mdot
.29838 .25081 Mdot
.29848 .29523 Mdot
.29857 .33409 Mdot
.29867 .3681 Mdot
.29876 .27905 Mdot
.29886 .21226 Mdot
.29895 .26149 Mdot
.29905 .19909 Mdot
.29914 .24997 Mdot
.29924 .19045 Mdot
.29933 .24241 Mdot
.29943 .28788 Mdot
.29952 .21888 Mdot
.29962 .26729 Mdot
.29971 .20344 Mdot
.29981 .25378 Mdot
.2999 .1933 Mdot
.3 .14795 Mdot
.3001 .20522 Mdot
.30019 .15689 Mdot
.30029 .12064 Mdot
.30038 .18133 Mdot
.30048 .23443 Mdot
.30057 .28089 Mdot
.30067 .32155 Mdot
.30076 .35713 Mdot
.30086 .27082 Mdot
.30095 .20608 Mdot
.30105 .25609 Mdot
.30114 .29985 Mdot
.30124 .22786 Mdot
.30133 .17386 Mdot
.30143 .2279 Mdot
.30152 .27518 Mdot
.30162 .20936 Mdot
.30171 .15999 Mdot
.30181 .12296 Mdot
.3019 .09519 Mdot
.302 .15906 Mdot
.3021 .21495 Mdot
.30219 .26385 Mdot
.30229 .30664 Mdot
.30238 .34408 Mdot
.30248 .37683 Mdot
.30257 .2856 Mdot
.30267 .21717 Mdot
.30276 .26579 Mdot
.30286 .20232 Mdot
.30295 .15471 Mdot
.30305 .119 Mdot
.30314 .1799 Mdot
.30324 .23318 Mdot
.30333 .17785 Mdot
.30343 .23139 Mdot
.30352 .17651 Mdot
.30362 .23022 Mdot
.30371 .27721 Mdot
.30381 .21088 Mdot
.3039 .26029 Mdot
.304 .19819 Mdot
.3041 .15161 Mdot
.30419 .11668 Mdot
.30429 .17786 Mdot
.30438 .13637 Mdot
.30448 .19509 Mdot
.30457 .24647 Mdot
.30467 .29143 Mdot
.30476 .33077 Mdot
.30486 .36519 Mdot
.30495 .39531 Mdot
.30505 .29946 Mdot
.30514 .22756 Mdot
.30524 .27489 Mdot
.30533 .20914 Mdot
.30543 .25876 Mdot
.30552 .30219 Mdot
.30562 .22961 Mdot
.30571 .27668 Mdot
.30581 .31786 Mdot
.3059 .3539 Mdot
.306 .26839 Mdot
.3061 .20427 Mdot
.30619 .2545 Mdot
.30629 .19385 Mdot
.30638 .24539 Mdot
.30648 .18701 Mdot
.30657 .2394 Mdot
.30667 .18252 Mdot
.30676 .13986 Mdot
.30686 .10787 Mdot
.30695 .17015 Mdot
.30705 .13059 Mdot
.30714 .10091 Mdot
.30724 .16407 Mdot
.30733 .21933 Mdot
.30743 .26768 Mdot
.30752 .30999 Mdot
.30762 .34701 Mdot
.30771 .3794 Mdot
.30781 .40774 Mdot
.3079 .43254 Mdot
.308 .45425 Mdot
.3081 .34366 Mdot
.30819 .37647 Mdot
.30829 .40518 Mdot
.30838 .30685 Mdot
.30848 .34427 Mdot
.30857 .26117 Mdot
.30867 .19885 Mdot
.30876 .15211 Mdot
.30886 .20886 Mdot
.30895 .25852 Mdot
.30905 .19686 Mdot
.30914 .15062 Mdot
.30924 .20756 Mdot
.30933 .15864 Mdot
.30943 .21458 Mdot
.30952 .16391 Mdot
.30962 .21919 Mdot
.30971 .26756 Mdot
.30981 .30988 Mdot
.3099 .23538 Mdot
.31 .28173 Mdot
.3101 .21427 Mdot
.31019 .16367 Mdot
.31029 .21898 Mdot
.31038 .26738 Mdot
.31048 .2035 Mdot
.31057 .1556 Mdot
.31067 .11967 Mdot
.31076 .18048 Mdot
.31086 .23369 Mdot
.31095 .28025 Mdot
.31105 .21316 Mdot
.31114 .16284 Mdot
.31124 .1251 Mdot
.31133 .18523 Mdot
.31143 .14189 Mdot
.31152 .19993 Mdot
.31162 .2507 Mdot
.31171 .29513 Mdot
.31181 .22432 Mdot
.3119 .17121 Mdot
.312 .22558 Mdot
.3121 .27315 Mdot
.31219 .20783 Mdot
.31229 .25762 Mdot
.31238 .30119 Mdot
.31248 .22886 Mdot
.31257 .17462 Mdot
.31267 .22856 Mdot
.31276 .17439 Mdot
.31286 .22836 Mdot
.31295 .27558 Mdot
.31305 .20966 Mdot
.31314 .16022 Mdot
.31324 .21596 Mdot
.31333 .26473 Mdot
.31343 .30741 Mdot
.31352 .23353 Mdot
.31362 .17812 Mdot
.31371 .23162 Mdot
.31381 .27844 Mdot
.3139 .2118 Mdot
.314 .16182 Mdot
.3141 .21736 Mdot
.31419 .26596 Mdot
.31429 .20244 Mdot
.31438 .1548 Mdot
.31448 .21122 Mdot
.31457 .16139 Mdot
.31467 .21698 Mdot
.31476 .26563 Mdot
.31486 .30819 Mdot
.31495 .34544 Mdot
.31505 .26205 Mdot
.31514 .30506 Mdot
.31524 .3427 Mdot
.31533 .37563 Mdot
.31543 .28469 Mdot
.31552 .21649 Mdot
.31562 .2652 Mdot
.31571 .30782 Mdot
.31581 .34511 Mdot
.3159 .37774 Mdot
.316 .40629 Mdot
.3161 .30769 Mdot
.31619 .23374 Mdot
.31629 .28029 Mdot
.31638 .32102 Mdot
.31648 .24374 Mdot
.31657 .28904 Mdot
.31667 .21975 Mdot
.31676 .26805 Mdot
.31686 .20401 Mdot
.31695 .15598 Mdot
.31705 .21225 Mdot
.31714 .16216 Mdot
.31724 .21766 Mdot
.31733 .26622 Mdot
.31743 .30871 Mdot
.31752 .34589 Mdot
.31762 .37842 Mdot
.31771 .40689 Mdot
.31781 .30814 Mdot
.3179 .23407 Mdot
.318 .28058 Mdot
.3181 .21341 Mdot
.31819 .16303 Mdot
.31829 .21842 Mdot
.31838 .26688 Mdot
.31848 .30929 Mdot
.31857 .3464 Mdot
.31867 .37887 Mdot
.31876 .40728 Mdot
.31886 .43214 Mdot
.31895 .45389 Mdot
.31905 .47292 Mdot
.31914 .48957 Mdot
.31924 .37015 Mdot
.31933 .28059 Mdot
.31943 .21341 Mdot
.31952 .2625 Mdot
.31962 .19985 Mdot
.31971 .15286 Mdot
.31981 .20952 Mdot
.3199 .16011 Mdot
.32 .21587 Mdot
.3201 .26465 Mdot
.32019 .30734 Mdot
.32029 .23347 Mdot
.32038 .17808 Mdot
.32048 .13653 Mdot
.32057 .19523 Mdot
.32067 .2466 Mdot
.32076 .29154 Mdot
.32086 .22163 Mdot
.32095 .16919 Mdot
.32105 .22381 Mdot
.32114 .2716 Mdot
.32124 .20667 Mdot
.32133 .15798 Mdot
.32143 .214 Mdot
.32152 .26302 Mdot
.32162 .20023 Mdot
.32171 .25097 Mdot
.32181 .29537 Mdot
.3219 .2245 Mdot
.322 .17135 Mdot
.3221 .2257 Mdot
.32219 .27325 Mdot
.32229 .20791 Mdot
.32238 .25769 Mdot
.32248 .19624 Mdot
.32257 .15015 Mdot
.32267 .11558 Mdot
.32276 .1769 Mdot
.32286 .23056 Mdot
.32295 .27751 Mdot
.32305 .31859 Mdot
.32314 .35453 Mdot
.32324 .38599 Mdot
.32333 .29246 Mdot
.32343 .22232 Mdot
.32352 .16971 Mdot
.32362 .13025 Mdot
.32371 .18974 Mdot
.32381 .24179 Mdot
.3239 .28734 Mdot
.324 .21847 Mdot
.3241 .16683 Mdot
.32419 .12809 Mdot
.32429 .09904 Mdot
.32438 .16243 Mdot
.32448 .12479 Mdot
.32457 .18496 Mdot
.32467 .23761 Mdot
.32476 .28368 Mdot
.32486 .21573 Mdot
.32495 .26453 Mdot
.32505 .30723 Mdot
.32514 .2334 Mdot
.32524 .17802 Mdot
.32533 .23154 Mdot
.32543 .17662 Mdot
.32552 .13544 Mdot
.32562 .19428 Mdot
.32571 .24576 Mdot
.32581 .29081 Mdot
.3259 .22108 Mdot
.326 .26921 Mdot
.3261 .31133 Mdot
.32619 .23647 Mdot
.32629 .28268 Mdot
.32638 .32311 Mdot
.32648 .24531 Mdot
.32657 .18695 Mdot
.32667 .14318 Mdot
.32676 .20105 Mdot
.32686 .25169 Mdot
.32695 .296 Mdot
.32705 .22497 Mdot
.32714 .27262 Mdot
.32724 .20743 Mdot
.32733 .25727 Mdot
.32743 .19593 Mdot
.32752 .14992 Mdot
.32762 .20695 Mdot
.32771 .15818 Mdot
.32781 .21418 Mdot
.3279 .1636 Mdot
.328 .21892 Mdot
.3281 .16716 Mdot
.32819 .12834 Mdot
.32829 .09923 Mdot
.32838 .16259 Mdot
.32848 .21804 Mdot
.32857 .1665 Mdot
.32867 .22146 Mdot
.32876 .16906 Mdot
.32886 .12977 Mdot
.32895 .18932 Mdot
.32905 .24142 Mdot
.32914 .18404 Mdot
.32924 .2368 Mdot
.32933 .28297 Mdot
.32943 .32337 Mdot
.32952 .35871 Mdot
.32962 .38964 Mdot
.32971 .2952 Mdot
.32981 .22437 Mdot
.3299 .17125 Mdot
.33 .22561 Mdot
.3301 .27318 Mdot
.33019 .20786 Mdot
.33029 .25764 Mdot
.33038 .1962 Mdot
.33048 .24745 Mdot
.33057 .29228 Mdot
.33067 .22218 Mdot
.33076 .27018 Mdot
.33086 .31218 Mdot
.33095 .2371 Mdot
.33105 .1808 Mdot
.33114 .23397 Mdot
.33124 .28049 Mdot
.33133 .21334 Mdot
.33143 .16298 Mdot
.33152 .21837 Mdot
.33162 .26684 Mdot
.33171 .2031 Mdot
.33181 .1553 Mdot
.3319 .21166 Mdot
.332 .16171 Mdot
.3321 .21727 Mdot
.33219 .16592 Mdot
.33229 .22095 Mdot
.33238 .2691 Mdot
.33248 .31123 Mdot
.33257 .23639 Mdot
.33267 .18027 Mdot
.33276 .2335 Mdot
.33286 .28008 Mdot
.33295 .32084 Mdot
.33305 .3565 Mdot
.33314 .38771 Mdot
.33324 .41502 Mdot
.33333 .43891 Mdot
.33343 .45981 Mdot
.33352 .34783 Mdot
.33362 .26384 Mdot
.33371 .30663 Mdot
.33381 .34407 Mdot
.3339 .37683 Mdot
.334 .4055 Mdot
.3341 .30709 Mdot
.33419 .23329 Mdot
.33429 .2799 Mdot
.33438 .2129 Mdot
.33448 .16264 Mdot
.33457 .12495 Mdot
.33467 .09669 Mdot
.33476 .16037 Mdot
.33486 .21609 Mdot
.33495 .26485 Mdot
.33505 .30751 Mdot
.33514 .2336 Mdot
.33524 .28017 Mdot
.33533 .32092 Mdot
.33543 .24366 Mdot
.33552 .18572 Mdot
.33562 .23827 Mdot
.33571 .18167 Mdot
.33581 .23473 Mdot
.3359 .17902 Mdot
.336 .23241 Mdot
.3361 .27913 Mdot
.33619 .21232 Mdot
.33629 .26155 Mdot
.33638 .19913 Mdot
.33648 .25001 Mdot
.33657 .19048 Mdot
.33667 .24244 Mdot
.33676 .2879 Mdot
.33686 .2189 Mdot
.33695 .2673 Mdot
.33705 .30966 Mdot
.33714 .34672 Mdot
.33724 .37915 Mdot
.33733 .40752 Mdot
.33743 .30861 Mdot
.33752 .23443 Mdot
.33762 .1788 Mdot
.33771 .23221 Mdot
.33781 .17713 Mdot
.3379 .13582 Mdot
.338 .19461 Mdot
.3381 .14893 Mdot
.33819 .11467 Mdot
.33829 .1761 Mdot
.33838 .22986 Mdot
.33848 .2769 Mdot
.33857 .21064 Mdot
.33867 .16095 Mdot
.33876 .12369 Mdot
.33886 .18399 Mdot
.33895 .14097 Mdot
.33905 .1087 Mdot
.33914 .17088 Mdot
.33924 .13113 Mdot
.33933 .10132 Mdot
.33943 .16442 Mdot
.33952 .21964 Mdot
.33962 .26795 Mdot
.33971 .20394 Mdot
.33981 .15592 Mdot
.3399 .11991 Mdot
.34 .18069 Mdot
.3401 .13849 Mdot
.34019 .19695 Mdot
.34029 .15068 Mdot
.34038 .20762 Mdot
.34048 .15868 Mdot
.34057 .12198 Mdot
.34067 .09446 Mdot
.34076 .15842 Mdot
.34086 .21439 Mdot
.34095 .26336 Mdot
.34105 .20049 Mdot
.34114 .15334 Mdot
.34124 .11797 Mdot
.34133 .179 Mdot
.34143 .13722 Mdot
.34152 .10589 Mdot
.34162 .16842 Mdot
.34171 .22313 Mdot
.34181 .27101 Mdot
.3419 .20623 Mdot
.342 .15764 Mdot
.3421 .21371 Mdot
.34219 .26276 Mdot
.34229 .20004 Mdot
.34238 .153 Mdot
.34248 .20965 Mdot
.34257 .25921 Mdot
.34267 .30258 Mdot
.34276 .2299 Mdot
.34286 .27693 Mdot
.34295 .31809 Mdot
.34305 .35409 Mdot
.34314 .26854 Mdot
.34324 .20438 Mdot
.34333 .2546 Mdot
.34343 .19392 Mdot
.34352 .24545 Mdot
.34362 .18706 Mdot
.34371 .14326 Mdot
.34381 .20113 Mdot
.3439 .25175 Mdot
.344 .29605 Mdot
.3441 .22501 Mdot
.34419 .27265 Mdot
.34429 .31434 Mdot
.34438 .23873 Mdot
.34448 .18202 Mdot
.34457 .23503 Mdot
.34467 .17925 Mdot
.34476 .13741 Mdot
.34486 .196 Mdot
.34495 .24727 Mdot
.34505 .18842 Mdot
.34514 .14429 Mdot
.34524 .20202 Mdot
.34533 .25254 Mdot
.34543 .29674 Mdot
.34552 .22552 Mdot
.34562 .2731 Mdot
.34571 .2078 Mdot
.34581 .15882 Mdot
.3459 .12209 Mdot
.346 .09454 Mdot
.3461 .07387 Mdot
.34619 .14041 Mdot
.34629 .19863 Mdot
.34638 .24957 Mdot
.34648 .29414 Mdot
.34657 .22358 Mdot
.34667 .2714 Mdot
.34676 .20652 Mdot
.34686 .15786 Mdot
.34695 .2139 Mdot
.34705 .16339 Mdot
.34714 .21874 Mdot
.34724 .26716 Mdot
.34733 .20334 Mdot
.34743 .15548 Mdot
.34752 .21181 Mdot
.34762 .26111 Mdot
.34771 .1988 Mdot
.34781 .15207 Mdot
.3479 .11702 Mdot
.348 .09074 Mdot
.3481 .15517 Mdot
.34819 .21154 Mdot
.34829 .16163 Mdot
.34838 .21719 Mdot
.34848 .16586 Mdot
.34857 .12737 Mdot
.34867 .18722 Mdot
.34876 .23958 Mdot
.34886 .18266 Mdot
.34895 .2356 Mdot
.34905 .17967 Mdot
.34914 .23298 Mdot
.34924 .27962 Mdot
.34933 .21269 Mdot
.34943 .26187 Mdot
.34952 .19938 Mdot
.34962 .25022 Mdot
.34971 .29471 Mdot
.34981 .22401 Mdot
.3499 .27177 Mdot
.35 .31357 Mdot
.3501 .23815 Mdot
.35019 .28415 Mdot
.35029 .3244 Mdot
.35038 .35962 Mdot
.35048 .39043 Mdot
.35057 .2958 Mdot
.35067 .22482 Mdot
.35076 .27249 Mdot
.35086 .31419 Mdot
.35095 .35069 Mdot
.35105 .26599 Mdot
.35114 .20246 Mdot
.35124 .25292 Mdot
.35133 .19266 Mdot
.35143 .14747 Mdot
.35152 .2048 Mdot
.35162 .25497 Mdot
.35171 .1942 Mdot
.35181 .24569 Mdot
.3519 .29075 Mdot
.352 .33018 Mdot
.3521 .2506 Mdot
.35219 .29505 Mdot
.35229 .33393 Mdot
.35238 .25342 Mdot
.35248 .29751 Mdot
.35257 .22611 Mdot
.35267 .27361 Mdot
.35276 .31518 Mdot
.35286 .35155 Mdot
.35295 .38337 Mdot
.35305 .41122 Mdot
.35314 .43559 Mdot
.35324 .32966 Mdot
.35333 .36422 Mdot
.35343 .27614 Mdot
.35352 .21008 Mdot
.35362 .16053 Mdot
.35371 .21623 Mdot
.35381 .16514 Mdot
.3539 .12683 Mdot
.354 .18674 Mdot
.3541 .23917 Mdot
.35419 .28504 Mdot
.35429 .32518 Mdot
.35438 .3603 Mdot
.35448 .39103 Mdot
.35457 .29625 Mdot
.35467 .22516 Mdot
.35476 .27278 Mdot
.35486 .20756 Mdot
.35495 .15864 Mdot
.35505 .21458 Mdot
.35514 .26352 Mdot
.35524 .30635 Mdot
.35533 .23274 Mdot
.35543 .17752 Mdot
.35552 .13611 Mdot
.35562 .19487 Mdot
.35571 .24628 Mdot
.35581 .18768 Mdot
.3559 .14373 Mdot
.356 .20153 Mdot
.3561 .15412 Mdot
.35619 .11856 Mdot
.35629 .09189 Mdot
.35638 .15617 Mdot
.35648 .1201 Mdot
.35657 .09305 Mdot
.35667 .15719 Mdot
.35676 .21331 Mdot
.35686 .26241 Mdot
.35695 .19978 Mdot
.35705 .15281 Mdot
.35714 .20947 Mdot
.35724 .25906 Mdot
.35733 .30244 Mdot
.35743 .2298 Mdot
.35752 .27685 Mdot
.35762 .21061 Mdot
.35771 .26005 Mdot
.35781 .19801 Mdot
.3579 .15148 Mdot
.358 .20831 Mdot
.3581 .25804 Mdot
.35819 .1965 Mdot
.35829 .24771 Mdot
.35838 .29251 Mdot
.35848 .33172 Mdot
.35857 .36602 Mdot
.35867 .39604 Mdot
.35876 .3 Mdot
.35886 .22797 Mdot
.35895 .27524 Mdot
.35905 .31661 Mdot
.35914 .3528 Mdot
.35924 .38447 Mdot
.35933 .41218 Mdot
.35943 .3121 Mdot
.35952 .34886 Mdot
.35962 .26462 Mdot
.35971 .20143 Mdot
.35981 .15405 Mdot
.3599 .11851 Mdot
.36 .17946 Mdot
.3601 .2328 Mdot
.36019 .17757 Mdot
.36029 .23114 Mdot
.36038 .17633 Mdot
.36048 .13522 Mdot
.36057 .10438 Mdot
.36067 .1671 Mdot
.36076 .22199 Mdot
.36086 .16946 Mdot
.36095 .22405 Mdot
.36105 .17101 Mdot
.36114 .13123 Mdot
.36124 .19059 Mdot
.36133 .24254 Mdot
.36143 .18487 Mdot
.36152 .23753 Mdot
.36162 .18112 Mdot
.36171 .23425 Mdot
.36181 .17866 Mdot
.3619 .23209 Mdot
.362 .27885 Mdot
.3621 .31976 Mdot
.36219 .35556 Mdot
.36229 .26964 Mdot
.36238 .2052 Mdot
.36248 .25532 Mdot
.36257 .29917 Mdot
.36267 .33755 Mdot
.36276 .25613 Mdot
.36286 .19507 Mdot
.36295 .14927 Mdot
.36305 .20638 Mdot
.36314 .25635 Mdot
.36324 .30008 Mdot
.36333 .22803 Mdot
.36343 .17399 Mdot
.36352 .13347 Mdot
.36362 .10307 Mdot
.36371 .16596 Mdot
.36381 .12744 Mdot
.3639 .18728 Mdot
.364 .14343 Mdot
.3641 .20127 Mdot
.36419 .15392 Mdot
.36429 .21045 Mdot
.36438 .25991 Mdot
.36448 .30319 Mdot
.36457 .34106 Mdot
.36467 .25877 Mdot
.36476 .19705 Mdot
.36486 .15076 Mdot
.36495 .20768 Mdot
.36505 .25749 Mdot
.36514 .19609 Mdot
.36524 .15004 Mdot
.36533 .20705 Mdot
.36543 .25694 Mdot
.36552 .30059 Mdot
.36562 .22841 Mdot
.36571 .27563 Mdot
.36581 .31695 Mdot
.3659 .24068 Mdot
.366 .28636 Mdot
.3661 .32634 Mdot
.36619 .24772 Mdot
.36629 .18876 Mdot
.36638 .24094 Mdot
.36648 .18367 Mdot
.36657 .23648 Mdot
.36667 .28269 Mdot
.36676 .21499 Mdot
.36686 .26388 Mdot
.36695 .20089 Mdot
.36705 .25154 Mdot
.36714 .29587 Mdot
.36724 .33465 Mdot
.36733 .36859 Mdot
.36743 .27941 Mdot
.36752 .32026 Mdot
.36762 .24316 Mdot
.36771 .18534 Mdot
.36781 .23794 Mdot
.3679 .18143 Mdot
.368 .13904 Mdot
.3681 .19743 Mdot
.36819 .24852 Mdot
.36829 .18936 Mdot
.36838 .24146 Mdot
.36848 .28705 Mdot
.36857 .21826 Mdot
.36867 .26674 Mdot
.36876 .30917 Mdot
.36886 .34629 Mdot
.36895 .37877 Mdot
.36905 .28705 Mdot
.36914 .32694 Mdot
.36924 .36184 Mdot
.36933 .39238 Mdot
.36943 .29726 Mdot
.36952 .22591 Mdot
.36962 .17241 Mdot
.36971 .13228 Mdot
.36981 .10218 Mdot
.3699 .16517 Mdot
.37 .2203 Mdot
.3701 .26853 Mdot
.37019 .20437 Mdot
.37029 .15625 Mdot
.37038 .21248 Mdot
.37048 .26169 Mdot
.37057 .30475 Mdot
.37067 .23153 Mdot
.37076 .27836 Mdot
.37086 .31933 Mdot
.37095 .35519 Mdot
.37105 .26936 Mdot
.37114 .20499 Mdot
.37124 .25514 Mdot
.37133 .19432 Mdot
.37143 .2458 Mdot
.37152 .29085 Mdot
.37162 .22111 Mdot
.37171 .1688 Mdot
.37181 .22347 Mdot
.3719 .2713 Mdot
.372 .20645 Mdot
.3721 .15781 Mdot
.37219 .21385 Mdot
.37229 .26289 Mdot
.37238 .20014 Mdot
.37248 .15307 Mdot
.37257 .11778 Mdot
.37267 .0913 Mdot
.37276 .15566 Mdot
.37286 .21197 Mdot
.37295 .16195 Mdot
.37305 .21747 Mdot
.37314 .16608 Mdot
.37324 .22109 Mdot
.37333 .26922 Mdot
.37343 .31134 Mdot
.37352 .23647 Mdot
.37362 .18033 Mdot
.37371 .23355 Mdot
.37381 .28013 Mdot
.3739 .21307 Mdot
.374 .16277 Mdot
.3741 .12505 Mdot
.37419 .18519 Mdot
.37429 .23781 Mdot
.37438 .18133 Mdot
.37448 .23443 Mdot
.37457 .28089 Mdot
.37467 .32155 Mdot
.37476 .24413 Mdot
.37486 .18607 Mdot
.37495 .14253 Mdot
.37505 .20048 Mdot
.37514 .25119 Mdot
.37524 .29556 Mdot
.37533 .33438 Mdot
.37543 .25376 Mdot
.37552 .29781 Mdot
.37562 .33635 Mdot
.37571 .37007 Mdot
.37581 .39958 Mdot
.3759 .30266 Mdot
.376 .3406 Mdot
.3761 .25842 Mdot
.37619 .19678 Mdot
.37629 .24796 Mdot
.37638 .18894 Mdot
.37648 .14467 Mdot
.37657 .20236 Mdot
.37667 .25283 Mdot
.37676 .1926 Mdot
.37686 .14742 Mdot
.37695 .20476 Mdot
.37705 .25493 Mdot
.37714 .19417 Mdot
.37724 .24567 Mdot
.37733 .18722 Mdot
.37743 .23959 Mdot
.37752 .28541 Mdot
.37762 .21703 Mdot
.37771 .16574 Mdot
.37781 .22079 Mdot
.3779 .16857 Mdot
.378 .1294 Mdot
.3781 .18899 Mdot
.37819 .24113 Mdot
.37829 .18382 Mdot
.37838 .14084 Mdot
.37848 .1086 Mdot
.37857 .08442 Mdot
.37867 .14964 Mdot
.37876 .2067 Mdot
.37886 .25663 Mdot
.37895 .30032 Mdot
.37905 .33855 Mdot
.37914 .25688 Mdot
.37924 .30054 Mdot
.37933 .22838 Mdot
.37943 .2756 Mdot
.37952 .31692 Mdot
.37962 .24066 Mdot
.37971 .18347 Mdot
.37981 .2363 Mdot
.3799 .28253 Mdot
.38 .32298 Mdot
.3801 .35838 Mdot
.38019 .38935 Mdot
.38029 .41645 Mdot
.38038 .44016 Mdot
.38048 .46091 Mdot
.38057 .47907 Mdot
.38067 .49495 Mdot
.38076 .50885 Mdot
.38086 .52101 Mdot
.38095 .53166 Mdot
.38105 .54097 Mdot
.38114 .54911 Mdot
.38124 .55624 Mdot
.38133 .56248 Mdot
.38143 .56794 Mdot
.38152 .42893 Mdot
.38162 .32467 Mdot
.38171 .24647 Mdot
.38181 .29143 Mdot
.3819 .22154 Mdot
.382 .26962 Mdot
.3821 .31169 Mdot
.38219 .34849 Mdot
.38229 .26434 Mdot
.38238 .20123 Mdot
.38248 .15389 Mdot
.38257 .11839 Mdot
.38267 .17936 Mdot
.38276 .13749 Mdot
.38286 .19607 Mdot
.38295 .15003 Mdot
.38305 .20704 Mdot
.38314 .15825 Mdot
.38324 .12166 Mdot
.38333 .09422 Mdot
.38343 .15821 Mdot
.38352 .12163 Mdot
.38362 .09419 Mdot
.38371 .07362 Mdot
.38381 .05818 Mdot
.3839 .12668 Mdot
.384 .18661 Mdot
.3841 .23905 Mdot
.38419 .28494 Mdot
.38429 .21668 Mdot
.38438 .16548 Mdot
.38448 .12708 Mdot
.38457 .18696 Mdot
.38467 .23936 Mdot
.38476 .28521 Mdot
.38486 .32533 Mdot
.38495 .24697 Mdot
.38505 .1882 Mdot
.38514 .24044 Mdot
.38524 .1833 Mdot
.38533 .14045 Mdot
.38543 .19866 Mdot
.38552 .15197 Mdot
.38562 .20874 Mdot
.38571 .25842 Mdot
.38581 .30188 Mdot
.3859 .22938 Mdot
.386 .17501 Mdot
.3861 .2289 Mdot
.38619 .17465 Mdot
.38629 .22858 Mdot
.38638 .17441 Mdot
.38648 .13378 Mdot
.38657 .10331 Mdot
.38667 .16616 Mdot
.38676 .22116 Mdot
.38686 .16884 Mdot
.38695 .2235 Mdot
.38705 .27133 Mdot
.38714 .31319 Mdot
.38724 .34981 Mdot
.38733 .26533 Mdot
.38743 .30793 Mdot
.38752 .23392 Mdot
.38762 .17841 Mdot
.38771 .23188 Mdot
.38781 .27866 Mdot
.3879 .21197 Mdot
.388 .16195 Mdot
.3881 .21747 Mdot
.38819 .16608 Mdot
.38829 .22108 Mdot
.38838 .16878 Mdot
.38848 .12956 Mdot
.38857 .18913 Mdot
.38867 .14482 Mdot
.38876 .20249 Mdot
.38886 .15484 Mdot
.38895 .21125 Mdot
.38905 .26061 Mdot
.38914 .19843 Mdot
.38924 .2494 Mdot
.38933 .29399 Mdot
.38943 .22346 Mdot
.38952 .2713 Mdot
.38962 .31316 Mdot
.38971 .34978 Mdot
.38981 .38183 Mdot
.3899 .40987 Mdot
.39 .31037 Mdot
.3901 .23575 Mdot
.39019 .28205 Mdot
.39029 .21451 Mdot
.39038 .16385 Mdot
.39048 .21914 Mdot
.39057 .16733 Mdot
.39067 .12847 Mdot
.39076 .18818 Mdot
.39086 .1441 Mdot
.39095 .20186 Mdot
.39105 .2524 Mdot
.39114 .19227 Mdot
.39124 .244 Mdot
.39133 .28927 Mdot
.39143 .32888 Mdot
.39152 .24963 Mdot
.39162 .1902 Mdot
.39171 .24219 Mdot
.39181 .18461 Mdot
.3919 .14143 Mdot
.392 .19952 Mdot
.3921 .15261 Mdot
.39219 .2093 Mdot
.39229 .25891 Mdot
.39238 .30231 Mdot
.39248 .22971 Mdot
.39257 .17525 Mdot
.39267 .13441 Mdot
.39276 .19338 Mdot
.39286 .24497 Mdot
.39295 .1867 Mdot
.39305 .23913 Mdot
.39314 .18232 Mdot
.39324 .13971 Mdot
.39333 .19802 Mdot
.39343 .24903 Mdot
.39352 .29367 Mdot
.39362 .33273 Mdot
.39371 .36691 Mdot
.39381 .39681 Mdot
.3939 .42298 Mdot
.394 .44588 Mdot
.3941 .46591 Mdot
.39419 .3524 Mdot
.39429 .38412 Mdot
.39438 .29106 Mdot
.39448 .33045 Mdot
.39457 .36491 Mdot
.39467 .27665 Mdot
.39476 .21046 Mdot
.39486 .25992 Mdot
.39495 .3032 Mdot
.39505 .34107 Mdot
.39514 .25877 Mdot
.39524 .19705 Mdot
.39533 .15076 Mdot
.39543 .20768 Mdot
.39552 .25749 Mdot
.39562 .19609 Mdot
.39571 .15004 Mdot
.39581 .1155 Mdot
.3959 .17683 Mdot
.396 .2305 Mdot
.3961 .27745 Mdot
.39619 .31854 Mdot
.39629 .24188 Mdot
.39638 .28741 Mdot
.39648 .21853 Mdot
.39657 .16687 Mdot
.39667 .22178 Mdot
.39676 .1693 Mdot
.39686 .22391 Mdot
.39695 .1709 Mdot
.39705 .22531 Mdot
.39714 .17195 Mdot
.39724 .22623 Mdot
.39733 .17264 Mdot
.39743 .22683 Mdot
.39752 .27425 Mdot
.39762 .31573 Mdot
.39771 .35204 Mdot
.39781 .267 Mdot
.3979 .20322 Mdot
.398 .15539 Mdot
.3981 .11951 Mdot
.39819 .0926 Mdot
.39829 .1568 Mdot
.39838 .12057 Mdot
.39848 .18127 Mdot
.39857 .23438 Mdot
.39867 .17875 Mdot
.39876 .23218 Mdot
.39886 .17711 Mdot
.39895 .1358 Mdot
.39905 .10482 Mdot
.39914 .16749 Mdot
.39924 .22232 Mdot
.39933 .2703 Mdot
.39943 .31228 Mdot
.39952 .23718 Mdot
.39962 .18086 Mdot
.39971 .23402 Mdot
.39981 .17849 Mdot
.3999 .23194 Mdot
.4 .17693 Mdot
.4001 .13567 Mdot
.40019 .19448 Mdot
.40029 .24594 Mdot
.40038 .18742 Mdot
.40048 .14354 Mdot
.40057 .20137 Mdot
.40067 .25196 Mdot
.40076 .19194 Mdot
.40086 .24372 Mdot
.40095 .28902 Mdot
.40105 .32866 Mdot
.40114 .36335 Mdot
.40124 .3937 Mdot
.40133 .29825 Mdot
.40143 .33673 Mdot
.40152 .25552 Mdot
.40162 .29935 Mdot
.40171 .22748 Mdot
.40181 .17358 Mdot
.4019 .22765 Mdot
.402 .17371 Mdot
.4021 .13326 Mdot
.40219 .10291 Mdot
.40229 .16582 Mdot
.40238 .22086 Mdot
.40248 .26902 Mdot
.40257 .20474 Mdot
.40267 .25491 Mdot
.40276 .29882 Mdot
.40286 .22708 Mdot
.40295 .27447 Mdot
.40305 .31593 Mdot
.40314 .23992 Mdot
.40324 .2857 Mdot
.40333 .32575 Mdot
.40343 .3608 Mdot
.40352 .39147 Mdot
.40362 .41831 Mdot
.40371 .3167 Mdot
.40381 .2405 Mdot
.4039 .18334 Mdot
.404 .23619 Mdot
.4041 .28244 Mdot
.40419 .2148 Mdot
.40429 .26372 Mdot
.40438 .20076 Mdot
.40448 .15354 Mdot
.40457 .21012 Mdot
.40467 .16056 Mdot
.40476 .12339 Mdot
.40486 .18374 Mdot
.40495 .23654 Mdot
.40505 .28274 Mdot
.40514 .21503 Mdot
.40524 .26392 Mdot
.40533 .30669 Mdot
.40543 .23299 Mdot
.40552 .27964 Mdot
.40562 .2127 Mdot
.40571 .1625 Mdot
.40581 .12484 Mdot
.4059 .18501 Mdot
.406 .14173 Mdot
.4061 .19978 Mdot
.40619 .25058 Mdot
.40629 .29502 Mdot
.40638 .33391 Mdot
.40648 .36794 Mdot
.40657 .39772 Mdot
.40667 .42377 Mdot
.40676 .44657 Mdot
.40686 .3379 Mdot
.40695 .25639 Mdot
.40705 .19527 Mdot
.40714 .24663 Mdot
.40724 .29157 Mdot
.40733 .22165 Mdot
.40743 .16921 Mdot
.40752 .12988 Mdot
.40762 .18941 Mdot
.40771 .14503 Mdot
.40781 .20267 Mdot
.4079 .2531 Mdot
.408 .1928 Mdot
.4081 .24447 Mdot
.40819 .28968 Mdot
.40829 .22023 Mdot
.40838 .26847 Mdot
.40848 .31068 Mdot
.40857 .23598 Mdot
.40867 .17996 Mdot
.40876 .13794 Mdot
.40886 .10643 Mdot
.40895 .16889 Mdot
.40905 .12964 Mdot
.40914 .1892 Mdot
.40924 .24132 Mdot
.40933 .18396 Mdot
.40943 .23674 Mdot
.40952 .18052 Mdot
.40962 .23373 Mdot
.40971 .28028 Mdot
.40981 .32101 Mdot
.4099 .24373 Mdot
.41 .28903 Mdot
.4101 .21975 Mdot
.41019 .26805 Mdot
.41029 .20401 Mdot
.41038 .25427 Mdot
.41048 .29826 Mdot
.41057 .22667 Mdot
.41067 .2741 Mdot
.41076 .31561 Mdot
.41086 .35192 Mdot
.41095 .26691 Mdot
.41105 .30932 Mdot
.41114 .34642 Mdot
.41124 .37889 Mdot
.41133 .28714 Mdot
.41143 .32701 Mdot
.41152 .24823 Mdot
.41162 .29297 Mdot
.41171 .2227 Mdot
.41181 .27063 Mdot
.4119 .31257 Mdot
.412 .2374 Mdot
.4121 .18102 Mdot
.41219 .23416 Mdot
.41229 .17859 Mdot
.41238 .23204 Mdot
.41248 .2788 Mdot
.41257 .31972 Mdot
.41267 .24276 Mdot
.41276 .28818 Mdot
.41286 .32793 Mdot
.41295 .24892 Mdot
.41305 .18966 Mdot
.41314 .14522 Mdot
.41324 .11188 Mdot
.41333 .17367 Mdot
.41343 .13322 Mdot
.41352 .19234 Mdot
.41362 .14722 Mdot
.41371 .11339 Mdot
.41381 .17498 Mdot
.4139 .13421 Mdot
.414 .10363 Mdot
.4141 .16644 Mdot
.41419 .22141 Mdot
.41429 .16903 Mdot
.41438 .22367 Mdot
.41448 .27148 Mdot
.41457 .20658 Mdot
.41467 .15791 Mdot
.41476 .21394 Mdot
.41486 .16342 Mdot
.41495 .21876 Mdot
.41505 .16704 Mdot
.41514 .22193 Mdot
.41524 .16942 Mdot
.41533 .13004 Mdot
.41543 .1005 Mdot
.41552 .16371 Mdot
.41562 .12575 Mdot
.41571 .1858 Mdot
.41581 .23834 Mdot
.4159 .18173 Mdot
.416 .23478 Mdot
.4161 .2812 Mdot
.41619 .32182 Mdot
.41629 .24434 Mdot
.41638 .28956 Mdot
.41648 .22014 Mdot
.41657 .16808 Mdot
.41667 .22284 Mdot
.41676 .1701 Mdot
.41686 .13055 Mdot
.41695 .19 Mdot
.41705 .24202 Mdot
.41714 .28753 Mdot
.41724 .32736 Mdot
.41733 .24849 Mdot
.41743 .18934 Mdot
.41752 .14498 Mdot
.41762 .20262 Mdot
.41771 .15494 Mdot
.41781 .11917 Mdot
.4179 .09235 Mdot
.418 .15658 Mdot
.4181 .21277 Mdot
.41819 .16255 Mdot
.41829 .218 Mdot
.41838 .16647 Mdot
.41848 .22143 Mdot
.41857 .26952 Mdot
.41867 .20511 Mdot
.41876 .15681 Mdot
.41886 .12058 Mdot
.41895 .18127 Mdot
.41905 .23438 Mdot
.41914 .17876 Mdot
.41924 .23218 Mdot
.41933 .17711 Mdot
.41943 .23074 Mdot
.41952 .17602 Mdot
.41962 .13499 Mdot
.41971 .19388 Mdot
.41981 .24542 Mdot
.4199 .18703 Mdot
.42 .23942 Mdot
.4201 .28526 Mdot
.42019 .21692 Mdot
.42029 .26557 Mdot
.42038 .30815 Mdot
.42048 .23408 Mdot
.42057 .17853 Mdot
.42067 .13687 Mdot
.42076 .19553 Mdot
.42086 .24686 Mdot
.42095 .29177 Mdot
.42105 .2218 Mdot
.42114 .26984 Mdot
.42124 .31188 Mdot
.42133 .34866 Mdot
.42143 .26447 Mdot
.42152 .20132 Mdot
.42162 .25193 Mdot
.42171 .2962 Mdot
.42181 .33495 Mdot
.4219 .36885 Mdot
.422 .39851 Mdot
.4221 .30185 Mdot
.42219 .22936 Mdot
.42229 .27646 Mdot
.42238 .31767 Mdot
.42248 .35373 Mdot
.42257 .26827 Mdot
.42267 .3105 Mdot
.42276 .34746 Mdot
.42286 .26357 Mdot
.42295 .20065 Mdot
.42305 .15346 Mdot
.42314 .21004 Mdot
.42324 .1605 Mdot
.42333 .21621 Mdot
.42343 .16513 Mdot
.42352 .22026 Mdot
.42362 .26849 Mdot
.42371 .3107 Mdot
.42381 .34763 Mdot
.4239 .26369 Mdot
.424 .3065 Mdot
.4241 .23285 Mdot
.42419 .17761 Mdot
.42429 .23117 Mdot
.42438 .17635 Mdot
.42448 .23008 Mdot
.42457 .27709 Mdot
.42467 .21079 Mdot
.42476 .26021 Mdot
.42486 .19813 Mdot
.42495 .24913 Mdot
.42505 .29376 Mdot
.42514 .33281 Mdot
.42524 .36697 Mdot
.42533 .39687 Mdot
.42543 .42303 Mdot
.42552 .32024 Mdot
.42562 .35598 Mdot
.42571 .26996 Mdot
.42581 .20544 Mdot
.4259 .15705 Mdot
.426 .21319 Mdot
.4261 .16286 Mdot
.42619 .21827 Mdot
.42629 .16668 Mdot
.42638 .22161 Mdot
.42648 .26968 Mdot
.42657 .31174 Mdot
.42667 .34854 Mdot
.42676 .26437 Mdot
.42686 .3071 Mdot
.42695 .23329 Mdot
.42705 .17794 Mdot
.42714 .13643 Mdot
.42724 .19514 Mdot
.42733 .24652 Mdot
.42743 .29147 Mdot
.42752 .33081 Mdot
.42762 .25108 Mdot
.42771 .19128 Mdot
.42781 .24314 Mdot
.4279 .28851 Mdot
.428 .32822 Mdot
.4281 .36296 Mdot
.42819 .39336 Mdot
.42829 .29799 Mdot
.42838 .33651 Mdot
.42848 .25535 Mdot
.42857 .19449 Mdot
.42867 .24594 Mdot
.42876 .29097 Mdot
.42886 .33037 Mdot
.42895 .25075 Mdot
.42905 .29517 Mdot
.42914 .33404 Mdot
.42924 .36806 Mdot
.42933 .39782 Mdot
.42943 .30134 Mdot
.42952 .33944 Mdot
.42962 .25755 Mdot
.42971 .19613 Mdot
.42981 .15007 Mdot
.4299 .20708 Mdot
.43 .25696 Mdot
.4301 .30061 Mdot
.43019 .22843 Mdot
.43029 .17429 Mdot
.43038 .13369 Mdot
.43048 .19275 Mdot
.43057 .14753 Mdot
.43067 .20486 Mdot
.43076 .15662 Mdot
.43086 .21281 Mdot
.43095 .26198 Mdot
.43105 .19945 Mdot
.43114 .15256 Mdot
.43124 .20926 Mdot
.43133 .15992 Mdot
.43143 .2157 Mdot
.43152 .16474 Mdot
.43162 .12653 Mdot
.43171 .09787 Mdot
.43181 .1614 Mdot
.4319 .217 Mdot
.432 .26564 Mdot
.4321 .2022 Mdot
.43219 .15462 Mdot
.43229 .11894 Mdot
.43238 .17984 Mdot
.43248 .23313 Mdot
.43257 .17782 Mdot
.43267 .23136 Mdot
.43276 .17649 Mdot
.43286 .13534 Mdot
.43295 .19419 Mdot
.43305 .24569 Mdot
.43314 .29074 Mdot
.43324 .33017 Mdot
.43333 .36467 Mdot
.43343 .27647 Mdot
.43352 .21032 Mdot
.43362 .2598 Mdot
.43371 .19782 Mdot
.43381 .15134 Mdot
.4339 .20819 Mdot
.434 .15911 Mdot
.4341 .21499 Mdot
.43419 .26389 Mdot
.43429 .30667 Mdot
.43438 .23297 Mdot
.43448 .27962 Mdot
.43457 .32044 Mdot
.43467 .2433 Mdot
.43476 .18545 Mdot
.43486 .23803 Mdot
.43495 .28405 Mdot
.43505 .21601 Mdot
.43514 .16498 Mdot
.43524 .22012 Mdot
.43533 .26838 Mdot
.43543 .20425 Mdot
.43552 .25449 Mdot
.43562 .29845 Mdot
.43571 .33691 Mdot
.43581 .25565 Mdot
.4359 .29947 Mdot
.436 .3378 Mdot
.4361 .25632 Mdot
.43619 .19521 Mdot
.43629 .24658 Mdot
.43638 .18791 Mdot
.43648 .24019 Mdot
.43657 .28593 Mdot
.43667 .21742 Mdot
.43676 .26601 Mdot
.43686 .30853 Mdot
.43695 .34573 Mdot
.43705 .37828 Mdot
.43714 .40677 Mdot
.43724 .43169 Mdot
.43733 .4535 Mdot
.43743 .34309 Mdot
.43752 .37598 Mdot
.43762 .28495 Mdot
.43771 .3251 Mdot
.43781 .36023 Mdot
.4379 .27315 Mdot
.438 .20783 Mdot
.4381 .25762 Mdot
.43819 .30119 Mdot
.43829 .33931 Mdot
.43838 .25745 Mdot
.43848 .19606 Mdot
.43857 .15002 Mdot
.43867 .11548 Mdot
.43876 .17682 Mdot
.43886 .13558 Mdot
.43895 .10466 Mdot
.43905 .16735 Mdot
.43914 .2222 Mdot
.43924 .27019 Mdot
.43933 .31218 Mdot
.43943 .34893 Mdot
.43952 .26467 Mdot
.43962 .30735 Mdot
.43971 .3447 Mdot
.43981 .2615 Mdot
.4399 .1991 Mdot
.44 .15229 Mdot
.4401 .11719 Mdot
.44019 .09086 Mdot
.44029 .15528 Mdot
.44038 .21163 Mdot
.44048 .26095 Mdot
.44057 .3041 Mdot
.44067 .23105 Mdot
.44076 .27793 Mdot
.44086 .31896 Mdot
.44095 .35486 Mdot
.44105 .26912 Mdot
.44114 .20481 Mdot
.44124 .25498 Mdot
.44133 .29887 Mdot
.44143 .33728 Mdot
.44152 .37089 Mdot
.44162 .4003 Mdot
.44171 .30319 Mdot
.44181 .23037 Mdot
.4419 .27734 Mdot
.442 .31844 Mdot
.4421 .3544 Mdot
.44219 .38587 Mdot
.44229 .29238 Mdot
.44238 .3316 Mdot
.44248 .36592 Mdot
.44257 .27741 Mdot
.44267 .3185 Mdot
.44276 .35446 Mdot
.44286 .26881 Mdot
.44295 .31098 Mdot
.44305 .23621 Mdot
.44314 .18013 Mdot
.44324 .13807 Mdot
.44333 .19658 Mdot
.44343 .24777 Mdot
.44352 .29257 Mdot
.44362 .2224 Mdot
.44371 .16977 Mdot
.44381 .1303 Mdot
.4439 .18978 Mdot
.444 .24183 Mdot
.4441 .28737 Mdot
.44419 .32721 Mdot
.44429 .36208 Mdot
.44438 .27453 Mdot
.44448 .20887 Mdot
.44457 .15962 Mdot
.44467 .12269 Mdot
.44476 .09499 Mdot
.44486 .15888 Mdot
.44495 .21479 Mdot
.44505 .26371 Mdot
.44514 .30652 Mdot
.44524 .34397 Mdot
.44533 .37674 Mdot
.44543 .40542 Mdot
.44552 .43051 Mdot
.44562 .45246 Mdot
.44571 .47167 Mdot
.44581 .35673 Mdot
.4459 .38791 Mdot
.446 .2939 Mdot
.4461 .33293 Mdot
.44619 .36708 Mdot
.44629 .39697 Mdot
.44638 .42311 Mdot
.44648 .44599 Mdot
.44657 .46601 Mdot
.44667 .48353 Mdot
.44676 .36562 Mdot
.44686 .39569 Mdot
.44695 .29974 Mdot
.44705 .22777 Mdot
.44714 .27507 Mdot
.44724 .31645 Mdot
.44733 .35267 Mdot
.44743 .26747 Mdot
.44752 .30981 Mdot
.44762 .23533 Mdot
.44771 .17947 Mdot
.44781 .13757 Mdot
.4479 .10615 Mdot
.448 .16865 Mdot
.4481 .22334 Mdot
.44819 .27119 Mdot
.44829 .31306 Mdot
.44838 .23776 Mdot
.44848 .1813 Mdot
.44857 .2344 Mdot
.44867 .17877 Mdot
.44876 .13705 Mdot
.44886 .19569 Mdot
.44895 .247 Mdot
.44905 .29189 Mdot
.44914 .33117 Mdot
.44924 .25135 Mdot
.44933 .2957 Mdot
.44943 .33451 Mdot
.44952 .36846 Mdot
.44962 .27932 Mdot
.44971 .32017 Mdot
.44981 .35592 Mdot
.4499 .3872 Mdot
.45 .29337 Mdot
.4501 .223 Mdot
.45019 .17022 Mdot
.45029 .22471 Mdot
.45038 .1715 Mdot
.45048 .22584 Mdot
.45057 .17235 Mdot
.45067 .22657 Mdot
.45076 .1729 Mdot
.45086 .22706 Mdot
.45095 .17326 Mdot
.45105 .22737 Mdot
.45114 .1735 Mdot
.45124 .22758 Mdot
.45133 .17366 Mdot
.45143 .22772 Mdot
.45152 .27502 Mdot
.45162 .20924 Mdot
.45171 .25885 Mdot
.45181 .30226 Mdot
.4519 .34025 Mdot
.452 .37349 Mdot
.4521 .40257 Mdot
.45219 .3049 Mdot
.45229 .23165 Mdot
.45238 .17671 Mdot
.45248 .23039 Mdot
.45257 .27736 Mdot
.45267 .21099 Mdot
.45276 .26038 Mdot
.45286 .19826 Mdot
.45295 .24925 Mdot
.45305 .29386 Mdot
.45314 .33289 Mdot
.45324 .25264 Mdot
.45333 .19245 Mdot
.45343 .24416 Mdot
.45352 .18609 Mdot
.45362 .2386 Mdot
.45371 .28455 Mdot
.45381 .21638 Mdot
.4539 .2651 Mdot
.454 .30773 Mdot
.4541 .23377 Mdot
.45419 .1783 Mdot
.45429 .23178 Mdot
.45438 .17681 Mdot
.45448 .23047 Mdot
.45457 .27743 Mdot
.45467 .21105 Mdot
.45476 .26043 Mdot
.45486 .30365 Mdot
.45495 .34146 Mdot
.45505 .37455 Mdot
.45514 .4035 Mdot
.45524 .42883 Mdot
.45533 .32459 Mdot
.45543 .24642 Mdot
.45552 .18778 Mdot
.45562 .24008 Mdot
.45571 .18303 Mdot
.45581 .23592 Mdot
.4559 .2822 Mdot
.456 .21462 Mdot
.4561 .26356 Mdot
.45619 .20064 Mdot
.45629 .15345 Mdot
.45638 .11806 Mdot
.45648 .17907 Mdot
.45657 .23246 Mdot
.45667 .27917 Mdot
.45676 .21235 Mdot
.45686 .16223 Mdot
.45695 .21772 Mdot
.45705 .16626 Mdot
.45714 .22125 Mdot
.45724 .16891 Mdot
.45733 .12965 Mdot
.45743 .18921 Mdot
.45752 .14488 Mdot
.45762 .20254 Mdot
.45771 .25299 Mdot
.45781 .29714 Mdot
.4579 .22582 Mdot
.458 .17234 Mdot
.4581 .22657 Mdot
.45819 .1729 Mdot
.45829 .22705 Mdot
.45838 .27444 Mdot
.45848 .2088 Mdot
.45857 .25847 Mdot
.45867 .30193 Mdot
.45876 .22942 Mdot
.45886 .17503 Mdot
.45895 .22892 Mdot
.45905 .17466 Mdot
.45914 .2286 Mdot
.45924 .17442 Mdot
.45933 .22839 Mdot
.45943 .17426 Mdot
.45952 .13367 Mdot
.45962 .19273 Mdot
.45971 .14752 Mdot
.45981 .11361 Mdot
.4599 .08818 Mdot
.46 .15292 Mdot
.4601 .20958 Mdot
.46019 .16015 Mdot
.46029 .12309 Mdot
.46038 .18347 Mdot
.46048 .2363 Mdot
.46057 .28254 Mdot
.46067 .21487 Mdot
.46076 .26378 Mdot
.46086 .20081 Mdot
.46095 .15358 Mdot
.46105 .11815 Mdot
.46114 .17915 Mdot
.46124 .13734 Mdot
.46133 .19594 Mdot
.46143 .24721 Mdot
.46152 .18838 Mdot
.46162 .2406 Mdot
.46171 .18342 Mdot
.46181 .14054 Mdot
.4619 .10838 Mdot
.462 .1706 Mdot
.4621 .22504 Mdot
.46219 .27268 Mdot
.46229 .31436 Mdot
.46238 .23874 Mdot
.46248 .18203 Mdot
.46257 .13949 Mdot
.46267 .19783 Mdot
.46276 .24887 Mdot
.46286 .29353 Mdot
.46295 .3326 Mdot
.46305 .25242 Mdot
.46314 .19229 Mdot
.46324 .14719 Mdot
.46333 .20456 Mdot
.46343 .25476 Mdot
.46352 .19404 Mdot
.46362 .1485 Mdot
.46371 .11435 Mdot
.46381 .08873 Mdot
.4639 .15341 Mdot
.464 .21 Mdot
.4641 .25952 Mdot
.46419 .19761 Mdot
.46429 .15118 Mdot
.46438 .20805 Mdot
.46448 .15901 Mdot
.46457 .12223 Mdot
.46467 .18272 Mdot
.46476 .14001 Mdot
.46486 .10798 Mdot
.46495 .17025 Mdot
.46505 .22474 Mdot
.46514 .27241 Mdot
.46524 .20728 Mdot
.46533 .25714 Mdot
.46543 .30077 Mdot
.46552 .22855 Mdot
.46562 .17438 Mdot
.46571 .22835 Mdot
.46581 .17424 Mdot
.4659 .22822 Mdot
.466 .17414 Mdot
.4661 .13358 Mdot
.46619 .10315 Mdot
.46629 .16603 Mdot
.46638 .22104 Mdot
.46648 .26918 Mdot
.46657 .3113 Mdot
.46667 .34816 Mdot
.46676 .26409 Mdot
.46686 .30685 Mdot
.46695 .23311 Mdot
.46705 .27974 Mdot
.46714 .21277 Mdot
.46724 .16255 Mdot
.46733 .12489 Mdot
.46743 .18504 Mdot
.46752 .23768 Mdot
.46762 .28374 Mdot
.46771 .32404 Mdot
.46781 .3593 Mdot
.4679 .27245 Mdot
.468 .20731 Mdot
.4681 .25716 Mdot
.46819 .30079 Mdot
.46829 .33896 Mdot
.46838 .25719 Mdot
.46848 .19586 Mdot
.46857 .24715 Mdot
.46867 .29202 Mdot
.46876 .33129 Mdot
.46886 .25144 Mdot
.46895 .19155 Mdot
.46905 .24337 Mdot
.46914 .28872 Mdot
.46924 .3284 Mdot
.46933 .24927 Mdot
.46943 .18992 Mdot
.46952 .24195 Mdot
.46962 .28748 Mdot
.46971 .21858 Mdot
.46981 .16691 Mdot
.4699 .22181 Mdot
.47 .26985 Mdot
.4701 .31189 Mdot
.47019 .23689 Mdot
.47029 .18064 Mdot
.47038 .13845 Mdot
.47048 .19691 Mdot
.47057 .24807 Mdot
.47067 .18902 Mdot
.47076 .14474 Mdot
.47086 .20241 Mdot
.47095 .25288 Mdot
.47105 .29704 Mdot
.47114 .22575 Mdot
.47124 .2733 Mdot
.47133 .31491 Mdot
.47143 .35131 Mdot
.47152 .26646 Mdot
.47162 .30892 Mdot
.47171 .23466 Mdot
.47181 .17897 Mdot
.4719 .23236 Mdot
.472 .17724 Mdot
.4721 .23086 Mdot
.47219 .17611 Mdot
.47229 .22987 Mdot
.47238 .17537 Mdot
.47248 .1345 Mdot
.47257 .19346 Mdot
.47267 .24504 Mdot
.47276 .18675 Mdot
.47286 .14304 Mdot
.47295 .11025 Mdot
.47305 .08566 Mdot
.47314 .15072 Mdot
.47324 .20765 Mdot
.47333 .15871 Mdot
.47343 .122 Mdot
.47352 .18252 Mdot
.47362 .23547 Mdot
.47371 .17958 Mdot
.47381 .2329 Mdot
.4739 .27955 Mdot
.474 .32038 Mdot
.4741 .24326 Mdot
.47419 .18541 Mdot
.47429 .238 Mdot
.47438 .28402 Mdot
.47448 .32429 Mdot
.47457 .35952 Mdot
.47467 .39035 Mdot
.47476 .41732 Mdot
.47486 .44093 Mdot
.47495 .33367 Mdot
.47505 .36773 Mdot
.47514 .39753 Mdot
.47524 .30112 Mdot
.47533 .22881 Mdot
.47543 .27598 Mdot
.47552 .20995 Mdot
.47562 .16044 Mdot
.47571 .21615 Mdot
.47581 .16508 Mdot
.4759 .22022 Mdot
.476 .26846 Mdot
.4761 .31067 Mdot
.47619 .23597 Mdot
.47629 .17995 Mdot
.47638 .23323 Mdot
.47648 .27984 Mdot
.47657 .32063 Mdot
.47667 .35632 Mdot
.47676 .27021 Mdot
.47686 .20563 Mdot
.47695 .15719 Mdot
.47705 .12087 Mdot
.47714 .18153 Mdot
.47724 .2346 Mdot
.47733 .28105 Mdot
.47743 .32169 Mdot
.47752 .35724 Mdot
.47762 .38836 Mdot
.47771 .29424 Mdot
.47781 .22365 Mdot
.4779 .17071 Mdot
.478 .131 Mdot
.4781 .10122 Mdot
.47819 .16434 Mdot
.47829 .21957 Mdot
.47838 .26789 Mdot
.47848 .31017 Mdot
.47857 .2356 Mdot
.47867 .28192 Mdot
.47876 .32245 Mdot
.47886 .35791 Mdot
.47895 .2714 Mdot
.47905 .31325 Mdot
.47914 .34986 Mdot
.47924 .26537 Mdot
.47933 .202 Mdot
.47943 .15447 Mdot
.47952 .21093 Mdot
.47962 .26033 Mdot
.47971 .30356 Mdot
.47981 .23064 Mdot
.4799 .27758 Mdot
.48 .31865 Mdot
.4801 .35459 Mdot
.48019 .38603 Mdot
.48029 .2925 Mdot
.48038 .22234 Mdot
.48048 .16973 Mdot
.48057 .22428 Mdot
.48067 .27201 Mdot
.48076 .20698 Mdot
.48086 .25688 Mdot
.48095 .19563 Mdot
.48105 .24694 Mdot
.48114 .29185 Mdot
.48124 .22186 Mdot
.48133 .26989 Mdot
.48143 .31192 Mdot
.48152 .23691 Mdot
.48162 .18066 Mdot
.48171 .23384 Mdot
.48181 .28038 Mdot
.4819 .21326 Mdot
.482 .26237 Mdot
.4821 .19975 Mdot
.48219 .15278 Mdot
.48229 .20945 Mdot
.48238 .25904 Mdot
.48248 .19725 Mdot
.48257 .24836 Mdot
.48267 .29309 Mdot
.48276 .22279 Mdot
.48286 .27071 Mdot
.48295 .31264 Mdot
.48305 .23745 Mdot
.48314 .18106 Mdot
.48324 .13876 Mdot
.48333 .19719 Mdot
.48343 .15086 Mdot
.48352 .11612 Mdot
.48362 .09006 Mdot
.48371 .15457 Mdot
.48381 .21102 Mdot
.4839 .26041 Mdot
.484 .19828 Mdot
.4841 .24926 Mdot
.48419 .18992 Mdot
.48429 .24195 Mdot
.48438 .18443 Mdot
.48448 .23715 Mdot
.48457 .18083 Mdot
.48467 .234 Mdot
.48476 .17847 Mdot
.48486 .23193 Mdot
.48495 .27871 Mdot
.48505 .212 Mdot
.48514 .16197 Mdot
.48524 .12445 Mdot
.48533 .18466 Mdot
.48543 .23735 Mdot
.48552 .18098 Mdot
.48562 .13871 Mdot
.48571 .19714 Mdot
.48581 .15083 Mdot
.4859 .20774 Mdot
.486 .25754 Mdot
.4861 .30112 Mdot
.48619 .33925 Mdot
.48629 .37261 Mdot
.48638 .4018 Mdot
.48648 .30432 Mdot
.48657 .23121 Mdot
.48667 .27808 Mdot
.48676 .31909 Mdot
.48686 .24229 Mdot
.48695 .28777 Mdot
.48705 .32757 Mdot
.48714 .36239 Mdot
.48724 .39286 Mdot
.48733 .41952 Mdot
.48743 .44285 Mdot
.48752 .46326 Mdot
.48762 .48112 Mdot
.48771 .49675 Mdot
.48781 .51043 Mdot
.4879 .52239 Mdot
.488 .53286 Mdot
.4881 .40262 Mdot
.48819 .30493 Mdot
.48829 .23167 Mdot
.48838 .27848 Mdot
.48848 .21183 Mdot
.48857 .26112 Mdot
.48867 .19881 Mdot
.48876 .24973 Mdot
.48886 .19027 Mdot
.48895 .14567 Mdot
.48905 .20323 Mdot
.48914 .2536 Mdot
.48924 .19317 Mdot
.48933 .14785 Mdot
.48943 .20514 Mdot
.48952 .25526 Mdot
.48962 .19442 Mdot
.48971 .24588 Mdot
.48981 .29092 Mdot
.4899 .33032 Mdot
.49 .25071 Mdot
.4901 .19101 Mdot
.49019 .14623 Mdot
.49029 .20372 Mdot
.49038 .15576 Mdot
.49048 .11979 Mdot
.49057 .18058 Mdot
.49067 .23378 Mdot
.49076 .28033 Mdot
.49086 .32105 Mdot
.49095 .24376 Mdot
.49105 .28906 Mdot
.49114 .3287 Mdot
.49124 .24949 Mdot
.49133 .19009 Mdot
.49143 .2421 Mdot
.49152 .2876 Mdot
.49162 .21867 Mdot
.49171 .16698 Mdot
.49181 .1282 Mdot
.4919 .09912 Mdot
.492 .1625 Mdot
.4921 .21796 Mdot
.49219 .16644 Mdot
.49229 .2214 Mdot
.49238 .16902 Mdot
.49248 .22366 Mdot
.49257 .27148 Mdot
.49267 .20658 Mdot
.49276 .1579 Mdot
.49286 .1214 Mdot
.49295 .09402 Mdot
.49305 .15804 Mdot
.49314 .1215 Mdot
.49324 .18208 Mdot
.49333 .23509 Mdot
.49343 .28147 Mdot
.49352 .32206 Mdot
.49362 .35757 Mdot
.49371 .27115 Mdot
.49381 .31302 Mdot
.4939 .34966 Mdot
.494 .38172 Mdot
.4941 .28926 Mdot
.49419 .32887 Mdot
.49429 .36353 Mdot
.49438 .39386 Mdot
.49448 .4204 Mdot
.49457 .31827 Mdot
.49467 .24167 Mdot
.49476 .28723 Mdot
.49486 .3271 Mdot
.49495 .36198 Mdot
.49505 .3925 Mdot
.49514 .41921 Mdot
.49524 .44257 Mdot
.49533 .3349 Mdot
.49543 .36881 Mdot
.49552 .27958 Mdot
.49562 .3204 Mdot
.49571 .24327 Mdot
.49581 .18542 Mdot
.4959 .14204 Mdot
.496 .20005 Mdot
.4961 .15301 Mdot
.49619 .20965 Mdot
.49629 .25922 Mdot
.49638 .30258 Mdot
.49648 .22991 Mdot
.49657 .1754 Mdot
.49667 .13452 Mdot
.49676 .19348 Mdot
.49686 .14808 Mdot
.49695 .11403 Mdot
.49705 .08849 Mdot
.49714 .1532 Mdot
.49724 .20982 Mdot
.49733 .25936 Mdot
.49743 .19749 Mdot
.49752 .24857 Mdot
.49762 .29327 Mdot
.49771 .33238 Mdot
.49781 .3666 Mdot
.4979 .39654 Mdot
.498 .30038 Mdot
.4981 .3386 Mdot
.49819 .25692 Mdot
.49829 .30058 Mdot
.49838 .2284 Mdot
.49848 .27562 Mdot
.49857 .20969 Mdot
.49867 .25924 Mdot
.49876 .30261 Mdot
.49886 .22993 Mdot
.49895 .17542 Mdot
.49905 .22926 Mdot
.49914 .27637 Mdot
.49924 .31759 Mdot
.49933 .24117 Mdot
.49943 .18385 Mdot
.49952 .14086 Mdot
.49962 .10861 Mdot
.49971 .1708 Mdot
.49981 .13107 Mdot
.4999 .19046 Mdot
.5 .14582 Mdot
.5001 .11233 Mdot
.50019 .17406 Mdot
.50029 .22807 Mdot
.50038 .27533 Mdot
.50048 .20947 Mdot
.50057 .16007 Mdot
.50067 .21583 Mdot
.50076 .16485 Mdot
.50086 .12661 Mdot
.50095 .09793 Mdot
.50105 .16145 Mdot
.50114 .21704 Mdot
.50124 .26568 Mdot
.50133 .30824 Mdot
.50143 .23415 Mdot
.50152 .17858 Mdot
.50162 .13691 Mdot
.50171 .19556 Mdot
.50181 .24689 Mdot
.5019 .29179 Mdot
.502 .22182 Mdot
.5021 .26986 Mdot
.50219 .20537 Mdot
.50229 .25546 Mdot
.50238 .19457 Mdot
.50248 .24602 Mdot
.50257 .18748 Mdot
.50267 .23982 Mdot
.50276 .18283 Mdot
.50286 .23575 Mdot
.50295 .17978 Mdot
.50305 .23308 Mdot
.50314 .27971 Mdot
.50324 .32052 Mdot
.50333 .24336 Mdot
.50343 .28871 Mdot
.50352 .2195 Mdot
.50362 .1676 Mdot
.50371 .22242 Mdot
.50381 .16978 Mdot
.5039 .22433 Mdot
.504 .17122 Mdot
.5041 .13139 Mdot
.50419 .19073 Mdot
.50429 .14602 Mdot
.50438 .20354 Mdot
.50448 .15562 Mdot
.50457 .21194 Mdot
.50467 .16193 Mdot
.50476 .12442 Mdot
.50486 .18463 Mdot
.50495 .14145 Mdot
.50505 .10906 Mdot
.50514 .17119 Mdot
.50524 .22556 Mdot
.50533 .27313 Mdot
.50543 .31476 Mdot
.50552 .35119 Mdot
.50562 .38306 Mdot
.50571 .41094 Mdot
.50581 .43534 Mdot
.5059 .45669 Mdot
.506 .47538 Mdot
.5061 .49172 Mdot
.50619 .50603 Mdot
.50629 .38249 Mdot
.50638 .41045 Mdot
.50648 .31081 Mdot
.50657 .23608 Mdot
.50667 .28234 Mdot
.50676 .21472 Mdot
.50686 .16401 Mdot
.50695 .21928 Mdot
.50705 .26764 Mdot
.50714 .2037 Mdot
.50724 .15575 Mdot
.50733 .21205 Mdot
.50743 .16201 Mdot
.50752 .21752 Mdot
.50762 .2661 Mdot
.50771 .30861 Mdot
.50781 .3458 Mdot
.5079 .37834 Mdot
.508 .40682 Mdot
.5081 .43174 Mdot
.50819 .32677 Mdot
.50829 .3617 Mdot
.50838 .39225 Mdot
.50848 .41899 Mdot
.50857 .44238 Mdot
.50867 .33476 Mdot
.50876 .25404 Mdot
.50886 .29805 Mdot
.50895 .22651 Mdot
.50905 .27397 Mdot
.50914 .31549 Mdot
.50924 .23959 Mdot
.50933 .18266 Mdot
.50943 .2356 Mdot
.50952 .28192 Mdot
.50962 .32245 Mdot
.50971 .24481 Mdot
.50981 .18658 Mdot
.5099 .1429 Mdot
.51 .20081 Mdot
.5101 .15358 Mdot
.51019 .21015 Mdot
.51029 .25965 Mdot
.51038 .19771 Mdot
.51048 .24876 Mdot
.51057 .29344 Mdot
.51067 .33253 Mdot
.51076 .36673 Mdot
.51086 .39666 Mdot
.51095 .30046 Mdot
.51105 .33867 Mdot
.51114 .37211 Mdot
.51124 .40136 Mdot
.51133 .42696 Mdot
.51143 .32319 Mdot
.51152 .35856 Mdot
.51162 .27189 Mdot
.51171 .31367 Mdot
.51181 .35023 Mdot
.5119 .38222 Mdot
.512 .41021 Mdot
.5121 .43471 Mdot
.51219 .45614 Mdot
.51229 .34507 Mdot
.51238 .26178 Mdot
.51248 .1993 Mdot
.51257 .25016 Mdot
.51267 .29466 Mdot
.51276 .33359 Mdot
.51286 .25317 Mdot
.51295 .29729 Mdot
.51305 .3359 Mdot
.51314 .36968 Mdot
.51324 .28023 Mdot
.51333 .32097 Mdot
.51343 .35662 Mdot
.51352 .27043 Mdot
.51362 .2058 Mdot
.51371 .25584 Mdot
.51381 .29963 Mdot
.5139 .22769 Mdot
.514 .275 Mdot
.5141 .31639 Mdot
.51419 .24027 Mdot
.51429 .286 Mdot
.51438 .32602 Mdot
.51448 .36104 Mdot
.51457 .39168 Mdot
.51467 .29673 Mdot
.51476 .33541 Mdot
.51486 .25453 Mdot
.51495 .29848 Mdot
.51505 .33694 Mdot
.51514 .37059 Mdot
.51524 .40003 Mdot
.51533 .303 Mdot
.51543 .23022 Mdot
.51552 .27721 Mdot
.51562 .31833 Mdot
.51571 .24172 Mdot
.51581 .18426 Mdot
.5159 .14117 Mdot
.516 .19929 Mdot
.5161 .15244 Mdot
.51619 .1173 Mdot
.51629 .17841 Mdot
.51638 .23187 Mdot
.51648 .27866 Mdot
.51657 .31959 Mdot
.51667 .24267 Mdot
.51676 .2881 Mdot
.51686 .32786 Mdot
.51695 .24886 Mdot
.51705 .18962 Mdot
.51714 .24169 Mdot
.51724 .28724 Mdot
.51733 .32711 Mdot
.51743 .36199 Mdot
.51752 .27446 Mdot
.51762 .20882 Mdot
.51771 .25848 Mdot
.51781 .30194 Mdot
.5179 .33997 Mdot
.518 .25795 Mdot
.5181 .19643 Mdot
.51819 .1503 Mdot
.51829 .20728 Mdot
.51838 .15843 Mdot
.51848 .21439 Mdot
.51857 .26336 Mdot
.51867 .20049 Mdot
.51876 .15334 Mdot
.51886 .11798 Mdot
.51895 .179 Mdot
.51905 .23239 Mdot
.51914 .27911 Mdot
.51924 .21231 Mdot
.51933 .26154 Mdot
.51943 .19912 Mdot
.51952 .25 Mdot
.51962 .29452 Mdot
.51971 .33347 Mdot
.51981 .25308 Mdot
.5199 .19278 Mdot
.52 .24445 Mdot
.5201 .28966 Mdot
.52019 .32922 Mdot
.52029 .24989 Mdot
.52038 .29442 Mdot
.52048 .22379 Mdot
.52057 .27158 Mdot
.52067 .20666 Mdot
.52076 .15796 Mdot
.52086 .12144 Mdot
.52095 .18203 Mdot
.52105 .23505 Mdot
.52114 .28144 Mdot
.52124 .21405 Mdot
.52133 .26306 Mdot
.52143 .20027 Mdot
.52152 .15317 Mdot
.52162 .20979 Mdot
.52171 .16032 Mdot
.52181 .21605 Mdot
.5219 .16501 Mdot
.522 .12673 Mdot
.5221 .18665 Mdot
.52219 .23909 Mdot
.52229 .28497 Mdot
.52238 .32512 Mdot
.52248 .24681 Mdot
.52257 .18808 Mdot
.52267 .24034 Mdot
.52276 .18322 Mdot
.52286 .23609 Mdot
.52295 .28235 Mdot
.52305 .21473 Mdot
.52314 .16402 Mdot
.52324 .12599 Mdot
.52333 .18601 Mdot
.52343 .14248 Mdot
.52352 .10983 Mdot
.52362 .17187 Mdot
.52371 .22615 Mdot
.52381 .17259 Mdot
.5239 .22678 Mdot
.524 .2742 Mdot
.5241 .20862 Mdot
.52419 .15944 Mdot
.52429 .21528 Mdot
.52438 .26414 Mdot
.52448 .30689 Mdot
.52457 .3443 Mdot
.52467 .26119 Mdot
.52476 .19887 Mdot
.52486 .15212 Mdot
.52495 .20887 Mdot
.52505 .25853 Mdot
.52514 .30199 Mdot
.52524 .22946 Mdot
.52533 .17507 Mdot
.52543 .13427 Mdot
.52552 .19326 Mdot
.52562 .14791 Mdot
.52571 .20519 Mdot
.52581 .25531 Mdot
.5259 .29917 Mdot
.526 .33754 Mdot
.5261 .25613 Mdot
.52619 .29988 Mdot
.52629 .22788 Mdot
.52638 .17388 Mdot
.52648 .22792 Mdot
.52657 .17391 Mdot
.52667 .22794 Mdot
.52676 .27521 Mdot
.52686 .20938 Mdot
.52695 .25898 Mdot
.52705 .30237 Mdot
.52714 .34035 Mdot
.52724 .37357 Mdot
.52733 .28315 Mdot
.52743 .32352 Mdot
.52752 .24561 Mdot
.52762 .18718 Mdot
.52771 .23955 Mdot
.52781 .28538 Mdot
.5279 .217 Mdot
.528 .16572 Mdot
.5281 .22078 Mdot
.52819 .16855 Mdot
.52829 .22325 Mdot
.52838 .27112 Mdot
.52848 .31299 Mdot
.52857 .34964 Mdot
.52867 .3817 Mdot
.52876 .28925 Mdot
.52886 .32886 Mdot
.52895 .24962 Mdot
.52905 .19018 Mdot
.52914 .14561 Mdot
.52924 .11218 Mdot
.52933 .17392 Mdot
.52943 .22795 Mdot
.52952 .17394 Mdot
.52962 .13342 Mdot
.52971 .19251 Mdot
.52981 .24422 Mdot
.5299 .18613 Mdot
.53 .14257 Mdot
.5301 .1099 Mdot
.53019 .17193 Mdot
.53029 .22621 Mdot
.53038 .17263 Mdot
.53048 .22682 Mdot
.53057 .27423 Mdot
.53067 .20865 Mdot
.53076 .15946 Mdot
.53086 .12256 Mdot
.53095 .18301 Mdot
.53105 .2359 Mdot
.53114 .28218 Mdot
.53124 .21461 Mdot
.53133 .26355 Mdot
.53143 .20064 Mdot
.53152 .25132 Mdot
.53162 .19146 Mdot
.53171 .14657 Mdot
.53181 .1129 Mdot
.5319 .08765 Mdot
.532 .15246 Mdot
.5321 .20917 Mdot
.53219 .25879 Mdot
.53229 .19707 Mdot
.53238 .2482 Mdot
.53248 .18912 Mdot
.53257 .14481 Mdot
.53267 .20248 Mdot
.53276 .15483 Mdot
.53286 .21125 Mdot
.53295 .26061 Mdot
.53305 .19843 Mdot
.53314 .24939 Mdot
.53324 .29399 Mdot
.53333 .33301 Mdot
.53343 .36715 Mdot
.53352 .27833 Mdot
.53362 .21172 Mdot
.53371 .16176 Mdot
.53381 .21731 Mdot
.5339 .26592 Mdot
.534 .20241 Mdot
.5341 .25288 Mdot
.53419 .29703 Mdot
.53429 .22575 Mdot
.53438 .17228 Mdot
.53448 .13218 Mdot
.53457 .10211 Mdot
.53467 .07955 Mdot
.53476 .14538 Mdot
.53486 .20297 Mdot
.53495 .1552 Mdot
.53505 .21157 Mdot
.53514 .16165 Mdot
.53524 .21721 Mdot
.53533 .26583 Mdot
.53543 .30837 Mdot
.53552 .23425 Mdot
.53562 .17866 Mdot
.53571 .23209 Mdot
.53581 .27885 Mdot
.5359 .21211 Mdot
.536 .16205 Mdot
.5361 .12451 Mdot
.53619 .18472 Mdot
.53629 .14151 Mdot
.53638 .19959 Mdot
.53648 .25041 Mdot
.53657 .19078 Mdot
.53667 .14605 Mdot
.53676 .11251 Mdot
.53686 .17422 Mdot
.53695 .22821 Mdot
.53705 .17413 Mdot
.53714 .22813 Mdot
.53724 .17407 Mdot
.53733 .22808 Mdot
.53743 .17403 Mdot
.53752 .22805 Mdot
.53762 .17401 Mdot
.53771 .22802 Mdot
.53781 .27529 Mdot
.5379 .20944 Mdot
.538 .25903 Mdot
.5381 .30242 Mdot
.53819 .22978 Mdot
.53829 .27683 Mdot
.53838 .21059 Mdot
.53848 .16092 Mdot
.53857 .12366 Mdot
.53867 .18397 Mdot
.53876 .23674 Mdot
.53886 .28292 Mdot
.53895 .32332 Mdot
.53905 .35868 Mdot
.53914 .27198 Mdot
.53924 .20695 Mdot
.53933 .25685 Mdot
.53943 .30052 Mdot
.53952 .22836 Mdot
.53962 .27558 Mdot
.53971 .3169 Mdot
.53981 .35306 Mdot
.5399 .26777 Mdot
.54 .2038 Mdot
.5401 .15582 Mdot
.54019 .21211 Mdot
.54029 .16205 Mdot
.54038 .21757 Mdot
.54048 .16615 Mdot
.54057 .12758 Mdot
.54067 .1874 Mdot
.54076 .23974 Mdot
.54086 .28555 Mdot
.54095 .21713 Mdot
.54105 .26576 Mdot
.54114 .20229 Mdot
.54124 .15469 Mdot
.54133 .11899 Mdot
.54143 .17988 Mdot
.54152 .23317 Mdot
.54162 .17785 Mdot
.54171 .13636 Mdot
.54181 .19508 Mdot
.5419 .14928 Mdot
.542 .20639 Mdot
.5421 .25636 Mdot
.54219 .30008 Mdot
.54229 .22803 Mdot
.54238 .174 Mdot
.54248 .22802 Mdot
.54257 .17398 Mdot
.54267 .228 Mdot
.54276 .17397 Mdot
.54286 .228 Mdot
.54295 .17397 Mdot
.54305 .22799 Mdot
.54314 .17396 Mdot
.54324 .22799 Mdot
.54333 .27526 Mdot
.54343 .31662 Mdot
.54352 .24044 Mdot
.54362 .28615 Mdot
.54371 .32615 Mdot
.54381 .36115 Mdot
.5439 .27383 Mdot
.544 .20835 Mdot
.5441 .25807 Mdot
.54419 .19653 Mdot
.54429 .24773 Mdot
.54438 .18877 Mdot
.54448 .14455 Mdot
.54457 .20225 Mdot
.54467 .25273 Mdot
.54476 .29691 Mdot
.54486 .33557 Mdot
.54495 .36939 Mdot
.54505 .39898 Mdot
.54514 .42488 Mdot
.54524 .44754 Mdot
.54533 .33862 Mdot
.54543 .25694 Mdot
.54552 .19568 Mdot
.54562 .24699 Mdot
.54571 .29188 Mdot
.54581 .33116 Mdot
.5459 .25134 Mdot
.546 .19148 Mdot
.5461 .24331 Mdot
.54619 .18546 Mdot
.54629 .14206 Mdot
.54638 .20007 Mdot
.54648 .25083 Mdot
.54657 .29525 Mdot
.54667 .22441 Mdot
.54676 .27212 Mdot
.54686 .20707 Mdot
.54695 .25695 Mdot
.54705 .3006 Mdot
.54714 .22842 Mdot
.54724 .17429 Mdot
.54733 .13369 Mdot
.54743 .10324 Mdot
.54752 .1661 Mdot
.54762 .12755 Mdot
.54771 .09863 Mdot
.54781 .16207 Mdot
.5479 .12452 Mdot
.548 .09636 Mdot
.5481 .16009 Mdot
.54819 .21585 Mdot
.54829 .16486 Mdot
.54838 .12661 Mdot
.54848 .18655 Mdot
.54857 .239 Mdot
.54867 .18222 Mdot
.54876 .23521 Mdot
.54886 .28158 Mdot
.54895 .21416 Mdot
.54905 .26316 Mdot
.54914 .30603 Mdot
.54924 .23249 Mdot
.54933 .17734 Mdot
.54943 .13598 Mdot
.54952 .19475 Mdot
.54962 .14903 Mdot
.54971 .20617 Mdot
.54981 .1576 Mdot
.5499 .21367 Mdot
.55 .16322 Mdot
.5501 .12539 Mdot
.55019 .09701 Mdot
.55029 .07573 Mdot
.55038 .05977 Mdot
.55048 .12807 Mdot
.55057 .18783 Mdot
.55067 .14384 Mdot
.55076 .11085 Mdot
.55086 .08611 Mdot
.55095 .06755 Mdot
.55105 .13488 Mdot
.55114 .10413 Mdot
.55124 .08107 Mdot
.55133 .06377 Mdot
.55143 .13157 Mdot
.55152 .19089 Mdot
.55162 .2428 Mdot
.55171 .18507 Mdot
.55181 .23771 Mdot
.5519 .18125 Mdot
.552 .13891 Mdot
.5521 .19731 Mdot
.55219 .24842 Mdot
.55229 .18929 Mdot
.55238 .24139 Mdot
.55248 .28699 Mdot
.55257 .21821 Mdot
.55267 .16663 Mdot
.55276 .12794 Mdot
.55286 .09893 Mdot
.55295 .07717 Mdot
.55305 .14329 Mdot
.55314 .20115 Mdot
.55324 .15383 Mdot
.55333 .11835 Mdot
.55343 .17932 Mdot
.55352 .23267 Mdot
.55362 .17748 Mdot
.55371 .13608 Mdot
.55381 .10503 Mdot
.5539 .08174 Mdot
.554 .06428 Mdot
.5541 .13201 Mdot
.55419 .19128 Mdot
.55429 .24314 Mdot
.55438 .18533 Mdot
.55448 .23793 Mdot
.55457 .28396 Mdot
.55467 .21594 Mdot
.55476 .26471 Mdot
.55486 .20151 Mdot
.55495 .25209 Mdot
.55505 .29635 Mdot
.55514 .33507 Mdot
.55524 .25427 Mdot
.55533 .19368 Mdot
.55543 .24524 Mdot
.55552 .1869 Mdot
.55562 .14315 Mdot
.55571 .20102 Mdot
.55581 .25166 Mdot
.5559 .29597 Mdot
.556 .33474 Mdot
.5561 .25403 Mdot
.55619 .29804 Mdot
.55629 .2265 Mdot
.55638 .17285 Mdot
.55648 .22701 Mdot
.55657 .2744 Mdot
.55667 .31587 Mdot
.55676 .35216 Mdot
.55686 .38391 Mdot
.55695 .2909 Mdot
.55705 .22115 Mdot
.55714 .16883 Mdot
.55724 .2235 Mdot
.55733 .17059 Mdot
.55743 .13092 Mdot
.55752 .19032 Mdot
.55762 .14571 Mdot
.55771 .11226 Mdot
.55781 .08716 Mdot
.5579 .15204 Mdot
.558 .2088 Mdot
.5581 .25847 Mdot
.55819 .30193 Mdot
.55829 .33996 Mdot
.55838 .25794 Mdot
.55848 .19643 Mdot
.55857 .24764 Mdot
.55867 .1887 Mdot
.55876 .24088 Mdot
.55886 .28654 Mdot
.55895 .21788 Mdot
.55905 .26641 Mdot
.55914 .20278 Mdot
.55924 .2532 Mdot
.55933 .29732 Mdot
.55943 .33592 Mdot
.55952 .3697 Mdot
.55962 .39926 Mdot
.55971 .42512 Mdot
.55981 .44775 Mdot
.5599 .46755 Mdot
.56 .35363 Mdot
.5601 .3852 Mdot
.56019 .41282 Mdot
.56029 .43698 Mdot
.56038 .33071 Mdot
.56048 .36514 Mdot
.56057 .39526 Mdot
.56067 .42162 Mdot
.56076 .44469 Mdot
.56086 .46487 Mdot
.56095 .48253 Mdot
.56105 .49798 Mdot
.56114 .5115 Mdot
.56124 .52334 Mdot
.56133 .53369 Mdot
.56143 .54274 Mdot
.56152 .55067 Mdot
.56162 .55761 Mdot
.56171 .56367 Mdot
.56181 .56898 Mdot
.5619 .57363 Mdot
.562 .57769 Mdot
.5621 .58125 Mdot
.56219 .58436 Mdot
.56229 .58709 Mdot
.56238 .58947 Mdot
.56248 .59155 Mdot
.56257 .59338 Mdot
.56267 .59497 Mdot
.56276 .59637 Mdot
.56286 .59759 Mdot
.56295 .59866 Mdot
.56305 .5996 Mdot
.56314 .60042 Mdot
.56324 .60113 Mdot
.56333 .60176 Mdot
.56343 .60231 Mdot
.56352 .60279 Mdot
.56362 .60321 Mdot
.56371 .60358 Mdot
.56381 .6039 Mdot
.5639 .60418 Mdot
.564 .60443 Mdot
.5641 .60464 Mdot
.56419 .60483 Mdot
.56429 .60499 Mdot
.56438 .60514 Mdot
.56448 .60526 Mdot
.56457 .60538 Mdot
.56467 .60547 Mdot
.56476 .60556 Mdot
.56486 .60563 Mdot
.56495 .6057 Mdot
.56505 .60575 Mdot
.56514 .6058 Mdot
.56524 .60585 Mdot
.56533 .60588 Mdot
.56543 .60592 Mdot
.56552 .60595 Mdot
.56562 .60597 Mdot
.56571 .60599 Mdot
.56581 .60601 Mdot
.5659 .60603 Mdot
.566 .60604 Mdot
.5661 .60606 Mdot
.56619 .60607 Mdot
.56629 .60608 Mdot
.56638 .60609 Mdot
.56648 .6061 Mdot
.56657 .6061 Mdot
.56667 .60611 Mdot
.56676 .60611 Mdot
.56686 .60612 Mdot
.56695 .60612 Mdot
.56705 .60612 Mdot
.56714 .60613 Mdot
.56724 .60613 Mdot
.56733 .60613 Mdot
.56743 .60613 Mdot
.56752 .60614 Mdot
.56762 .60614 Mdot
.56771 .60614 Mdot
.56781 .60614 Mdot
.5679 .60614 Mdot
.568 .60614 Mdot
.5681 .60614 Mdot
.56819 .60614 Mdot
.56829 .60614 Mdot
.56838 .60615 Mdot
.56848 .60615 Mdot
.56857 .60615 Mdot
.56867 .60615 Mdot
.56876 .60615 Mdot
.56886 .60615 Mdot
.56895 .60615 Mdot
.56905 .60615 Mdot
.56914 .60615 Mdot
.56924 .60615 Mdot
.56933 .60615 Mdot
.56943 .60615 Mdot
.56952 .60615 Mdot
.56962 .60615 Mdot
.56971 .60615 Mdot
.56981 .60615 Mdot
.5699 .60615 Mdot
.57 .60615 Mdot
.5701 .60615 Mdot
.57019 .60615 Mdot
.57029 .60615 Mdot
.57038 .60615 Mdot
.57048 .60615 Mdot
.57057 .60615 Mdot
.57067 .60615 Mdot
.57076 .60615 Mdot
.57086 .60615 Mdot
.57095 .60615 Mdot
.57105 .60615 Mdot
.57114 .60615 Mdot
.57124 .60615 Mdot
.57133 .60615 Mdot
.57143 .60615 Mdot
.57152 .60615 Mdot
.57162 .60615 Mdot
.57171 .60615 Mdot
.57181 .60615 Mdot
.5719 .60615 Mdot
.572 .60615 Mdot
.5721 .60615 Mdot
.57219 .60615 Mdot
.57229 .60615 Mdot
.57238 .60615 Mdot
.57248 .60615 Mdot
.57257 .60615 Mdot
.57267 .60615 Mdot
.57276 .60615 Mdot
.57286 .60615 Mdot
.57295 .60615 Mdot
.57305 .60615 Mdot
.57314 .60615 Mdot
.57324 .60615 Mdot
.57333 .60615 Mdot
.57343 .60615 Mdot
.57352 .60615 Mdot
.57362 .60615 Mdot
.57371 .60615 Mdot
.57381 .60615 Mdot
.5739 .60615 Mdot
.574 .60615 Mdot
.5741 .60615 Mdot
.57419 .60615 Mdot
.57429 .60615 Mdot
.57438 .60615 Mdot
.57448 .60615 Mdot
.57457 .60615 Mdot
.57467 .60615 Mdot
.57476 .60615 Mdot
.57486 .60615 Mdot
.57495 .60615 Mdot
.57505 .60615 Mdot
.57514 .60615 Mdot
.57524 .60615 Mdot
.57533 .60615 Mdot
.57543 .60615 Mdot
.57552 .60615 Mdot
.57562 .60615 Mdot
.57571 .60615 Mdot
.57581 .60615 Mdot
.5759 .60615 Mdot
.576 .60615 Mdot
.5761 .60615 Mdot
.57619 .60615 Mdot
.57629 .60615 Mdot
.57638 .60615 Mdot
.57648 .60615 Mdot
.57657 .60615 Mdot
.57667 .60615 Mdot
.57676 .60615 Mdot
.57686 .60615 Mdot
.57695 .60615 Mdot
.57705 .60615 Mdot
.57714 .60615 Mdot
.57724 .60615 Mdot
.57733 .60615 Mdot
.57743 .60615 Mdot
.57752 .60615 Mdot
.57762 .60615 Mdot
.57771 .60615 Mdot
.57781 .60615 Mdot
.5779 .60615 Mdot
.578 .60615 Mdot
.5781 .60615 Mdot
.57819 .60615 Mdot
.57829 .60615 Mdot
.57838 .60615 Mdot
.57848 .60615 Mdot
.57857 .60615 Mdot
.57867 .60615 Mdot
.57876 .60615 Mdot
.57886 .60615 Mdot
.57895 .60615 Mdot
.57905 .60615 Mdot
.57914 .60615 Mdot
.57924 .60615 Mdot
.57933 .60615 Mdot
.57943 .60615 Mdot
.57952 .60615 Mdot
.57962 .60615 Mdot
.57971 .60615 Mdot
.57981 .60615 Mdot
.5799 .60615 Mdot
.58 .60615 Mdot
.5801 .60615 Mdot
.58019 .60615 Mdot
.58029 .60615 Mdot
.58038 .60615 Mdot
.58048 .60615 Mdot
.58057 .60615 Mdot
.58067 .60615 Mdot
.58076 .60615 Mdot
.58086 .60615 Mdot
.58095 .60615 Mdot
.58105 .60615 Mdot
.58114 .60615 Mdot
.58124 .60615 Mdot
.58133 .60615 Mdot
.58143 .60615 Mdot
.58152 .60615 Mdot
.58162 .60615 Mdot
.58171 .60615 Mdot
.58181 .60615 Mdot
.5819 .60615 Mdot
.582 .60615 Mdot
.5821 .60615 Mdot
.58219 .60615 Mdot
.58229 .60615 Mdot
.58238 .60615 Mdot
.58248 .60615 Mdot
.58257 .60615 Mdot
.58267 .60615 Mdot
.58276 .60615 Mdot
.58286 .60615 Mdot
.58295 .60615 Mdot
.58305 .60615 Mdot
.58314 .60615 Mdot
.58324 .60615 Mdot
.58333 .60615 Mdot
.58343 .60615 Mdot
.58352 .60615 Mdot
.58362 .60615 Mdot
.58371 .60615 Mdot
.58381 .60615 Mdot
.5839 .60615 Mdot
.584 .60615 Mdot
.5841 .60615 Mdot
.58419 .60615 Mdot
.58429 .60615 Mdot
.58438 .60615 Mdot
.58448 .60615 Mdot
.58457 .60615 Mdot
.58467 .60615 Mdot
.58476 .60615 Mdot
.58486 .60615 Mdot
.58495 .60615 Mdot
.58505 .60615 Mdot
.58514 .60615 Mdot
.58524 .60615 Mdot
.58533 .60615 Mdot
.58543 .60615 Mdot
.58552 .60615 Mdot
.58562 .60615 Mdot
.58571 .60615 Mdot
.58581 .60615 Mdot
.5859 .60615 Mdot
.586 .60615 Mdot
.5861 .60615 Mdot
.58619 .60615 Mdot
.58629 .60615 Mdot
.58638 .60615 Mdot
.58648 .60615 Mdot
.58657 .60615 Mdot
.58667 .60615 Mdot
.58676 .60615 Mdot
.58686 .60615 Mdot
.58695 .60615 Mdot
.58705 .60615 Mdot
.58714 .60615 Mdot
.58724 .60615 Mdot
.58733 .60615 Mdot
.58743 .60615 Mdot
.58752 .60615 Mdot
.58762 .60615 Mdot
.58771 .60615 Mdot
.58781 .60615 Mdot
.5879 .60615 Mdot
.588 .60615 Mdot
.5881 .60615 Mdot
.58819 .60615 Mdot
.58829 .60615 Mdot
.58838 .60615 Mdot
.58848 .60615 Mdot
.58857 .60615 Mdot
.58867 .60615 Mdot
.58876 .60615 Mdot
.58886 .60615 Mdot
.58895 .60615 Mdot
.58905 .60615 Mdot
.58914 .60615 Mdot
.58924 .60615 Mdot
.58933 .60615 Mdot
.58943 .60615 Mdot
.58952 .60615 Mdot
.58962 .60615 Mdot
.58971 .60615 Mdot
.58981 .60615 Mdot
.5899 .60615 Mdot
.59 .60615 Mdot
.5901 .60615 Mdot
.59019 .60615 Mdot
.59029 .60615 Mdot
.59038 .60615 Mdot
.59048 .60615 Mdot
.59057 .60615 Mdot
.59067 .60615 Mdot
.59076 .60615 Mdot
.59086 .60615 Mdot
.59095 .60615 Mdot
.59105 .60615 Mdot
.59114 .60615 Mdot
.59124 .60615 Mdot
.59133 .60615 Mdot
.59143 .60615 Mdot
.59152 .60615 Mdot
.59162 .60615 Mdot
.59171 .60615 Mdot
.59181 .60615 Mdot
.5919 .60615 Mdot
.592 .60615 Mdot
.5921 .60615 Mdot
.59219 .60615 Mdot
.59229 .60615 Mdot
.59238 .60615 Mdot
.59248 .60615 Mdot
.59257 .60615 Mdot
.59267 .60615 Mdot
.59276 .60615 Mdot
.59286 .60615 Mdot
.59295 .60615 Mdot
.59305 .60615 Mdot
.59314 .60615 Mdot
.59324 .60615 Mdot
.59333 .60615 Mdot
.59343 .60615 Mdot
.59352 .60615 Mdot
.59362 .60615 Mdot
.59371 .60615 Mdot
.59381 .60615 Mdot
.5939 .60615 Mdot
.594 .60615 Mdot
.5941 .60615 Mdot
.59419 .60615 Mdot
.59429 .60615 Mdot
.59438 .60615 Mdot
.59448 .60615 Mdot
.59457 .60615 Mdot
.59467 .60615 Mdot
.59476 .60615 Mdot
.59486 .60615 Mdot
.59495 .60615 Mdot
.59505 .60615 Mdot
.59514 .60615 Mdot
.59524 .60615 Mdot
.59533 .60615 Mdot
.59543 .60615 Mdot
.59552 .60615 Mdot
.59562 .60615 Mdot
.59571 .60615 Mdot
.59581 .60615 Mdot
.5959 .60615 Mdot
.596 .60615 Mdot
.5961 .60615 Mdot
.59619 .60615 Mdot
.59629 .60615 Mdot
.59638 .60615 Mdot
.59648 .60615 Mdot
.59657 .60615 Mdot
.59667 .60615 Mdot
.59676 .60615 Mdot
.59686 .60615 Mdot
.59695 .60615 Mdot
.59705 .60615 Mdot
.59714 .60615 Mdot
.59724 .60615 Mdot
.59733 .60615 Mdot
.59743 .60615 Mdot
.59752 .60615 Mdot
.59762 .60615 Mdot
.59771 .60615 Mdot
.59781 .60615 Mdot
.5979 .60615 Mdot
.598 .60615 Mdot
.5981 .60615 Mdot
.59819 .60615 Mdot
.59829 .60615 Mdot
.59838 .60615 Mdot
.59848 .60615 Mdot
.59857 .60615 Mdot
.59867 .60615 Mdot
.59876 .60615 Mdot
.59886 .60615 Mdot
.59895 .60615 Mdot
.59905 .60615 Mdot
.59914 .60615 Mdot
.59924 .60615 Mdot
.59933 .60615 Mdot
.59943 .60615 Mdot
.59952 .60615 Mdot
.59962 .60615 Mdot
.59971 .60615 Mdot
.59981 .60615 Mdot
.5999 .60615 Mdot
.6 .60615 Mdot
.6001 .60615 Mdot
.60019 .60615 Mdot
.60029 .60615 Mdot
.60038 .60615 Mdot
.60048 .60615 Mdot
.60057 .60615 Mdot
.60067 .60615 Mdot
.60076 .60615 Mdot
.60086 .60615 Mdot
.60095 .60615 Mdot
.60105 .60615 Mdot
.60114 .60615 Mdot
.60124 .60615 Mdot
.60133 .60615 Mdot
.60143 .60615 Mdot
.60152 .60615 Mdot
.60162 .60615 Mdot
.60171 .60615 Mdot
.60181 .60615 Mdot
.6019 .60615 Mdot
.602 .60615 Mdot
.6021 .60615 Mdot
.60219 .60615 Mdot
.60229 .60615 Mdot
.60238 .60615 Mdot
.60248 .60615 Mdot
.60257 .60615 Mdot
.60267 .60615 Mdot
.60276 .60615 Mdot
.60286 .60615 Mdot
.60295 .60615 Mdot
.60305 .60615 Mdot
.60314 .60615 Mdot
.60324 .60615 Mdot
.60333 .60615 Mdot
.60343 .60615 Mdot
.60352 .60615 Mdot
.60362 .60615 Mdot
.60371 .60615 Mdot
.60381 .60615 Mdot
.6039 .60615 Mdot
.604 .60615 Mdot
.6041 .60615 Mdot
.60419 .60615 Mdot
.60429 .60615 Mdot
.60438 .60615 Mdot
.60448 .60615 Mdot
.60457 .60615 Mdot
.60467 .60615 Mdot
.60476 .60615 Mdot
.60486 .60615 Mdot
.60495 .60615 Mdot
.60505 .60615 Mdot
.60514 .60615 Mdot
.60524 .60615 Mdot
.60533 .60615 Mdot
.60543 .60615 Mdot
.60552 .60615 Mdot
.60562 .60615 Mdot
.60571 .60615 Mdot
.60581 .60615 Mdot
.6059 .60615 Mdot
.606 .60615 Mdot
.6061 .60615 Mdot
.60619 .60615 Mdot
.60629 .60615 Mdot
.60638 .60615 Mdot
.60648 .60615 Mdot
.60657 .60615 Mdot
.60667 .60615 Mdot
.60676 .60615 Mdot
.60686 .60615 Mdot
.60695 .60615 Mdot
.60705 .60615 Mdot
.60714 .60615 Mdot
.60724 .60615 Mdot
.60733 .60615 Mdot
.60743 .60615 Mdot
.60752 .60615 Mdot
.60762 .60615 Mdot
.60771 .60615 Mdot
.60781 .60615 Mdot
.6079 .60615 Mdot
.608 .60615 Mdot
.6081 .60615 Mdot
.60819 .60615 Mdot
.60829 .60615 Mdot
.60838 .60615 Mdot
.60848 .60615 Mdot
.60857 .60615 Mdot
.60867 .60615 Mdot
.60876 .60615 Mdot
.60886 .60615 Mdot
.60895 .60615 Mdot
.60905 .60615 Mdot
.60914 .60615 Mdot
.60924 .60615 Mdot
.60933 .60615 Mdot
.60943 .60615 Mdot
.60952 .60615 Mdot
.60962 .60615 Mdot
.60971 .60615 Mdot
.60981 .60615 Mdot
.6099 .60615 Mdot
.61 .60615 Mdot
.6101 .60615 Mdot
.61019 .60615 Mdot
.61029 .60615 Mdot
.61038 .60615 Mdot
.61048 .60615 Mdot
.61057 .60615 Mdot
.61067 .60615 Mdot
.61076 .60615 Mdot
.61086 .60615 Mdot
.61095 .60615 Mdot
.61105 .60615 Mdot
.61114 .60615 Mdot
.61124 .60615 Mdot
.61133 .60615 Mdot
.61143 .60615 Mdot
.61152 .60615 Mdot
.61162 .60615 Mdot
.61171 .60615 Mdot
.61181 .60615 Mdot
.6119 .60615 Mdot
.612 .60615 Mdot
.6121 .60615 Mdot
.61219 .60615 Mdot
.61229 .60615 Mdot
.61238 .60615 Mdot
.61248 .60615 Mdot
.61257 .60615 Mdot
.61267 .60615 Mdot
.61276 .60615 Mdot
.61286 .60615 Mdot
.61295 .60615 Mdot
.61305 .60615 Mdot
.61314 .60615 Mdot
.61324 .60615 Mdot
.61333 .60615 Mdot
.61343 .60615 Mdot
.61352 .60615 Mdot
.61362 .60615 Mdot
.61371 .60615 Mdot
.61381 .60615 Mdot
.6139 .60615 Mdot
.614 .60615 Mdot
.6141 .60615 Mdot
.61419 .60615 Mdot
.61429 .60615 Mdot
.61438 .60615 Mdot
.61448 .60615 Mdot
.61457 .60615 Mdot
.61467 .60615 Mdot
.61476 .60615 Mdot
.61486 .60615 Mdot
.61495 .60615 Mdot
.61505 .60615 Mdot
.61514 .60615 Mdot
.61524 .60615 Mdot
.61533 .60615 Mdot
.61543 .60615 Mdot
.61552 .60615 Mdot
.61562 .60615 Mdot
.61571 .60615 Mdot
.61581 .60615 Mdot
.6159 .60615 Mdot
.616 .60615 Mdot
.6161 .60615 Mdot
.61619 .60615 Mdot
.61629 .60615 Mdot
.61638 .60615 Mdot
.61648 .60615 Mdot
.61657 .60615 Mdot
.61667 .60615 Mdot
.61676 .60615 Mdot
.61686 .60615 Mdot
.61695 .60615 Mdot
.61705 .60615 Mdot
.61714 .60615 Mdot
.61724 .60615 Mdot
.61733 .60615 Mdot
.61743 .60615 Mdot
.61752 .60615 Mdot
.61762 .60615 Mdot
.61771 .60615 Mdot
.61781 .60615 Mdot
.6179 .60615 Mdot
.618 .60615 Mdot
.6181 .60615 Mdot
.61819 .60615 Mdot
.61829 .60615 Mdot
.61838 .60615 Mdot
.61848 .60615 Mdot
.61857 .60615 Mdot
.61867 .60615 Mdot
.61876 .60615 Mdot
.61886 .60615 Mdot
.61895 .60615 Mdot
.61905 .60615 Mdot
.61914 .60615 Mdot
.61924 .60615 Mdot
.61933 .60615 Mdot
.61943 .60615 Mdot
.61952 .60615 Mdot
.61962 .60615 Mdot
.61971 .60615 Mdot
.61981 .60615 Mdot
.6199 .60615 Mdot
.62 .60615 Mdot
.6201 .60615 Mdot
.62019 .60615 Mdot
.62029 .60615 Mdot
.62038 .60615 Mdot
.62048 .60615 Mdot
.62057 .60615 Mdot
.62067 .60615 Mdot
.62076 .60615 Mdot
.62086 .60615 Mdot
.62095 .60615 Mdot
.62105 .60615 Mdot
.62114 .60615 Mdot
.62124 .60615 Mdot
.62133 .60615 Mdot
.62143 .60615 Mdot
.62152 .60615 Mdot
.62162 .60615 Mdot
.62171 .60615 Mdot
.62181 .60615 Mdot
.6219 .60615 Mdot
.622 .60615 Mdot
.6221 .60615 Mdot
.62219 .60615 Mdot
.62229 .60615 Mdot
.62238 .60615 Mdot
.62248 .60615 Mdot
.62257 .60615 Mdot
.62267 .60615 Mdot
.62276 .60615 Mdot
.62286 .60615 Mdot
.62295 .60615 Mdot
.62305 .60615 Mdot
.62314 .60615 Mdot
.62324 .60615 Mdot
.62333 .60615 Mdot
.62343 .60615 Mdot
.62352 .60615 Mdot
.62362 .60615 Mdot
.62371 .60615 Mdot
.62381 .60615 Mdot
.6239 .60615 Mdot
.624 .60615 Mdot
.6241 .60615 Mdot
.62419 .60615 Mdot
.62429 .60615 Mdot
.62438 .60615 Mdot
.62448 .60615 Mdot
.62457 .60615 Mdot
.62467 .60615 Mdot
.62476 .60615 Mdot
.62486 .60615 Mdot
.62495 .60615 Mdot
.62505 .60615 Mdot
.62514 .60615 Mdot
.62524 .60615 Mdot
.62533 .60615 Mdot
.62543 .60615 Mdot
.62552 .60615 Mdot
.62562 .60615 Mdot
.62571 .60615 Mdot
.62581 .60615 Mdot
.6259 .60615 Mdot
.626 .60615 Mdot
.6261 .60615 Mdot
.62619 .60615 Mdot
.62629 .60615 Mdot
.62638 .60615 Mdot
.62648 .60615 Mdot
.62657 .60615 Mdot
.62667 .60615 Mdot
.62676 .60615 Mdot
.62686 .60615 Mdot
.62695 .60615 Mdot
.62705 .60615 Mdot
.62714 .60615 Mdot
.62724 .60615 Mdot
.62733 .60615 Mdot
.62743 .60615 Mdot
.62752 .60615 Mdot
.62762 .60615 Mdot
.62771 .60615 Mdot
.62781 .60615 Mdot
.6279 .60615 Mdot
.628 .60615 Mdot
.6281 .60615 Mdot
.62819 .60615 Mdot
.62829 .60615 Mdot
.62838 .60615 Mdot
.62848 .60615 Mdot
.62857 .60615 Mdot
.62867 .60615 Mdot
.62876 .60615 Mdot
.62886 .60615 Mdot
.62895 .60615 Mdot
.62905 .60615 Mdot
.62914 .60615 Mdot
.62924 .60615 Mdot
.62933 .60615 Mdot
.62943 .60615 Mdot
.62952 .60615 Mdot
.62962 .60615 Mdot
.62971 .60615 Mdot
.62981 .60615 Mdot
.6299 .60615 Mdot
.63 .60615 Mdot
.6301 .60615 Mdot
.63019 .60615 Mdot
.63029 .60615 Mdot
.63038 .60615 Mdot
.63048 .60615 Mdot
.63057 .60615 Mdot
.63067 .60615 Mdot
.63076 .60615 Mdot
.63086 .60615 Mdot
.63095 .60615 Mdot
.63105 .60615 Mdot
.63114 .60615 Mdot
.63124 .60615 Mdot
.63133 .60615 Mdot
.63143 .60615 Mdot
.63152 .60615 Mdot
.63162 .60615 Mdot
.63171 .60615 Mdot
.63181 .60615 Mdot
.6319 .60615 Mdot
.632 .60615 Mdot
.6321 .60615 Mdot
.63219 .60615 Mdot
.63229 .60615 Mdot
.63238 .60615 Mdot
.63248 .60615 Mdot
.63257 .60615 Mdot
.63267 .60615 Mdot
.63276 .60615 Mdot
.63286 .60615 Mdot
.63295 .60615 Mdot
.63305 .60615 Mdot
.63314 .60615 Mdot
.63324 .60615 Mdot
.63333 .60615 Mdot
.63343 .60615 Mdot
.63352 .60615 Mdot
.63362 .60615 Mdot
.63371 .60615 Mdot
.63381 .60615 Mdot
.6339 .60615 Mdot
.634 .60615 Mdot
.6341 .60615 Mdot
.63419 .60615 Mdot
.63429 .60615 Mdot
.63438 .60615 Mdot
.63448 .60615 Mdot
.63457 .60615 Mdot
.63467 .60615 Mdot
.63476 .60615 Mdot
.63486 .60615 Mdot
.63495 .60615 Mdot
.63505 .60615 Mdot
.63514 .60615 Mdot
.63524 .60615 Mdot
.63533 .60615 Mdot
.63543 .60615 Mdot
.63552 .60615 Mdot
.63562 .60615 Mdot
.63571 .60615 Mdot
.63581 .60615 Mdot
.6359 .60615 Mdot
.636 .60615 Mdot
.6361 .60615 Mdot
.63619 .60615 Mdot
.63629 .60615 Mdot
.63638 .60615 Mdot
.63648 .60615 Mdot
.63657 .60615 Mdot
.63667 .60615 Mdot
.63676 .60615 Mdot
.63686 .60615 Mdot
.63695 .60615 Mdot
.63705 .60615 Mdot
.63714 .60615 Mdot
.63724 .60615 Mdot
.63733 .60615 Mdot
.63743 .60615 Mdot
.63752 .60615 Mdot
.63762 .60615 Mdot
.63771 .60615 Mdot
.63781 .60615 Mdot
.6379 .60615 Mdot
.638 .60615 Mdot
.6381 .60615 Mdot
.63819 .60615 Mdot
.63829 .60615 Mdot
.63838 .60615 Mdot
.63848 .60615 Mdot
.63857 .60615 Mdot
.63867 .60615 Mdot
.63876 .60615 Mdot
.63886 .60615 Mdot
.63895 .60615 Mdot
.63905 .60615 Mdot
.63914 .60615 Mdot
.63924 .60615 Mdot
.63933 .60615 Mdot
.63943 .60615 Mdot
.63952 .60615 Mdot
.63962 .60615 Mdot
.63971 .60615 Mdot
.63981 .60615 Mdot
.6399 .60615 Mdot
.64 .60615 Mdot
.6401 .60615 Mdot
.64019 .60615 Mdot
.64029 .60615 Mdot
.64038 .60615 Mdot
.64048 .60615 Mdot
.64057 .60615 Mdot
.64067 .60615 Mdot
.64076 .60615 Mdot
.64086 .60615 Mdot
.64095 .60615 Mdot
.64105 .60615 Mdot
.64114 .60615 Mdot
.64124 .60615 Mdot
.64133 .60615 Mdot
.64143 .60615 Mdot
.64152 .60615 Mdot
.64162 .60615 Mdot
.64171 .60615 Mdot
.64181 .60615 Mdot
.6419 .60615 Mdot
.642 .60615 Mdot
.6421 .60615 Mdot
.64219 .60615 Mdot
.64229 .60615 Mdot
.64238 .60615 Mdot
.64248 .60615 Mdot
.64257 .60615 Mdot
.64267 .60615 Mdot
.64276 .60615 Mdot
.64286 .60615 Mdot
.64295 .60615 Mdot
.64305 .60615 Mdot
.64314 .60615 Mdot
.64324 .60615 Mdot
.64333 .60615 Mdot
.64343 .60615 Mdot
.64352 .60615 Mdot
.64362 .60615 Mdot
.64371 .60615 Mdot
.64381 .60615 Mdot
.6439 .60615 Mdot
.644 .60615 Mdot
.6441 .60615 Mdot
.64419 .60615 Mdot
.64429 .60615 Mdot
.64438 .60615 Mdot
.64448 .60615 Mdot
.64457 .60615 Mdot
.64467 .60615 Mdot
.64476 .60615 Mdot
.64486 .60615 Mdot
.64495 .60615 Mdot
.64505 .60615 Mdot
.64514 .60615 Mdot
.64524 .60615 Mdot
.64533 .60615 Mdot
.64543 .60615 Mdot
.64552 .60615 Mdot
.64562 .60615 Mdot
.64571 .60615 Mdot
.64581 .60615 Mdot
.6459 .60615 Mdot
.646 .60615 Mdot
.6461 .60615 Mdot
.64619 .60615 Mdot
.64629 .60615 Mdot
.64638 .60615 Mdot
.64648 .60615 Mdot
.64657 .60615 Mdot
.64667 .60615 Mdot
.64676 .60615 Mdot
.64686 .60615 Mdot
.64695 .60615 Mdot
.64705 .60615 Mdot
.64714 .60615 Mdot
.64724 .60615 Mdot
.64733 .60615 Mdot
.64743 .60615 Mdot
.64752 .60615 Mdot
.64762 .60615 Mdot
.64771 .60615 Mdot
.64781 .60615 Mdot
.6479 .60615 Mdot
.648 .60615 Mdot
.6481 .60615 Mdot
.64819 .60615 Mdot
.64829 .60615 Mdot
.64838 .60615 Mdot
.64848 .60615 Mdot
.64857 .60615 Mdot
.64867 .60615 Mdot
.64876 .60615 Mdot
.64886 .60615 Mdot
.64895 .60615 Mdot
.64905 .60615 Mdot
.64914 .60615 Mdot
.64924 .60615 Mdot
.64933 .60615 Mdot
.64943 .60615 Mdot
.64952 .60615 Mdot
.64962 .60615 Mdot
.64971 .60615 Mdot
.64981 .60615 Mdot
.6499 .60615 Mdot
.65 .60615 Mdot
.6501 .60615 Mdot
.65019 .60615 Mdot
.65029 .60615 Mdot
.65038 .60615 Mdot
.65048 .60615 Mdot
.65057 .60615 Mdot
.65067 .60615 Mdot
.65076 .60615 Mdot
.65086 .60615 Mdot
.65095 .60615 Mdot
.65105 .60615 Mdot
.65114 .60615 Mdot
.65124 .60615 Mdot
.65133 .60615 Mdot
.65143 .60615 Mdot
.65152 .60615 Mdot
.65162 .60615 Mdot
.65171 .60615 Mdot
.65181 .60615 Mdot
.6519 .60615 Mdot
.652 .60615 Mdot
.6521 .60615 Mdot
.65219 .60615 Mdot
.65229 .60615 Mdot
.65238 .60615 Mdot
.65248 .60615 Mdot
.65257 .60615 Mdot
.65267 .60615 Mdot
.65276 .60615 Mdot
.65286 .60615 Mdot
.65295 .60615 Mdot
.65305 .60615 Mdot
.65314 .60615 Mdot
.65324 .60615 Mdot
.65333 .60615 Mdot
.65343 .60615 Mdot
.65352 .60615 Mdot
.65362 .60615 Mdot
.65371 .60615 Mdot
.65381 .60615 Mdot
.6539 .60615 Mdot
.654 .60615 Mdot
.6541 .60615 Mdot
.65419 .60615 Mdot
.65429 .60615 Mdot
.65438 .60615 Mdot
.65448 .60615 Mdot
.65457 .60615 Mdot
.65467 .60615 Mdot
.65476 .60615 Mdot
.65486 .60615 Mdot
.65495 .60615 Mdot
.65505 .60615 Mdot
.65514 .60615 Mdot
.65524 .60615 Mdot
.65533 .60615 Mdot
.65543 .60615 Mdot
.65552 .60615 Mdot
.65562 .60615 Mdot
.65571 .60615 Mdot
.65581 .60615 Mdot
.6559 .60615 Mdot
.656 .60615 Mdot
.6561 .60615 Mdot
.65619 .60615 Mdot
.65629 .60615 Mdot
.65638 .60615 Mdot
.65648 .60615 Mdot
.65657 .60615 Mdot
.65667 .60615 Mdot
.65676 .60615 Mdot
.65686 .60615 Mdot
.65695 .60615 Mdot
.65705 .60615 Mdot
.65714 .60615 Mdot
.65724 .60615 Mdot
.65733 .60615 Mdot
.65743 .60615 Mdot
.65752 .60615 Mdot
.65762 .60615 Mdot
.65771 .60615 Mdot
.65781 .60615 Mdot
.6579 .60615 Mdot
.658 .60615 Mdot
.6581 .60615 Mdot
.65819 .60615 Mdot
.65829 .60615 Mdot
.65838 .60615 Mdot
.65848 .60615 Mdot
.65857 .60615 Mdot
.65867 .60615 Mdot
.65876 .60615 Mdot
.65886 .60615 Mdot
.65895 .60615 Mdot
.65905 .60615 Mdot
.65914 .60615 Mdot
.65924 .60615 Mdot
.65933 .60615 Mdot
.65943 .60615 Mdot
.65952 .60615 Mdot
.65962 .60615 Mdot
.65971 .60615 Mdot
.65981 .60615 Mdot
.6599 .60615 Mdot
.66 .60615 Mdot
.6601 .60615 Mdot
.66019 .60615 Mdot
.66029 .60615 Mdot
.66038 .60615 Mdot
.66048 .60615 Mdot
.66057 .60615 Mdot
.66067 .60615 Mdot
.66076 .60615 Mdot
.66086 .60615 Mdot
.66095 .60615 Mdot
.66105 .60615 Mdot
.66114 .60615 Mdot
.66124 .60615 Mdot
.66133 .60615 Mdot
.66143 .60615 Mdot
.66152 .60615 Mdot
.66162 .60615 Mdot
.66171 .60615 Mdot
.66181 .60615 Mdot
.6619 .60615 Mdot
.662 .60615 Mdot
.6621 .60615 Mdot
.66219 .60615 Mdot
.66229 .60615 Mdot
.66238 .60615 Mdot
.66248 .60615 Mdot
.66257 .60615 Mdot
.66267 .60615 Mdot
.66276 .60615 Mdot
.66286 .60615 Mdot
.66295 .60615 Mdot
.66305 .60615 Mdot
.66314 .60615 Mdot
.66324 .60615 Mdot
.66333 .60615 Mdot
.66343 .60615 Mdot
.66352 .60615 Mdot
.66362 .60615 Mdot
.66371 .60615 Mdot
.66381 .60615 Mdot
.6639 .60615 Mdot
.664 .60615 Mdot
.6641 .60615 Mdot
.66419 .60615 Mdot
.66429 .60615 Mdot
.66438 .60615 Mdot
.66448 .60615 Mdot
.66457 .60615 Mdot
.66467 .60615 Mdot
.66476 .60615 Mdot
.66486 .60615 Mdot
.66495 .60615 Mdot
.66505 .60615 Mdot
.66514 .60615 Mdot
.66524 .60615 Mdot
.66533 .60615 Mdot
.66543 .60615 Mdot
.66552 .60615 Mdot
.66562 .60615 Mdot
.66571 .60615 Mdot
.66581 .60615 Mdot
.6659 .60615 Mdot
.666 .60615 Mdot
.6661 .60615 Mdot
.66619 .60615 Mdot
.66629 .60615 Mdot
.66638 .60615 Mdot
.66648 .60615 Mdot
.66657 .60615 Mdot
.66667 .60615 Mdot
.66676 .60615 Mdot
.66686 .60615 Mdot
.66695 .60615 Mdot
.66705 .60615 Mdot
.66714 .60615 Mdot
.66724 .60615 Mdot
.66733 .60615 Mdot
.66743 .60615 Mdot
.66752 .60615 Mdot
.66762 .60615 Mdot
.66771 .60615 Mdot
.66781 .60615 Mdot
.6679 .60615 Mdot
.668 .60615 Mdot
.6681 .60615 Mdot
.66819 .60615 Mdot
.66829 .60615 Mdot
.66838 .60615 Mdot
.66848 .60615 Mdot
.66857 .60615 Mdot
.66867 .60615 Mdot
.66876 .60615 Mdot
.66886 .60615 Mdot
.66895 .60615 Mdot
.66905 .60615 Mdot
.66914 .60615 Mdot
.66924 .60615 Mdot
.66933 .60615 Mdot
.66943 .60615 Mdot
.66952 .60615 Mdot
.66962 .60615 Mdot
.66971 .60615 Mdot
.66981 .60615 Mdot
.6699 .60615 Mdot
.67 .60615 Mdot
.6701 .60615 Mdot
.67019 .60615 Mdot
.67029 .60615 Mdot
.67038 .60615 Mdot
.67048 .60615 Mdot
.67057 .60615 Mdot
.67067 .60615 Mdot
.67076 .60615 Mdot
.67086 .60615 Mdot
.67095 .60615 Mdot
.67105 .60615 Mdot
.67114 .60615 Mdot
.67124 .60615 Mdot
.67133 .60615 Mdot
.67143 .60615 Mdot
.67152 .60615 Mdot
.67162 .60615 Mdot
.67171 .60615 Mdot
.67181 .60615 Mdot
.6719 .60615 Mdot
.672 .60615 Mdot
.6721 .60615 Mdot
.67219 .60615 Mdot
.67229 .60615 Mdot
.67238 .60615 Mdot
.67248 .60615 Mdot
.67257 .60615 Mdot
.67267 .60615 Mdot
.67276 .60615 Mdot
.67286 .60615 Mdot
.67295 .60615 Mdot
.67305 .60615 Mdot
.67314 .60615 Mdot
.67324 .60615 Mdot
.67333 .60615 Mdot
.67343 .60615 Mdot
.67352 .60615 Mdot
.67362 .60615 Mdot
.67371 .60615 Mdot
.67381 .60615 Mdot
.6739 .60615 Mdot
.674 .60615 Mdot
.6741 .60615 Mdot
.67419 .60615 Mdot
.67429 .60615 Mdot
.67438 .60615 Mdot
.67448 .60615 Mdot
.67457 .60615 Mdot
.67467 .60615 Mdot
.67476 .60615 Mdot
.67486 .60615 Mdot
.67495 .60615 Mdot
.67505 .60615 Mdot
.67514 .60615 Mdot
.67524 .60615 Mdot
.67533 .60615 Mdot
.67543 .60615 Mdot
.67552 .60615 Mdot
.67562 .60615 Mdot
.67571 .60615 Mdot
.67581 .60615 Mdot
.6759 .60615 Mdot
.676 .60615 Mdot
.6761 .60615 Mdot
.67619 .60615 Mdot
.67629 .60615 Mdot
.67638 .60615 Mdot
.67648 .60615 Mdot
.67657 .60615 Mdot
.67667 .60615 Mdot
.67676 .60615 Mdot
.67686 .60615 Mdot
.67695 .60615 Mdot
.67705 .60615 Mdot
.67714 .60615 Mdot
.67724 .60615 Mdot
.67733 .60615 Mdot
.67743 .60615 Mdot
.67752 .60615 Mdot
.67762 .60615 Mdot
.67771 .60615 Mdot
.67781 .60615 Mdot
.6779 .60615 Mdot
.678 .60615 Mdot
.6781 .60615 Mdot
.67819 .60615 Mdot
.67829 .60615 Mdot
.67838 .60615 Mdot
.67848 .60615 Mdot
.67857 .60615 Mdot
.67867 .60615 Mdot
.67876 .60615 Mdot
.67886 .60615 Mdot
.67895 .60615 Mdot
.67905 .60615 Mdot
.67914 .60615 Mdot
.67924 .60615 Mdot
.67933 .60615 Mdot
.67943 .60615 Mdot
.67952 .60615 Mdot
.67962 .60615 Mdot
.67971 .60615 Mdot
.67981 .60615 Mdot
.6799 .60615 Mdot
.68 .60615 Mdot
.6801 .60615 Mdot
.68019 .60615 Mdot
.68029 .60615 Mdot
.68038 .60615 Mdot
.68048 .60615 Mdot
.68057 .60615 Mdot
.68067 .60615 Mdot
.68076 .60615 Mdot
.68086 .60615 Mdot
.68095 .60615 Mdot
.68105 .60615 Mdot
.68114 .60615 Mdot
.68124 .60615 Mdot
.68133 .60615 Mdot
.68143 .60615 Mdot
.68152 .60615 Mdot
.68162 .60615 Mdot
.68171 .60615 Mdot
.68181 .60615 Mdot
.6819 .60615 Mdot
.682 .60615 Mdot
.6821 .60615 Mdot
.68219 .60615 Mdot
.68229 .60615 Mdot
.68238 .60615 Mdot
.68248 .60615 Mdot
.68257 .60615 Mdot
.68267 .60615 Mdot
.68276 .60615 Mdot
.68286 .60615 Mdot
.68295 .60615 Mdot
.68305 .60615 Mdot
.68314 .60615 Mdot
.68324 .60615 Mdot
.68333 .60615 Mdot
.68343 .60615 Mdot
.68352 .60615 Mdot
.68362 .60615 Mdot
.68371 .60615 Mdot
.68381 .60615 Mdot
.6839 .60615 Mdot
.684 .60615 Mdot
.6841 .60615 Mdot
.68419 .60615 Mdot
.68429 .60615 Mdot
.68438 .60615 Mdot
.68448 .60615 Mdot
.68457 .60615 Mdot
.68467 .60615 Mdot
.68476 .60615 Mdot
.68486 .60615 Mdot
.68495 .60615 Mdot
.68505 .60615 Mdot
.68514 .60615 Mdot
.68524 .60615 Mdot
.68533 .60615 Mdot
.68543 .60615 Mdot
.68552 .60615 Mdot
.68562 .60615 Mdot
.68571 .60615 Mdot
.68581 .60615 Mdot
.6859 .60615 Mdot
.686 .60615 Mdot
.6861 .60615 Mdot
.68619 .60615 Mdot
.68629 .60615 Mdot
.68638 .60615 Mdot
.68648 .60615 Mdot
.68657 .60615 Mdot
.68667 .60615 Mdot
.68676 .60615 Mdot
.68686 .60615 Mdot
.68695 .60615 Mdot
.68705 .60615 Mdot
.68714 .60615 Mdot
.68724 .60615 Mdot
.68733 .60615 Mdot
.68743 .60615 Mdot
.68752 .60615 Mdot
.68762 .60615 Mdot
.68771 .60615 Mdot
.68781 .60615 Mdot
.6879 .60615 Mdot
.688 .60615 Mdot
.6881 .60615 Mdot
.68819 .60615 Mdot
.68829 .60615 Mdot
.68838 .60615 Mdot
.68848 .60615 Mdot
.68857 .60615 Mdot
.68867 .60615 Mdot
.68876 .60615 Mdot
.68886 .60615 Mdot
.68895 .60615 Mdot
.68905 .60615 Mdot
.68914 .60615 Mdot
.68924 .60615 Mdot
.68933 .60615 Mdot
.68943 .60615 Mdot
.68952 .60615 Mdot
.68962 .60615 Mdot
.68971 .60615 Mdot
.68981 .60615 Mdot
.6899 .60615 Mdot
.69 .60615 Mdot
.6901 .60615 Mdot
.69019 .60615 Mdot
.69029 .60615 Mdot
.69038 .60615 Mdot
.69048 .60615 Mdot
.69057 .60615 Mdot
.69067 .60615 Mdot
.69076 .60615 Mdot
.69086 .60615 Mdot
.69095 .60615 Mdot
.69105 .60615 Mdot
.69114 .60615 Mdot
.69124 .60615 Mdot
.69133 .60615 Mdot
.69143 .60615 Mdot
.69152 .60615 Mdot
.69162 .60615 Mdot
.69171 .60615 Mdot
.69181 .60615 Mdot
.6919 .60615 Mdot
.692 .60615 Mdot
.6921 .60615 Mdot
.69219 .60615 Mdot
.69229 .60615 Mdot
.69238 .60615 Mdot
.69248 .60615 Mdot
.69257 .60615 Mdot
.69267 .60615 Mdot
.69276 .60615 Mdot
.69286 .60615 Mdot
.69295 .60615 Mdot
.69305 .60615 Mdot
.69314 .60615 Mdot
.69324 .60615 Mdot
.69333 .60615 Mdot
.69343 .60615 Mdot
.69352 .60615 Mdot
.69362 .60615 Mdot
.69371 .60615 Mdot
.69381 .60615 Mdot
.6939 .60615 Mdot
.694 .60615 Mdot
.6941 .60615 Mdot
.69419 .60615 Mdot
.69429 .60615 Mdot
.69438 .60615 Mdot
.69448 .60615 Mdot
.69457 .60615 Mdot
.69467 .60615 Mdot
.69476 .60615 Mdot
.69486 .60615 Mdot
.69495 .60615 Mdot
.69505 .60615 Mdot
.69514 .60615 Mdot
.69524 .60615 Mdot
.69533 .60615 Mdot
.69543 .60615 Mdot
.69552 .60615 Mdot
.69562 .60615 Mdot
.69571 .60615 Mdot
.69581 .60615 Mdot
.6959 .60615 Mdot
.696 .60615 Mdot
.6961 .60615 Mdot
.69619 .60615 Mdot
.69629 .60615 Mdot
.69638 .60615 Mdot
.69648 .60615 Mdot
.69657 .60615 Mdot
.69667 .60615 Mdot
.69676 .60615 Mdot
.69686 .60615 Mdot
.69695 .60615 Mdot
.69705 .60615 Mdot
.69714 .60615 Mdot
.69724 .60615 Mdot
.69733 .60615 Mdot
.69743 .60615 Mdot
.69752 .60615 Mdot
.69762 .60615 Mdot
.69771 .60615 Mdot
.69781 .60615 Mdot
.6979 .60615 Mdot
.698 .60615 Mdot
.6981 .60615 Mdot
.69819 .60615 Mdot
.69829 .60615 Mdot
.69838 .60615 Mdot
.69848 .60615 Mdot
.69857 .60615 Mdot
.69867 .60615 Mdot
.69876 .60615 Mdot
.69886 .60615 Mdot
.69895 .60615 Mdot
.69905 .60615 Mdot
.69914 .60615 Mdot
.69924 .60615 Mdot
.69933 .60615 Mdot
.69943 .60615 Mdot
.69952 .60615 Mdot
.69962 .60615 Mdot
.69971 .60615 Mdot
.69981 .60615 Mdot
.6999 .60615 Mdot
.7 .60615 Mdot
.7001 .60615 Mdot
.70019 .60615 Mdot
.70029 .60615 Mdot
.70038 .60615 Mdot
.70048 .60615 Mdot
.70057 .60615 Mdot
.70067 .60615 Mdot
.70076 .60615 Mdot
.70086 .60615 Mdot
.70095 .60615 Mdot
.70105 .60615 Mdot
.70114 .60615 Mdot
.70124 .60615 Mdot
.70133 .60615 Mdot
.70143 .60615 Mdot
.70152 .60615 Mdot
.70162 .60615 Mdot
.70171 .60615 Mdot
.70181 .60615 Mdot
.7019 .60615 Mdot
.702 .60615 Mdot
.7021 .60615 Mdot
.70219 .60615 Mdot
.70229 .60615 Mdot
.70238 .60615 Mdot
.70248 .60615 Mdot
.70257 .60615 Mdot
.70267 .60615 Mdot
.70276 .60615 Mdot
.70286 .60615 Mdot
.70295 .60615 Mdot
.70305 .60615 Mdot
.70314 .60615 Mdot
.70324 .60615 Mdot
.70333 .60615 Mdot
.70343 .60615 Mdot
.70352 .60615 Mdot
.70362 .60615 Mdot
.70371 .60615 Mdot
.70381 .60615 Mdot
.7039 .60615 Mdot
.704 .60615 Mdot
.7041 .60615 Mdot
.70419 .60615 Mdot
.70429 .60615 Mdot
.70438 .60615 Mdot
.70448 .60615 Mdot
.70457 .60615 Mdot
.70467 .60615 Mdot
.70476 .60615 Mdot
.70486 .60615 Mdot
.70495 .60615 Mdot
.70505 .60615 Mdot
.70514 .60615 Mdot
.70524 .60615 Mdot
.70533 .60615 Mdot
.70543 .60615 Mdot
.70552 .60615 Mdot
.70562 .60615 Mdot
.70571 .60615 Mdot
.70581 .60615 Mdot
.7059 .60615 Mdot
.706 .60615 Mdot
.7061 .60615 Mdot
.70619 .60615 Mdot
.70629 .60615 Mdot
.70638 .60615 Mdot
.70648 .60615 Mdot
.70657 .60615 Mdot
.70667 .60615 Mdot
.70676 .60615 Mdot
.70686 .60615 Mdot
.70695 .60615 Mdot
.70705 .60615 Mdot
.70714 .60615 Mdot
.70724 .60615 Mdot
.70733 .60615 Mdot
.70743 .60615 Mdot
.70752 .60615 Mdot
.70762 .60615 Mdot
.70771 .60615 Mdot
.70781 .60615 Mdot
.7079 .60615 Mdot
.708 .60615 Mdot
.7081 .60615 Mdot
.70819 .60615 Mdot
.70829 .60615 Mdot
.70838 .60615 Mdot
.70848 .60615 Mdot
.70857 .60615 Mdot
.70867 .60615 Mdot
.70876 .60615 Mdot
.70886 .60615 Mdot
.70895 .60615 Mdot
.70905 .60615 Mdot
.70914 .60615 Mdot
.70924 .60615 Mdot
.70933 .60615 Mdot
.70943 .60615 Mdot
.70952 .60615 Mdot
.70962 .60615 Mdot
.70971 .60615 Mdot
.70981 .60615 Mdot
.7099 .60615 Mdot
.71 .60615 Mdot
.7101 .60615 Mdot
.71019 .60615 Mdot
.71029 .60615 Mdot
.71038 .60615 Mdot
.71048 .60615 Mdot
.71057 .60615 Mdot
.71067 .60615 Mdot
.71076 .60615 Mdot
.71086 .60615 Mdot
.71095 .60615 Mdot
.71105 .60615 Mdot
.71114 .60615 Mdot
.71124 .60615 Mdot
.71133 .60615 Mdot
.71143 .60615 Mdot
.71152 .60615 Mdot
.71162 .60615 Mdot
.71171 .60615 Mdot
.71181 .60615 Mdot
.7119 .60615 Mdot
.712 .60615 Mdot
.7121 .60615 Mdot
.71219 .60615 Mdot
.71229 .60615 Mdot
.71238 .60615 Mdot
.71248 .60615 Mdot
.71257 .60615 Mdot
.71267 .60615 Mdot
.71276 .60615 Mdot
.71286 .60615 Mdot
.71295 .60615 Mdot
.71305 .60615 Mdot
.71314 .60615 Mdot
.71324 .60615 Mdot
.71333 .60615 Mdot
.71343 .60615 Mdot
.71352 .60615 Mdot
.71362 .60615 Mdot
.71371 .60615 Mdot
.71381 .60615 Mdot
.7139 .60615 Mdot
.714 .60615 Mdot
.7141 .60615 Mdot
.71419 .60615 Mdot
.71429 .60615 Mdot
.71438 .60615 Mdot
.71448 .60615 Mdot
.71457 .60615 Mdot
.71467 .60615 Mdot
.71476 .60615 Mdot
.71486 .60615 Mdot
.71495 .60615 Mdot
.71505 .60615 Mdot
.71514 .60615 Mdot
.71524 .60615 Mdot
.71533 .60615 Mdot
.71543 .60615 Mdot
.71552 .60615 Mdot
.71562 .60615 Mdot
.71571 .60615 Mdot
.71581 .60615 Mdot
.7159 .60615 Mdot
.716 .60615 Mdot
.7161 .60615 Mdot
.71619 .60615 Mdot
.71629 .60615 Mdot
.71638 .60615 Mdot
.71648 .60615 Mdot
.71657 .60615 Mdot
.71667 .60615 Mdot
.71676 .60615 Mdot
.71686 .60615 Mdot
.71695 .60615 Mdot
.71705 .60615 Mdot
.71714 .60615 Mdot
.71724 .60615 Mdot
.71733 .60615 Mdot
.71743 .60615 Mdot
.71752 .60615 Mdot
.71762 .60615 Mdot
.71771 .60615 Mdot
.71781 .60615 Mdot
.7179 .60615 Mdot
.718 .60615 Mdot
.7181 .60615 Mdot
.71819 .60615 Mdot
.71829 .60615 Mdot
.71838 .60615 Mdot
.71848 .60615 Mdot
.71857 .60615 Mdot
.71867 .60615 Mdot
.71876 .60615 Mdot
.71886 .60615 Mdot
.71895 .60615 Mdot
.71905 .60615 Mdot
.71914 .60615 Mdot
.71924 .60615 Mdot
.71933 .60615 Mdot
.71943 .60615 Mdot
.71952 .60615 Mdot
.71962 .60615 Mdot
.71971 .60615 Mdot
.71981 .60615 Mdot
.7199 .60615 Mdot
.72 .60615 Mdot
.7201 .60615 Mdot
.72019 .60615 Mdot
.72029 .60615 Mdot
.72038 .60615 Mdot
.72048 .60615 Mdot
.72057 .60615 Mdot
.72067 .60615 Mdot
.72076 .60615 Mdot
.72086 .60615 Mdot
.72095 .60615 Mdot
.72105 .60615 Mdot
.72114 .60615 Mdot
.72124 .60615 Mdot
.72133 .60615 Mdot
.72143 .60615 Mdot
.72152 .60615 Mdot
.72162 .60615 Mdot
.72171 .60615 Mdot
.72181 .60615 Mdot
.7219 .60615 Mdot
.722 .60615 Mdot
.7221 .60615 Mdot
.72219 .60615 Mdot
.72229 .60615 Mdot
.72238 .60615 Mdot
.72248 .60615 Mdot
.72257 .60615 Mdot
.72267 .60615 Mdot
.72276 .60615 Mdot
.72286 .60615 Mdot
.72295 .60615 Mdot
.72305 .60615 Mdot
.72314 .60615 Mdot
.72324 .60615 Mdot
.72333 .60615 Mdot
.72343 .60615 Mdot
.72352 .60615 Mdot
.72362 .60615 Mdot
.72371 .60615 Mdot
.72381 .60615 Mdot
.7239 .60615 Mdot
.724 .60615 Mdot
.7241 .60615 Mdot
.72419 .60615 Mdot
.72429 .60615 Mdot
.72438 .60615 Mdot
.72448 .60615 Mdot
.72457 .60615 Mdot
.72467 .60615 Mdot
.72476 .60615 Mdot
.72486 .60615 Mdot
.72495 .60615 Mdot
.72505 .60615 Mdot
.72514 .60615 Mdot
.72524 .60615 Mdot
.72533 .60615 Mdot
.72543 .60615 Mdot
.72552 .60615 Mdot
.72562 .60615 Mdot
.72571 .60615 Mdot
.72581 .60615 Mdot
.7259 .60615 Mdot
.726 .60615 Mdot
.7261 .60615 Mdot
.72619 .60615 Mdot
.72629 .60615 Mdot
.72638 .60615 Mdot
.72648 .60615 Mdot
.72657 .60615 Mdot
.72667 .60615 Mdot
.72676 .60615 Mdot
.72686 .60615 Mdot
.72695 .60615 Mdot
.72705 .60615 Mdot
.72714 .60615 Mdot
.72724 .60615 Mdot
.72733 .60615 Mdot
.72743 .60615 Mdot
.72752 .60615 Mdot
.72762 .60615 Mdot
.72771 .60615 Mdot
.72781 .60615 Mdot
.7279 .60615 Mdot
.728 .60615 Mdot
.7281 .60615 Mdot
.72819 .60615 Mdot
.72829 .60615 Mdot
.72838 .60615 Mdot
.72848 .60615 Mdot
.72857 .60615 Mdot
.72867 .60615 Mdot
.72876 .60615 Mdot
.72886 .60615 Mdot
.72895 .60615 Mdot
.72905 .60615 Mdot
.72914 .60615 Mdot
.72924 .60615 Mdot
.72933 .60615 Mdot
.72943 .60615 Mdot
.72952 .60615 Mdot
.72962 .60615 Mdot
.72971 .60615 Mdot
.72981 .60615 Mdot
.7299 .60615 Mdot
.73 .60615 Mdot
.7301 .60615 Mdot
.73019 .60615 Mdot
.73029 .60615 Mdot
.73038 .60615 Mdot
.73048 .60615 Mdot
.73057 .60615 Mdot
.73067 .60615 Mdot
.73076 .60615 Mdot
.73086 .60615 Mdot
.73095 .60615 Mdot
.73105 .60615 Mdot
.73114 .60615 Mdot
.73124 .60615 Mdot
.73133 .60615 Mdot
.73143 .60615 Mdot
.73152 .60615 Mdot
.73162 .60615 Mdot
.73171 .60615 Mdot
.73181 .60615 Mdot
.7319 .60615 Mdot
.732 .60615 Mdot
.7321 .60615 Mdot
.73219 .60615 Mdot
.73229 .60615 Mdot
.73238 .60615 Mdot
.73248 .60615 Mdot
.73257 .60615 Mdot
.73267 .60615 Mdot
.73276 .60615 Mdot
.73286 .60615 Mdot
.73295 .60615 Mdot
.73305 .60615 Mdot
.73314 .60615 Mdot
.73324 .60615 Mdot
.73333 .60615 Mdot
.73343 .60615 Mdot
.73352 .60615 Mdot
.73362 .60615 Mdot
.73371 .60615 Mdot
.73381 .60615 Mdot
.7339 .60615 Mdot
.734 .60615 Mdot
.7341 .60615 Mdot
.73419 .60615 Mdot
.73429 .60615 Mdot
.73438 .60615 Mdot
.73448 .60615 Mdot
.73457 .60615 Mdot
.73467 .60615 Mdot
.73476 .60615 Mdot
.73486 .60615 Mdot
.73495 .60615 Mdot
.73505 .60615 Mdot
.73514 .60615 Mdot
.73524 .60615 Mdot
.73533 .60615 Mdot
.73543 .60615 Mdot
.73552 .60615 Mdot
.73562 .60615 Mdot
.73571 .60615 Mdot
.73581 .60615 Mdot
.7359 .60615 Mdot
.736 .60615 Mdot
.7361 .60615 Mdot
.73619 .60615 Mdot
.73629 .60615 Mdot
.73638 .60615 Mdot
.73648 .60615 Mdot
.73657 .60615 Mdot
.73667 .60615 Mdot
.73676 .60615 Mdot
.73686 .60615 Mdot
.73695 .60615 Mdot
.73705 .60615 Mdot
.73714 .60615 Mdot
.73724 .60615 Mdot
.73733 .60615 Mdot
.73743 .60615 Mdot
.73752 .60615 Mdot
.73762 .60615 Mdot
.73771 .60615 Mdot
.73781 .60615 Mdot
.7379 .60615 Mdot
.738 .60615 Mdot
.7381 .60615 Mdot
.73819 .60615 Mdot
.73829 .60615 Mdot
.73838 .60615 Mdot
.73848 .60615 Mdot
.73857 .60615 Mdot
.73867 .60615 Mdot
.73876 .60615 Mdot
.73886 .60615 Mdot
.73895 .60615 Mdot
.73905 .60615 Mdot
.73914 .60615 Mdot
.73924 .60615 Mdot
.73933 .60615 Mdot
.73943 .60615 Mdot
.73952 .60615 Mdot
.73962 .60615 Mdot
.73971 .60615 Mdot
.73981 .60615 Mdot
.7399 .60615 Mdot
.74 .60615 Mdot
.7401 .60615 Mdot
.74019 .60615 Mdot
.74029 .60615 Mdot
.74038 .60615 Mdot
.74048 .60615 Mdot
.74057 .60615 Mdot
.74067 .60615 Mdot
.74076 .60615 Mdot
.74086 .60615 Mdot
.74095 .60615 Mdot
.74105 .60615 Mdot
.74114 .60615 Mdot
.74124 .60615 Mdot
.74133 .60615 Mdot
.74143 .60615 Mdot
.74152 .60615 Mdot
.74162 .60615 Mdot
.74171 .60615 Mdot
.74181 .60615 Mdot
.7419 .60615 Mdot
.742 .60615 Mdot
.7421 .60615 Mdot
.74219 .60615 Mdot
.74229 .60615 Mdot
.74238 .60615 Mdot
.74248 .60615 Mdot
.74257 .60615 Mdot
.74267 .60615 Mdot
.74276 .60615 Mdot
.74286 .60615 Mdot
.74295 .60615 Mdot
.74305 .60615 Mdot
.74314 .60615 Mdot
.74324 .60615 Mdot
.74333 .60615 Mdot
.74343 .60615 Mdot
.74352 .60615 Mdot
.74362 .60615 Mdot
.74371 .60615 Mdot
.74381 .60615 Mdot
.7439 .60615 Mdot
.744 .60615 Mdot
.7441 .60615 Mdot
.74419 .60615 Mdot
.74429 .60615 Mdot
.74438 .60615 Mdot
.74448 .60615 Mdot
.74457 .60615 Mdot
.74467 .60615 Mdot
.74476 .60615 Mdot
.74486 .60615 Mdot
.74495 .60615 Mdot
.74505 .60615 Mdot
.74514 .60615 Mdot
.74524 .60615 Mdot
.74533 .60615 Mdot
.74543 .60615 Mdot
.74552 .60615 Mdot
.74562 .60615 Mdot
.74571 .60615 Mdot
.74581 .60615 Mdot
.7459 .60615 Mdot
.746 .60615 Mdot
.7461 .60615 Mdot
.74619 .60615 Mdot
.74629 .60615 Mdot
.74638 .60615 Mdot
.74648 .60615 Mdot
.74657 .60615 Mdot
.74667 .60615 Mdot
.74676 .60615 Mdot
.74686 .60615 Mdot
.74695 .60615 Mdot
.74705 .60615 Mdot
.74714 .60615 Mdot
.74724 .60615 Mdot
.74733 .60615 Mdot
.74743 .60615 Mdot
.74752 .60615 Mdot
.74762 .60615 Mdot
.74771 .60615 Mdot
.74781 .60615 Mdot
.7479 .60615 Mdot
.748 .60615 Mdot
.7481 .60615 Mdot
.74819 .60615 Mdot
.74829 .60615 Mdot
.74838 .60615 Mdot
.74848 .60615 Mdot
.74857 .60615 Mdot
.74867 .60615 Mdot
.74876 .60615 Mdot
.74886 .60615 Mdot
.74895 .60615 Mdot
.74905 .60615 Mdot
.74914 .60615 Mdot
.74924 .60615 Mdot
.74933 .60615 Mdot
.74943 .60615 Mdot
.74952 .60615 Mdot
.74962 .60615 Mdot
.74971 .60615 Mdot
.74981 .60615 Mdot
.7499 .60615 Mdot
.75 .60615 Mdot
.7501 .60615 Mdot
.75019 .60615 Mdot
.75029 .60615 Mdot
.75038 .60615 Mdot
.75048 .60615 Mdot
.75057 .60615 Mdot
.75067 .60615 Mdot
.75076 .60615 Mdot
.75086 .60615 Mdot
.75095 .60615 Mdot
.75105 .60615 Mdot
.75114 .60615 Mdot
.75124 .60615 Mdot
.75133 .60615 Mdot
.75143 .60615 Mdot
.75152 .60615 Mdot
.75162 .60615 Mdot
.75171 .60615 Mdot
.75181 .60615 Mdot
.7519 .60615 Mdot
.752 .60615 Mdot
.7521 .60615 Mdot
.75219 .60615 Mdot
.75229 .60615 Mdot
.75238 .60615 Mdot
.75248 .60615 Mdot
.75257 .60615 Mdot
.75267 .60615 Mdot
.75276 .60615 Mdot
.75286 .60615 Mdot
.75295 .60615 Mdot
.75305 .60615 Mdot
.75314 .60615 Mdot
.75324 .60615 Mdot
.75333 .60615 Mdot
.75343 .60615 Mdot
.75352 .60615 Mdot
.75362 .60615 Mdot
.75371 .60615 Mdot
.75381 .60615 Mdot
.7539 .60615 Mdot
.754 .60615 Mdot
.7541 .60615 Mdot
.75419 .60615 Mdot
.75429 .60615 Mdot
.75438 .60615 Mdot
.75448 .60615 Mdot
.75457 .60615 Mdot
.75467 .60615 Mdot
.75476 .60615 Mdot
.75486 .60615 Mdot
.75495 .60615 Mdot
.75505 .60615 Mdot
.75514 .60615 Mdot
.75524 .60615 Mdot
.75533 .60615 Mdot
.75543 .60615 Mdot
.75552 .60615 Mdot
.75562 .60615 Mdot
.75571 .60615 Mdot
.75581 .60615 Mdot
.7559 .60615 Mdot
.756 .60615 Mdot
.7561 .60615 Mdot
.75619 .60615 Mdot
.75629 .60615 Mdot
.75638 .60615 Mdot
.75648 .60615 Mdot
.75657 .60615 Mdot
.75667 .60615 Mdot
.75676 .60615 Mdot
.75686 .60615 Mdot
.75695 .60615 Mdot
.75705 .60615 Mdot
.75714 .60615 Mdot
.75724 .60615 Mdot
.75733 .60615 Mdot
.75743 .60615 Mdot
.75752 .60615 Mdot
.75762 .60615 Mdot
.75771 .60615 Mdot
.75781 .60615 Mdot
.7579 .60615 Mdot
.758 .60615 Mdot
.7581 .60615 Mdot
.75819 .60615 Mdot
.75829 .60615 Mdot
.75838 .60615 Mdot
.75848 .60615 Mdot
.75857 .60615 Mdot
.75867 .60615 Mdot
.75876 .60615 Mdot
.75886 .60615 Mdot
.75895 .60615 Mdot
.75905 .60615 Mdot
.75914 .60615 Mdot
.75924 .60615 Mdot
.75933 .60615 Mdot
.75943 .60615 Mdot
.75952 .60615 Mdot
.75962 .60615 Mdot
.75971 .60615 Mdot
.75981 .60615 Mdot
.7599 .60615 Mdot
.76 .60615 Mdot
.7601 .60615 Mdot
.76019 .60615 Mdot
.76029 .60615 Mdot
.76038 .60615 Mdot
.76048 .60615 Mdot
.76057 .60615 Mdot
.76067 .60615 Mdot
.76076 .60615 Mdot
.76086 .60615 Mdot
.76095 .60615 Mdot
.76105 .60615 Mdot
.76114 .60615 Mdot
.76124 .60615 Mdot
.76133 .60615 Mdot
.76143 .60615 Mdot
.76152 .60615 Mdot
.76162 .60615 Mdot
.76171 .60615 Mdot
.76181 .60615 Mdot
.7619 .60615 Mdot
.762 .60615 Mdot
.7621 .60615 Mdot
.76219 .60615 Mdot
.76229 .60615 Mdot
.76238 .60615 Mdot
.76248 .60615 Mdot
.76257 .60615 Mdot
.76267 .60615 Mdot
.76276 .60615 Mdot
.76286 .60615 Mdot
.76295 .60615 Mdot
.76305 .60615 Mdot
.76314 .60615 Mdot
.76324 .60615 Mdot
.76333 .60615 Mdot
.76343 .60615 Mdot
.76352 .60615 Mdot
.76362 .60615 Mdot
.76371 .60615 Mdot
.76381 .60615 Mdot
.7639 .60615 Mdot
.764 .60615 Mdot
.7641 .60615 Mdot
.76419 .60615 Mdot
.76429 .60615 Mdot
.76438 .60615 Mdot
.76448 .60615 Mdot
.76457 .60615 Mdot
.76467 .60615 Mdot
.76476 .60615 Mdot
.76486 .60615 Mdot
.76495 .60615 Mdot
.76505 .60615 Mdot
.76514 .60615 Mdot
.76524 .60615 Mdot
.76533 .60615 Mdot
.76543 .60615 Mdot
.76552 .60615 Mdot
.76562 .60615 Mdot
.76571 .60615 Mdot
.76581 .60615 Mdot
.7659 .60615 Mdot
.766 .60615 Mdot
.7661 .60615 Mdot
.76619 .60615 Mdot
.76629 .60615 Mdot
.76638 .60615 Mdot
.76648 .60615 Mdot
.76657 .60615 Mdot
.76667 .60615 Mdot
.76676 .60615 Mdot
.76686 .60615 Mdot
.76695 .60615 Mdot
.76705 .60615 Mdot
.76714 .60615 Mdot
.76724 .60615 Mdot
.76733 .60615 Mdot
.76743 .60615 Mdot
.76752 .60615 Mdot
.76762 .60615 Mdot
.76771 .60615 Mdot
.76781 .60615 Mdot
.7679 .60615 Mdot
.768 .60615 Mdot
.7681 .60615 Mdot
.76819 .60615 Mdot
.76829 .60615 Mdot
.76838 .60615 Mdot
.76848 .60615 Mdot
.76857 .60615 Mdot
.76867 .60615 Mdot
.76876 .60615 Mdot
.76886 .60615 Mdot
.76895 .60615 Mdot
.76905 .60615 Mdot
.76914 .60615 Mdot
.76924 .60615 Mdot
.76933 .60615 Mdot
.76943 .60615 Mdot
.76952 .60615 Mdot
.76962 .60615 Mdot
.76971 .60615 Mdot
.76981 .60615 Mdot
.7699 .60615 Mdot
.77 .60615 Mdot
.7701 .60615 Mdot
.77019 .60615 Mdot
.77029 .60615 Mdot
.77038 .60615 Mdot
.77048 .60615 Mdot
.77057 .60615 Mdot
.77067 .60615 Mdot
.77076 .60615 Mdot
.77086 .60615 Mdot
.77095 .60615 Mdot
.77105 .60615 Mdot
.77114 .60615 Mdot
.77124 .60615 Mdot
.77133 .60615 Mdot
.77143 .60615 Mdot
.77152 .60615 Mdot
.77162 .60615 Mdot
.77171 .60615 Mdot
.77181 .60615 Mdot
.7719 .60615 Mdot
.772 .60615 Mdot
.7721 .60615 Mdot
.77219 .60615 Mdot
.77229 .60615 Mdot
.77238 .60615 Mdot
.77248 .60615 Mdot
.77257 .60615 Mdot
.77267 .60615 Mdot
.77276 .60615 Mdot
.77286 .60615 Mdot
.77295 .60615 Mdot
.77305 .60615 Mdot
.77314 .60615 Mdot
.77324 .60615 Mdot
.77333 .60615 Mdot
.77343 .60615 Mdot
.77352 .60615 Mdot
.77362 .60615 Mdot
.77371 .60615 Mdot
.77381 .60615 Mdot
.7739 .60615 Mdot
.774 .60615 Mdot
.7741 .60615 Mdot
.77419 .60615 Mdot
.77429 .60615 Mdot
.77438 .60615 Mdot
.77448 .60615 Mdot
.77457 .60615 Mdot
.77467 .60615 Mdot
.77476 .60615 Mdot
.77486 .60615 Mdot
.77495 .60615 Mdot
.77505 .60615 Mdot
.77514 .60615 Mdot
.77524 .60615 Mdot
.77533 .60615 Mdot
.77543 .60615 Mdot
.77552 .60615 Mdot
.77562 .60615 Mdot
.77571 .60615 Mdot
.77581 .60615 Mdot
.7759 .60615 Mdot
.776 .60615 Mdot
.7761 .60615 Mdot
.77619 .60615 Mdot
.77629 .60615 Mdot
.77638 .60615 Mdot
.77648 .60615 Mdot
.77657 .60615 Mdot
.77667 .60615 Mdot
.77676 .60615 Mdot
.77686 .60615 Mdot
.77695 .60615 Mdot
.77705 .60615 Mdot
.77714 .60615 Mdot
.77724 .60615 Mdot
.77733 .60615 Mdot
.77743 .60615 Mdot
.77752 .60615 Mdot
.77762 .60615 Mdot
.77771 .60615 Mdot
.77781 .60615 Mdot
.7779 .60615 Mdot
.778 .60615 Mdot
.7781 .60615 Mdot
.77819 .60615 Mdot
.77829 .60615 Mdot
.77838 .60615 Mdot
.77848 .60615 Mdot
.77857 .60615 Mdot
.77867 .60615 Mdot
.77876 .60615 Mdot
.77886 .60615 Mdot
.77895 .60615 Mdot
.77905 .60615 Mdot
.77914 .60615 Mdot
.77924 .60615 Mdot
.77933 .60615 Mdot
.77943 .60615 Mdot
.77952 .60615 Mdot
.77962 .60615 Mdot
.77971 .60615 Mdot
.77981 .60615 Mdot
.7799 .60615 Mdot
.78 .60615 Mdot
.7801 .60615 Mdot
.78019 .60615 Mdot
.78029 .60615 Mdot
.78038 .60615 Mdot
.78048 .60615 Mdot
.78057 .60615 Mdot
.78067 .60615 Mdot
.78076 .60615 Mdot
.78086 .60615 Mdot
.78095 .60615 Mdot
.78105 .60615 Mdot
.78114 .60615 Mdot
.78124 .60615 Mdot
.78133 .60615 Mdot
.78143 .60615 Mdot
.78152 .60615 Mdot
.78162 .60615 Mdot
.78171 .60615 Mdot
.78181 .60615 Mdot
.7819 .60615 Mdot
.782 .60615 Mdot
.7821 .60615 Mdot
.78219 .60615 Mdot
.78229 .60615 Mdot
.78238 .60615 Mdot
.78248 .60615 Mdot
.78257 .60615 Mdot
.78267 .60615 Mdot
.78276 .60615 Mdot
.78286 .60615 Mdot
.78295 .60615 Mdot
.78305 .60615 Mdot
.78314 .60615 Mdot
.78324 .60615 Mdot
.78333 .60615 Mdot
.78343 .60615 Mdot
.78352 .60615 Mdot
.78362 .60615 Mdot
.78371 .60615 Mdot
.78381 .60615 Mdot
.7839 .60615 Mdot
.784 .60615 Mdot
.7841 .60615 Mdot
.78419 .60615 Mdot
.78429 .60615 Mdot
.78438 .60615 Mdot
.78448 .60615 Mdot
.78457 .60615 Mdot
.78467 .60615 Mdot
.78476 .60615 Mdot
.78486 .60615 Mdot
.78495 .60615 Mdot
.78505 .60615 Mdot
.78514 .60615 Mdot
.78524 .60615 Mdot
.78533 .60615 Mdot
.78543 .60615 Mdot
.78552 .60615 Mdot
.78562 .60615 Mdot
.78571 .60615 Mdot
.78581 .60615 Mdot
.7859 .60615 Mdot
.786 .60615 Mdot
.7861 .60615 Mdot
.78619 .60615 Mdot
.78629 .60615 Mdot
.78638 .60615 Mdot
.78648 .60615 Mdot
.78657 .60615 Mdot
.78667 .60615 Mdot
.78676 .60615 Mdot
.78686 .60615 Mdot
.78695 .60615 Mdot
.78705 .60615 Mdot
.78714 .60615 Mdot
.78724 .60615 Mdot
.78733 .60615 Mdot
.78743 .60615 Mdot
.78752 .60615 Mdot
.78762 .60615 Mdot
.78771 .60615 Mdot
.78781 .60615 Mdot
.7879 .60615 Mdot
.788 .60615 Mdot
.7881 .60615 Mdot
.78819 .60615 Mdot
.78829 .60615 Mdot
.78838 .60615 Mdot
.78848 .60615 Mdot
.78857 .60615 Mdot
.78867 .60615 Mdot
.78876 .60615 Mdot
.78886 .60615 Mdot
.78895 .60615 Mdot
.78905 .60615 Mdot
.78914 .60615 Mdot
.78924 .60615 Mdot
.78933 .60615 Mdot
.78943 .60615 Mdot
.78952 .60615 Mdot
.78962 .60615 Mdot
.78971 .60615 Mdot
.78981 .60615 Mdot
.7899 .60615 Mdot
.79 .60615 Mdot
.7901 .60615 Mdot
.79019 .60615 Mdot
.79029 .60615 Mdot
.79038 .60615 Mdot
.79048 .60615 Mdot
.79057 .60615 Mdot
.79067 .60615 Mdot
.79076 .60615 Mdot
.79086 .60615 Mdot
.79095 .60615 Mdot
.79105 .60615 Mdot
.79114 .60615 Mdot
.79124 .60615 Mdot
.79133 .60615 Mdot
.79143 .60615 Mdot
.79152 .60615 Mdot
.79162 .60615 Mdot
.79171 .60615 Mdot
.79181 .60615 Mdot
.7919 .60615 Mdot
.792 .60615 Mdot
.7921 .60615 Mdot
.79219 .60615 Mdot
.79229 .60615 Mdot
.79238 .60615 Mdot
.79248 .60615 Mdot
.79257 .60615 Mdot
.79267 .60615 Mdot
.79276 .60615 Mdot
.79286 .60615 Mdot
.79295 .60615 Mdot
.79305 .60615 Mdot
.79314 .60615 Mdot
.79324 .60615 Mdot
.79333 .60615 Mdot
.79343 .60615 Mdot
.79352 .60615 Mdot
.79362 .60615 Mdot
.79371 .60615 Mdot
.79381 .60615 Mdot
.7939 .60615 Mdot
.794 .60615 Mdot
.7941 .60615 Mdot
.79419 .60615 Mdot
.79429 .60615 Mdot
.79438 .60615 Mdot
.79448 .60615 Mdot
.79457 .60615 Mdot
.79467 .60615 Mdot
.79476 .60615 Mdot
.79486 .60615 Mdot
.79495 .60615 Mdot
.79505 .60615 Mdot
.79514 .60615 Mdot
.79524 .60615 Mdot
.79533 .60615 Mdot
.79543 .60615 Mdot
.79552 .60615 Mdot
.79562 .60615 Mdot
.79571 .60615 Mdot
.79581 .60615 Mdot
.7959 .60615 Mdot
.796 .60615 Mdot
.7961 .60615 Mdot
.79619 .60615 Mdot
.79629 .60615 Mdot
.79638 .60615 Mdot
.79648 .60615 Mdot
.79657 .60615 Mdot
.79667 .60615 Mdot
.79676 .60615 Mdot
.79686 .60615 Mdot
.79695 .60615 Mdot
.79705 .60615 Mdot
.79714 .60615 Mdot
.79724 .60615 Mdot
.79733 .60615 Mdot
.79743 .60615 Mdot
.79752 .60615 Mdot
.79762 .60615 Mdot
.79771 .60615 Mdot
.79781 .60615 Mdot
.7979 .60615 Mdot
.798 .60615 Mdot
.7981 .60615 Mdot
.79819 .60615 Mdot
.79829 .60615 Mdot
.79838 .60615 Mdot
.79848 .60615 Mdot
.79857 .60615 Mdot
.79867 .60615 Mdot
.79876 .60615 Mdot
.79886 .60615 Mdot
.79895 .60615 Mdot
.79905 .60615 Mdot
.79914 .60615 Mdot
.79924 .60615 Mdot
.79933 .60615 Mdot
.79943 .60615 Mdot
.79952 .60615 Mdot
.79962 .60615 Mdot
.79971 .60615 Mdot
.79981 .60615 Mdot
.7999 .60615 Mdot
.8 .60615 Mdot
.8001 .60615 Mdot
.80019 .60615 Mdot
.80029 .60615 Mdot
.80038 .60615 Mdot
.80048 .60615 Mdot
.80057 .60615 Mdot
.80067 .60615 Mdot
.80076 .60615 Mdot
.80086 .60615 Mdot
.80095 .60615 Mdot
.80105 .60615 Mdot
.80114 .60615 Mdot
.80124 .60615 Mdot
.80133 .60615 Mdot
.80143 .60615 Mdot
.80152 .60615 Mdot
.80162 .60615 Mdot
.80171 .60615 Mdot
.80181 .60615 Mdot
.8019 .60615 Mdot
.802 .60615 Mdot
.8021 .60615 Mdot
.80219 .60615 Mdot
.80229 .60615 Mdot
.80238 .60615 Mdot
.80248 .60615 Mdot
.80257 .60615 Mdot
.80267 .60615 Mdot
.80276 .60615 Mdot
.80286 .60615 Mdot
.80295 .60615 Mdot
.80305 .60615 Mdot
.80314 .60615 Mdot
.80324 .60615 Mdot
.80333 .60615 Mdot
.80343 .60615 Mdot
.80352 .60615 Mdot
.80362 .60615 Mdot
.80371 .60615 Mdot
.80381 .60615 Mdot
.8039 .60615 Mdot
.804 .60615 Mdot
.8041 .60615 Mdot
.80419 .60615 Mdot
.80429 .60615 Mdot
.80438 .60615 Mdot
.80448 .60615 Mdot
.80457 .60615 Mdot
.80467 .60615 Mdot
.80476 .60615 Mdot
.80486 .60615 Mdot
.80495 .60615 Mdot
.80505 .60615 Mdot
.80514 .60615 Mdot
.80524 .60615 Mdot
.80533 .60615 Mdot
.80543 .60615 Mdot
.80552 .60615 Mdot
.80562 .60615 Mdot
.80571 .60615 Mdot
.80581 .60615 Mdot
.8059 .60615 Mdot
.806 .60615 Mdot
.8061 .60615 Mdot
.80619 .60615 Mdot
.80629 .60615 Mdot
.80638 .60615 Mdot
.80648 .60615 Mdot
.80657 .60615 Mdot
.80667 .60615 Mdot
.80676 .60615 Mdot
.80686 .60615 Mdot
.80695 .60615 Mdot
.80705 .60615 Mdot
.80714 .60615 Mdot
.80724 .60615 Mdot
.80733 .60615 Mdot
.80743 .60615 Mdot
.80752 .60615 Mdot
.80762 .60615 Mdot
.80771 .60615 Mdot
.80781 .60615 Mdot
.8079 .60615 Mdot
.808 .60615 Mdot
.8081 .60615 Mdot
.80819 .60615 Mdot
.80829 .60615 Mdot
.80838 .60615 Mdot
.80848 .60615 Mdot
.80857 .60615 Mdot
.80867 .60615 Mdot
.80876 .60615 Mdot
.80886 .60615 Mdot
.80895 .60615 Mdot
.80905 .60615 Mdot
.80914 .60615 Mdot
.80924 .60615 Mdot
.80933 .60615 Mdot
.80943 .60615 Mdot
.80952 .60615 Mdot
.80962 .60615 Mdot
.80971 .60615 Mdot
.80981 .60615 Mdot
.8099 .60615 Mdot
.81 .60615 Mdot
.8101 .60615 Mdot
.81019 .60615 Mdot
.81029 .60615 Mdot
.81038 .60615 Mdot
.81048 .60615 Mdot
.81057 .60615 Mdot
.81067 .60615 Mdot
.81076 .60615 Mdot
.81086 .60615 Mdot
.81095 .60615 Mdot
.81105 .60615 Mdot
.81114 .60615 Mdot
.81124 .60615 Mdot
.81133 .60615 Mdot
.81143 .60615 Mdot
.81152 .60615 Mdot
.81162 .60615 Mdot
.81171 .60615 Mdot
.81181 .60615 Mdot
.8119 .60615 Mdot
.812 .60615 Mdot
.8121 .60615 Mdot
.81219 .60615 Mdot
.81229 .60615 Mdot
.81238 .60615 Mdot
.81248 .60615 Mdot
.81257 .60615 Mdot
.81267 .60615 Mdot
.81276 .60615 Mdot
.81286 .60615 Mdot
.81295 .60615 Mdot
.81305 .60615 Mdot
.81314 .60615 Mdot
.81324 .60615 Mdot
.81333 .60615 Mdot
.81343 .60615 Mdot
.81352 .60615 Mdot
.81362 .60615 Mdot
.81371 .60615 Mdot
.81381 .60615 Mdot
.8139 .60615 Mdot
.814 .60615 Mdot
.8141 .60615 Mdot
.81419 .60615 Mdot
.81429 .60615 Mdot
.81438 .60615 Mdot
.81448 .60615 Mdot
.81457 .60615 Mdot
.81467 .60615 Mdot
.81476 .60615 Mdot
.81486 .60615 Mdot
.81495 .60615 Mdot
.81505 .60615 Mdot
.81514 .60615 Mdot
.81524 .60615 Mdot
.81533 .60615 Mdot
.81543 .60615 Mdot
.81552 .60615 Mdot
.81562 .60615 Mdot
.81571 .60615 Mdot
.81581 .60615 Mdot
.8159 .60615 Mdot
.816 .60615 Mdot
.8161 .60615 Mdot
.81619 .60615 Mdot
.81629 .60615 Mdot
.81638 .60615 Mdot
.81648 .60615 Mdot
.81657 .60615 Mdot
.81667 .60615 Mdot
.81676 .60615 Mdot
.81686 .60615 Mdot
.81695 .60615 Mdot
.81705 .60615 Mdot
.81714 .60615 Mdot
.81724 .60615 Mdot
.81733 .60615 Mdot
.81743 .60615 Mdot
.81752 .60615 Mdot
.81762 .60615 Mdot
.81771 .60615 Mdot
.81781 .60615 Mdot
.8179 .60615 Mdot
.818 .60615 Mdot
.8181 .60615 Mdot
.81819 .60615 Mdot
.81829 .60615 Mdot
.81838 .60615 Mdot
.81848 .60615 Mdot
.81857 .60615 Mdot
.81867 .60615 Mdot
.81876 .60615 Mdot
.81886 .60615 Mdot
.81895 .60615 Mdot
.81905 .60615 Mdot
.81914 .60615 Mdot
.81924 .60615 Mdot
.81933 .60615 Mdot
.81943 .60615 Mdot
.81952 .60615 Mdot
.81962 .60615 Mdot
.81971 .60615 Mdot
.81981 .60615 Mdot
.8199 .60615 Mdot
.82 .60615 Mdot
.8201 .60615 Mdot
.82019 .60615 Mdot
.82029 .60615 Mdot
.82038 .60615 Mdot
.82048 .60615 Mdot
.82057 .60615 Mdot
.82067 .60615 Mdot
.82076 .60615 Mdot
.82086 .60615 Mdot
.82095 .60615 Mdot
.82105 .60615 Mdot
.82114 .60615 Mdot
.82124 .60615 Mdot
.82133 .60615 Mdot
.82143 .60615 Mdot
.82152 .60615 Mdot
.82162 .60615 Mdot
.82171 .60615 Mdot
.82181 .60615 Mdot
.8219 .60615 Mdot
.822 .60615 Mdot
.8221 .60615 Mdot
.82219 .60615 Mdot
.82229 .60615 Mdot
.82238 .60615 Mdot
.82248 .60615 Mdot
.82257 .60615 Mdot
.82267 .60615 Mdot
.82276 .60615 Mdot
.82286 .60615 Mdot
.82295 .60615 Mdot
.82305 .60615 Mdot
.82314 .60615 Mdot
.82324 .60615 Mdot
.82333 .60615 Mdot
.82343 .60615 Mdot
.82352 .60615 Mdot
.82362 .60615 Mdot
.82371 .60615 Mdot
.82381 .60615 Mdot
.8239 .60615 Mdot
.824 .60615 Mdot
.8241 .60615 Mdot
.82419 .60615 Mdot
.82429 .60615 Mdot
.82438 .60615 Mdot
.82448 .60615 Mdot
.82457 .60615 Mdot
.82467 .60615 Mdot
.82476 .60615 Mdot
.82486 .60615 Mdot
.82495 .60615 Mdot
.82505 .60615 Mdot
.82514 .60615 Mdot
.82524 .60615 Mdot
.82533 .60615 Mdot
.82543 .60615 Mdot
.82552 .60615 Mdot
.82562 .60615 Mdot
.82571 .60615 Mdot
.82581 .60615 Mdot
.8259 .60615 Mdot
.826 .60615 Mdot
.8261 .60615 Mdot
.82619 .60615 Mdot
.82629 .60615 Mdot
.82638 .60615 Mdot
.82648 .60615 Mdot
.82657 .60615 Mdot
.82667 .60615 Mdot
.82676 .60615 Mdot
.82686 .60615 Mdot
.82695 .60615 Mdot
.82705 .60615 Mdot
.82714 .60615 Mdot
.82724 .60615 Mdot
.82733 .60615 Mdot
.82743 .60615 Mdot
.82752 .60615 Mdot
.82762 .60615 Mdot
.82771 .60615 Mdot
.82781 .60615 Mdot
.8279 .60615 Mdot
.828 .60615 Mdot
.8281 .60615 Mdot
.82819 .60615 Mdot
.82829 .60615 Mdot
.82838 .60615 Mdot
.82848 .60615 Mdot
.82857 .60615 Mdot
.82867 .60615 Mdot
.82876 .60615 Mdot
.82886 .60615 Mdot
.82895 .60615 Mdot
.82905 .60615 Mdot
.82914 .60615 Mdot
.82924 .60615 Mdot
.82933 .60615 Mdot
.82943 .60615 Mdot
.82952 .60615 Mdot
.82962 .60615 Mdot
.82971 .60615 Mdot
.82981 .60615 Mdot
.8299 .60615 Mdot
.83 .60615 Mdot
.8301 .60615 Mdot
.83019 .60615 Mdot
.83029 .60615 Mdot
.83038 .60615 Mdot
.83048 .60615 Mdot
.83057 .60615 Mdot
.83067 .60615 Mdot
.83076 .60615 Mdot
.83086 .60615 Mdot
.83095 .60615 Mdot
.83105 .60615 Mdot
.83114 .60615 Mdot
.83124 .60615 Mdot
.83133 .60615 Mdot
.83143 .60615 Mdot
.83152 .60615 Mdot
.83162 .60615 Mdot
.83171 .60615 Mdot
.83181 .60615 Mdot
.8319 .60615 Mdot
.832 .60615 Mdot
.8321 .60615 Mdot
.83219 .60615 Mdot
.83229 .60615 Mdot
.83238 .60615 Mdot
.83248 .60615 Mdot
.83257 .60615 Mdot
.83267 .60615 Mdot
.83276 .60615 Mdot
.83286 .60615 Mdot
.83295 .60615 Mdot
.83305 .60615 Mdot
.83314 .60615 Mdot
.83324 .60615 Mdot
.83333 .60615 Mdot
.83343 .60615 Mdot
.83352 .60615 Mdot
.83362 .60615 Mdot
.83371 .60615 Mdot
.83381 .60615 Mdot
.8339 .60615 Mdot
.834 .60615 Mdot
.8341 .60615 Mdot
.83419 .60615 Mdot
.83429 .60615 Mdot
.83438 .60615 Mdot
.83448 .60615 Mdot
.83457 .60615 Mdot
.83467 .60615 Mdot
.83476 .60615 Mdot
.83486 .60615 Mdot
.83495 .60615 Mdot
.83505 .60615 Mdot
.83514 .60615 Mdot
.83524 .60615 Mdot
.83533 .60615 Mdot
.83543 .60615 Mdot
.83552 .60615 Mdot
.83562 .60615 Mdot
.83571 .60615 Mdot
.83581 .60615 Mdot
.8359 .60615 Mdot
.836 .60615 Mdot
.8361 .60615 Mdot
.83619 .60615 Mdot
.83629 .60615 Mdot
.83638 .60615 Mdot
.83648 .60615 Mdot
.83657 .60615 Mdot
.83667 .60615 Mdot
.83676 .60615 Mdot
.83686 .60615 Mdot
.83695 .60615 Mdot
.83705 .60615 Mdot
.83714 .60615 Mdot
.83724 .60615 Mdot
.83733 .60615 Mdot
.83743 .60615 Mdot
.83752 .60615 Mdot
.83762 .60615 Mdot
.83771 .60615 Mdot
.83781 .60615 Mdot
.8379 .60615 Mdot
.838 .60615 Mdot
.8381 .60615 Mdot
.83819 .60615 Mdot
.83829 .60615 Mdot
.83838 .60615 Mdot
.83848 .60615 Mdot
.83857 .60615 Mdot
.83867 .60615 Mdot
.83876 .60615 Mdot
.83886 .60615 Mdot
.83895 .60615 Mdot
.83905 .60615 Mdot
.83914 .60615 Mdot
.83924 .60615 Mdot
.83933 .60615 Mdot
.83943 .60615 Mdot
.83952 .60615 Mdot
.83962 .60615 Mdot
.83971 .60615 Mdot
.83981 .60615 Mdot
.8399 .60615 Mdot
.84 .60615 Mdot
.8401 .60615 Mdot
.84019 .60615 Mdot
.84029 .60615 Mdot
.84038 .60615 Mdot
.84048 .60615 Mdot
.84057 .60615 Mdot
.84067 .60615 Mdot
.84076 .60615 Mdot
.84086 .60615 Mdot
.84095 .60615 Mdot
.84105 .60615 Mdot
.84114 .60615 Mdot
.84124 .60615 Mdot
.84133 .60615 Mdot
.84143 .60615 Mdot
.84152 .60615 Mdot
.84162 .60615 Mdot
.84171 .60615 Mdot
.84181 .60615 Mdot
.8419 .60615 Mdot
.842 .60615 Mdot
.8421 .60615 Mdot
.84219 .60615 Mdot
.84229 .60615 Mdot
.84238 .60615 Mdot
.84248 .60615 Mdot
.84257 .60615 Mdot
.84267 .60615 Mdot
.84276 .60615 Mdot
.84286 .60615 Mdot
.84295 .60615 Mdot
.84305 .60615 Mdot
.84314 .60615 Mdot
.84324 .60615 Mdot
.84333 .60615 Mdot
.84343 .60615 Mdot
.84352 .60615 Mdot
.84362 .60615 Mdot
.84371 .60615 Mdot
.84381 .60615 Mdot
.8439 .60615 Mdot
.844 .60615 Mdot
.8441 .60615 Mdot
.84419 .60615 Mdot
.84429 .60615 Mdot
.84438 .60615 Mdot
.84448 .60615 Mdot
.84457 .60615 Mdot
.84467 .60615 Mdot
.84476 .60615 Mdot
.84486 .60615 Mdot
.84495 .60615 Mdot
.84505 .60615 Mdot
.84514 .60615 Mdot
.84524 .60615 Mdot
.84533 .60615 Mdot
.84543 .60615 Mdot
.84552 .60615 Mdot
.84562 .60615 Mdot
.84571 .60615 Mdot
.84581 .60615 Mdot
.8459 .60615 Mdot
.846 .60615 Mdot
.8461 .60615 Mdot
.84619 .60615 Mdot
.84629 .60615 Mdot
.84638 .60615 Mdot
.84648 .60615 Mdot
.84657 .60615 Mdot
.84667 .60615 Mdot
.84676 .60615 Mdot
.84686 .60615 Mdot
.84695 .60615 Mdot
.84705 .60615 Mdot
.84714 .60615 Mdot
.84724 .60615 Mdot
.84733 .60615 Mdot
.84743 .60615 Mdot
.84752 .60615 Mdot
.84762 .60615 Mdot
.84771 .60615 Mdot
.84781 .60615 Mdot
.8479 .60615 Mdot
.848 .60615 Mdot
.8481 .60615 Mdot
.84819 .60615 Mdot
.84829 .60615 Mdot
.84838 .60615 Mdot
.84848 .60615 Mdot
.84857 .60615 Mdot
.84867 .60615 Mdot
.84876 .60615 Mdot
.84886 .60615 Mdot
.84895 .60615 Mdot
.84905 .60615 Mdot
.84914 .60615 Mdot
.84924 .60615 Mdot
.84933 .60615 Mdot
.84943 .60615 Mdot
.84952 .60615 Mdot
.84962 .60615 Mdot
.84971 .60615 Mdot
.84981 .60615 Mdot
.8499 .60615 Mdot
.85 .60615 Mdot
.8501 .60615 Mdot
.85019 .60615 Mdot
.85029 .60615 Mdot
.85038 .60615 Mdot
.85048 .60615 Mdot
.85057 .60615 Mdot
.85067 .60615 Mdot
.85076 .60615 Mdot
.85086 .60615 Mdot
.85095 .60615 Mdot
.85105 .60615 Mdot
.85114 .60615 Mdot
.85124 .60615 Mdot
.85133 .60615 Mdot
.85143 .60615 Mdot
.85152 .60615 Mdot
.85162 .60615 Mdot
.85171 .60615 Mdot
.85181 .60615 Mdot
.8519 .60615 Mdot
.852 .60615 Mdot
.8521 .60615 Mdot
.85219 .60615 Mdot
.85229 .60615 Mdot
.85238 .60615 Mdot
.85248 .60615 Mdot
.85257 .60615 Mdot
.85267 .60615 Mdot
.85276 .60615 Mdot
.85286 .60615 Mdot
.85295 .60615 Mdot
.85305 .60615 Mdot
.85314 .60615 Mdot
.85324 .60615 Mdot
.85333 .60615 Mdot
.85343 .60615 Mdot
.85352 .60615 Mdot
.85362 .60615 Mdot
.85371 .60615 Mdot
.85381 .60615 Mdot
.8539 .60615 Mdot
.854 .60615 Mdot
.8541 .60615 Mdot
.85419 .60615 Mdot
.85429 .60615 Mdot
.85438 .60615 Mdot
.85448 .60615 Mdot
.85457 .60615 Mdot
.85467 .60615 Mdot
.85476 .60615 Mdot
.85486 .60615 Mdot
.85495 .60615 Mdot
.85505 .60615 Mdot
.85514 .60615 Mdot
.85524 .60615 Mdot
.85533 .60615 Mdot
.85543 .60615 Mdot
.85552 .60615 Mdot
.85562 .60615 Mdot
.85571 .60615 Mdot
.85581 .60615 Mdot
.8559 .60615 Mdot
.856 .60615 Mdot
.8561 .60615 Mdot
.85619 .60615 Mdot
.85629 .60615 Mdot
.85638 .60615 Mdot
.85648 .60615 Mdot
.85657 .60615 Mdot
.85667 .60615 Mdot
.85676 .60615 Mdot
.85686 .60615 Mdot
.85695 .60615 Mdot
.85705 .60615 Mdot
.85714 .60615 Mdot
.85724 .60615 Mdot
.85733 .60615 Mdot
.85743 .60615 Mdot
.85752 .60615 Mdot
.85762 .60615 Mdot
.85771 .60615 Mdot
.85781 .60615 Mdot
.8579 .60615 Mdot
.858 .60615 Mdot
.8581 .60615 Mdot
.85819 .60615 Mdot
.85829 .60615 Mdot
.85838 .60615 Mdot
.85848 .60615 Mdot
.85857 .60615 Mdot
.85867 .60615 Mdot
.85876 .60615 Mdot
.85886 .60615 Mdot
.85895 .60615 Mdot
.85905 .60615 Mdot
.85914 .60615 Mdot
.85924 .60615 Mdot
.85933 .60615 Mdot
.85943 .60615 Mdot
.85952 .60615 Mdot
.85962 .60615 Mdot
.85971 .60615 Mdot
.85981 .60615 Mdot
.8599 .60615 Mdot
.86 .60615 Mdot
.8601 .60615 Mdot
.86019 .60615 Mdot
.86029 .60615 Mdot
.86038 .60615 Mdot
.86048 .60615 Mdot
.86057 .60615 Mdot
.86067 .60615 Mdot
.86076 .60615 Mdot
.86086 .60615 Mdot
.86095 .60615 Mdot
.86105 .60615 Mdot
.86114 .60615 Mdot
.86124 .60615 Mdot
.86133 .60615 Mdot
.86143 .60615 Mdot
.86152 .60615 Mdot
.86162 .60615 Mdot
.86171 .60615 Mdot
.86181 .60615 Mdot
.8619 .60615 Mdot
.862 .60615 Mdot
.8621 .60615 Mdot
.86219 .60615 Mdot
.86229 .60615 Mdot
.86238 .60615 Mdot
.86248 .60615 Mdot
.86257 .60615 Mdot
.86267 .60615 Mdot
.86276 .60615 Mdot
.86286 .60615 Mdot
.86295 .60615 Mdot
.86305 .60615 Mdot
.86314 .60615 Mdot
.86324 .60615 Mdot
.86333 .60615 Mdot
.86343 .60615 Mdot
.86352 .60615 Mdot
.86362 .60615 Mdot
.86371 .60615 Mdot
.86381 .60615 Mdot
.8639 .60615 Mdot
.864 .60615 Mdot
.8641 .60615 Mdot
.86419 .60615 Mdot
.86429 .60615 Mdot
.86438 .60615 Mdot
.86448 .60615 Mdot
.86457 .60615 Mdot
.86467 .60615 Mdot
.86476 .60615 Mdot
.86486 .60615 Mdot
.86495 .60615 Mdot
.86505 .60615 Mdot
.86514 .60615 Mdot
.86524 .60615 Mdot
.86533 .60615 Mdot
.86543 .60615 Mdot
.86552 .60615 Mdot
.86562 .60615 Mdot
.86571 .60615 Mdot
.86581 .60615 Mdot
.8659 .60615 Mdot
.866 .60615 Mdot
.8661 .60615 Mdot
.86619 .60615 Mdot
.86629 .60615 Mdot
.86638 .60615 Mdot
.86648 .60615 Mdot
.86657 .60615 Mdot
.86667 .60615 Mdot
.86676 .60615 Mdot
.86686 .60615 Mdot
.86695 .60615 Mdot
.86705 .60615 Mdot
.86714 .60615 Mdot
.86724 .60615 Mdot
.86733 .60615 Mdot
.86743 .60615 Mdot
.86752 .60615 Mdot
.86762 .60615 Mdot
.86771 .60615 Mdot
.86781 .60615 Mdot
.8679 .60615 Mdot
.868 .60615 Mdot
.8681 .60615 Mdot
.86819 .60615 Mdot
.86829 .60615 Mdot
.86838 .60615 Mdot
.86848 .60615 Mdot
.86857 .60615 Mdot
.86867 .60615 Mdot
.86876 .60615 Mdot
.86886 .60615 Mdot
.86895 .60615 Mdot
.86905 .60615 Mdot
.86914 .60615 Mdot
.86924 .60615 Mdot
.86933 .60615 Mdot
.86943 .60615 Mdot
.86952 .60615 Mdot
.86962 .60615 Mdot
.86971 .60615 Mdot
.86981 .60615 Mdot
.8699 .60615 Mdot
.87 .60615 Mdot
.8701 .60615 Mdot
.87019 .60615 Mdot
.87029 .60615 Mdot
.87038 .60615 Mdot
.87048 .60615 Mdot
.87057 .60615 Mdot
.87067 .60615 Mdot
.87076 .60615 Mdot
.87086 .60615 Mdot
.87095 .60615 Mdot
.87105 .60615 Mdot
.87114 .60615 Mdot
.87124 .60615 Mdot
.87133 .60615 Mdot
.87143 .60615 Mdot
.87152 .60615 Mdot
.87162 .60615 Mdot
.87171 .60615 Mdot
.87181 .60615 Mdot
.8719 .60615 Mdot
.872 .60615 Mdot
.8721 .60615 Mdot
.87219 .60615 Mdot
.87229 .60615 Mdot
.87238 .60615 Mdot
.87248 .60615 Mdot
.87257 .60615 Mdot
.87267 .60615 Mdot
.87276 .60615 Mdot
.87286 .60615 Mdot
.87295 .60615 Mdot
.87305 .60615 Mdot
.87314 .60615 Mdot
.87324 .60615 Mdot
.87333 .60615 Mdot
.87343 .60615 Mdot
.87352 .60615 Mdot
.87362 .60615 Mdot
.87371 .60615 Mdot
.87381 .60615 Mdot
.8739 .60615 Mdot
.874 .60615 Mdot
.8741 .60615 Mdot
.87419 .60615 Mdot
.87429 .60615 Mdot
.87438 .60615 Mdot
.87448 .60615 Mdot
.87457 .60615 Mdot
.87467 .60615 Mdot
.87476 .60615 Mdot
.87486 .60615 Mdot
.87495 .60615 Mdot
.87505 .60615 Mdot
.87514 .60615 Mdot
.87524 .60615 Mdot
.87533 .60615 Mdot
.87543 .60615 Mdot
.87552 .60615 Mdot
.87562 .60615 Mdot
.87571 .60615 Mdot
.87581 .60615 Mdot
.8759 .60615 Mdot
.876 .60615 Mdot
.8761 .60615 Mdot
.87619 .60615 Mdot
.87629 .60615 Mdot
.87638 .60615 Mdot
.87648 .60615 Mdot
.87657 .60615 Mdot
.87667 .60615 Mdot
.87676 .60615 Mdot
.87686 .60615 Mdot
.87695 .60615 Mdot
.87705 .60615 Mdot
.87714 .60615 Mdot
.87724 .60615 Mdot
.87733 .60615 Mdot
.87743 .60615 Mdot
.87752 .60615 Mdot
.87762 .60615 Mdot
.87771 .60615 Mdot
.87781 .60615 Mdot
.8779 .60615 Mdot
.878 .60615 Mdot
.8781 .60615 Mdot
.87819 .60615 Mdot
.87829 .60615 Mdot
.87838 .60615 Mdot
.87848 .60615 Mdot
.87857 .60615 Mdot
.87867 .60615 Mdot
.87876 .60615 Mdot
.87886 .60615 Mdot
.87895 .60615 Mdot
.87905 .60615 Mdot
.87914 .60615 Mdot
.87924 .60615 Mdot
.87933 .60615 Mdot
.87943 .60615 Mdot
.87952 .60615 Mdot
.87962 .60615 Mdot
.87971 .60615 Mdot
.87981 .60615 Mdot
.8799 .60615 Mdot
.88 .60615 Mdot
.8801 .60615 Mdot
.88019 .60615 Mdot
.88029 .60615 Mdot
.88038 .60615 Mdot
.88048 .60615 Mdot
.88057 .60615 Mdot
.88067 .60615 Mdot
.88076 .60615 Mdot
.88086 .60615 Mdot
.88095 .60615 Mdot
.88105 .60615 Mdot
.88114 .60615 Mdot
.88124 .60615 Mdot
.88133 .60615 Mdot
.88143 .60615 Mdot
.88152 .60615 Mdot
.88162 .60615 Mdot
.88171 .60615 Mdot
.88181 .60615 Mdot
.8819 .60615 Mdot
.882 .60615 Mdot
.8821 .60615 Mdot
.88219 .60615 Mdot
.88229 .60615 Mdot
.88238 .60615 Mdot
.88248 .60615 Mdot
.88257 .60615 Mdot
.88267 .60615 Mdot
.88276 .60615 Mdot
.88286 .60615 Mdot
.88295 .60615 Mdot
.88305 .60615 Mdot
.88314 .60615 Mdot
.88324 .60615 Mdot
.88333 .60615 Mdot
.88343 .60615 Mdot
.88352 .60615 Mdot
.88362 .60615 Mdot
.88371 .60615 Mdot
.88381 .60615 Mdot
.8839 .60615 Mdot
.884 .60615 Mdot
.8841 .60615 Mdot
.88419 .60615 Mdot
.88429 .60615 Mdot
.88438 .60615 Mdot
.88448 .60615 Mdot
.88457 .60615 Mdot
.88467 .60615 Mdot
.88476 .60615 Mdot
.88486 .60615 Mdot
.88495 .60615 Mdot
.88505 .60615 Mdot
.88514 .60615 Mdot
.88524 .60615 Mdot
.88533 .60615 Mdot
.88543 .60615 Mdot
.88552 .60615 Mdot
.88562 .60615 Mdot
.88571 .60615 Mdot
.88581 .60615 Mdot
.8859 .60615 Mdot
.886 .60615 Mdot
.8861 .60615 Mdot
.88619 .60615 Mdot
.88629 .60615 Mdot
.88638 .60615 Mdot
.88648 .60615 Mdot
.88657 .60615 Mdot
.88667 .60615 Mdot
.88676 .60615 Mdot
.88686 .60615 Mdot
.88695 .60615 Mdot
.88705 .60615 Mdot
.88714 .60615 Mdot
.88724 .60615 Mdot
.88733 .60615 Mdot
.88743 .60615 Mdot
.88752 .60615 Mdot
.88762 .60615 Mdot
.88771 .60615 Mdot
.88781 .60615 Mdot
.8879 .60615 Mdot
.888 .60615 Mdot
.8881 .60615 Mdot
.88819 .60615 Mdot
.88829 .60615 Mdot
.88838 .60615 Mdot
.88848 .60615 Mdot
.88857 .60615 Mdot
.88867 .60615 Mdot
.88876 .60615 Mdot
.88886 .60615 Mdot
.88895 .60615 Mdot
.88905 .60615 Mdot
.88914 .60615 Mdot
.88924 .60615 Mdot
.88933 .60615 Mdot
.88943 .60615 Mdot
.88952 .60615 Mdot
.88962 .60615 Mdot
.88971 .60615 Mdot
.88981 .60615 Mdot
.8899 .60615 Mdot
.89 .60615 Mdot
.8901 .60615 Mdot
.89019 .60615 Mdot
.89029 .60615 Mdot
.89038 .60615 Mdot
.89048 .60615 Mdot
.89057 .60615 Mdot
.89067 .60615 Mdot
.89076 .60615 Mdot
.89086 .60615 Mdot
.89095 .60615 Mdot
.89105 .60615 Mdot
.89114 .60615 Mdot
.89124 .60615 Mdot
.89133 .60615 Mdot
.89143 .60615 Mdot
.89152 .60615 Mdot
.89162 .60615 Mdot
.89171 .60615 Mdot
.89181 .60615 Mdot
.8919 .60615 Mdot
.892 .60615 Mdot
.8921 .60615 Mdot
.89219 .60615 Mdot
.89229 .60615 Mdot
.89238 .60615 Mdot
.89248 .60615 Mdot
.89257 .60615 Mdot
.89267 .60615 Mdot
.89276 .60615 Mdot
.89286 .60615 Mdot
.89295 .60615 Mdot
.89305 .60615 Mdot
.89314 .60615 Mdot
.89324 .60615 Mdot
.89333 .60615 Mdot
.89343 .60615 Mdot
.89352 .60615 Mdot
.89362 .60615 Mdot
.89371 .60615 Mdot
.89381 .60615 Mdot
.8939 .60615 Mdot
.894 .60615 Mdot
.8941 .60615 Mdot
.89419 .60615 Mdot
.89429 .60615 Mdot
.89438 .60615 Mdot
.89448 .60615 Mdot
.89457 .60615 Mdot
.89467 .60615 Mdot
.89476 .60615 Mdot
.89486 .60615 Mdot
.89495 .60615 Mdot
.89505 .60615 Mdot
.89514 .60615 Mdot
.89524 .60615 Mdot
.89533 .60615 Mdot
.89543 .60615 Mdot
.89552 .60615 Mdot
.89562 .60615 Mdot
.89571 .60615 Mdot
.89581 .60615 Mdot
.8959 .60615 Mdot
.896 .60615 Mdot
.8961 .60615 Mdot
.89619 .60615 Mdot
.89629 .60615 Mdot
.89638 .60615 Mdot
.89648 .60615 Mdot
.89657 .60615 Mdot
.89667 .60615 Mdot
.89676 .60615 Mdot
.89686 .60615 Mdot
.89695 .60615 Mdot
.89705 .60615 Mdot
.89714 .60615 Mdot
.89724 .60615 Mdot
.89733 .60615 Mdot
.89743 .60615 Mdot
.89752 .60615 Mdot
.89762 .60615 Mdot
.89771 .60615 Mdot
.89781 .60615 Mdot
.8979 .60615 Mdot
.898 .60615 Mdot
.8981 .60615 Mdot
.89819 .60615 Mdot
.89829 .60615 Mdot
.89838 .60615 Mdot
.89848 .60615 Mdot
.89857 .60615 Mdot
.89867 .60615 Mdot
.89876 .60615 Mdot
.89886 .60615 Mdot
.89895 .60615 Mdot
.89905 .60615 Mdot
.89914 .60615 Mdot
.89924 .60615 Mdot
.89933 .60615 Mdot
.89943 .60615 Mdot
.89952 .60615 Mdot
.89962 .60615 Mdot
.89971 .60615 Mdot
.89981 .60615 Mdot
.8999 .60615 Mdot
.9 .60615 Mdot
.9001 .60615 Mdot
.90019 .60615 Mdot
.90029 .60615 Mdot
.90038 .60615 Mdot
.90048 .60615 Mdot
.90057 .60615 Mdot
.90067 .60615 Mdot
.90076 .60615 Mdot
.90086 .60615 Mdot
.90095 .60615 Mdot
.90105 .60615 Mdot
.90114 .60615 Mdot
.90124 .60615 Mdot
.90133 .60615 Mdot
.90143 .60615 Mdot
.90152 .60615 Mdot
.90162 .60615 Mdot
.90171 .60615 Mdot
.90181 .60615 Mdot
.9019 .60615 Mdot
.902 .60615 Mdot
.9021 .60615 Mdot
.90219 .60615 Mdot
.90229 .60615 Mdot
.90238 .60615 Mdot
.90248 .60615 Mdot
.90257 .60615 Mdot
.90267 .60615 Mdot
.90276 .60615 Mdot
.90286 .60615 Mdot
.90295 .60615 Mdot
.90305 .60615 Mdot
.90314 .60615 Mdot
.90324 .60615 Mdot
.90333 .60615 Mdot
.90343 .60615 Mdot
.90352 .60615 Mdot
.90362 .60615 Mdot
.90371 .60615 Mdot
.90381 .60615 Mdot
.9039 .60615 Mdot
.904 .60615 Mdot
.9041 .60615 Mdot
.90419 .60615 Mdot
.90429 .60615 Mdot
.90438 .60615 Mdot
.90448 .60615 Mdot
.90457 .60615 Mdot
.90467 .60615 Mdot
.90476 .60615 Mdot
.90486 .60615 Mdot
.90495 .60615 Mdot
.90505 .60615 Mdot
.90514 .60615 Mdot
.90524 .60615 Mdot
.90533 .60615 Mdot
.90543 .60615 Mdot
.90552 .60615 Mdot
.90562 .60615 Mdot
.90571 .60615 Mdot
.90581 .60615 Mdot
.9059 .60615 Mdot
.906 .60615 Mdot
.9061 .60615 Mdot
.90619 .60615 Mdot
.90629 .60615 Mdot
.90638 .60615 Mdot
.90648 .60615 Mdot
.90657 .60615 Mdot
.90667 .60615 Mdot
.90676 .60615 Mdot
.90686 .60615 Mdot
.90695 .60615 Mdot
.90705 .60615 Mdot
.90714 .60615 Mdot
.90724 .60615 Mdot
.90733 .60615 Mdot
.90743 .60615 Mdot
.90752 .60615 Mdot
.90762 .60615 Mdot
.90771 .60615 Mdot
.90781 .60615 Mdot
.9079 .60615 Mdot
.908 .60615 Mdot
.9081 .60615 Mdot
.90819 .60615 Mdot
.90829 .60615 Mdot
.90838 .60615 Mdot
.90848 .60615 Mdot
.90857 .60615 Mdot
.90867 .60615 Mdot
.90876 .60615 Mdot
.90886 .60615 Mdot
.90895 .60615 Mdot
.90905 .60615 Mdot
.90914 .60615 Mdot
.90924 .60615 Mdot
.90933 .60615 Mdot
.90943 .60615 Mdot
.90952 .60615 Mdot
.90962 .60615 Mdot
.90971 .60615 Mdot
.90981 .60615 Mdot
.9099 .60615 Mdot
.91 .60615 Mdot
.9101 .60615 Mdot
.91019 .60615 Mdot
.91029 .60615 Mdot
.91038 .60615 Mdot
.91048 .60615 Mdot
.91057 .60615 Mdot
.91067 .60615 Mdot
.91076 .60615 Mdot
.91086 .60615 Mdot
.91095 .60615 Mdot
.91105 .60615 Mdot
.91114 .60615 Mdot
.91124 .60615 Mdot
.91133 .60615 Mdot
.91143 .60615 Mdot
.91152 .60615 Mdot
.91162 .60615 Mdot
.91171 .60615 Mdot
.91181 .60615 Mdot
.9119 .60615 Mdot
.912 .60615 Mdot
.9121 .60615 Mdot
.91219 .60615 Mdot
.91229 .60615 Mdot
.91238 .60615 Mdot
.91248 .60615 Mdot
.91257 .60615 Mdot
.91267 .60615 Mdot
.91276 .60615 Mdot
.91286 .60615 Mdot
.91295 .60615 Mdot
.91305 .60615 Mdot
.91314 .60615 Mdot
.91324 .60615 Mdot
.91333 .60615 Mdot
.91343 .60615 Mdot
.91352 .60615 Mdot
.91362 .60615 Mdot
.91371 .60615 Mdot
.91381 .60615 Mdot
.9139 .60615 Mdot
.914 .60615 Mdot
.9141 .60615 Mdot
.91419 .60615 Mdot
.91429 .60615 Mdot
.91438 .60615 Mdot
.91448 .60615 Mdot
.91457 .60615 Mdot
.91467 .60615 Mdot
.91476 .60615 Mdot
.91486 .60615 Mdot
.91495 .60615 Mdot
.91505 .60615 Mdot
.91514 .60615 Mdot
.91524 .60615 Mdot
.91533 .60615 Mdot
.91543 .60615 Mdot
.91552 .60615 Mdot
.91562 .60615 Mdot
.91571 .60615 Mdot
.91581 .60615 Mdot
.9159 .60615 Mdot
.916 .60615 Mdot
.9161 .60615 Mdot
.91619 .60615 Mdot
.91629 .60615 Mdot
.91638 .60615 Mdot
.91648 .60615 Mdot
.91657 .60615 Mdot
.91667 .60615 Mdot
.91676 .60615 Mdot
.91686 .60615 Mdot
.91695 .60615 Mdot
.91705 .60615 Mdot
.91714 .60615 Mdot
.91724 .60615 Mdot
.91733 .60615 Mdot
.91743 .60615 Mdot
.91752 .60615 Mdot
.91762 .60615 Mdot
.91771 .60615 Mdot
.91781 .60615 Mdot
.9179 .60615 Mdot
.918 .60615 Mdot
.9181 .60615 Mdot
.91819 .60615 Mdot
.91829 .60615 Mdot
.91838 .60615 Mdot
.91848 .60615 Mdot
.91857 .60615 Mdot
.91867 .60615 Mdot
.91876 .60615 Mdot
.91886 .60615 Mdot
.91895 .60615 Mdot
.91905 .60615 Mdot
.91914 .60615 Mdot
.91924 .60615 Mdot
.91933 .60615 Mdot
.91943 .60615 Mdot
.91952 .60615 Mdot
.91962 .60615 Mdot
.91971 .60615 Mdot
.91981 .60615 Mdot
.9199 .60615 Mdot
.92 .60615 Mdot
.9201 .60615 Mdot
.92019 .60615 Mdot
.92029 .60615 Mdot
.92038 .60615 Mdot
.92048 .60615 Mdot
.92057 .60615 Mdot
.92067 .60615 Mdot
.92076 .60615 Mdot
.92086 .60615 Mdot
.92095 .60615 Mdot
.92105 .60615 Mdot
.92114 .60615 Mdot
.92124 .60615 Mdot
.92133 .60615 Mdot
.92143 .60615 Mdot
.92152 .60615 Mdot
.92162 .60615 Mdot
.92171 .60615 Mdot
.92181 .60615 Mdot
.9219 .60615 Mdot
.922 .60615 Mdot
.9221 .60615 Mdot
.92219 .60615 Mdot
.92229 .60615 Mdot
.92238 .60615 Mdot
.92248 .60615 Mdot
.92257 .60615 Mdot
.92267 .60615 Mdot
.92276 .60615 Mdot
.92286 .60615 Mdot
.92295 .60615 Mdot
.92305 .60615 Mdot
.92314 .60615 Mdot
.92324 .60615 Mdot
.92333 .60615 Mdot
.92343 .60615 Mdot
.92352 .60615 Mdot
.92362 .60615 Mdot
.92371 .60615 Mdot
.92381 .60615 Mdot
.9239 .60615 Mdot
.924 .60615 Mdot
.9241 .60615 Mdot
.92419 .60615 Mdot
.92429 .60615 Mdot
.92438 .60615 Mdot
.92448 .60615 Mdot
.92457 .60615 Mdot
.92467 .60615 Mdot
.92476 .60615 Mdot
.92486 .60615 Mdot
.92495 .60615 Mdot
.92505 .60615 Mdot
.92514 .60615 Mdot
.92524 .60615 Mdot
.92533 .60615 Mdot
.92543 .60615 Mdot
.92552 .60615 Mdot
.92562 .60615 Mdot
.92571 .60615 Mdot
.92581 .60615 Mdot
.9259 .60615 Mdot
.926 .60615 Mdot
.9261 .60615 Mdot
.92619 .60615 Mdot
.92629 .60615 Mdot
.92638 .60615 Mdot
.92648 .60615 Mdot
.92657 .60615 Mdot
.92667 .60615 Mdot
.92676 .60615 Mdot
.92686 .60615 Mdot
.92695 .60615 Mdot
.92705 .60615 Mdot
.92714 .60615 Mdot
.92724 .60615 Mdot
.92733 .60615 Mdot
.92743 .60615 Mdot
.92752 .60615 Mdot
.92762 .60615 Mdot
.92771 .60615 Mdot
.92781 .60615 Mdot
.9279 .60615 Mdot
.928 .60615 Mdot
.9281 .60615 Mdot
.92819 .60615 Mdot
.92829 .60615 Mdot
.92838 .60615 Mdot
.92848 .60615 Mdot
.92857 .60615 Mdot
.92867 .60615 Mdot
.92876 .60615 Mdot
.92886 .60615 Mdot
.92895 .60615 Mdot
.92905 .60615 Mdot
.92914 .60615 Mdot
.92924 .60615 Mdot
.92933 .60615 Mdot
.92943 .60615 Mdot
.92952 .60615 Mdot
.92962 .60615 Mdot
.92971 .60615 Mdot
.92981 .60615 Mdot
.9299 .60615 Mdot
.93 .60615 Mdot
.9301 .60615 Mdot
.93019 .60615 Mdot
.93029 .60615 Mdot
.93038 .60615 Mdot
.93048 .60615 Mdot
.93057 .60615 Mdot
.93067 .60615 Mdot
.93076 .60615 Mdot
.93086 .60615 Mdot
.93095 .60615 Mdot
.93105 .60615 Mdot
.93114 .60615 Mdot
.93124 .60615 Mdot
.93133 .60615 Mdot
.93143 .60615 Mdot
.93152 .60615 Mdot
.93162 .60615 Mdot
.93171 .60615 Mdot
.93181 .60615 Mdot
.9319 .60615 Mdot
.932 .60615 Mdot
.9321 .60615 Mdot
.93219 .60615 Mdot
.93229 .60615 Mdot
.93238 .60615 Mdot
.93248 .60615 Mdot
.93257 .60615 Mdot
.93267 .60615 Mdot
.93276 .60615 Mdot
.93286 .60615 Mdot
.93295 .60615 Mdot
.93305 .60615 Mdot
.93314 .60615 Mdot
.93324 .60615 Mdot
.93333 .60615 Mdot
.93343 .60615 Mdot
.93352 .60615 Mdot
.93362 .60615 Mdot
.93371 .60615 Mdot
.93381 .60615 Mdot
.9339 .60615 Mdot
.934 .60615 Mdot
.9341 .60615 Mdot
.93419 .60615 Mdot
.93429 .60615 Mdot
.93438 .60615 Mdot
.93448 .60615 Mdot
.93457 .60615 Mdot
.93467 .60615 Mdot
.93476 .60615 Mdot
.93486 .60615 Mdot
.93495 .60615 Mdot
.93505 .60615 Mdot
.93514 .60615 Mdot
.93524 .60615 Mdot
.93533 .60615 Mdot
.93543 .60615 Mdot
.93552 .60615 Mdot
.93562 .60615 Mdot
.93571 .60615 Mdot
.93581 .60615 Mdot
.9359 .60615 Mdot
.936 .60615 Mdot
.9361 .60615 Mdot
.93619 .60615 Mdot
.93629 .60615 Mdot
.93638 .60615 Mdot
.93648 .60615 Mdot
.93657 .60615 Mdot
.93667 .60615 Mdot
.93676 .60615 Mdot
.93686 .60615 Mdot
.93695 .60615 Mdot
.93705 .60615 Mdot
.93714 .60615 Mdot
.93724 .60615 Mdot
.93733 .60615 Mdot
.93743 .60615 Mdot
.93752 .60615 Mdot
.93762 .60615 Mdot
.93771 .60615 Mdot
.93781 .60615 Mdot
.9379 .60615 Mdot
.938 .60615 Mdot
.9381 .60615 Mdot
.93819 .60615 Mdot
.93829 .60615 Mdot
.93838 .60615 Mdot
.93848 .60615 Mdot
.93857 .60615 Mdot
.93867 .60615 Mdot
.93876 .60615 Mdot
.93886 .60615 Mdot
.93895 .60615 Mdot
.93905 .60615 Mdot
.93914 .60615 Mdot
.93924 .60615 Mdot
.93933 .60615 Mdot
.93943 .60615 Mdot
.93952 .60615 Mdot
.93962 .60615 Mdot
.93971 .60615 Mdot
.93981 .60615 Mdot
.9399 .60615 Mdot
.94 .60615 Mdot
.9401 .60615 Mdot
.94019 .60615 Mdot
.94029 .60615 Mdot
.94038 .60615 Mdot
.94048 .60615 Mdot
.94057 .60615 Mdot
.94067 .60615 Mdot
.94076 .60615 Mdot
.94086 .60615 Mdot
.94095 .60615 Mdot
.94105 .60615 Mdot
.94114 .60615 Mdot
.94124 .60615 Mdot
.94133 .60615 Mdot
.94143 .60615 Mdot
.94152 .60615 Mdot
.94162 .60615 Mdot
.94171 .60615 Mdot
.94181 .60615 Mdot
.9419 .60615 Mdot
.942 .60615 Mdot
.9421 .60615 Mdot
.94219 .60615 Mdot
.94229 .60615 Mdot
.94238 .60615 Mdot
.94248 .60615 Mdot
.94257 .60615 Mdot
.94267 .60615 Mdot
.94276 .60615 Mdot
.94286 .60615 Mdot
.94295 .60615 Mdot
.94305 .60615 Mdot
.94314 .60615 Mdot
.94324 .60615 Mdot
.94333 .60615 Mdot
.94343 .60615 Mdot
.94352 .60615 Mdot
.94362 .60615 Mdot
.94371 .60615 Mdot
.94381 .60615 Mdot
.9439 .60615 Mdot
.944 .60615 Mdot
.9441 .60615 Mdot
.94419 .60615 Mdot
.94429 .60615 Mdot
.94438 .60615 Mdot
.94448 .60615 Mdot
.94457 .60615 Mdot
.94467 .60615 Mdot
.94476 .60615 Mdot
.94486 .60615 Mdot
.94495 .60615 Mdot
.94505 .60615 Mdot
.94514 .60615 Mdot
.94524 .60615 Mdot
.94533 .60615 Mdot
.94543 .60615 Mdot
.94552 .60615 Mdot
.94562 .60615 Mdot
.94571 .60615 Mdot
.94581 .60615 Mdot
.9459 .60615 Mdot
.946 .60615 Mdot
.9461 .60615 Mdot
.94619 .60615 Mdot
.94629 .60615 Mdot
.94638 .60615 Mdot
.94648 .60615 Mdot
.94657 .60615 Mdot
.94667 .60615 Mdot
.94676 .60615 Mdot
.94686 .60615 Mdot
.94695 .60615 Mdot
.94705 .60615 Mdot
.94714 .60615 Mdot
.94724 .60615 Mdot
.94733 .60615 Mdot
.94743 .60615 Mdot
.94752 .60615 Mdot
.94762 .60615 Mdot
.94771 .60615 Mdot
.94781 .60615 Mdot
.9479 .60615 Mdot
.948 .60615 Mdot
.9481 .60615 Mdot
.94819 .60615 Mdot
.94829 .60615 Mdot
.94838 .60615 Mdot
.94848 .60615 Mdot
.94857 .60615 Mdot
.94867 .60615 Mdot
.94876 .60615 Mdot
.94886 .60615 Mdot
.94895 .60615 Mdot
.94905 .60615 Mdot
.94914 .60615 Mdot
.94924 .60615 Mdot
.94933 .60615 Mdot
.94943 .60615 Mdot
.94952 .60615 Mdot
.94962 .60615 Mdot
.94971 .60615 Mdot
.94981 .60615 Mdot
.9499 .60615 Mdot
.95 .60615 Mdot
.9501 .60615 Mdot
.95019 .60615 Mdot
.95029 .60615 Mdot
.95038 .60615 Mdot
.95048 .60615 Mdot
.95057 .60615 Mdot
.95067 .60615 Mdot
.95076 .60615 Mdot
.95086 .60615 Mdot
.95095 .60615 Mdot
.95105 .60615 Mdot
.95114 .60615 Mdot
.95124 .60615 Mdot
.95133 .60615 Mdot
.95143 .60615 Mdot
.95152 .60615 Mdot
.95162 .60615 Mdot
.95171 .60615 Mdot
.95181 .60615 Mdot
.9519 .60615 Mdot
.952 .60615 Mdot
.9521 .60615 Mdot
.95219 .60615 Mdot
.95229 .60615 Mdot
.95238 .60615 Mdot
.95248 .60615 Mdot
.95257 .60615 Mdot
.95267 .60615 Mdot
.95276 .60615 Mdot
.95286 .60615 Mdot
.95295 .60615 Mdot
.95305 .60615 Mdot
.95314 .60615 Mdot
.95324 .60615 Mdot
.95333 .60615 Mdot
.95343 .60615 Mdot
.95352 .60615 Mdot
.95362 .60615 Mdot
.95371 .60615 Mdot
.95381 .60615 Mdot
.9539 .60615 Mdot
.954 .60615 Mdot
.9541 .60615 Mdot
.95419 .60615 Mdot
.95429 .60615 Mdot
.95438 .60615 Mdot
.95448 .60615 Mdot
.95457 .60615 Mdot
.95467 .60615 Mdot
.95476 .60615 Mdot
.95486 .60615 Mdot
.95495 .60615 Mdot
.95505 .60615 Mdot
.95514 .60615 Mdot
.95524 .60615 Mdot
.95533 .60615 Mdot
.95543 .60615 Mdot
.95552 .60615 Mdot
.95562 .60615 Mdot
.95571 .60615 Mdot
.95581 .60615 Mdot
.9559 .60615 Mdot
.956 .60615 Mdot
.9561 .60615 Mdot
.95619 .60615 Mdot
.95629 .60615 Mdot
.95638 .60615 Mdot
.95648 .60615 Mdot
.95657 .60615 Mdot
.95667 .60615 Mdot
.95676 .60615 Mdot
.95686 .60615 Mdot
.95695 .60615 Mdot
.95705 .60615 Mdot
.95714 .60615 Mdot
.95724 .60615 Mdot
.95733 .60615 Mdot
.95743 .60615 Mdot
.95752 .60615 Mdot
.95762 .60615 Mdot
.95771 .60615 Mdot
.95781 .60615 Mdot
.9579 .60615 Mdot
.958 .60615 Mdot
.9581 .60615 Mdot
.95819 .60615 Mdot
.95829 .60615 Mdot
.95838 .60615 Mdot
.95848 .60615 Mdot
.95857 .60615 Mdot
.95867 .60615 Mdot
.95876 .60615 Mdot
.95886 .60615 Mdot
.95895 .60615 Mdot
.95905 .60615 Mdot
.95914 .60615 Mdot
.95924 .60615 Mdot
.95933 .60615 Mdot
.95943 .60615 Mdot
.95952 .60615 Mdot
.95962 .60615 Mdot
.95971 .60615 Mdot
.95981 .60615 Mdot
.9599 .60615 Mdot
.96 .60615 Mdot
.9601 .60615 Mdot
.96019 .60615 Mdot
.96029 .60615 Mdot
.96038 .60615 Mdot
.96048 .60615 Mdot
.96057 .60615 Mdot
.96067 .60615 Mdot
.96076 .60615 Mdot
.96086 .60615 Mdot
.96095 .60615 Mdot
.96105 .60615 Mdot
.96114 .60615 Mdot
.96124 .60615 Mdot
.96133 .60615 Mdot
.96143 .60615 Mdot
.96152 .60615 Mdot
.96162 .60615 Mdot
.96171 .60615 Mdot
.96181 .60615 Mdot
.9619 .60615 Mdot
.962 .60615 Mdot
.9621 .60615 Mdot
.96219 .60615 Mdot
.96229 .60615 Mdot
.96238 .60615 Mdot
.96248 .60615 Mdot
.96257 .60615 Mdot
.96267 .60615 Mdot
.96276 .60615 Mdot
.96286 .60615 Mdot
.96295 .60615 Mdot
.96305 .60615 Mdot
.96314 .60615 Mdot
.96324 .60615 Mdot
.96333 .60615 Mdot
.96343 .60615 Mdot
.96352 .60615 Mdot
.96362 .60615 Mdot
.96371 .60615 Mdot
.96381 .60615 Mdot
.9639 .60615 Mdot
.964 .60615 Mdot
.9641 .60615 Mdot
.96419 .60615 Mdot
.96429 .60615 Mdot
.96438 .60615 Mdot
.96448 .60615 Mdot
.96457 .60615 Mdot
.96467 .60615 Mdot
.96476 .60615 Mdot
.96486 .60615 Mdot
.96495 .60615 Mdot
.96505 .60615 Mdot
.96514 .60615 Mdot
.96524 .60615 Mdot
.96533 .60615 Mdot
.96543 .60615 Mdot
.96552 .60615 Mdot
.96562 .60615 Mdot
.96571 .60615 Mdot
.96581 .60615 Mdot
.9659 .60615 Mdot
.966 .60615 Mdot
.9661 .60615 Mdot
.96619 .60615 Mdot
.96629 .60615 Mdot
.96638 .60615 Mdot
.96648 .60615 Mdot
.96657 .60615 Mdot
.96667 .60615 Mdot
.96676 .60615 Mdot
.96686 .60615 Mdot
.96695 .60615 Mdot
.96705 .60615 Mdot
.96714 .60615 Mdot
.96724 .60615 Mdot
.96733 .60615 Mdot
.96743 .60615 Mdot
.96752 .60615 Mdot
.96762 .60615 Mdot
.96771 .60615 Mdot
.96781 .60615 Mdot
.9679 .60615 Mdot
.968 .60615 Mdot
.9681 .60615 Mdot
.96819 .60615 Mdot
.96829 .60615 Mdot
.96838 .60615 Mdot
.96848 .60615 Mdot
.96857 .60615 Mdot
.96867 .60615 Mdot
.96876 .60615 Mdot
.96886 .60615 Mdot
.96895 .60615 Mdot
.96905 .60615 Mdot
.96914 .60615 Mdot
.96924 .60615 Mdot
.96933 .60615 Mdot
.96943 .60615 Mdot
.96952 .60615 Mdot
.96962 .60615 Mdot
.96971 .60615 Mdot
.96981 .60615 Mdot
.9699 .60615 Mdot
.97 .60615 Mdot
.9701 .60615 Mdot
.97019 .60615 Mdot
.97029 .60615 Mdot
.97038 .60615 Mdot
.97048 .60615 Mdot
.97057 .60615 Mdot
.97067 .60615 Mdot
.97076 .60615 Mdot
.97086 .60615 Mdot
.97095 .60615 Mdot
.97105 .60615 Mdot
.97114 .60615 Mdot
.97124 .60615 Mdot
.97133 .60615 Mdot
.97143 .60615 Mdot
.97152 .60615 Mdot
.97162 .60615 Mdot
.97171 .60615 Mdot
.97181 .60615 Mdot
.9719 .60615 Mdot
.972 .60615 Mdot
.9721 .60615 Mdot
.97219 .60615 Mdot
.97229 .60615 Mdot
.97238 .60615 Mdot
.97248 .60615 Mdot
.97257 .60615 Mdot
.97267 .60615 Mdot
.97276 .60615 Mdot
.97286 .60615 Mdot
.97295 .60615 Mdot
.97305 .60615 Mdot
.97314 .60615 Mdot
.97324 .60615 Mdot
.97333 .60615 Mdot
.97343 .60615 Mdot
.97352 .60615 Mdot
.97362 .60615 Mdot
.97371 .60615 Mdot
.97381 .60615 Mdot
.9739 .60615 Mdot
.974 .60615 Mdot
.9741 .60615 Mdot
.97419 .60615 Mdot
.97429 .60615 Mdot
.97438 .60615 Mdot
.97448 .60615 Mdot
.97457 .60615 Mdot
.97467 .60615 Mdot
.97476 .60615 Mdot
.97486 .60615 Mdot
.97495 .60615 Mdot
.97505 .60615 Mdot
.97514 .60615 Mdot
.97524 .60615 Mdot
.97533 .60615 Mdot
.97543 .60615 Mdot
.97552 .60615 Mdot
.97562 .60615 Mdot
.97571 .60615 Mdot
.97581 .60615 Mdot
.9759 .60615 Mdot
.976 .60615 Mdot
.9761 .60615 Mdot
.97619 .60615 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{455.75, 281.688},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 454.75}, {280.688, 0}} -> {-1420.35, -0.137771, \
27.2803, 0.00437202}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figures - Saving to file", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numberOfExtensions", "=", "  ", 
    RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", " ", 
    RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig11-phase-plane\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "finalFigure", ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig11-time-series\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "timeSeriesFigure", 
       ",", 
       RowBox[{"ImageResolution", "\[Rule]", " ", "figureResolution"}]}], 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input"]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 791},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 86, 2, 56, "Title"],
Cell[657, 25, 99, 1, 37, "Subtitle"],
Cell[759, 28, 701, 14, 90, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1485, 46, 57, 0, 52, "Section"],
Cell[1545, 48, 779, 17, 310, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[2361, 70, 42, 0, 32, "Section"],
Cell[2406, 72, 213, 6, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2656, 83, 29, 0, 32, "Section"],
Cell[2688, 85, 2546, 67, 640, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5271, 157, 53, 0, 32, "Section"],
Cell[5327, 159, 9151, 242, 960, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14515, 406, 48, 0, 32, "Section"],
Cell[14566, 408, 186, 6, 60, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14789, 419, 42, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[14856, 423, 5977, 146, 500, "Input"],
Cell[20836, 571, 160493, 10054, 70, "Graphics"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[181378, 10631, 46, 0, 32, "Section"],
Cell[181427, 10633, 982, 27, 200, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[182446, 10665, 41, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[182512, 10669, 11124, 271, 1160, "Input"],
Cell[193639, 10942, 46778, 1843, 246, 44307, 1799, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[240466, 12791, 37, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[240528, 12795, 4455, 116, 200, "Input"],
Cell[244986, 12913, 237652, 12606, 472, 215132, 12233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[482641, 25521, 228836, 11339, 298, 214529, 11101, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[711526, 36866, 43, 0, 32, "Section"],
Cell[711572, 36868, 1167, 29, 140, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)

